/* -----------------------------------------------------------------------------
 * Copyright (c) 2013 - 2015 ARM Ltd.
 *
 * This software is provided 'as-is', without any express or implied warranty. 
 * In no event will the authors be held liable for any damages arising from 
 * the use of this software. Permission is granted to anyone to use this 
 * software for any purpose, including commercial applications, and to alter 
 * it and redistribute it freely, subject to the following restrictions:
 *
 * 1. The origin of this software must not be misrepresented; you must not 
 *    claim that you wrote the original software. If you use this software in
 *    a product, an acknowledgment in the product documentation would be 
 *    appreciated but is not required. 
 * 
 * 2. Altered source versions must be plainly marked as such, and must not be 
 *    misrepresented as being the original software. 
 * 
 * 3. This notice may not be removed or altered from any source distribution.
 *
 *
 * $Date:        15. July 2015
 * $Revision:    V1.00
 *  
 * Driver:       Driver_Flash# (default: Driver_Flash0)
 * Project:      Flash Device Description for M29EW 128Mb (16-bit)
 *               Part Number: JS28F128M29EW, PC28F128M29EW, RC28F128M29EW
 * -------------------------------------------------------------------- */

#define FLASH_SECTOR_COUNT      128         /* Number of sectors */
#define FLASH_SECTOR_SIZE       0           /* FLASH_SECTORS information used */
#define FLASH_PAGE_SIZE         2           /* Programming page size in bytes */
#define FLASH_PROGRAM_UNIT      2           /* Smallest programmable unit in bytes */
#define FLASH_ERASED_VALUE      0xFF        /* Contents of erased memory */

#define FLASH_SECTORS                                                 \
  ARM_FLASH_SECTOR_INFO(0x000000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x020000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x040000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x060000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x080000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x0A0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x0C0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x0E0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x100000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x120000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x140000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x160000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x180000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x1A0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x1C0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x1E0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x200000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x220000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x240000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x260000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x280000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x2A0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x2C0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x2E0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x300000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x320000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x340000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x360000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x380000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x3A0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x3C0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x3E0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x400000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x420000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x440000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x460000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x480000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x4A0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x4C0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x4E0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x500000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x520000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x540000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x560000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x580000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x5A0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x5C0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x5E0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x600000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x620000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x640000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x660000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x680000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x6A0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x6C0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x6E0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x700000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x720000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x740000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x760000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x780000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x7A0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x7C0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x7E0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x800000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x820000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x840000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x860000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x880000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x8A0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x8C0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x8E0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x900000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x920000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x940000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x960000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x980000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x9A0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x9C0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x9E0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xA00000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xA20000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xA40000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xA60000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xA80000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xAA0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xAC0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xAE0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xB00000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xB20000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xB40000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xB60000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xB80000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xBA0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xBC0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xBE0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xC00000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xC20000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xC40000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xC60000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xC80000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xCA0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xCC0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xCE0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xD00000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xD20000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xD40000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xD60000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xD80000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xDA0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xDC0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xDE0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xE00000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xE20000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xE40000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xE60000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xE80000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xEA0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xEC0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xEE0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xF00000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xF20000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xF40000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xF60000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xF80000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xFA0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xFC0000, 0x20000), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xFE0000, 0x20000)  /* Sector size 128kB */
