/*********************************************************************
*                SEGGER Microcontroller GmbH & Co. KG                *
*        Solutions for real time microcontroller applications        *
**********************************************************************
*                                                                    *
*        (c) 1996 - 2015  SEGGER Microcontroller GmbH & Co. KG       *
*                                                                    *
*        Internet: www.segger.com    Support:  support@segger.com    *
*                                                                    *
**********************************************************************

** emWin V5.30 - Graphical user interface for embedded applications **
All  Intellectual Property rights  in the Software belongs to  SEGGER.
emWin is protected by  international copyright laws.  Knowledge of the
source code may not be used to write a similar product.  This file may
only be used in accordance with the following terms:

The software has been licensed to  ARM LIMITED whose registered office
is situated at  110 Fulbourn Road,  Cambridge CB1 9NJ,  England solely
for  the  purposes  of  creating  libraries  for  ARM7, ARM9, Cortex-M
series,  and   Cortex-R4   processor-based  devices,  sublicensed  and
distributed as part of the  MDK-ARM  Professional  under the terms and
conditions  of  the   End  User  License  supplied  with  the  MDK-ARM
Professional. 
Full source code is available at: www.segger.com

We appreciate your understanding and fairness.
----------------------------------------------------------------------
Licensing information

Licensor:                 SEGGER Software GmbH
Licensed to:              ARM Ltd
Licensed SEGGER software: emWin
License number:           GUI-00181
License model:            LES-SLA-20007, Agreement, effective since October 1st 2011 
Licensed product:         MDK-ARM Professional
Licensed platform:        ARM7/9, Cortex-M/R4
Licensed number of seats: -
----------------------------------------------------------------------
File        : MEMDEV_ZoomAndRotate.c
Purpose     : Sample application to show how to zoom and rotate images
              using Memory Devices.
Requirements: WindowManager - ( )
              MemoryDevices - (x)
              AntiAliasing  - ( )
              VNC-Server    - ( )
              PNG-Library   - ( )
              TrueTypeFonts - ( )
---------------------------END-OF-HEADER------------------------------
*/

#include <stdlib.h>
#include "GUI.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define MAG                        300
#define TITLE_SIZE                 40
#define MIN_TIME_PER_FRAME_SHIFT   20
#define MIN_TIME_PER_FRAME_ENLARGE 30
#define BORDER_SIZE                4
#define FINAL_STEP                 100

//
// Recommended memory to run the sample with adequate performance
//
#define RECOMMENDED_MEMORY (1024L * 2200)

/*********************************************************************
*
*       Static const data
*
**********************************************************************
*/
/*********************************************************************
*                                                                    *
*       GUI_FontRounded22                                            *
*                                                                    *
**********************************************************************
*/
GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0020[  1] = { // Code 0020, SPACE
  0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0021[ 30] = { // Code 0021, EXCLAMATION MARK
  0x02, 0x10,
  0x6F, 0xE2,
  0x9F, 0xF4,
  0x9F, 0xF4,
  0x9F, 0xF4,
  0x7F, 0xF2,
  0x5F, 0xF0,
  0x3F, 0xD0,
  0x1F, 0xB0,
  0x0D, 0x80,
  0x00, 0x00,
  0x2B, 0xA0,
  0x9F, 0xF4,
  0x5F, 0xE1,
  0x01, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0022[ 28] = { // Code 0022, QUOTATION MARK
  0x01, 0x10, 0x02, 0x00,
  0x0E, 0xF2, 0x7F, 0x90,
  0x2F, 0xF4, 0x9F, 0xB0,
  0x2F, 0xF4, 0x9F, 0xB0,
  0x2F, 0xF4, 0x9F, 0xB0,
  0x1E, 0xF2, 0x8F, 0xA0,
  0x02, 0x20, 0x03, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0023[ 84] = { // Code 0023, NUMBER SIGN
  0x00, 0x02, 0xB4, 0x08, 0x90, 0x00,
  0x00, 0x06, 0xF7, 0x0F, 0xD0, 0x00,
  0x00, 0x08, 0xF5, 0x2F, 0xB0, 0x00,
  0x00, 0x2B, 0xF4, 0x5F, 0xA1, 0x00,
  0x07, 0xFF, 0xFF, 0xFF, 0xFE, 0x10,
  0x03, 0x9F, 0xE9, 0xDF, 0xB8, 0x00,
  0x00, 0x1F, 0xB0, 0xAF, 0x30, 0x00,
  0x02, 0x6F, 0xB4, 0xDF, 0x40, 0x00,
  0x0F, 0xFF, 0xFF, 0xFF, 0xF7, 0x00,
  0x06, 0xBF, 0x98, 0xFD, 0x72, 0x00,
  0x00, 0xAF, 0x33, 0xF9, 0x00, 0x00,
  0x00, 0xCF, 0x15, 0xF7, 0x00, 0x00,
  0x00, 0xDD, 0x07, 0xF4, 0x00, 0x00,
  0x00, 0x22, 0x00, 0x30, 0x00, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0024[ 96] = { // Code 0024, DOLLAR SIGN
  0x00, 0x00, 0x0B, 0x10, 0x00, 0x00,
  0x00, 0x28, 0xBF, 0xC8, 0x30, 0x00,
  0x05, 0xFF, 0xFF, 0xFF, 0xF9, 0x00,
  0x1E, 0xF9, 0x2F, 0x39, 0xFF, 0x50,
  0x3F, 0xF0, 0x0F, 0x20, 0x9E, 0x30,
  0x3F, 0xF6, 0x0F, 0x20, 0x00, 0x00,
  0x0D, 0xFF, 0xDF, 0x73, 0x00, 0x00,
  0x02, 0xCF, 0xFF, 0xFF, 0xC3, 0x00,
  0x00, 0x04, 0x8F, 0xEF, 0xFE, 0x10,
  0x03, 0x00, 0x0F, 0x25, 0xFF, 0x70,
  0x7F, 0xA0, 0x0F, 0x20, 0xBF, 0x80,
  0x7F, 0xF3, 0x0F, 0x21, 0xEF, 0x60,
  0x1D, 0xFE, 0xAF, 0xBE, 0xFD, 0x10,
  0x01, 0xAF, 0xFF, 0xFF, 0xA2, 0x00,
  0x00, 0x01, 0x3F, 0x41, 0x00, 0x00,
  0x00, 0x00, 0x0D, 0x10, 0x00, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0025[120] = { // Code 0025, PERCENT SIGN
  0x00, 0x00, 0x00, 0x00, 0x00, 0x03, 0x00, 0x00,
  0x03, 0xAB, 0xA2, 0x00, 0x00, 0x7F, 0x00, 0x00,
  0x2E, 0xEA, 0xFE, 0x10, 0x01, 0xE8, 0x00, 0x00,
  0x7F, 0x70, 0x9F, 0x50, 0x08, 0xE1, 0x00, 0x00,
  0x9F, 0x60, 0x7F, 0x70, 0x2F, 0x70, 0x00, 0x00,
  0x7F, 0x60, 0x8F, 0x60, 0x9E, 0x10, 0x00, 0x00,
  0x3F, 0xD6, 0xEF, 0x22, 0xF7, 0x00, 0x00, 0x00,
  0x07, 0xEF, 0xE6, 0x0A, 0xE0, 0x17, 0x98, 0x20,
  0x00, 0x01, 0x00, 0x3F, 0x60, 0xCF, 0xCF, 0xE1,
  0x00, 0x00, 0x00, 0xBD, 0x04, 0xFA, 0x09, 0xF6,
  0x00, 0x00, 0x04, 0xF5, 0x07, 0xF7, 0x06, 0xF9,
  0x00, 0x00, 0x0C, 0xC0, 0x06, 0xF8, 0x06, 0xF8,
  0x00, 0x00, 0x5F, 0x40, 0x03, 0xFC, 0x3B, 0xF4,
  0x00, 0x00, 0xCB, 0x00, 0x00, 0x8F, 0xFF, 0x90,
  0x00, 0x00, 0x93, 0x00, 0x00, 0x01, 0x42, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0026[105] = { // Code 0026, AMPERSAND
  0x00, 0x00, 0x01, 0x10, 0x00, 0x00, 0x00,
  0x00, 0x04, 0xDF, 0xFD, 0x50, 0x00, 0x00,
  0x00, 0x3F, 0xFD, 0xCF, 0xF4, 0x00, 0x00,
  0x00, 0x9F, 0xD0, 0x0B, 0xFA, 0x00, 0x00,
  0x00, 0x9F, 0xD0, 0x0B, 0xFA, 0x00, 0x00,
  0x00, 0x4F, 0xF9, 0x8F, 0xF5, 0x00, 0x00,
  0x00, 0x0A, 0xFF, 0xFF, 0x80, 0x00, 0x00,
  0x00, 0x9F, 0xFF, 0xFB, 0x00, 0x54, 0x00,
  0x09, 0xFF, 0xBA, 0xFF, 0x74, 0xFF, 0x00,
  0x1F, 0xFB, 0x00, 0xBF, 0xFE, 0xFC, 0x00,
  0x3F, 0xF7, 0x00, 0x1D, 0xFF, 0xE3, 0x00,
  0x1F, 0xFB, 0x00, 0x2C, 0xFF, 0xE3, 0x00,
  0x0A, 0xFF, 0xED, 0xFF, 0xEE, 0xFD, 0x00,
  0x01, 0xAF, 0xFF, 0xFB, 0x24, 0xFD, 0x00,
  0x00, 0x01, 0x43, 0x10, 0x00, 0x10, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0027[ 14] = { // Code 0027, APOSTROPHE
  0x01, 0x10,
  0x3F, 0xD0,
  0x6F, 0xF0,
  0x6F, 0xF0,
  0x6F, 0xF0,
  0x3F, 0xE0,
  0x03, 0x10
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0028[ 54] = { // Code 0028, LEFT PARENTHESIS
  0x00, 0x03, 0x00,
  0x00, 0x9F, 0x40,
  0x02, 0xFF, 0x20,
  0x08, 0xFB, 0x00,
  0x0E, 0xF7, 0x00,
  0x4F, 0xF3, 0x00,
  0x7F, 0xE0, 0x00,
  0xAF, 0xC0, 0x00,
  0xBF, 0xB0, 0x00,
  0xBF, 0xB0, 0x00,
  0xBF, 0xB0, 0x00,
  0x8F, 0xE0, 0x00,
  0x5F, 0xF2, 0x00,
  0x1F, 0xF5, 0x00,
  0x0A, 0xFA, 0x00,
  0x04, 0xFE, 0x10,
  0x00, 0xCF, 0x50,
  0x00, 0x29, 0x10
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0029[ 54] = { // Code 0029, RIGHT PARENTHESIS
  0x03, 0x00, 0x00,
  0x5F, 0x90, 0x00,
  0x2F, 0xF2, 0x00,
  0x0B, 0xF8, 0x00,
  0x07, 0xFE, 0x00,
  0x03, 0xFF, 0x30,
  0x00, 0xFF, 0x70,
  0x00, 0xCF, 0xA0,
  0x00, 0xBF, 0xB0,
  0x00, 0xBF, 0xB0,
  0x00, 0xCF, 0xB0,
  0x00, 0xEF, 0x80,
  0x02, 0xFF, 0x50,
  0x05, 0xFF, 0x10,
  0x0A, 0xFA, 0x00,
  0x1E, 0xF4, 0x00,
  0x5F, 0xC0, 0x00,
  0x19, 0x20, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_002A[ 32] = { // Code 002A, ASTERISK
  0x00, 0x00, 0x10, 0x00,
  0x00, 0x08, 0xE0, 0x00,
  0x05, 0x29, 0xF0, 0x51,
  0x2F, 0xFE, 0xFE, 0xF7,
  0x02, 0x7F, 0xFB, 0x40,
  0x00, 0xAF, 0xCE, 0x20,
  0x03, 0xF7, 0x2F, 0x90,
  0x00, 0x30, 0x03, 0x10
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_002B[ 66] = { // Code 002B, PLUS SIGN
  0x00, 0x00, 0x02, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x8F, 0x50, 0x00, 0x00,
  0x00, 0x00, 0xBF, 0x70, 0x00, 0x00,
  0x00, 0x00, 0xBF, 0x70, 0x00, 0x00,
  0x02, 0x22, 0xCF, 0x82, 0x22, 0x00,
  0x8F, 0xFF, 0xFF, 0xFF, 0xFF, 0x60,
  0x6F, 0xFF, 0xFF, 0xFF, 0xFE, 0x40,
  0x00, 0x00, 0xBF, 0x70, 0x00, 0x00,
  0x00, 0x00, 0xBF, 0x70, 0x00, 0x00,
  0x00, 0x00, 0xBF, 0x70, 0x00, 0x00,
  0x00, 0x00, 0x7F, 0x40, 0x00, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_002C[ 12] = { // Code 002C, COMMA
  0x3C, 0x90,
  0xBF, 0xF5,
  0x6F, 0xF7,
  0x01, 0xE5,
  0x4C, 0xC0,
  0x67, 0x10
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_002D[ 16] = { // Code 002D, HYPHEN-MINUS
  0x01, 0x44, 0x42, 0x00,
  0x2F, 0xFF, 0xFF, 0x70,
  0x3F, 0xFF, 0xFF, 0x80,
  0x02, 0x44, 0x43, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_002E[  8] = { // Code 002E, FULL STOP
  0x3C, 0x90,
  0xBF, 0xF3,
  0x6F, 0xD1,
  0x01, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_002F[ 60] = { // Code 002F, SOLIDUS
  0x00, 0x00, 0x03, 0x00,
  0x00, 0x00, 0x6F, 0x70,
  0x00, 0x00, 0xCF, 0x40,
  0x00, 0x03, 0xFD, 0x00,
  0x00, 0x08, 0xF8, 0x00,
  0x00, 0x0E, 0xF2, 0x00,
  0x00, 0x5F, 0xB0, 0x00,
  0x00, 0xBF, 0x60, 0x00,
  0x01, 0xFE, 0x10, 0x00,
  0x07, 0xF9, 0x00, 0x00,
  0x0D, 0xF3, 0x00, 0x00,
  0x3F, 0xD0, 0x00, 0x00,
  0x9F, 0x70, 0x00, 0x00,
  0xCF, 0x20, 0x00, 0x00,
  0x23, 0x00, 0x00, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0030[ 84] = { // Code 0030, DIGIT ZERO
  0x00, 0x05, 0xBB, 0xB6, 0x00, 0x00,
  0x00, 0xAF, 0xFF, 0xFF, 0xA0, 0x00,
  0x06, 0xFF, 0xA6, 0xAF, 0xF7, 0x00,
  0x0D, 0xFC, 0x00, 0x0C, 0xFD, 0x00,
  0x2F, 0xF8, 0x00, 0x08, 0xFF, 0x20,
  0x4F, 0xF6, 0x00, 0x06, 0xFF, 0x40,
  0x4F, 0xF6, 0x00, 0x06, 0xFF, 0x40,
  0x4F, 0xF6, 0x00, 0x06, 0xFF, 0x40,
  0x2F, 0xF7, 0x00, 0x06, 0xFF, 0x30,
  0x0E, 0xFA, 0x00, 0x0A, 0xFE, 0x00,
  0x09, 0xFF, 0x40, 0x4F, 0xF9, 0x00,
  0x02, 0xEF, 0xFE, 0xFF, 0xE2, 0x00,
  0x00, 0x3C, 0xFF, 0xFC, 0x30, 0x00,
  0x00, 0x00, 0x24, 0x20, 0x00, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0031[ 56] = { // Code 0031, DIGIT ONE
  0x00, 0x00, 0x2B, 0x70,
  0x00, 0x00, 0xAF, 0xC0,
  0x01, 0x49, 0xFF, 0xD0,
  0x1E, 0xFF, 0xFF, 0xD0,
  0x1B, 0xDD, 0xFF, 0xD0,
  0x00, 0x00, 0xDF, 0xD0,
  0x00, 0x00, 0xDF, 0xD0,
  0x00, 0x00, 0xDF, 0xD0,
  0x00, 0x00, 0xDF, 0xD0,
  0x00, 0x00, 0xDF, 0xD0,
  0x00, 0x00, 0xDF, 0xD0,
  0x00, 0x00, 0xDF, 0xC0,
  0x00, 0x00, 0xBF, 0xA0,
  0x00, 0x00, 0x13, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0032[ 78] = { // Code 0032, DIGIT TWO
  0x00, 0x17, 0xBB, 0xB6, 0x00, 0x00,
  0x03, 0xEF, 0xFF, 0xFF, 0xD1, 0x00,
  0x0D, 0xFE, 0x86, 0xAF, 0xFB, 0x00,
  0x5F, 0xF6, 0x00, 0x0D, 0xFF, 0x00,
  0x4F, 0xE1, 0x00, 0x0B, 0xFF, 0x00,
  0x03, 0x20, 0x00, 0x3F, 0xFB, 0x00,
  0x00, 0x00, 0x07, 0xEF, 0xF3, 0x00,
  0x00, 0x03, 0xCF, 0xFD, 0x30, 0x00,
  0x00, 0x6F, 0xFE, 0x70, 0x00, 0x00,
  0x06, 0xFF, 0xA2, 0x00, 0x00, 0x00,
  0x2F, 0xFC, 0x44, 0x44, 0x42, 0x00,
  0x6F, 0xFF, 0xFF, 0xFF, 0xFF, 0x10,
  0x3E, 0xFF, 0xFF, 0xFF, 0xFD, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0033[ 70] = { // Code 0033, DIGIT THREE
  0x00, 0x28, 0xBB, 0xA5, 0x00,
  0x05, 0xFF, 0xFF, 0xFF, 0xA0,
  0x1F, 0xFE, 0x76, 0xCF, 0xF4,
  0x2F, 0xF4, 0x00, 0x2F, 0xF7,
  0x04, 0x40, 0x00, 0x2F, 0xF5,
  0x00, 0x00, 0x5A, 0xEF, 0xB0,
  0x00, 0x00, 0xFF, 0xFF, 0x90,
  0x00, 0x00, 0x38, 0xCF, 0xF8,
  0x01, 0x00, 0x00, 0x1E, 0xFC,
  0x3F, 0xC0, 0x00, 0x0E, 0xFD,
  0x5F, 0xF8, 0x00, 0x7F, 0xF9,
  0x1D, 0xFF, 0xFE, 0xFF, 0xE2,
  0x02, 0xBF, 0xFF, 0xFB, 0x30,
  0x00, 0x01, 0x33, 0x10, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0034[ 84] = { // Code 0034, DIGIT FOUR
  0x00, 0x00, 0x00, 0x9B, 0x40, 0x00,
  0x00, 0x00, 0x07, 0xFF, 0x90, 0x00,
  0x00, 0x00, 0x4F, 0xFF, 0x90, 0x00,
  0x00, 0x02, 0xEE, 0xEF, 0x90, 0x00,
  0x00, 0x0C, 0xF4, 0xDF, 0x90, 0x00,
  0x00, 0x9F, 0x80, 0xDF, 0x90, 0x00,
  0x06, 0xFB, 0x00, 0xDF, 0x90, 0x00,
  0x3F, 0xE2, 0x00, 0xDF, 0x90, 0x00,
  0xBF, 0xFF, 0xFF, 0xFF, 0xFE, 0x50,
  0x8F, 0xFF, 0xFF, 0xFF, 0xFF, 0x60,
  0x02, 0x22, 0x22, 0xDF, 0xA2, 0x00,
  0x00, 0x00, 0x00, 0xDF, 0x90, 0x00,
  0x00, 0x00, 0x00, 0xBF, 0x80, 0x00,
  0x00, 0x00, 0x00, 0x13, 0x00, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0035[ 70] = { // Code 0035, DIGIT FIVE
  0x01, 0x89, 0x99, 0x99, 0x70,
  0x07, 0xFF, 0xFF, 0xFF, 0xF3,
  0x0A, 0xFD, 0xBB, 0xBB, 0x90,
  0x0C, 0xF5, 0x00, 0x00, 0x00,
  0x0F, 0xF3, 0x46, 0x51, 0x00,
  0x3F, 0xFD, 0xFF, 0xFE, 0x60,
  0x3F, 0xFE, 0xAB, 0xFF, 0xF3,
  0x06, 0x60, 0x00, 0x4F, 0xFA,
  0x00, 0x00, 0x00, 0x0D, 0xFB,
  0x17, 0x40, 0x00, 0x0E, 0xFB,
  0x5F, 0xF4, 0x00, 0x8F, 0xF7,
  0x3F, 0xFF, 0xDE, 0xFF, 0xD1,
  0x04, 0xCF, 0xFF, 0xFA, 0x10,
  0x00, 0x02, 0x43, 0x10, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0036[ 84] = { // Code 0036, DIGIT SIX
  0x00, 0x04, 0x9B, 0xB9, 0x30, 0x00,
  0x00, 0x8F, 0xFF, 0xFF, 0xF4, 0x00,
  0x04, 0xFF, 0x93, 0x4E, 0xFB, 0x00,
  0x0B, 0xFC, 0x00, 0x02, 0x93, 0x00,
  0x1F, 0xF7, 0x02, 0x31, 0x00, 0x00,
  0x3F, 0xF9, 0xDF, 0xFF, 0x91, 0x00,
  0x4F, 0xFF, 0xEB, 0xDF, 0xFA, 0x00,
  0x4F, 0xFD, 0x10, 0x0B, 0xFF, 0x20,
  0x3F, 0xF8, 0x00, 0x06, 0xFF, 0x40,
  0x1F, 0xF8, 0x00, 0x06, 0xFF, 0x40,
  0x0B, 0xFE, 0x20, 0x1C, 0xFF, 0x10,
  0x03, 0xEF, 0xFD, 0xEF, 0xF7, 0x00,
  0x00, 0x3C, 0xFF, 0xFE, 0x70, 0x00,
  0x00, 0x00, 0x24, 0x30, 0x00, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0037[ 70] = { // Code 0037, DIGIT SEVEN
  0x49, 0x99, 0x99, 0x99, 0x94,
  0xBF, 0xFF, 0xFF, 0xFF, 0xFD,
  0x5B, 0xBB, 0xBB, 0xBF, 0xF9,
  0x00, 0x00, 0x00, 0x9F, 0xC0,
  0x00, 0x00, 0x05, 0xFE, 0x20,
  0x00, 0x00, 0x1E, 0xF6, 0x00,
  0x00, 0x00, 0x9F, 0xD0, 0x00,
  0x00, 0x02, 0xFF, 0x70, 0x00,
  0x00, 0x08, 0xFF, 0x10, 0x00,
  0x00, 0x0E, 0xFB, 0x00, 0x00,
  0x00, 0x4F, 0xF7, 0x00, 0x00,
  0x00, 0x7F, 0xF3, 0x00, 0x00,
  0x00, 0x6F, 0xD0, 0x00, 0x00,
  0x00, 0x03, 0x10, 0x00, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0038[ 84] = { // Code 0038, DIGIT EIGHT
  0x00, 0x17, 0xBB, 0xB8, 0x10, 0x00,
  0x02, 0xEF, 0xFF, 0xFF, 0xE3, 0x00,
  0x0B, 0xFE, 0x62, 0x6E, 0xFB, 0x00,
  0x0D, 0xFA, 0x00, 0x0A, 0xFF, 0x00,
  0x0C, 0xFB, 0x00, 0x0B, 0xFC, 0x00,
  0x04, 0xFF, 0xB8, 0xBF, 0xF4, 0x00,
  0x02, 0xBF, 0xFF, 0xFF, 0xB2, 0x00,
  0x0C, 0xFE, 0x64, 0x6E, 0xFD, 0x00,
  0x3F, 0xF7, 0x00, 0x07, 0xFF, 0x30,
  0x4F, 0xF6, 0x00, 0x06, 0xFF, 0x40,
  0x2F, 0xFC, 0x10, 0x1B, 0xFF, 0x20,
  0x09, 0xFF, 0xED, 0xEF, 0xF9, 0x00,
  0x00, 0x7E, 0xFF, 0xFE, 0x80, 0x00,
  0x00, 0x00, 0x24, 0x30, 0x00, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0039[ 84] = { // Code 0039, DIGIT NINE
  0x00, 0x17, 0xBB, 0xB6, 0x00, 0x00,
  0x03, 0xEF, 0xFF, 0xFF, 0xB0, 0x00,
  0x0C, 0xFE, 0x74, 0x8F, 0xF8, 0x00,
  0x3F, 0xF8, 0x00, 0x0A, 0xFE, 0x00,
  0x4F, 0xF6, 0x00, 0x07, 0xFF, 0x30,
  0x3F, 0xF7, 0x00, 0x0A, 0xFF, 0x40,
  0x0D, 0xFF, 0x74, 0x9F, 0xFF, 0x40,
  0x03, 0xEF, 0xFF, 0xFD, 0xFF, 0x40,
  0x00, 0x17, 0x99, 0x56, 0xFF, 0x20,
  0x00, 0x30, 0x00, 0x09, 0xFD, 0x00,
  0x09, 0xFA, 0x00, 0x3F, 0xF8, 0x00,
  0x08, 0xFF, 0xDB, 0xFF, 0xD1, 0x00,
  0x01, 0x9F, 0xFF, 0xFA, 0x20, 0x00,
  0x00, 0x01, 0x33, 0x10, 0x00, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_003A[ 22] = { // Code 003A, COLON
  0x05, 0x30,
  0x9F, 0xF2,
  0x9F, 0xF2,
  0x17, 0x40,
  0x00, 0x00,
  0x00, 0x00,
  0x00, 0x00,
  0x3C, 0x90,
  0xBF, 0xF3,
  0x6F, 0xD1,
  0x01, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_003B[ 26] = { // Code 003B, SEMICOLON
  0x05, 0x30,
  0x9F, 0xF2,
  0x9F, 0xF2,
  0x17, 0x40,
  0x00, 0x00,
  0x00, 0x00,
  0x00, 0x00,
  0x3C, 0x90,
  0xBF, 0xF5,
  0x6F, 0xF7,
  0x01, 0xE5,
  0x4C, 0xC0,
  0x67, 0x10
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_003C[ 60] = { // Code 003C, LESS-THAN SIGN
  0x00, 0x00, 0x00, 0x01, 0x8B, 0x20,
  0x00, 0x00, 0x02, 0x9F, 0xFF, 0x50,
  0x00, 0x03, 0xAF, 0xFF, 0xC6, 0x00,
  0x05, 0xCF, 0xFF, 0xB4, 0x00, 0x00,
  0x7F, 0xFF, 0x92, 0x00, 0x00, 0x00,
  0x5F, 0xFF, 0xB5, 0x00, 0x00, 0x00,
  0x02, 0x9F, 0xFF, 0xD7, 0x10, 0x00,
  0x00, 0x01, 0x7E, 0xFF, 0xF8, 0x10,
  0x00, 0x00, 0x00, 0x7D, 0xFF, 0x50,
  0x00, 0x00, 0x00, 0x00, 0x57, 0x10
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_003D[ 48] = { // Code 003D, EQUALS SIGN
  0x04, 0x44, 0x44, 0x44, 0x43, 0x00,
  0x9F, 0xFF, 0xFF, 0xFF, 0xFF, 0x70,
  0x5D, 0xDD, 0xDD, 0xDD, 0xDC, 0x30,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x7F, 0xFF, 0xFF, 0xFF, 0xFF, 0x50,
  0x7F, 0xFF, 0xFF, 0xFF, 0xFF, 0x50,
  0x02, 0x22, 0x22, 0x22, 0x21, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_003E[ 60] = { // Code 003E, GREATER-THAN SIGN
  0x4B, 0x70, 0x00, 0x00, 0x00, 0x00,
  0x8F, 0xFE, 0x81, 0x00, 0x00, 0x00,
  0x17, 0xEF, 0xFF, 0x92, 0x00, 0x00,
  0x00, 0x05, 0xCF, 0xFF, 0xA3, 0x00,
  0x00, 0x00, 0x03, 0xAF, 0xFF, 0x40,
  0x00, 0x00, 0x06, 0xDF, 0xFE, 0x30,
  0x00, 0x28, 0xEF, 0xFE, 0x71, 0x00,
  0x1A, 0xFF, 0xFD, 0x60, 0x00, 0x00,
  0x9F, 0xFC, 0x50, 0x00, 0x00, 0x00,
  0x27, 0x30, 0x00, 0x00, 0x00, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_003F[ 75] = { // Code 003F, QUESTION MARK
  0x00, 0x00, 0x22, 0x00, 0x00,
  0x00, 0x7E, 0xFF, 0xFA, 0x20,
  0x09, 0xFF, 0xEE, 0xFF, 0xE1,
  0x2F, 0xFA, 0x00, 0x7F, 0xF7,
  0x2F, 0xE2, 0x00, 0x3F, 0xF7,
  0x02, 0x20, 0x00, 0xAF, 0xF5,
  0x00, 0x00, 0x1B, 0xFF, 0xA0,
  0x00, 0x00, 0xCF, 0xF7, 0x00,
  0x00, 0x05, 0xFF, 0x50, 0x00,
  0x00, 0x02, 0xEC, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x02, 0xBA, 0x10, 0x00,
  0x00, 0x08, 0xFF, 0x50, 0x00,
  0x00, 0x04, 0xFE, 0x20, 0x00,
  0x00, 0x00, 0x11, 0x00, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0040[105] = { // Code 0040, COMMERCIAL AT
  0x00, 0x00, 0x00, 0x34, 0x31, 0x00, 0x00,
  0x00, 0x02, 0x9E, 0xFF, 0xFF, 0xA2, 0x00,
  0x00, 0x3E, 0xFB, 0x76, 0x7A, 0xFE, 0x50,
  0x02, 0xEF, 0x50, 0x00, 0x00, 0x3E, 0xE2,
  0x0B, 0xF6, 0x07, 0xEE, 0x96, 0xB5, 0xF8,
  0x2F, 0xD0, 0x7F, 0xFF, 0xFF, 0xF0, 0xEC,
  0x5F, 0x91, 0xEF, 0x40, 0x8F, 0xC0, 0xBD,
  0x7F, 0x74, 0xFA, 0x00, 0x4F, 0x90, 0xCB,
  0x6F, 0x85, 0xFB, 0x00, 0x6F, 0x71, 0xF7,
  0x3F, 0xC2, 0xFF, 0x98, 0xEF, 0xAC, 0xD1,
  0x0C, 0xF4, 0x9F, 0xFF, 0xEF, 0xFB, 0x20,
  0x03, 0xFE, 0x45, 0x73, 0x37, 0x57, 0x00,
  0x00, 0x5E, 0xFB, 0x66, 0x69, 0xEE, 0x10,
  0x00, 0x02, 0x9F, 0xFF, 0xFF, 0xA2, 0x00,
  0x00, 0x00, 0x01, 0x34, 0x31, 0x00, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0041[ 90] = { // Code 0041, LATIN CAPITAL LETTER A
  0x00, 0x00, 0x02, 0x30, 0x00, 0x00,
  0x00, 0x00, 0x9F, 0xFB, 0x00, 0x00,
  0x00, 0x01, 0xFF, 0xFF, 0x30, 0x00,
  0x00, 0x06, 0xFF, 0xFF, 0x80, 0x00,
  0x00, 0x0C, 0xFD, 0xCF, 0xE0, 0x00,
  0x00, 0x3F, 0xF8, 0x7F, 0xF4, 0x00,
  0x00, 0x8F, 0xF3, 0x2F, 0xFA, 0x00,
  0x00, 0xEF, 0xD0, 0x0D, 0xFF, 0x10,
  0x04, 0xFF, 0x80, 0x08, 0xFF, 0x60,
  0x0A, 0xFF, 0xCB, 0xBC, 0xFF, 0xB0,
  0x1F, 0xFF, 0xFF, 0xFF, 0xFF, 0xF2,
  0x7F, 0xF9, 0x44, 0x44, 0x9F, 0xF7,
  0xCF, 0xF3, 0x00, 0x00, 0x3F, 0xFC,
  0xAF, 0xC0, 0x00, 0x00, 0x0C, 0xFA,
  0x03, 0x10, 0x00, 0x00, 0x01, 0x30
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0042[ 78] = { // Code 0042, LATIN CAPITAL LETTER B
  0x3D, 0xFF, 0xFF, 0xED, 0xA3, 0x00,
  0x9F, 0xFF, 0xFF, 0xFF, 0xFF, 0x30,
  0x9F, 0xF8, 0x44, 0x4C, 0xFF, 0xA0,
  0x9F, 0xF6, 0x00, 0x04, 0xFF, 0xB0,
  0x9F, 0xF6, 0x00, 0x06, 0xFF, 0x70,
  0x9F, 0xFB, 0x99, 0xBF, 0xFB, 0x10,
  0x9F, 0xFF, 0xFF, 0xFF, 0xFB, 0x20,
  0x9F, 0xF8, 0x44, 0x4A, 0xFF, 0xD0,
  0x9F, 0xF6, 0x00, 0x00, 0xCF, 0xF2,
  0x9F, 0xF6, 0x00, 0x00, 0xCF, 0xF3,
  0x9F, 0xF8, 0x44, 0x5A, 0xFF, 0xE0,
  0x9F, 0xFF, 0xFF, 0xFF, 0xFF, 0x60,
  0x4E, 0xFF, 0xFF, 0xFE, 0xB4, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0043[ 90] = { // Code 0043, LATIN CAPITAL LETTER C
  0x00, 0x00, 0x13, 0x43, 0x00, 0x00,
  0x00, 0x2A, 0xFF, 0xFF, 0xE7, 0x00,
  0x03, 0xEF, 0xFF, 0xFF, 0xFF, 0xB0,
  0x1E, 0xFF, 0xB3, 0x25, 0xEF, 0xF6,
  0x7F, 0xFB, 0x00, 0x00, 0x4F, 0xF7,
  0xCF, 0xF3, 0x00, 0x00, 0x03, 0x61,
  0xFF, 0xF0, 0x00, 0x00, 0x00, 0x00,
  0xFF, 0xD0, 0x00, 0x00, 0x00, 0x00,
  0xFF, 0xF0, 0x00, 0x00, 0x00, 0x00,
  0xDF, 0xF3, 0x00, 0x00, 0x05, 0x71,
  0x9F, 0xFA, 0x00, 0x00, 0x4F, 0xF7,
  0x3F, 0xFF, 0x93, 0x25, 0xEF, 0xF5,
  0x06, 0xFF, 0xFF, 0xFF, 0xFF, 0xA0,
  0x00, 0x4C, 0xFF, 0xFF, 0xE7, 0x00,
  0x00, 0x00, 0x24, 0x43, 0x00, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0044[ 78] = { // Code 0044, LATIN CAPITAL LETTER D
  0x3D, 0xFF, 0xFF, 0xEC, 0x71, 0x00,
  0x9F, 0xFF, 0xFF, 0xFF, 0xFE, 0x30,
  0x9F, 0xF9, 0x66, 0x7D, 0xFF, 0xD0,
  0x9F, 0xF6, 0x00, 0x01, 0xCF, 0xF6,
  0x9F, 0xF6, 0x00, 0x00, 0x5F, 0xFA,
  0x9F, 0xF6, 0x00, 0x00, 0x2F, 0xFD,
  0x9F, 0xF6, 0x00, 0x00, 0x2F, 0xFD,
  0x9F, 0xF6, 0x00, 0x00, 0x2F, 0xFC,
  0x9F, 0xF6, 0x00, 0x00, 0x6F, 0xFA,
  0x9F, 0xF6, 0x00, 0x01, 0xDF, 0xF5,
  0x9F, 0xF9, 0x66, 0x7D, 0xFF, 0xC0,
  0x9F, 0xFF, 0xFF, 0xFF, 0xFD, 0x20,
  0x4E, 0xFF, 0xFF, 0xFC, 0x71, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0045[ 78] = { // Code 0045, LATIN CAPITAL LETTER E
  0x3D, 0xFF, 0xFF, 0xFF, 0xFE, 0x50,
  0x8F, 0xFF, 0xFF, 0xFF, 0xFF, 0x80,
  0x9F, 0xF9, 0x66, 0x66, 0x65, 0x10,
  0x9F, 0xF6, 0x00, 0x00, 0x00, 0x00,
  0x9F, 0xF6, 0x00, 0x00, 0x00, 0x00,
  0x9F, 0xFD, 0xBB, 0xBB, 0xB6, 0x00,
  0x9F, 0xFF, 0xFF, 0xFF, 0xFB, 0x00,
  0x9F, 0xFA, 0x77, 0x77, 0x73, 0x00,
  0x9F, 0xF6, 0x00, 0x00, 0x00, 0x00,
  0x9F, 0xF6, 0x00, 0x00, 0x00, 0x00,
  0x9F, 0xF9, 0x66, 0x66, 0x65, 0x10,
  0x8F, 0xFF, 0xFF, 0xFF, 0xFF, 0xA0,
  0x3D, 0xFF, 0xFF, 0xFF, 0xFF, 0x70
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0046[ 84] = { // Code 0046, LATIN CAPITAL LETTER F
  0x3D, 0xFF, 0xFF, 0xFF, 0xFB, 0x10,
  0x8F, 0xFF, 0xFF, 0xFF, 0xFF, 0x10,
  0x9F, 0xF9, 0x66, 0x66, 0x64, 0x00,
  0x9F, 0xF6, 0x00, 0x00, 0x00, 0x00,
  0x9F, 0xF6, 0x00, 0x00, 0x00, 0x00,
  0x9F, 0xFB, 0x99, 0x99, 0x70, 0x00,
  0x9F, 0xFF, 0xFF, 0xFF, 0xF3, 0x00,
  0x9F, 0xFD, 0xBB, 0xBB, 0x90, 0x00,
  0x9F, 0xF6, 0x00, 0x00, 0x00, 0x00,
  0x9F, 0xF6, 0x00, 0x00, 0x00, 0x00,
  0x9F, 0xF6, 0x00, 0x00, 0x00, 0x00,
  0x9F, 0xF6, 0x00, 0x00, 0x00, 0x00,
  0x5F, 0xF3, 0x00, 0x00, 0x00, 0x00,
  0x03, 0x20, 0x00, 0x00, 0x00, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0047[105] = { // Code 0047, LATIN CAPITAL LETTER G
  0x00, 0x00, 0x03, 0x43, 0x10, 0x00, 0x00,
  0x00, 0x2A, 0xFF, 0xFF, 0xFA, 0x20, 0x00,
  0x03, 0xEF, 0xFF, 0xFF, 0xFF, 0xE2, 0x00,
  0x1E, 0xFF, 0xB4, 0x23, 0xAF, 0xFA, 0x00,
  0x8F, 0xFB, 0x00, 0x00, 0x0B, 0xF8, 0x00,
  0xCF, 0xF3, 0x00, 0x00, 0x00, 0x20, 0x00,
  0xFF, 0xF0, 0x00, 0x00, 0x00, 0x00, 0x00,
  0xFF, 0xD0, 0x00, 0x5D, 0xDD, 0xDD, 0x30,
  0xFF, 0xE0, 0x00, 0x8F, 0xFF, 0xFF, 0x60,
  0xDF, 0xF2, 0x00, 0x15, 0x69, 0xFF, 0x60,
  0x9F, 0xF9, 0x00, 0x00, 0x0B, 0xFF, 0x60,
  0x2F, 0xFF, 0x82, 0x02, 0x9F, 0xFF, 0x60,
  0x06, 0xFF, 0xFF, 0xFF, 0xFE, 0xEF, 0x60,
  0x00, 0x4C, 0xFF, 0xFF, 0xD3, 0x9F, 0x50,
  0x00, 0x00, 0x24, 0x43, 0x00, 0x03, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0048[ 90] = { // Code 0048, LATIN CAPITAL LETTER H
  0x02, 0x10, 0x00, 0x00, 0x01, 0x20,
  0x6F, 0xE2, 0x00, 0x00, 0x2E, 0xF6,
  0x9F, 0xF5, 0x00, 0x00, 0x5F, 0xF9,
  0x9F, 0xF6, 0x00, 0x00, 0x6F, 0xF9,
  0x9F, 0xF6, 0x00, 0x00, 0x6F, 0xF9,
  0x9F, 0xF6, 0x00, 0x00, 0x6F, 0xF9,
  0x9F, 0xFF, 0xFF, 0xFF, 0xFF, 0xF9,
  0x9F, 0xFF, 0xFF, 0xFF, 0xFF, 0xF9,
  0x9F, 0xFA, 0x77, 0x77, 0xAF, 0xF9,
  0x9F, 0xF6, 0x00, 0x00, 0x6F, 0xF9,
  0x9F, 0xF6, 0x00, 0x00, 0x6F, 0xF9,
  0x9F, 0xF6, 0x00, 0x00, 0x6F, 0xF9,
  0x9F, 0xF5, 0x00, 0x00, 0x5F, 0xF9,
  0x6F, 0xE2, 0x00, 0x00, 0x2E, 0xF7,
  0x03, 0x20, 0x00, 0x00, 0x02, 0x30
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0049[ 30] = { // Code 0049, LATIN CAPITAL LETTER I
  0x02, 0x10,
  0x6F, 0xE2,
  0x9F, 0xF5,
  0x9F, 0xF6,
  0x9F, 0xF6,
  0x9F, 0xF6,
  0x9F, 0xF6,
  0x9F, 0xF6,
  0x9F, 0xF6,
  0x9F, 0xF6,
  0x9F, 0xF6,
  0x9F, 0xF6,
  0x9F, 0xF5,
  0x6F, 0xE2,
  0x03, 0x20
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_004A[ 75] = { // Code 004A, LATIN CAPITAL LETTER J
  0x00, 0x00, 0x00, 0x02, 0x00,
  0x00, 0x00, 0x00, 0xBF, 0xB0,
  0x00, 0x00, 0x00, 0xFF, 0xF0,
  0x00, 0x00, 0x00, 0xFF, 0xF0,
  0x00, 0x00, 0x00, 0xFF, 0xF0,
  0x00, 0x00, 0x00, 0xFF, 0xF0,
  0x00, 0x00, 0x00, 0xFF, 0xF0,
  0x00, 0x00, 0x00, 0xFF, 0xF0,
  0x01, 0x00, 0x00, 0xFF, 0xF0,
  0x5F, 0xC0, 0x00, 0xFF, 0xF0,
  0x9F, 0xF1, 0x00, 0xFF, 0xE0,
  0x9F, 0xF6, 0x07, 0xFF, 0xB0,
  0x3F, 0xFF, 0xFF, 0xFF, 0x50,
  0x05, 0xEF, 0xFF, 0xF7, 0x00,
  0x00, 0x03, 0x43, 0x10, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_004B[ 90] = { // Code 004B, LATIN CAPITAL LETTER K
  0x02, 0x10, 0x00, 0x00, 0x11, 0x00,
  0x6F, 0xE2, 0x00, 0x02, 0xEF, 0x50,
  0x9F, 0xF5, 0x00, 0x1D, 0xFF, 0x60,
  0x9F, 0xF6, 0x01, 0xDF, 0xF8, 0x00,
  0x9F, 0xF6, 0x1B, 0xFF, 0x90, 0x00,
  0x9F, 0xF6, 0xAF, 0xFA, 0x00, 0x00,
  0x9F, 0xFE, 0xFF, 0xF4, 0x00, 0x00,
  0x9F, 0xFF, 0xFF, 0xFD, 0x00, 0x00,
  0x9F, 0xFF, 0xAD, 0xFF, 0x80, 0x00,
  0x9F, 0xFA, 0x03, 0xFF, 0xF3, 0x00,
  0x9F, 0xF6, 0x00, 0x9F, 0xFD, 0x00,
  0x9F, 0xF6, 0x00, 0x1D, 0xFF, 0x70,
  0x9F, 0xF5, 0x00, 0x04, 0xFF, 0xF1,
  0x6F, 0xE2, 0x00, 0x00, 0x9F, 0xE1,
  0x03, 0x20, 0x00, 0x00, 0x03, 0x10
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_004C[ 70] = { // Code 004C, LATIN CAPITAL LETTER L
  0x02, 0x10, 0x00, 0x00, 0x00,
  0x6F, 0xE2, 0x00, 0x00, 0x00,
  0x9F, 0xF5, 0x00, 0x00, 0x00,
  0x9F, 0xF6, 0x00, 0x00, 0x00,
  0x9F, 0xF6, 0x00, 0x00, 0x00,
  0x9F, 0xF6, 0x00, 0x00, 0x00,
  0x9F, 0xF6, 0x00, 0x00, 0x00,
  0x9F, 0xF6, 0x00, 0x00, 0x00,
  0x9F, 0xF6, 0x00, 0x00, 0x00,
  0x9F, 0xF6, 0x00, 0x00, 0x00,
  0x9F, 0xF6, 0x00, 0x00, 0x00,
  0x9F, 0xFA, 0x77, 0x77, 0x72,
  0x9F, 0xFF, 0xFF, 0xFF, 0xFB,
  0x4E, 0xFF, 0xFF, 0xFF, 0xF7
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_004D[105] = { // Code 004D, LATIN CAPITAL LETTER M
  0x02, 0x31, 0x00, 0x00, 0x00, 0x13, 0x20,
  0x7F, 0xFE, 0x30, 0x00, 0x02, 0xEF, 0xF7,
  0xBF, 0xFF, 0x80, 0x00, 0x08, 0xFF, 0xF9,
  0xBF, 0xFF, 0xD0, 0x00, 0x0C, 0xFF, 0xF9,
  0xBF, 0xFF, 0xF2, 0x00, 0x2F, 0xFF, 0xF9,
  0xBF, 0xFB, 0xF7, 0x00, 0x7F, 0xBF, 0xF9,
  0xBF, 0xF7, 0xFC, 0x00, 0xBF, 0x7F, 0xF9,
  0xBF, 0xF2, 0xFF, 0x21, 0xFF, 0x2F, 0xF9,
  0xBF, 0xF0, 0xCF, 0x65, 0xFC, 0x0F, 0xF9,
  0xBF, 0xF0, 0x8F, 0xBA, 0xF7, 0x0F, 0xF9,
  0xBF, 0xF0, 0x3F, 0xFE, 0xF3, 0x0F, 0xF9,
  0xBF, 0xF0, 0x0D, 0xFF, 0xD0, 0x0F, 0xF9,
  0xBF, 0xF0, 0x08, 0xFF, 0x80, 0x0F, 0xF9,
  0x8F, 0xB0, 0x03, 0xFF, 0x30, 0x0B, 0xF7,
  0x03, 0x10, 0x00, 0x22, 0x00, 0x01, 0x30
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_004E[ 90] = { // Code 004E, LATIN CAPITAL LETTER N
  0x01, 0x20, 0x00, 0x00, 0x01, 0x20,
  0x6F, 0xF8, 0x00, 0x00, 0x1E, 0xF8,
  0xAF, 0xFF, 0x30, 0x00, 0x2F, 0xFB,
  0xBF, 0xFF, 0xC0, 0x00, 0x2F, 0xFB,
  0xBF, 0xFF, 0xF7, 0x00, 0x2F, 0xFB,
  0xBF, 0xFC, 0xFE, 0x20, 0x2F, 0xFB,
  0xBF, 0xF4, 0xEF, 0xB0, 0x2F, 0xFB,
  0xBF, 0xF2, 0x7F, 0xF5, 0x2F, 0xFB,
  0xBF, 0xF2, 0x0C, 0xFD, 0x3F, 0xFB,
  0xBF, 0xF2, 0x03, 0xFF, 0xAF, 0xFB,
  0xBF, 0xF2, 0x00, 0x8F, 0xFF, 0xFB,
  0xBF, 0xF2, 0x00, 0x0D, 0xFF, 0xFB,
  0xBF, 0xF2, 0x00, 0x04, 0xFF, 0xFA,
  0x8F, 0xE1, 0x00, 0x00, 0x9F, 0xF6,
  0x03, 0x10, 0x00, 0x00, 0x03, 0x30
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_004F[105] = { // Code 004F, LATIN CAPITAL LETTER O
  0x00, 0x00, 0x01, 0x34, 0x30, 0x00, 0x00,
  0x00, 0x03, 0xBF, 0xFF, 0xFE, 0x91, 0x00,
  0x00, 0x6F, 0xFF, 0xFF, 0xFF, 0xFE, 0x20,
  0x03, 0xFF, 0xF9, 0x32, 0x4B, 0xFF, 0xD0,
  0x0B, 0xFF, 0x80, 0x00, 0x00, 0xCF, 0xF6,
  0x0F, 0xFF, 0x10, 0x00, 0x00, 0x5F, 0xFA,
  0x2F, 0xFC, 0x00, 0x00, 0x00, 0x2F, 0xFD,
  0x4F, 0xFB, 0x00, 0x00, 0x00, 0x2F, 0xFD,
  0x2F, 0xFC, 0x00, 0x00, 0x00, 0x2F, 0xFC,
  0x0F, 0xFF, 0x10, 0x00, 0x00, 0x5F, 0xF9,
  0x0A, 0xFF, 0x70, 0x00, 0x00, 0xCF, 0xF4,
  0x03, 0xFF, 0xF8, 0x22, 0x3B, 0xFF, 0xC0,
  0x00, 0x7F, 0xFF, 0xFF, 0xFF, 0xFD, 0x20,
  0x00, 0x05, 0xDF, 0xFF, 0xFF, 0x91, 0x00,
  0x00, 0x00, 0x02, 0x44, 0x31, 0x00, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0050[ 84] = { // Code 0050, LATIN CAPITAL LETTER P
  0x3D, 0xFF, 0xFF, 0xFD, 0xA3, 0x00,
  0x9F, 0xFF, 0xFF, 0xFF, 0xFF, 0x40,
  0x9F, 0xF9, 0x66, 0x6B, 0xFF, 0xC0,
  0x9F, 0xF6, 0x00, 0x00, 0xEF, 0xF1,
  0x9F, 0xF6, 0x00, 0x00, 0xEF, 0xF1,
  0x9F, 0xF6, 0x00, 0x18, 0xFF, 0xD0,
  0x9F, 0xFF, 0xFF, 0xFF, 0xFF, 0x60,
  0x9F, 0xFF, 0xFF, 0xFF, 0xE6, 0x00,
  0x9F, 0xF8, 0x44, 0x43, 0x00, 0x00,
  0x9F, 0xF6, 0x00, 0x00, 0x00, 0x00,
  0x9F, 0xF6, 0x00, 0x00, 0x00, 0x00,
  0x9F, 0xF5, 0x00, 0x00, 0x00, 0x00,
  0x6F, 0xE2, 0x00, 0x00, 0x00, 0x00,
  0x03, 0x20, 0x00, 0x00, 0x00, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0051[105] = { // Code 0051, LATIN CAPITAL LETTER Q
  0x00, 0x00, 0x01, 0x34, 0x30, 0x00, 0x00,
  0x00, 0x03, 0xBF, 0xFF, 0xFE, 0x91, 0x00,
  0x00, 0x6F, 0xFF, 0xFF, 0xFF, 0xFE, 0x20,
  0x03, 0xFF, 0xF9, 0x32, 0x4B, 0xFF, 0xD0,
  0x0B, 0xFF, 0x80, 0x00, 0x00, 0xCF, 0xF6,
  0x0F, 0xFF, 0x10, 0x00, 0x00, 0x5F, 0xFA,
  0x2F, 0xFC, 0x00, 0x00, 0x00, 0x2F, 0xFD,
  0x4F, 0xFB, 0x00, 0x00, 0x00, 0x2F, 0xFD,
  0x2F, 0xFC, 0x00, 0x00, 0x00, 0x2F, 0xFC,
  0x0F, 0xFF, 0x10, 0x04, 0xB2, 0x5F, 0xF9,
  0x0A, 0xFF, 0x70, 0x09, 0xFE, 0xCF, 0xF4,
  0x03, 0xFF, 0xF8, 0x23, 0xCF, 0xFF, 0xC0,
  0x00, 0x7F, 0xFF, 0xFF, 0xFF, 0xFF, 0x60,
  0x00, 0x05, 0xDF, 0xFF, 0xFF, 0xBF, 0xF4,
  0x00, 0x00, 0x02, 0x44, 0x30, 0x08, 0xF4
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0052[ 84] = { // Code 0052, LATIN CAPITAL LETTER R
  0x3D, 0xFF, 0xFF, 0xFE, 0xC7, 0x10,
  0x9F, 0xFF, 0xFF, 0xFF, 0xFF, 0xB0,
  0x9F, 0xF9, 0x66, 0x67, 0xEF, 0xF4,
  0x9F, 0xF6, 0x00, 0x00, 0x9F, 0xF7,
  0x9F, 0xF6, 0x00, 0x00, 0x8F, 0xF5,
  0x9F, 0xF8, 0x44, 0x46, 0xEF, 0xD0,
  0x9F, 0xFF, 0xFF, 0xFF, 0xFC, 0x20,
  0x9F, 0xFF, 0xFF, 0xFF, 0xFF, 0x70,
  0x9F, 0xF6, 0x00, 0x06, 0xFF, 0xE0,
  0x9F, 0xF6, 0x00, 0x00, 0xDF, 0xF0,
  0x9F, 0xF6, 0x00, 0x00, 0xBF, 0xF1,
  0x9F, 0xF5, 0x00, 0x00, 0xBF, 0xF5,
  0x6F, 0xE2, 0x00, 0x00, 0x5F, 0xF4,
  0x03, 0x20, 0x00, 0x00, 0x03, 0x20
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0053[ 90] = { // Code 0053, LATIN CAPITAL LETTER S
  0x00, 0x00, 0x24, 0x41, 0x00, 0x00,
  0x00, 0x5D, 0xFF, 0xFF, 0xC4, 0x00,
  0x07, 0xFF, 0xFF, 0xFF, 0xFF, 0x70,
  0x0E, 0xFE, 0x40, 0x16, 0xEF, 0xF0,
  0x2F, 0xFA, 0x00, 0x00, 0x4D, 0x90,
  0x1F, 0xFF, 0x72, 0x00, 0x00, 0x00,
  0x0B, 0xFF, 0xFF, 0xDA, 0x61, 0x00,
  0x01, 0xAF, 0xFF, 0xFF, 0xFE, 0x50,
  0x00, 0x01, 0x69, 0xDF, 0xFF, 0xF2,
  0x01, 0x10, 0x00, 0x02, 0xCF, 0xF7,
  0x2E, 0xF4, 0x00, 0x00, 0x6F, 0xF7,
  0x2F, 0xFE, 0x40, 0x02, 0xDF, 0xF5,
  0x09, 0xFF, 0xFE, 0xDF, 0xFF, 0xC0,
  0x00, 0x6D, 0xFF, 0xFF, 0xF9, 0x10,
  0x00, 0x00, 0x34, 0x43, 0x10, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0054[ 84] = { // Code 0054, LATIN CAPITAL LETTER T
  0x6E, 0xFF, 0xFF, 0xFF, 0xFF, 0xE7,
  0xBF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFB,
  0x27, 0x77, 0xBF, 0xFB, 0x77, 0x72,
  0x00, 0x00, 0x7F, 0xF7, 0x00, 0x00,
  0x00, 0x00, 0x7F, 0xF7, 0x00, 0x00,
  0x00, 0x00, 0x7F, 0xF7, 0x00, 0x00,
  0x00, 0x00, 0x7F, 0xF7, 0x00, 0x00,
  0x00, 0x00, 0x7F, 0xF7, 0x00, 0x00,
  0x00, 0x00, 0x7F, 0xF7, 0x00, 0x00,
  0x00, 0x00, 0x7F, 0xF7, 0x00, 0x00,
  0x00, 0x00, 0x7F, 0xF7, 0x00, 0x00,
  0x00, 0x00, 0x7F, 0xF7, 0x00, 0x00,
  0x00, 0x00, 0x4F, 0xF4, 0x00, 0x00,
  0x00, 0x00, 0x02, 0x20, 0x00, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0055[ 90] = { // Code 0055, LATIN CAPITAL LETTER U
  0x02, 0x10, 0x00, 0x00, 0x01, 0x20,
  0x6F, 0xE2, 0x00, 0x00, 0x2E, 0xF6,
  0x9F, 0xF5, 0x00, 0x00, 0x5F, 0xF9,
  0x9F, 0xF6, 0x00, 0x00, 0x6F, 0xF9,
  0x9F, 0xF6, 0x00, 0x00, 0x6F, 0xF9,
  0x9F, 0xF6, 0x00, 0x00, 0x6F, 0xF9,
  0x9F, 0xF6, 0x00, 0x00, 0x6F, 0xF9,
  0x9F, 0xF6, 0x00, 0x00, 0x6F, 0xF9,
  0x9F, 0xF6, 0x00, 0x00, 0x6F, 0xF9,
  0x9F, 0xF6, 0x00, 0x00, 0x6F, 0xF9,
  0x7F, 0xF7, 0x00, 0x00, 0x7F, 0xF8,
  0x3F, 0xFE, 0x62, 0x26, 0xEF, 0xF3,
  0x0A, 0xFF, 0xFF, 0xFF, 0xFF, 0xA0,
  0x00, 0x7E, 0xFF, 0xFF, 0xE7, 0x00,
  0x00, 0x00, 0x34, 0x43, 0x00, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0056[ 90] = { // Code 0056, LATIN CAPITAL LETTER V
  0x02, 0x00, 0x00, 0x00, 0x01, 0x10,
  0xAF, 0xC0, 0x00, 0x00, 0x2E, 0xF5,
  0xCF, 0xF4, 0x00, 0x00, 0x7F, 0xF7,
  0x7F, 0xF9, 0x00, 0x00, 0xCF, 0xF2,
  0x2F, 0xFD, 0x00, 0x02, 0xFF, 0xB0,
  0x0B, 0xFF, 0x30, 0x07, 0xFF, 0x60,
  0x06, 0xFF, 0x70, 0x0B, 0xFF, 0x10,
  0x01, 0xFF, 0xB0, 0x1F, 0xFA, 0x00,
  0x00, 0xAF, 0xF1, 0x6F, 0xF5, 0x00,
  0x00, 0x5F, 0xF6, 0xBF, 0xE0, 0x00,
  0x00, 0x0E, 0xFB, 0xFF, 0x80, 0x00,
  0x00, 0x09, 0xFF, 0xFF, 0x30, 0x00,
  0x00, 0x04, 0xFF, 0xFD, 0x00, 0x00,
  0x00, 0x00, 0xCF, 0xF6, 0x00, 0x00,
  0x00, 0x00, 0x03, 0x20, 0x00, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0057[135] = { // Code 0057, LATIN CAPITAL LETTER W
  0x02, 0x00, 0x00, 0x01, 0x20, 0x00, 0x00, 0x11, 0x00,
  0xAF, 0xC0, 0x00, 0x2E, 0xFB, 0x00, 0x01, 0xEF, 0x50,
  0xCF, 0xF1, 0x00, 0x6F, 0xFF, 0x10, 0x05, 0xFF, 0x70,
  0x8F, 0xF4, 0x00, 0x9F, 0xFF, 0x40, 0x08, 0xFF, 0x30,
  0x4F, 0xF7, 0x00, 0xCF, 0xFF, 0x80, 0x0B, 0xFE, 0x00,
  0x1F, 0xFA, 0x01, 0xFF, 0xAF, 0xB0, 0x0E, 0xFB, 0x00,
  0x0C, 0xFD, 0x05, 0xFE, 0x4F, 0xF0, 0x3F, 0xF7, 0x00,
  0x08, 0xFF, 0x18, 0xFA, 0x0F, 0xF3, 0x6F, 0xF3, 0x00,
  0x04, 0xFF, 0x4B, 0xF7, 0x0B, 0xF7, 0x9F, 0xE0, 0x00,
  0x00, 0xFF, 0x8F, 0xF3, 0x08, 0xFA, 0xCF, 0xA0, 0x00,
  0x00, 0xBF, 0xDF, 0xE0, 0x04, 0xFE, 0xFF, 0x70, 0x00,
  0x00, 0x7F, 0xFF, 0xA0, 0x01, 0xFF, 0xFF, 0x20, 0x00,
  0x00, 0x4F, 0xFF, 0x70, 0x00, 0xCF, 0xFE, 0x00, 0x00,
  0x00, 0x0C, 0xFE, 0x20, 0x00, 0x6F, 0xF8, 0x00, 0x00,
  0x00, 0x01, 0x41, 0x00, 0x00, 0x03, 0x30, 0x00, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0058[ 90] = { // Code 0058, LATIN CAPITAL LETTER X
  0x01, 0x10, 0x00, 0x00, 0x11, 0x00,
  0x3F, 0xF3, 0x00, 0x04, 0xFF, 0x20,
  0x5F, 0xFC, 0x00, 0x0D, 0xFF, 0x30,
  0x0D, 0xFF, 0x60, 0x8F, 0xFA, 0x00,
  0x03, 0xFF, 0xE3, 0xFF, 0xD1, 0x00,
  0x00, 0x8F, 0xFF, 0xFF, 0x40, 0x00,
  0x00, 0x0D, 0xFF, 0xF9, 0x00, 0x00,
  0x00, 0x07, 0xFF, 0xF3, 0x00, 0x00,
  0x00, 0x2F, 0xFF, 0xFC, 0x00, 0x00,
  0x00, 0xCF, 0xFD, 0xFF, 0x70, 0x00,
  0x07, 0xFF, 0xB2, 0xFF, 0xF3, 0x00,
  0x3F, 0xFF, 0x20, 0x8F, 0xFC, 0x00,
  0xAF, 0xF7, 0x00, 0x0D, 0xFF, 0x60,
  0xAF, 0xC0, 0x00, 0x05, 0xFF, 0x40,
  0x03, 0x10, 0x00, 0x00, 0x32, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0059[ 90] = { // Code 0059, LATIN CAPITAL LETTER Y
  0x02, 0x10, 0x00, 0x00, 0x02, 0x00,
  0x9F, 0xC0, 0x00, 0x00, 0xBF, 0x90,
  0xBF, 0xF7, 0x00, 0x05, 0xFF, 0xC0,
  0x4F, 0xFE, 0x10, 0x0D, 0xFF, 0x40,
  0x0A, 0xFF, 0x80, 0x6F, 0xFA, 0x00,
  0x01, 0xEF, 0xF2, 0xEF, 0xE2, 0x00,
  0x00, 0x7F, 0xFE, 0xFF, 0x70, 0x00,
  0x00, 0x0C, 0xFF, 0xFD, 0x00, 0x00,
  0x00, 0x03, 0xFF, 0xF4, 0x00, 0x00,
  0x00, 0x00, 0xFF, 0xF0, 0x00, 0x00,
  0x00, 0x00, 0xFF, 0xF0, 0x00, 0x00,
  0x00, 0x00, 0xFF, 0xF0, 0x00, 0x00,
  0x00, 0x00, 0xFF, 0xF0, 0x00, 0x00,
  0x00, 0x00, 0xCF, 0xC0, 0x00, 0x00,
  0x00, 0x00, 0x03, 0x00, 0x00, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_005A[ 78] = { // Code 005A, LATIN CAPITAL LETTER Z
  0x09, 0xFF, 0xFF, 0xFF, 0xFF, 0xE6,
  0x0E, 0xFF, 0xFF, 0xFF, 0xFF, 0xFA,
  0x03, 0x77, 0x77, 0x7B, 0xFF, 0xF4,
  0x00, 0x00, 0x00, 0x3E, 0xFF, 0x60,
  0x00, 0x00, 0x01, 0xDF, 0xF8, 0x00,
  0x00, 0x00, 0x0C, 0xFF, 0xB0, 0x00,
  0x00, 0x00, 0xAF, 0xFC, 0x10, 0x00,
  0x00, 0x07, 0xFF, 0xE2, 0x00, 0x00,
  0x00, 0x5F, 0xFF, 0x30, 0x00, 0x00,
  0x03, 0xFF, 0xF5, 0x00, 0x00, 0x00,
  0x2E, 0xFF, 0xD7, 0x77, 0x77, 0x72,
  0x7F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFB,
  0x3D, 0xFF, 0xFF, 0xFF, 0xFF, 0xF7
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_005B[ 51] = { // Code 005B, LEFT SQUARE BRACKET
  0x3D, 0xFF, 0xE2,
  0x7F, 0xFF, 0xE2,
  0x7F, 0xF0, 0x00,
  0x7F, 0xF0, 0x00,
  0x7F, 0xF0, 0x00,
  0x7F, 0xF0, 0x00,
  0x7F, 0xF0, 0x00,
  0x7F, 0xF0, 0x00,
  0x7F, 0xF0, 0x00,
  0x7F, 0xF0, 0x00,
  0x7F, 0xF0, 0x00,
  0x7F, 0xF0, 0x00,
  0x7F, 0xF0, 0x00,
  0x7F, 0xF0, 0x00,
  0x7F, 0xF9, 0x91,
  0x4F, 0xFF, 0xF3,
  0x03, 0x66, 0x40
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_005C[ 60] = { // Code 005C, REVERSE SOLIDUS
  0x12, 0x00, 0x00, 0x00,
  0xCF, 0x10, 0x00, 0x00,
  0x9F, 0x70, 0x00, 0x00,
  0x4F, 0xC0, 0x00, 0x00,
  0x0D, 0xF3, 0x00, 0x00,
  0x07, 0xF9, 0x00, 0x00,
  0x02, 0xFE, 0x00, 0x00,
  0x00, 0xBF, 0x50, 0x00,
  0x00, 0x5F, 0xB0, 0x00,
  0x00, 0x0E, 0xF2, 0x00,
  0x00, 0x09, 0xF7, 0x00,
  0x00, 0x03, 0xFD, 0x00,
  0x00, 0x00, 0xCF, 0x40,
  0x00, 0x00, 0x6F, 0x70,
  0x00, 0x00, 0x04, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_005D[ 51] = { // Code 005D, RIGHT SQUARE BRACKET
  0xBF, 0xFE, 0x60,
  0xCF, 0xFF, 0xB0,
  0x00, 0x9F, 0xB0,
  0x00, 0x9F, 0xB0,
  0x00, 0x9F, 0xB0,
  0x00, 0x9F, 0xB0,
  0x00, 0x9F, 0xB0,
  0x00, 0x9F, 0xB0,
  0x00, 0x9F, 0xB0,
  0x00, 0x9F, 0xB0,
  0x00, 0x9F, 0xB0,
  0x00, 0x9F, 0xB0,
  0x00, 0x9F, 0xB0,
  0x00, 0x9F, 0xB0,
  0x79, 0xDF, 0xB0,
  0xEF, 0xFF, 0x90,
  0x25, 0x64, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_005E[ 40] = { // Code 005E, CIRCUMFLEX ACCENT
  0x00, 0x03, 0x72, 0x00, 0x00,
  0x00, 0x0E, 0xFB, 0x00, 0x00,
  0x00, 0x7F, 0xFF, 0x50, 0x00,
  0x01, 0xEF, 0xAF, 0xD0, 0x00,
  0x09, 0xFB, 0x0D, 0xF6, 0x00,
  0x2F, 0xF3, 0x06, 0xFE, 0x10,
  0xAF, 0x90, 0x00, 0xCF, 0x70,
  0x69, 0x10, 0x00, 0x39, 0x50
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_005F[ 12] = { // Code 005F, LOW LINE
  0x49, 0x99, 0x99, 0x99, 0x99, 0x40,
  0x14, 0x44, 0x44, 0x44, 0x44, 0x10
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0060[  8] = { // Code 0060, GRAVE ACCENT
  0x78, 0x00,
  0xEF, 0xC2,
  0x3C, 0xFE,
  0x00, 0x78
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0061[ 55] = { // Code 0061, LATIN SMALL LETTER A
  0x00, 0x05, 0x99, 0x96, 0x10,
  0x02, 0xDF, 0xFF, 0xFF, 0xE3,
  0x09, 0xFE, 0x74, 0x8F, 0xFB,
  0x04, 0xB3, 0x00, 0x0E, 0xFB,
  0x00, 0x15, 0x79, 0xCF, 0xFB,
  0x06, 0xFF, 0xFF, 0xDE, 0xFB,
  0x2F, 0xFC, 0x41, 0x0D, 0xFB,
  0x4F, 0xF6, 0x00, 0x3F, 0xFB,
  0x2F, 0xFE, 0x89, 0xEE, 0xFD,
  0x05, 0xEF, 0xFE, 0x67, 0xFE,
  0x00, 0x13, 0x30, 0x00, 0x31
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0062[ 75] = { // Code 0062, LATIN SMALL LETTER B
  0x02, 0x00, 0x00, 0x00, 0x00,
  0xCF, 0x80, 0x00, 0x00, 0x00,
  0xFF, 0x90, 0x00, 0x00, 0x00,
  0xFF, 0x90, 0x00, 0x00, 0x00,
  0xFF, 0x92, 0x89, 0x71, 0x00,
  0xFF, 0xCE, 0xFF, 0xFE, 0x20,
  0xFF, 0xFB, 0x69, 0xFF, 0xB0,
  0xFF, 0xE0, 0x00, 0xAF, 0xF2,
  0xFF, 0x90, 0x00, 0x5F, 0xF4,
  0xFF, 0x80, 0x00, 0x4F, 0xF6,
  0xFF, 0xB0, 0x00, 0x7F, 0xF3,
  0xFF, 0xF3, 0x02, 0xDF, 0xE0,
  0xFF, 0xEF, 0xDF, 0xFF, 0x70,
  0xDF, 0x6C, 0xFF, 0xF7, 0x00,
  0x13, 0x00, 0x33, 0x10, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0063[ 55] = { // Code 0063, LATIN SMALL LETTER C
  0x00, 0x05, 0x99, 0x83, 0x00,
  0x01, 0xCF, 0xFF, 0xFF, 0xA0,
  0x0B, 0xFF, 0xA6, 0xBF, 0xF3,
  0x3F, 0xF9, 0x00, 0x0B, 0xD2,
  0x6F, 0xF4, 0x00, 0x00, 0x00,
  0x7F, 0xF2, 0x00, 0x00, 0x00,
  0x5F, 0xF4, 0x00, 0x04, 0x70,
  0x2F, 0xFC, 0x10, 0x3F, 0xF4,
  0x09, 0xFF, 0xED, 0xFF, 0xE1,
  0x00, 0x8E, 0xFF, 0xFC, 0x30,
  0x00, 0x00, 0x34, 0x20, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0064[ 75] = { // Code 0064, LATIN SMALL LETTER D
  0x00, 0x00, 0x00, 0x00, 0x20,
  0x00, 0x00, 0x00, 0x08, 0xFC,
  0x00, 0x00, 0x00, 0x09, 0xFF,
  0x00, 0x00, 0x00, 0x09, 0xFF,
  0x00, 0x17, 0x98, 0x29, 0xFF,
  0x02, 0xEF, 0xFF, 0xEC, 0xFF,
  0x0B, 0xFF, 0x96, 0xBF, 0xFF,
  0x2F, 0xFA, 0x00, 0x0E, 0xFF,
  0x5F, 0xF5, 0x00, 0x09, 0xFF,
  0x6F, 0xF4, 0x00, 0x08, 0xFF,
  0x4F, 0xF7, 0x00, 0x0B, 0xFF,
  0x1E, 0xFD, 0x20, 0x3F, 0xFF,
  0x07, 0xFF, 0xFD, 0xFE, 0xFF,
  0x00, 0x7F, 0xFF, 0xC6, 0xFD,
  0x00, 0x01, 0x32, 0x00, 0x31
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0065[ 66] = { // Code 0065, LATIN SMALL LETTER E
  0x00, 0x03, 0x89, 0x95, 0x00, 0x00,
  0x00, 0xAF, 0xFF, 0xFF, 0xC1, 0x00,
  0x09, 0xFF, 0x74, 0x6E, 0xFB, 0x00,
  0x1F, 0xF8, 0x00, 0x05, 0xFF, 0x30,
  0x4F, 0xFC, 0xBB, 0xBC, 0xFF, 0x60,
  0x6F, 0xFC, 0xBB, 0xBB, 0xBB, 0x30,
  0x4F, 0xF6, 0x00, 0x00, 0x10, 0x00,
  0x0E, 0xFD, 0x20, 0x06, 0xFA, 0x00,
  0x05, 0xFF, 0xFD, 0xEF, 0xFA, 0x00,
  0x00, 0x5D, 0xFF, 0xFE, 0x91, 0x00,
  0x00, 0x00, 0x24, 0x30, 0x00, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0066[ 60] = { // Code 0066, LATIN SMALL LETTER F
  0x00, 0x01, 0x42, 0x00,
  0x00, 0x6F, 0xFF, 0x50,
  0x01, 0xFF, 0xFD, 0x40,
  0x02, 0xFF, 0x80, 0x00,
  0x37, 0xFF, 0xA6, 0x10,
  0xBF, 0xFF, 0xFF, 0x70,
  0x26, 0xFF, 0xA4, 0x10,
  0x02, 0xFF, 0x70, 0x00,
  0x02, 0xFF, 0x70, 0x00,
  0x02, 0xFF, 0x70, 0x00,
  0x02, 0xFF, 0x70, 0x00,
  0x02, 0xFF, 0x70, 0x00,
  0x02, 0xFF, 0x70, 0x00,
  0x01, 0xEF, 0x60, 0x00,
  0x00, 0x13, 0x00, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0067[ 70] = { // Code 0067, LATIN SMALL LETTER G
  0x00, 0x16, 0x98, 0x31, 0x96,
  0x02, 0xDF, 0xFF, 0xFA, 0xFE,
  0x0B, 0xFF, 0xA6, 0xBF, 0xFF,
  0x2F, 0xF9, 0x00, 0x0C, 0xFF,
  0x5F, 0xF5, 0x00, 0x09, 0xFF,
  0x6F, 0xF4, 0x00, 0x09, 0xFF,
  0x3F, 0xF8, 0x00, 0x0C, 0xFF,
  0x0E, 0xFF, 0x64, 0x8F, 0xFF,
  0x04, 0xFF, 0xFF, 0xFE, 0xFF,
  0x00, 0x38, 0xBA, 0x49, 0xFF,
  0x01, 0x61, 0x00, 0x0B, 0xFC,
  0x09, 0xFD, 0x32, 0x6F, 0xF7,
  0x05, 0xFF, 0xFF, 0xFF, 0xB1,
  0x00, 0x39, 0xCD, 0xB7, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0068[ 75] = { // Code 0068, LATIN SMALL LETTER H
  0x02, 0x00, 0x00, 0x00, 0x00,
  0xCF, 0x80, 0x00, 0x00, 0x00,
  0xFF, 0x90, 0x00, 0x00, 0x00,
  0xFF, 0x90, 0x00, 0x00, 0x00,
  0xFF, 0x91, 0x79, 0x83, 0x00,
  0xFF, 0xBE, 0xFF, 0xFF, 0x40,
  0xFF, 0xFD, 0x8B, 0xFF, 0xB0,
  0xFF, 0xE1, 0x00, 0xDF, 0xE0,
  0xFF, 0xA0, 0x00, 0x9F, 0xF0,
  0xFF, 0x90, 0x00, 0x9F, 0xF0,
  0xFF, 0x90, 0x00, 0x9F, 0xF0,
  0xFF, 0x90, 0x00, 0x9F, 0xF0,
  0xFF, 0x90, 0x00, 0x9F, 0xF0,
  0xCF, 0x80, 0x00, 0x8F, 0xC0,
  0x13, 0x00, 0x00, 0x03, 0x10
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0069[ 30] = { // Code 0069, LATIN SMALL LETTER I
  0x04, 0x00,
  0xAF, 0xB0,
  0xCF, 0xC0,
  0x27, 0x20,
  0x49, 0x40,
  0xCF, 0xC0,
  0xDF, 0xD0,
  0xDF, 0xD0,
  0xDF, 0xD0,
  0xDF, 0xD0,
  0xDF, 0xD0,
  0xDF, 0xD0,
  0xDF, 0xD0,
  0xAF, 0xA0,
  0x04, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_006A[ 54] = { // Code 006A, LATIN SMALL LETTER J
  0x00, 0x04, 0x00,
  0x00, 0xAF, 0xB0,
  0x00, 0xCF, 0xC0,
  0x00, 0x27, 0x20,
  0x00, 0x49, 0x40,
  0x00, 0xCF, 0xC0,
  0x00, 0xDF, 0xD0,
  0x00, 0xDF, 0xD0,
  0x00, 0xDF, 0xD0,
  0x00, 0xDF, 0xD0,
  0x00, 0xDF, 0xD0,
  0x00, 0xDF, 0xD0,
  0x00, 0xDF, 0xD0,
  0x00, 0xDF, 0xD0,
  0x00, 0xDF, 0xD0,
  0x05, 0xEF, 0xB0,
  0x4F, 0xFF, 0x80,
  0x1A, 0xB7, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_006B[ 75] = { // Code 006B, LATIN SMALL LETTER K
  0x02, 0x00, 0x00, 0x00, 0x00,
  0xCF, 0x80, 0x00, 0x00, 0x00,
  0xFF, 0x90, 0x00, 0x00, 0x00,
  0xFF, 0x90, 0x00, 0x00, 0x00,
  0xFF, 0x90, 0x02, 0x93, 0x00,
  0xFF, 0x90, 0x1D, 0xFC, 0x00,
  0xFF, 0x91, 0xDF, 0xF5, 0x00,
  0xFF, 0xAB, 0xFF, 0x60, 0x00,
  0xFF, 0xFF, 0xFB, 0x00, 0x00,
  0xFF, 0xFF, 0xFF, 0x40, 0x00,
  0xFF, 0xE6, 0xFF, 0xE2, 0x00,
  0xFF, 0x90, 0x6F, 0xFB, 0x00,
  0xFF, 0x90, 0x0B, 0xFF, 0x60,
  0xCF, 0x80, 0x01, 0xEF, 0x50,
  0x13, 0x00, 0x00, 0x13, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_006C[ 30] = { // Code 006C, LATIN SMALL LETTER L
  0x02, 0x00,
  0xAF, 0xA0,
  0xDF, 0xD0,
  0xDF, 0xD0,
  0xDF, 0xD0,
  0xDF, 0xD0,
  0xDF, 0xD0,
  0xDF, 0xD0,
  0xDF, 0xD0,
  0xDF, 0xD0,
  0xDF, 0xD0,
  0xDF, 0xD0,
  0xDF, 0xD0,
  0xAF, 0xA0,
  0x03, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_006D[ 88] = { // Code 006D, LATIN SMALL LETTER M
  0x59, 0x11, 0x79, 0x82, 0x03, 0x89, 0x72, 0x00,
  0xEF, 0x9D, 0xFF, 0xFE, 0x6F, 0xFF, 0xFE, 0x20,
  0xFF, 0xFC, 0x8C, 0xFF, 0xFC, 0x8C, 0xFF, 0x70,
  0xFF, 0xE1, 0x02, 0xFF, 0xD1, 0x02, 0xFF, 0x90,
  0xFF, 0xA0, 0x00, 0xFF, 0xA0, 0x00, 0xFF, 0x90,
  0xFF, 0x90, 0x00, 0xFF, 0x90, 0x00, 0xFF, 0x90,
  0xFF, 0x90, 0x00, 0xFF, 0x90, 0x00, 0xFF, 0x90,
  0xFF, 0x90, 0x00, 0xFF, 0x90, 0x00, 0xFF, 0x90,
  0xFF, 0x90, 0x00, 0xFF, 0x90, 0x00, 0xFF, 0x90,
  0xCF, 0x80, 0x00, 0xDF, 0x80, 0x00, 0xDF, 0x70,
  0x13, 0x00, 0x00, 0x13, 0x00, 0x00, 0x13, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_006E[ 55] = { // Code 006E, LATIN SMALL LETTER N
  0x59, 0x11, 0x79, 0x83, 0x00,
  0xEF, 0x8E, 0xFF, 0xFF, 0x40,
  0xFF, 0xFD, 0x8B, 0xFF, 0xB0,
  0xFF, 0xE1, 0x00, 0xDF, 0xE0,
  0xFF, 0xA0, 0x00, 0x9F, 0xF0,
  0xFF, 0x90, 0x00, 0x9F, 0xF0,
  0xFF, 0x90, 0x00, 0x9F, 0xF0,
  0xFF, 0x90, 0x00, 0x9F, 0xF0,
  0xFF, 0x90, 0x00, 0x9F, 0xF0,
  0xCF, 0x80, 0x00, 0x8F, 0xC0,
  0x13, 0x00, 0x00, 0x03, 0x10
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_006F[ 66] = { // Code 006F, LATIN SMALL LETTER O
  0x00, 0x04, 0x89, 0x84, 0x00, 0x00,
  0x01, 0xBF, 0xFF, 0xFF, 0xB1, 0x00,
  0x0A, 0xFF, 0x95, 0x8F, 0xFA, 0x00,
  0x1F, 0xFA, 0x00, 0x0A, 0xFF, 0x20,
  0x5F, 0xF5, 0x00, 0x05, 0xFF, 0x50,
  0x6F, 0xF4, 0x00, 0x04, 0xFF, 0x60,
  0x4F, 0xF7, 0x00, 0x06, 0xFF, 0x40,
  0x0E, 0xFD, 0x10, 0x1D, 0xFE, 0x10,
  0x07, 0xFF, 0xEB, 0xEF, 0xF7, 0x00,
  0x00, 0x6E, 0xFF, 0xFE, 0x60, 0x00,
  0x00, 0x00, 0x34, 0x30, 0x00, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0070[ 70] = { // Code 0070, LATIN SMALL LETTER P
  0x69, 0x13, 0x99, 0x61, 0x00,
  0xEF, 0xAF, 0xFF, 0xFD, 0x20,
  0xFF, 0xFB, 0x6A, 0xFF, 0xB0,
  0xFF, 0xD0, 0x00, 0xAF, 0xF2,
  0xFF, 0x90, 0x00, 0x5F, 0xF4,
  0xFF, 0x80, 0x00, 0x4F, 0xF6,
  0xFF, 0xB0, 0x00, 0x7F, 0xF3,
  0xFF, 0xF3, 0x01, 0xDF, 0xE1,
  0xFF, 0xFF, 0xDE, 0xFF, 0x80,
  0xFF, 0xAB, 0xFF, 0xF9, 0x00,
  0xFF, 0x90, 0x24, 0x10, 0x00,
  0xFF, 0x90, 0x00, 0x00, 0x00,
  0xEF, 0x90, 0x00, 0x00, 0x00,
  0x6B, 0x30, 0x00, 0x00, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0071[ 70] = { // Code 0071, LATIN SMALL LETTER Q
  0x00, 0x16, 0x99, 0x31, 0x96,
  0x02, 0xDF, 0xFF, 0xFA, 0xFE,
  0x0B, 0xFF, 0xA6, 0xBF, 0xFF,
  0x2F, 0xFA, 0x00, 0x0D, 0xFF,
  0x5F, 0xF5, 0x00, 0x09, 0xFF,
  0x6F, 0xF4, 0x00, 0x08, 0xFF,
  0x4F, 0xF7, 0x00, 0x0B, 0xFF,
  0x1F, 0xFD, 0x10, 0x3F, 0xFF,
  0x08, 0xFF, 0xED, 0xFF, 0xFF,
  0x00, 0x9F, 0xFF, 0xBA, 0xFF,
  0x00, 0x01, 0x42, 0x09, 0xFF,
  0x00, 0x00, 0x00, 0x09, 0xFF,
  0x00, 0x00, 0x00, 0x09, 0xFE,
  0x00, 0x00, 0x00, 0x03, 0xB6
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0072[ 44] = { // Code 0072, LATIN SMALL LETTER R
  0x49, 0x22, 0x97, 0x00,
  0xCF, 0x9E, 0xFF, 0x30,
  0xDF, 0xFF, 0xFB, 0x10,
  0xDF, 0xF5, 0x00, 0x00,
  0xDF, 0xE0, 0x00, 0x00,
  0xDF, 0xD0, 0x00, 0x00,
  0xDF, 0xD0, 0x00, 0x00,
  0xDF, 0xD0, 0x00, 0x00,
  0xDF, 0xD0, 0x00, 0x00,
  0xAF, 0xA0, 0x00, 0x00,
  0x04, 0x00, 0x00, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0073[ 55] = { // Code 0073, LATIN SMALL LETTER S
  0x00, 0x48, 0x99, 0x61, 0x00,
  0x0A, 0xFF, 0xFF, 0xFE, 0x30,
  0x4F, 0xFA, 0x46, 0xEF, 0x80,
  0x6F, 0xF7, 0x00, 0x27, 0x10,
  0x2F, 0xFF, 0xFB, 0x82, 0x00,
  0x04, 0xCF, 0xFF, 0xFF, 0x50,
  0x03, 0x01, 0x59, 0xEF, 0xE0,
  0x4F, 0xC1, 0x00, 0xAF, 0xF0,
  0x3F, 0xFE, 0xAB, 0xFF, 0xA0,
  0x04, 0xCF, 0xFF, 0xF9, 0x10,
  0x00, 0x01, 0x33, 0x10, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0074[ 56] = { // Code 0074, LATIN SMALL LETTER T
  0x00, 0x33, 0x00, 0x00,
  0x02, 0xFF, 0x40, 0x00,
  0x04, 0xFF, 0x60, 0x00,
  0x38, 0xFF, 0x95, 0x10,
  0xBF, 0xFF, 0xFF, 0x50,
  0x27, 0xFF, 0x94, 0x00,
  0x04, 0xFF, 0x60, 0x00,
  0x04, 0xFF, 0x60, 0x00,
  0x04, 0xFF, 0x60, 0x00,
  0x04, 0xFF, 0x60, 0x00,
  0x04, 0xFF, 0x60, 0x00,
  0x03, 0xFF, 0xEC, 0x30,
  0x00, 0xBF, 0xFF, 0x30,
  0x00, 0x02, 0x41, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0075[ 55] = { // Code 0075, LATIN SMALL LETTER U
  0x59, 0x30, 0x00, 0x39, 0x50,
  0xEF, 0x90, 0x00, 0x9F, 0xE0,
  0xFF, 0x90, 0x00, 0x9F, 0xF0,
  0xFF, 0x90, 0x00, 0x9F, 0xF0,
  0xFF, 0x90, 0x00, 0x9F, 0xF0,
  0xFF, 0x90, 0x00, 0x9F, 0xF0,
  0xFF, 0xA0, 0x00, 0xBF, 0xF0,
  0xEF, 0xE2, 0x06, 0xFF, 0xF0,
  0x9F, 0xFF, 0xEF, 0xEF, 0xF0,
  0x1C, 0xFF, 0xF9, 0x5F, 0xD0,
  0x00, 0x24, 0x10, 0x03, 0x10
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0076[ 55] = { // Code 0076, LATIN SMALL LETTER V
  0x49, 0x20, 0x00, 0x29, 0x40,
  0xDF, 0xB0, 0x00, 0xBF, 0xD0,
  0xAF, 0xF1, 0x01, 0xFF, 0xA0,
  0x5F, 0xF5, 0x05, 0xFF, 0x50,
  0x0E, 0xF9, 0x09, 0xFE, 0x00,
  0x09, 0xFE, 0x0E, 0xF9, 0x00,
  0x03, 0xFF, 0x7F, 0xF3, 0x00,
  0x00, 0xDF, 0xEF, 0xD0, 0x00,
  0x00, 0x8F, 0xFF, 0x80, 0x00,
  0x00, 0x2F, 0xFF, 0x20, 0x00,
  0x00, 0x02, 0x42, 0x00, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0077[ 77] = { // Code 0077, LATIN SMALL LETTER W
  0x39, 0x40, 0x01, 0x89, 0x10, 0x04, 0x93,
  0xBF, 0xB0, 0x07, 0xFF, 0x80, 0x0B, 0xFB,
  0x9F, 0xF1, 0x0B, 0xFF, 0xC0, 0x0F, 0xF9,
  0x4F, 0xF4, 0x0E, 0xFF, 0xF1, 0x3F, 0xF4,
  0x0E, 0xF7, 0x2F, 0xCC, 0xF3, 0x7F, 0xE0,
  0x0A, 0xFB, 0x5F, 0x88, 0xF7, 0xAF, 0xA0,
  0x06, 0xFE, 0x9F, 0x44, 0xFA, 0xDF, 0x60,
  0x01, 0xFF, 0xEF, 0x11, 0xFE, 0xFF, 0x10,
  0x00, 0xBF, 0xFC, 0x00, 0xCF, 0xFB, 0x00,
  0x00, 0x6F, 0xF7, 0x00, 0x7F, 0xF6, 0x00,
  0x00, 0x03, 0x30, 0x00, 0x03, 0x30, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0078[ 55] = { // Code 0078, LATIN SMALL LETTER X
  0x18, 0x70, 0x00, 0x78, 0x00,
  0x7F, 0xF4, 0x05, 0xFF, 0x30,
  0x2F, 0xFD, 0x1E, 0xFD, 0x00,
  0x07, 0xFF, 0xDF, 0xF3, 0x00,
  0x00, 0xCF, 0xFF, 0x80, 0x00,
  0x00, 0x8F, 0xFF, 0x50, 0x00,
  0x04, 0xFF, 0xFF, 0xD1, 0x00,
  0x1D, 0xFE, 0x6F, 0xF9, 0x00,
  0x8F, 0xF5, 0x0B, 0xFF, 0x30,
  0x8F, 0xB0, 0x02, 0xEF, 0x30,
  0x03, 0x00, 0x00, 0x22, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_0079[ 70] = { // Code 0079, LATIN SMALL LETTER Y
  0x39, 0x40, 0x00, 0x39, 0x30,
  0xBF, 0xD0, 0x00, 0xCF, 0xB0,
  0x8F, 0xF2, 0x01, 0xFF, 0x80,
  0x3F, 0xF7, 0x05, 0xFF, 0x30,
  0x0D, 0xFB, 0x09, 0xFD, 0x00,
  0x08, 0xFE, 0x0D, 0xF7, 0x00,
  0x03, 0xFF, 0x6F, 0xF2, 0x00,
  0x00, 0xCF, 0xEF, 0xB0, 0x00,
  0x00, 0x7F, 0xFF, 0x70, 0x00,
  0x00, 0x2F, 0xFF, 0x10, 0x00,
  0x00, 0x0C, 0xFB, 0x00, 0x00,
  0x06, 0x8F, 0xF5, 0x00, 0x00,
  0x1F, 0xFF, 0xC0, 0x00, 0x00,
  0x07, 0xB8, 0x10, 0x00, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_007A[ 50] = { // Code 007A, LATIN SMALL LETTER Z
  0x03, 0x66, 0x66, 0x66, 0x50,
  0x0F, 0xFF, 0xFF, 0xFF, 0xF5,
  0x07, 0x99, 0x9B, 0xFF, 0xE1,
  0x00, 0x00, 0x1D, 0xFE, 0x30,
  0x00, 0x01, 0xDF, 0xF4, 0x00,
  0x00, 0x1B, 0xFF, 0x50, 0x00,
  0x00, 0xBF, 0xF7, 0x00, 0x00,
  0x0A, 0xFF, 0x80, 0x00, 0x00,
  0x5F, 0xFF, 0xFF, 0xFF, 0xF5,
  0x4F, 0xFF, 0xFF, 0xFF, 0xF4
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_007B[ 68] = { // Code 007B, LEFT CURLY BRACKET
  0x00, 0x6D, 0xFE, 0x30,
  0x01, 0xFF, 0xC9, 0x20,
  0x03, 0xFF, 0x40, 0x00,
  0x04, 0xFF, 0x40, 0x00,
  0x04, 0xFF, 0x40, 0x00,
  0x04, 0xFF, 0x40, 0x00,
  0x04, 0xFF, 0x30, 0x00,
  0x8D, 0xFB, 0x00, 0x00,
  0xDF, 0xE7, 0x00, 0x00,
  0x06, 0xFF, 0x10, 0x00,
  0x04, 0xFF, 0x40, 0x00,
  0x04, 0xFF, 0x40, 0x00,
  0x04, 0xFF, 0x40, 0x00,
  0x03, 0xFF, 0x40, 0x00,
  0x02, 0xFF, 0x95, 0x00,
  0x00, 0xBF, 0xFF, 0x40,
  0x00, 0x03, 0x55, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_007C[ 30] = { // Code 007C, VERTICAL LINE
  0x02, 0x20,
  0x1E, 0xE1,
  0x2F, 0xF2,
  0x2F, 0xF2,
  0x2F, 0xF2,
  0x2F, 0xF2,
  0x2F, 0xF2,
  0x2F, 0xF2,
  0x2F, 0xF2,
  0x2F, 0xF2,
  0x2F, 0xF2,
  0x2F, 0xF2,
  0x2F, 0xF2,
  0x1F, 0xF1,
  0x02, 0x20
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_007D[ 68] = { // Code 007D, RIGHT CURLY BRACKET
  0xCF, 0xEA, 0x00, 0x00,
  0x8B, 0xFF, 0x60, 0x00,
  0x00, 0xDF, 0x70, 0x00,
  0x00, 0xDF, 0x70, 0x00,
  0x00, 0xDF, 0x70, 0x00,
  0x00, 0xDF, 0x70, 0x00,
  0x00, 0xDF, 0x80, 0x00,
  0x00, 0x7F, 0xEA, 0x10,
  0x00, 0x3C, 0xFF, 0x30,
  0x00, 0xCF, 0xA0, 0x00,
  0x00, 0xDF, 0x70, 0x00,
  0x00, 0xDF, 0x70, 0x00,
  0x00, 0xDF, 0x70, 0x00,
  0x00, 0xDF, 0x70, 0x00,
  0x36, 0xFF, 0x70, 0x00,
  0xEF, 0xFE, 0x20, 0x00,
  0x36, 0x41, 0x00, 0x00
};

GUI_CONST_STORAGE unsigned char acGUI_FontRounded22_007E[ 24] = { // Code 007E, TILDE
  0x02, 0xAB, 0x83, 0x00, 0x38, 0x00,
  0x0D, 0xFF, 0xFF, 0xBA, 0xFF, 0x00,
  0x4F, 0xC6, 0xAF, 0xFF, 0xF9, 0x00,
  0x06, 0x10, 0x01, 0x79, 0x50, 0x00
};

GUI_CONST_STORAGE GUI_CHARINFO_EXT GUI_FontRounded22_CharInfo[95] = {
   {   1,   1,   0,  18,   6, acGUI_FontRounded22_0020 } // Code 0020, SPACE
  ,{   4,  15,   1,   4,   6, acGUI_FontRounded22_0021 } // Code 0021, EXCLAMATION MARK
  ,{   7,   7,   1,   4,  10, acGUI_FontRounded22_0022 } // Code 0022, QUOTATION MARK
  ,{  11,  14,   0,   5,  11, acGUI_FontRounded22_0023 } // Code 0023, NUMBER SIGN
  ,{  11,  16,   0,   4,  11, acGUI_FontRounded22_0024 } // Code 0024, DOLLAR SIGN
  ,{  16,  15,   1,   4,  18, acGUI_FontRounded22_0025 } // Code 0025, PERCENT SIGN
  ,{  13,  15,   0,   4,  13, acGUI_FontRounded22_0026 } // Code 0026, AMPERSAND
  ,{   3,   7,   1,   4,   6, acGUI_FontRounded22_0027 } // Code 0027, APOSTROPHE
  ,{   5,  18,   1,   4,   6, acGUI_FontRounded22_0028 } // Code 0028, LEFT PARENTHESIS
  ,{   5,  18,   0,   4,   6, acGUI_FontRounded22_0029 } // Code 0029, RIGHT PARENTHESIS
  ,{   8,   8,   0,   4,   8, acGUI_FontRounded22_002A } // Code 002A, ASTERISK
  ,{  11,  11,   0,   7,  11, acGUI_FontRounded22_002B } // Code 002B, PLUS SIGN
  ,{   4,   6,   1,  15,   6, acGUI_FontRounded22_002C } // Code 002C, COMMA
  ,{   7,   4,   0,  11,   7, acGUI_FontRounded22_002D } // Code 002D, HYPHEN-MINUS
  ,{   4,   4,   1,  15,   6, acGUI_FontRounded22_002E } // Code 002E, FULL STOP
  ,{   7,  15,   0,   4,   7, acGUI_FontRounded22_002F } // Code 002F, SOLIDUS
  ,{  11,  14,   0,   5,  11, acGUI_FontRounded22_0030 } // Code 0030, DIGIT ZERO
  ,{   7,  14,  -1,   5,   7, acGUI_FontRounded22_0031 } // Code 0031, DIGIT ONE
  ,{  11,  13,   0,   5,  11, acGUI_FontRounded22_0032 } // Code 0032, DIGIT TWO
  ,{  10,  14,   0,   5,  11, acGUI_FontRounded22_0033 } // Code 0033, DIGIT THREE
  ,{  11,  14,   0,   5,  11, acGUI_FontRounded22_0034 } // Code 0034, DIGIT FOUR
  ,{  10,  14,   0,   5,  11, acGUI_FontRounded22_0035 } // Code 0035, DIGIT FIVE
  ,{  11,  14,   0,   5,  11, acGUI_FontRounded22_0036 } // Code 0036, DIGIT SIX
  ,{  10,  14,   0,   5,  10, acGUI_FontRounded22_0037 } // Code 0037, DIGIT SEVEN
  ,{  11,  14,   0,   5,  11, acGUI_FontRounded22_0038 } // Code 0038, DIGIT EIGHT
  ,{  11,  14,   0,   5,  11, acGUI_FontRounded22_0039 } // Code 0039, DIGIT NINE
  ,{   4,  11,   1,   8,   6, acGUI_FontRounded22_003A } // Code 003A, COLON
  ,{   4,  13,   1,   8,   6, acGUI_FontRounded22_003B } // Code 003B, SEMICOLON
  ,{  11,  10,   0,   8,  11, acGUI_FontRounded22_003C } // Code 003C, LESS-THAN SIGN
  ,{  11,   8,   0,   9,  11, acGUI_FontRounded22_003D } // Code 003D, EQUALS SIGN
  ,{  11,  10,   0,   8,  11, acGUI_FontRounded22_003E } // Code 003E, GREATER-THAN SIGN
  ,{  10,  15,   0,   4,  10, acGUI_FontRounded22_003F } // Code 003F, QUESTION MARK
  ,{  14,  15,   0,   4,  14, acGUI_FontRounded22_0040 } // Code 0040, COMMERCIAL AT
  ,{  12,  15,   0,   4,  12, acGUI_FontRounded22_0041 } // Code 0041, LATIN CAPITAL LETTER A
  ,{  12,  13,   1,   5,  13, acGUI_FontRounded22_0042 } // Code 0042, LATIN CAPITAL LETTER B
  ,{  12,  15,   1,   4,  13, acGUI_FontRounded22_0043 } // Code 0043, LATIN CAPITAL LETTER C
  ,{  12,  13,   1,   5,  14, acGUI_FontRounded22_0044 } // Code 0044, LATIN CAPITAL LETTER D
  ,{  11,  13,   1,   5,  12, acGUI_FontRounded22_0045 } // Code 0045, LATIN CAPITAL LETTER E
  ,{  11,  14,   1,   5,  11, acGUI_FontRounded22_0046 } // Code 0046, LATIN CAPITAL LETTER F
  ,{  13,  15,   1,   4,  15, acGUI_FontRounded22_0047 } // Code 0047, LATIN CAPITAL LETTER G
  ,{  12,  15,   1,   4,  14, acGUI_FontRounded22_0048 } // Code 0048, LATIN CAPITAL LETTER H
  ,{   4,  15,   1,   4,   6, acGUI_FontRounded22_0049 } // Code 0049, LATIN CAPITAL LETTER I
  ,{   9,  15,   0,   4,  10, acGUI_FontRounded22_004A } // Code 004A, LATIN CAPITAL LETTER J
  ,{  12,  15,   1,   4,  12, acGUI_FontRounded22_004B } // Code 004B, LATIN CAPITAL LETTER K
  ,{  10,  14,   1,   4,  11, acGUI_FontRounded22_004C } // Code 004C, LATIN CAPITAL LETTER L
  ,{  14,  15,   1,   4,  16, acGUI_FontRounded22_004D } // Code 004D, LATIN CAPITAL LETTER M
  ,{  12,  15,   1,   4,  14, acGUI_FontRounded22_004E } // Code 004E, LATIN CAPITAL LETTER N
  ,{  14,  15,   0,   4,  15, acGUI_FontRounded22_004F } // Code 004F, LATIN CAPITAL LETTER O
  ,{  12,  14,   1,   5,  13, acGUI_FontRounded22_0050 } // Code 0050, LATIN CAPITAL LETTER P
  ,{  14,  15,   0,   4,  15, acGUI_FontRounded22_0051 } // Code 0051, LATIN CAPITAL LETTER Q
  ,{  12,  14,   1,   5,  13, acGUI_FontRounded22_0052 } // Code 0052, LATIN CAPITAL LETTER R
  ,{  12,  15,   0,   4,  12, acGUI_FontRounded22_0053 } // Code 0053, LATIN CAPITAL LETTER S
  ,{  12,  14,   0,   5,  12, acGUI_FontRounded22_0054 } // Code 0054, LATIN CAPITAL LETTER T
  ,{  12,  15,   1,   4,  14, acGUI_FontRounded22_0055 } // Code 0055, LATIN CAPITAL LETTER U
  ,{  12,  15,   0,   4,  12, acGUI_FontRounded22_0056 } // Code 0056, LATIN CAPITAL LETTER V
  ,{  17,  15,   0,   4,  17, acGUI_FontRounded22_0057 } // Code 0057, LATIN CAPITAL LETTER W
  ,{  11,  15,   0,   4,  11, acGUI_FontRounded22_0058 } // Code 0058, LATIN CAPITAL LETTER X
  ,{  11,  15,   0,   4,  11, acGUI_FontRounded22_0059 } // Code 0059, LATIN CAPITAL LETTER Y
  ,{  12,  13,   0,   5,  12, acGUI_FontRounded22_005A } // Code 005A, LATIN CAPITAL LETTER Z
  ,{   6,  17,   1,   5,   6, acGUI_FontRounded22_005B } // Code 005B, LEFT SQUARE BRACKET
  ,{   7,  15,   0,   4,   7, acGUI_FontRounded22_005C } // Code 005C, REVERSE SOLIDUS
  ,{   5,  17,   0,   5,   6, acGUI_FontRounded22_005D } // Code 005D, RIGHT SQUARE BRACKET
  ,{   9,   8,   1,   5,  11, acGUI_FontRounded22_005E } // Code 005E, CIRCUMFLEX ACCENT
  ,{  11,   2,  -1,  19,   9, acGUI_FontRounded22_005F } // Code 005F, LOW LINE
  ,{   4,   4,   0,   4,   5, acGUI_FontRounded22_0060 } // Code 0060, GRAVE ACCENT
  ,{  10,  11,   0,   8,  11, acGUI_FontRounded22_0061 } // Code 0061, LATIN SMALL LETTER A
  ,{  10,  15,   1,   4,  11, acGUI_FontRounded22_0062 } // Code 0062, LATIN SMALL LETTER B
  ,{  10,  11,   0,   8,  10, acGUI_FontRounded22_0063 } // Code 0063, LATIN SMALL LETTER C
  ,{  10,  15,   0,   4,  11, acGUI_FontRounded22_0064 } // Code 0064, LATIN SMALL LETTER D
  ,{  11,  11,   0,   8,  11, acGUI_FontRounded22_0065 } // Code 0065, LATIN SMALL LETTER E
  ,{   7,  15,   0,   4,   7, acGUI_FontRounded22_0066 } // Code 0066, LATIN SMALL LETTER F
  ,{  10,  14,   0,   8,  11, acGUI_FontRounded22_0067 } // Code 0067, LATIN SMALL LETTER G
  ,{   9,  15,   1,   4,  11, acGUI_FontRounded22_0068 } // Code 0068, LATIN SMALL LETTER H
  ,{   3,  15,   1,   4,   5, acGUI_FontRounded22_0069 } // Code 0069, LATIN SMALL LETTER I
  ,{   5,  18,  -1,   4,   5, acGUI_FontRounded22_006A } // Code 006A, LATIN SMALL LETTER J
  ,{   9,  15,   1,   4,  10, acGUI_FontRounded22_006B } // Code 006B, LATIN SMALL LETTER K
  ,{   3,  15,   1,   4,   5, acGUI_FontRounded22_006C } // Code 006C, LATIN SMALL LETTER L
  ,{  15,  11,   1,   8,  17, acGUI_FontRounded22_006D } // Code 006D, LATIN SMALL LETTER M
  ,{   9,  11,   1,   8,  11, acGUI_FontRounded22_006E } // Code 006E, LATIN SMALL LETTER N
  ,{  11,  11,   0,   8,  11, acGUI_FontRounded22_006F } // Code 006F, LATIN SMALL LETTER O
  ,{  10,  14,   1,   8,  11, acGUI_FontRounded22_0070 } // Code 0070, LATIN SMALL LETTER P
  ,{  10,  14,   0,   8,  11, acGUI_FontRounded22_0071 } // Code 0071, LATIN SMALL LETTER Q
  ,{   7,  11,   1,   8,   7, acGUI_FontRounded22_0072 } // Code 0072, LATIN SMALL LETTER R
  ,{   9,  11,   0,   8,  10, acGUI_FontRounded22_0073 } // Code 0073, LATIN SMALL LETTER S
  ,{   7,  14,   0,   5,   7, acGUI_FontRounded22_0074 } // Code 0074, LATIN SMALL LETTER T
  ,{   9,  11,   1,   8,  11, acGUI_FontRounded22_0075 } // Code 0075, LATIN SMALL LETTER U
  ,{   9,  11,   0,   8,   9, acGUI_FontRounded22_0076 } // Code 0076, LATIN SMALL LETTER V
  ,{  14,  11,   0,   8,  14, acGUI_FontRounded22_0077 } // Code 0077, LATIN SMALL LETTER W
  ,{   9,  11,   0,   8,   9, acGUI_FontRounded22_0078 } // Code 0078, LATIN SMALL LETTER X
  ,{   9,  14,   0,   8,   9, acGUI_FontRounded22_0079 } // Code 0079, LATIN SMALL LETTER Y
  ,{  10,  10,   0,   8,  10, acGUI_FontRounded22_007A } // Code 007A, LATIN SMALL LETTER Z
  ,{   7,  17,   0,   5,   6, acGUI_FontRounded22_007B } // Code 007B, LEFT CURLY BRACKET
  ,{   4,  15,   0,   4,   4, acGUI_FontRounded22_007C } // Code 007C, VERTICAL LINE
  ,{   7,  17,   0,   5,   6, acGUI_FontRounded22_007D } // Code 007D, RIGHT CURLY BRACKET
  ,{  11,   4,   0,  11,  11, acGUI_FontRounded22_007E } // Code 007E, TILDE
};

GUI_CONST_STORAGE GUI_FONT_PROP_EXT GUI_FontRounded22_Prop1 = {
  0x0020,                                   // First character
  0x007E,                                   // Last character
  &GUI_FontRounded22_CharInfo[0],           // Address of first character
  (GUI_CONST_STORAGE GUI_FONT_PROP_EXT *)0  // Pointer to next GUI_FONT_PROP_EXT
};

GUI_CONST_STORAGE GUI_FONT GUI_FontRounded22 = {
  GUI_FONTTYPE_PROP_AA4_EXT,     // Type of font
  22,                            // Height of font
  22,                            // Space of font y
  1,                             // Magnification x
  1,                             // Magnification y
  { &GUI_FontRounded22_Prop1 },
  22,                            // Baseline
  11,                            // Height of lowercase characters
  15                             // Height of capital characters
};

/*********************************************************************
*
*       _bmSeggerLogo50
*/
static GUI_CONST_STORAGE GUI_COLOR _ColorsSeggerLogo50[] = {
  0xFFFFFF, 0xFFFFFF, 0x201F23, 0x979698,
  0xBE6767, 0xB85858, 0x949495, 0xA02020,
  0xECD3D3, 0xC0BFC0, 0x909092, 0x1C1B1E,
  0x444346, 0xA12323, 0xA42A2A, 0xA83333,
  0x939394, 0xAAA9AB, 0xEED6D6, 0xFDFAFA,
  0xFDFDFD, 0xFFFEFE, 0x7E7D7F, 0xBB5F5F,
  0xBD6464, 0x858486, 0x9E9E9F, 0xA2A2A3,
  0xC2C2C3, 0xFEFEFE, 0x1B1B1E, 0x212024,
  0x252427, 0x2C2B2F, 0x5A595C, 0x6D6C6F,
  0xA22424, 0xA32828, 0xA42828, 0xA52C2C,
  0xAB3939, 0xAD3F3F, 0xAE4141, 0xAE4242,
  0xB04646, 0xB24A4A, 0xB55151, 0xC06A6A,
  0xC37171, 0xC67979, 0xC87E7E, 0xC87F7F,
  0x929193, 0xA4A4A6, 0xA9A9AB, 0xB9B9BA,
  0xBABABB, 0xBDBDBE, 0xCA8383, 0xD09090,
  0xD19494, 0xD29595, 0xD49A9A, 0xDAA8A8,
  0xDDAFAF, 0xDDB0B0, 0xDFB3B3, 0xDFB5B5,
  0xE1B8B8, 0xBFBFC0, 0xC8C8C9, 0xCDCDCE,
  0xD3D3D4, 0xE6C4C4, 0xE9CCCC, 0xECD2D2,
  0xEED8D8, 0xEFD9D9, 0xF1DFDF, 0xE8E8E8,
  0xECECEC, 0xF4E4E4, 0xF4E6E6, 0xF5E6E6,
  0xF6EAEA, 0xF0F0F0, 0xF5F5F5, 0xF9F0F0,
  0xF9F1F1, 0xFAF3F3, 0xFBF5F5, 0xFBF6F6,
  0xFBFBFB, 0xFCF8F8, 0xFEFCFC, 0xFEFDFD,
  0x070708, 0x141314, 0x242326, 0x242327,
  0x252428, 0x27262A, 0x2B2A2E, 0x313033,
  0x313034, 0x343337, 0x363539, 0x38373B,
  0x39383C, 0x3B3B3E, 0x3D3C3F, 0x3E3D40,
  0x424145, 0x49484B, 0x4A494C, 0x4A494D,
  0x4C4B4E, 0x4F4E51, 0x515053, 0x535255,
  0x555458, 0x575659, 0x5B5A5D, 0x5B5B5E,
  0x5C5B5E, 0x5D5D5F, 0x5F5F62, 0x646366,
  0x666667, 0x666568, 0x6E6E6F, 0x717173,
  0x727174, 0x767578, 0x767678, 0x777679,
  0x777779, 0xAC3C3C, 0xAC3D3D, 0xBD6565,
  0x807F81, 0x808082, 0x838284, 0x868688,
  0x878688, 0x878789, 0x8C8B8E, 0x8D8D8F,
  0x8E8E90, 0x919192, 0x939294, 0x939395,
  0x969597, 0x969698, 0x979799, 0x9D9C9E,
  0x9E9D9F, 0x9E9EA0, 0xA3A2A4, 0xA4A4A5,
  0xA5A4A6, 0xA6A6A8, 0xA7A6A8, 0xA8A7A9,
  0xA9A9AA, 0xAAAAAC, 0xABAAAC, 0xACABAD,
  0xADADAE, 0xAEAEAF, 0xAFAFB0, 0xB0AFB1,
  0xB0B0B1, 0xB4B3B5, 0xB5B4B6, 0xB6B6B7,
  0xBCBCBD, 0xBDBCBD, 0xBEBEBF, 0xDBAAAA,
  0xDCACAC, 0xC0C0C1, 0xC8C7C8, 0xCAC9CA,
  0xCCCCCD, 0xCECECF, 0xCFCFD0, 0xD1D1D2,
  0xD6D6D7, 0xD8D8D9, 0xD9D9DA, 0xDADADA,
  0xDBDBDB, 0xDCDCDC, 0xDEDDDE, 0xDEDEDE,
  0xF0DBDB, 0xF0DCDC, 0xE2E2E2, 0xE4E4E4,
  0xE5E4E5, 0xE9E9E9, 0xEAEAEB, 0xEBEBEB,
  0xECECED, 0xEEEEEE, 0xF7EDED, 0xF8EDED,
  0xF0F0F1, 0xF1F1F2, 0xF2F2F2, 0xF3F3F3,
  0xF3F3F4, 0xF4F4F4, 0xF7F7F7, 0xF8F8F8,
  0xF9F9F9, 0xFAFAFA, 0xFCFCFC
};

static GUI_CONST_STORAGE GUI_LOGPALETTE _PalSeggerLogo50 = {
  219,	// Number of entries
  1, 	// Has transparency
  &_ColorsSeggerLogo50[0]
};

static GUI_CONST_STORAGE unsigned char _acSeggerLogo50[] = {
  0x00, 0x0B, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02,
        0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x0B, 0x00,
  0x1E, 0x0C, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03,
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x0C, 0x1E,
  0x02, 0x10, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01,
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x10, 0x02,
  0x02, 0x06, 0x5E, 0x42, 0x13, 0x01, 0x01, 0x4B, 0x4C, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01,
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x06, 0x02,
  0x02, 0x06, 0x51, 0x0D, 0x33, 0x01, 0x01, 0x2F, 0x0F, 0x53, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01,
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x06, 0x02,
  0x02, 0x06, 0x01, 0x3C, 0x07, 0x43, 0x01, 0x52, 0x0F, 0x2E, 0x13, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01,
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x06, 0x02,
  0x02, 0x06, 0x01, 0x5F, 0x17, 0x27, 0x4E, 0x01, 0x49, 0x0D, 0x32, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01,
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x06, 0x02,
  0x02, 0x06, 0x01, 0x01, 0xCE, 0x28, 0x2D, 0x5D, 0x01, 0x3D, 0x07, 0x41, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01,
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x06, 0x02,
  0x02, 0x06, 0x54, 0x5A, 0x01, 0x4A, 0x24, 0x31, 0x01, 0x15, 0x18, 0x0E, 0x4D, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01,
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x06, 0x02,
  0x02, 0x06, 0x08, 0x30, 0x01, 0x01, 0x3E, 0x07, 0x40, 0x01, 0x58, 0x29, 0x2A, 0x59, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01,
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x06, 0x02,
  0x02, 0x06, 0x08, 0x07, 0x3F, 0x01, 0x15, 0x18, 0x0E, 0xC5, 0x01, 0x12, 0x26, 0x2B, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05,
        0x05, 0x05, 0x05, 0x05, 0x3A, 0x01, 0x06, 0x02,
  0x02, 0x06, 0x08, 0x07, 0x25, 0x12, 0x01, 0x57, 0x89, 0x2C, 0x5B, 0x01, 0x44, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04,
        0x04, 0x04, 0x04, 0x04, 0x3B, 0x01, 0x06, 0x02,
  0x02, 0x06, 0x08, 0x07, 0x07, 0x17, 0x01, 0x01, 0xB4, 0x07, 0xB3, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01,
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x06, 0x02,
  0x02, 0x06, 0x08, 0x07, 0x25, 0x12, 0x01, 0x57, 0x8A, 0x2C, 0x5B, 0x01, 0x44, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04,
        0x04, 0x04, 0x04, 0x04, 0x3B, 0x01, 0x06, 0x02,
  0x02, 0x06, 0x08, 0x07, 0x3F, 0x01, 0x15, 0x8B, 0x0E, 0xC4, 0x01, 0x12, 0x26, 0x2B, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05,
        0x05, 0x05, 0x05, 0x05, 0x3A, 0x01, 0x06, 0x02,
  0x02, 0x06, 0x08, 0x30, 0x01, 0x01, 0x3E, 0x07, 0x40, 0x01, 0x58, 0x29, 0x2A, 0x59, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01,
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x06, 0x02,
  0x02, 0x06, 0x54, 0x5A, 0x01, 0x4A, 0x24, 0x31, 0x01, 0x15, 0x18, 0x0E, 0x4D, 0x01, 0xBB, 0xA2, 0x37, 0xD8, 0x01, 0xB8, 0x09, 0x09, 0x1C, 0x5C, 0x01, 0x47, 0xA1, 0xB1, 0xD9, 0x01, 0x01, 0xBD, 0xA3, 0xAF, 0xD5, 0x01, 0x4F, 0x09, 0x09, 0x09, 0xC6, 0xD1,
        0xB5, 0x09, 0x1C, 0xCB, 0x01, 0x01, 0x06, 0x02,
  0x02, 0x06, 0x01, 0x01, 0xCF, 0x28, 0x2D, 0x5D, 0x01, 0x3D, 0x07, 0x41, 0x01, 0x38, 0x6D, 0x9E, 0x81, 0x23, 0x14, 0x1F, 0x86, 0x19, 0x91, 0x55, 0x90, 0x70, 0x9A, 0x7C, 0x7A, 0x01, 0x35, 0x6A, 0x97, 0x23, 0x6E, 0x1D, 0x8C, 0x73, 0x19, 0x19, 0x39, 0x9F,
        0x6C, 0x8F, 0x84, 0x21, 0x55, 0x01, 0x06, 0x02,
  0x02, 0x06, 0x01, 0x5F, 0x17, 0x27, 0x4E, 0x01, 0x49, 0x0D, 0x32, 0x01, 0x01, 0xAD, 0x68, 0x94, 0x45, 0xCA, 0xDA, 0x02, 0x92, 0x1A, 0xA9, 0x56, 0x63, 0xBA, 0x1D, 0x4F, 0x47, 0x01, 0x6B, 0xAB, 0x01, 0xCC, 0x46, 0x1D, 0x16, 0x78, 0x1A, 0x9D, 0xC8, 0x1B,
        0x74, 0x48, 0xB2, 0x65, 0x50, 0x01, 0x06, 0x02,
  0x02, 0x06, 0x01, 0x3C, 0x07, 0x43, 0x01, 0x52, 0x0F, 0x2E, 0x13, 0x01, 0x01, 0x14, 0xB7, 0x96, 0x75, 0x6F, 0xD7, 0x02, 0x98, 0x36, 0x37, 0xD0, 0x02, 0xBE, 0xC2, 0x7D, 0x62, 0xC3, 0x67, 0x38, 0xD2, 0x7E, 0x21, 0x45, 0x16, 0x22, 0x36, 0x11, 0xC9, 0x1B,
        0x69, 0x83, 0x76, 0x77, 0x01, 0x01, 0x06, 0x02,
  0x02, 0x06, 0x51, 0x0D, 0x33, 0x01, 0x01, 0x2F, 0x0F, 0x53, 0x01, 0x01, 0x01, 0xAA, 0x72, 0x46, 0xA7, 0x66, 0x56, 0x02, 0x99, 0x11, 0xA5, 0x50, 0x7F, 0x7B, 0x1C, 0x34, 0x1F, 0xC0, 0x8E, 0x71, 0x39, 0x35, 0x64, 0xB0, 0x16, 0x22, 0x11, 0x11, 0xB6, 0x1B,
        0x79, 0x01, 0xBF, 0x02, 0xD4, 0x01, 0x06, 0x02,
  0x02, 0x06, 0x5E, 0x42, 0x13, 0x01, 0x01, 0x4B, 0x4C, 0x01, 0x01, 0x01, 0x01, 0x14, 0xA6, 0x88, 0x8D, 0x48, 0x01, 0x1A, 0x0A, 0x0A, 0x95, 0xC7, 0xD6, 0x9B, 0x85, 0x9C, 0xA0, 0xCD, 0x14, 0xA4, 0x87, 0x34, 0xAC, 0xC1, 0xB9, 0x0A, 0x0A, 0x0A, 0xAE, 0xBC,
        0xA8, 0x01, 0x5C, 0x93, 0xD3, 0x01, 0x06, 0x02,
  0x02, 0x10, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01,
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x10, 0x02,
  0x20, 0x0C, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03,
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x0C, 0x20,
  0x00, 0x0B, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02,
        0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x0B, 0x00
};

static GUI_CONST_STORAGE GUI_BITMAP _bmSeggerLogo50 = {
  50,                // XSize
  25,                // YSize
  50,                // BytesPerLine
  8,                 // BitsPerPixel
  _acSeggerLogo50,   // Pointer to picture data (indices)
  &_PalSeggerLogo50  // Pointer to palette
};

/*********************************************************************
*
*       bmPlatine_250x200
*/
static GUI_CONST_STORAGE unsigned long _acPlatine_250x200[] = {
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFEFEFE, 0xE4E8E8E8, 0xE8E9EBEB, 0xC2D6D8D8, 0xBAD2D4D4, 0xBAD2D4D4, 0xBAD2D4D4,
        0xC6D7D9D9, 0xC2D5D7D7, 0xBAD2D4D4, 0xC2D5DAD8, 0xBED4D9D8, 0xC2D6DBDA, 0xC2D5DAD9, 0xBAD1D5D6, 0xBED3D7D8, 0xCAD9DCE0, 0xCEDBDEE2, 0xBAD2D9DC, 0xC6D7DEE1, 0xCAD9E0E3, 0xC2D6DDE0, 0xBAD2D9DC, 0xBAD2D9DC, 0xC2D6DDE0, 0xCAD9E0E3, 0xBAD2DBDF,
        0xC2D6DFE3, 0xBED3DADD, 0xBED3DADD, 0xC6D7DCDD, 0xBED4D9DA, 0xC2D6DCDB, 0xCAD9DEDD, 0xB7CFD8DB, 0xC6D8E1E4, 0xBAD2DADA, 0xB7D0D8D8, 0xBAD2D8D7, 0xC2D5DBDA, 0xE4E7EDEC, 0xE4E7ECEA, 0xFFF8F8F8, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFF7F7F7, 0xB7CFCFCF, 0x00B8BABA, 0x00929494, 0x00828484, 0x00838585, 0x00888A8A,
        0x008E9090, 0x00888A8A, 0x00868888, 0x00919695, 0x00939897, 0x00949998, 0x00939798, 0x00929697, 0x0093969A, 0x00919498, 0x008C8F93, 0x0090979A, 0x00979EA1, 0x009AA1A4, 0x00969DA0, 0x00959C9F, 0x00989FA2, 0x00959C9F, 0x008F9699, 0x00949DA1,
        0x0098A1A5, 0x00959EA2, 0x009CA3A6, 0x009CA3A6, 0x00979C9D, 0x00979C9D, 0x008E9394, 0x008D9699, 0x00949DA0, 0x008B9497, 0x00899191, 0x00868E8E, 0x00949A99, 0x00AEB4B3, 0x8DBAC0BF, 0xFBF4F4F4, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFBF4F4F4, 0x91BCBCBC, 0x00B9BEBD, 0x00A8ADAC, 0x00AAAFAE, 0x00A7ACAB, 0x00A1A6A5,
        0x009EA3A2, 0x009BA09F, 0x00A9AEAD, 0x00C6CBCA, 0x00D2D6D7, 0x00D5D9DA, 0x00D6DADB, 0x00DCDFE3, 0x00D8DBDF, 0x00C2C5CA, 0x00AFB2B7, 0x00C7CCCF, 0x00D4D9DC, 0x00DCE1E4, 0x00DBE0E3, 0x00E0E5E8, 0x00E4E9EC, 0x00D5DADD, 0x00BEC3C6, 0x00C8D0D7,
        0x00C9CFD4, 0x00CAD0D5, 0x00D8DEE3, 0x00D8DDE0, 0x00D1D6D9, 0x00D1D5D6, 0x00BCC0C1, 0x00AFB8BC, 0x00B3B9BE, 0x00B0B7BA, 0x00ABB2B5, 0x00A2A7A8, 0x00A7ACAD, 0x00B2B6B7, 0x00C0C5C4, 0xF4F0F0F0, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFF5F5F5, 0x85B6B6B6, 0x00ACB1B0, 0x00B4B9B8, 0x00C7CCCB, 0x00BCC1C0, 0x00AEB3B2,
        0x00A9AEAD, 0x00A7ACAB, 0x00BCC1C0, 0x00CFD4D5, 0x00EEF3F4, 0x00FAFFFF, 0x00FAFFFF, 0x00FAFFFF, 0x00F6FAFF, 0x00D4D8DD, 0x00BDC1C6, 0x00DEE1E6, 0x00F3F6FB, 0x00FBFEFF, 0x00F8FBFF, 0x00FBFEFF, 0x00FBFEFF, 0x00F8FBFF, 0x00DEE1E6, 0x00E6E9F1,
        0x00E0E3EB, 0x00E4E8ED, 0x00FBFEFF, 0x00FBFEFF, 0x00FDFEFF, 0x00FDFEFF, 0x00E7E8EC, 0x00BBBFC4, 0x00B6BABF, 0x00BABEC3, 0x00BABDC1, 0x00AEB1B5, 0x00B1B3B4, 0x00A5A7A8, 0x00B0B2B3, 0xF0EDEDED, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCFCFC, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFF8F8F8, 0x89B8B8B8, 0x00ACB1B0, 0x00B2B7B6, 0x00B9BEBD, 0x00A6ABAA, 0x00A1A6A5,
        0x00A6ABAA, 0x009DA2A1, 0x00A9AEAD, 0x00B4B9BA, 0x00E5EAEB, 0x00FAFFFF, 0x00F7FCFF, 0x00FAFFFF, 0x00E9EDF2, 0x00C7CBD0, 0x00B6BABF, 0x00C4C4CA, 0x00E9E9EF, 0x00FDFDFF, 0x00FAFAFF, 0x00F7F7FD, 0x00FCFCFF, 0x00EFEFF5, 0x00D4D4DA, 0x00B3B5BD,
        0x00B4B6BE, 0x00CDCFD7, 0x00F9F9FF, 0x00FDFDFF, 0x00FCFBFF, 0x00F7F6FA, 0x00CAC9CD, 0x00A7AAAF, 0x009A9DA2, 0x00A0A3A8, 0x00A7A8AC, 0x00A4A5A9, 0x00B0AFB1, 0x00A09FA1, 0x00B0AFB1, 0xECECECEC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCFCFC, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFB, 0xFFFFFFFC, 0xFFFFFFFE, 0xFFFCFCFC, 0xFFFBFBFB, 0xFFFEFFFD, 0xFFFEFFFB, 0xFFFFFFFB, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFEFFFD, 0xFFFEFFFD, 0xFFFDFEFC,
        0xFFFEFFFD, 0xFFFEFFFD, 0xFFFEFFFD, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFEFFFD, 0xFFFFFFFE,
        0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFDFFFB, 0xFFFDFFFB, 0xFFFDFFFB, 0xFFFDFFFB, 0xFFFDFFFB,
        0xFFFDFFFB, 0xFFFDFFFB, 0xFFFDFFFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFFFB, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFDFBFF,
        0xFFFFFDFF, 0xFFFDFCFE, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFDFCFE, 0xFFFFFDFF, 0xFFFDFBFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFCFF, 0xFFFDFBFF, 0xFFFCFAFF, 0xFFFFFEFF, 0xFFFFFEFF,
        0xFFFDFCFE, 0xFFFBFAFC, 0xFFFCFCFC, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFCFBFF, 0xFFFCFBFF, 0xFFFDFCFF, 0xFFFEFDFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFEFDFF,
        0xFFFEFDFF, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFBFF, 0xFFFEFBFF, 0xFFFFFDFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFFFF, 0xFFF6F7F5, 0x85B7B8B6, 0x00B6BBBA, 0x00AFB4B3, 0x00B7BCBB, 0x00A6ABAA, 0x008F9493,
        0x00969B9A, 0x00A5AAA9, 0x00B0B5B4, 0x00B1B7B6, 0x00E9EFEE, 0x00F4FAF9, 0x00F3F9F8, 0x00F8FEFD, 0x00CDD3D2, 0x009BA1A0, 0x008F9594, 0x00A0A3A7, 0x00A5A8AC, 0x00EDF0F4, 0x00FBFEFF, 0x00F3F6FA, 0x00FBFEFF, 0x00CBCED2, 0x0095989C, 0x008E9392,
        0x008E9392, 0x009DA2A1, 0x00FDFFFF, 0x00F9FBFB, 0x00FDFDFD, 0x00F9F9F9, 0x00AFAFAF, 0x00A3A8A7, 0x009CA1A0, 0x00989D9C, 0x00969B9A, 0x009CA1A0, 0x00A1A6A5, 0x00A6ABAA, 0x00B5BAB9, 0xE8ECEAF0, 0xFFFFFDFF, 0xFFFFFDFF, 0xFFFFFDFF, 0xFFFCFAFF,
        0xFFFDFBFF, 0xFFFFFDFF, 0xFFFBF9FF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFDFCFE, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFEFEFE, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFDFBFF, 0xFFFFFDFF, 0xFFFFFDFF, 0xFFF8F7F9, 0xFFFFFEFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFC, 0xFFFEFFFD, 0xFFFEFEFE, 0xFFFEFDFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFFFF, 0xFFFAFAFA, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFEFDFF,
        0xFFFEFDFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCFCFC, 0xFFFDFDFD, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFDFFFE, 0xFFFDFFFE, 0xFFFDFFFE, 0xFFFDFFFE, 0xFFFDFFFE,
        0xFFFDFFFE, 0xFFFDFFFE, 0xFFFDFFFE, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFDFEFA, 0xFFFCFDFB, 0xFFFDFEFC, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFEFF,
        0xFFFFFFFF, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFF, 0xFFFFFEFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFDFF, 0xFFFDFCFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFE,
        0xFFFFFFFE, 0xFFFEFFFD, 0xFFFFFFFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFEFFFB, 0xFFFEFFFB, 0xFFFDFEFA,
        0xFFFDFEFA, 0xFFFCFDF9, 0xFFFBFCF8, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFDFDFD, 0xFFFCFCFC, 0xFFFBFBFB, 0xFFFEFFFB,
        0xFFFEFFFB, 0xFFFEFFFB, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFBFAFE, 0xFFFFFEFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFE, 0xFFFFFFFC, 0xF7F6F8F2, 0x76B1B3AD, 0x00B1B6B5, 0x00A7ACAB, 0x00B3B8B7, 0x00ACB1B0, 0x00979C9B,
        0x00969B9A, 0x009EA3A2, 0x00A5AAA9, 0x00929897, 0x00A3A9A8, 0x009EA4A3, 0x009CA2A1, 0x00A0A6A5, 0x00959B9A, 0x00909695, 0x00979D9C, 0x00888C8D, 0x00939798, 0x00A3A7A8, 0x009FA3A4, 0x00A0A4A5, 0x00A9ADAE, 0x00A4A8A9, 0x00A1A5A6, 0x008C9190,
        0x00A1A6A5, 0x00A1A6A5, 0x00B9BBBB, 0x00B5B7B7, 0x00B6B6B6, 0x00AFAFAF, 0x00A7A7A7, 0x009DA2A1, 0x00A6ABAA, 0x00AEB3B2, 0x00A8ADAC, 0x00A4A9A8, 0x00A5AAA9, 0x00ABB0AF, 0x00BDC2C1, 0xF0EDEDED, 0xFFFDFDFD, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFDFEFC, 0xFFFDFEFC, 0xFFFEFFFD, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFDFEFC, 0xFFFCFCFC, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFE, 0xFFFDFEFA, 0xFFFFFFFB, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFCFBFF, 0xFFFCFBFF, 0xFFFFFDFF, 0xFFFEFCFF, 0xFFFFFDFF, 0xFFFFFDFF, 0xFFFFFDFF, 0xFFFFFDFF, 0xFFFFFDFF,
        0xFFFFFDFF, 0xFFFFFDFF, 0xFFFFFDFF, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFDFCFE,
        0xFFFDFCFE, 0xFFFDFCFE, 0xFFFDFCFE, 0xFFFDFCFE, 0xFFFDFCFE, 0xFFFDFCFE, 0xFFFDFCFE, 0xFFFEFDFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFDFCFE, 0xFFFCFDFF, 0xFFFCFDFF, 0xFFFCFDFF, 0xFFFDFEFF, 0xFFFDFEFF,
        0xFFFDFEFF, 0xFFFDFEFF, 0xFFFDFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFEFFFD, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFC,
        0xFFFFFFFE, 0xFFFCFDFB, 0xFFFEFFFD, 0xFFFEFFFD, 0xFFFCFDFB, 0xFFFFFFFE, 0xFFFFFFFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFEFFFB,
        0xFFFCFDF9, 0xFFFEFFFB, 0xFFFFFFFC, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFCFDFB, 0xFFFDFEFC, 0xFFFDFEFC, 0xFFFDFEFC, 0xFFFEFFFD, 0xFFFEFFFD, 0xFFFEFFFD, 0xFFFFFFFE, 0xFFFDFEFC,
        0xFFFDFEFC, 0xFFFDFEFC, 0xFFFDFEFC, 0xFFFDFEFC, 0xFFFDFEFC, 0xFFFDFEFC, 0xFFFDFEFC, 0xFFFEFFFB, 0xFFFEFFFB, 0xFFFEFFFB, 0xFFFEFFFB, 0xFFFEFFFB, 0xFFFEFFFB, 0xFFFEFFFB, 0xFFFEFFFB, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFC,
        0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFEFFFB, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFC,
        0xFFFFFFFC, 0xFFFEFFFB, 0xFFFEFFFB, 0xFFFDFEFA, 0xFFFCFDF9, 0xFFFBFCF8, 0xFFFAFBF7, 0xFFFDFEFC, 0xFFFFFFFE, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFB, 0xFFFCFEF8, 0xF4F5F8EF, 0x6EAFB2A9, 0x00B5BAB9, 0x00B7BCBB, 0x00B8BDBC, 0x00A4A9A8, 0x00969B9A,
        0x009DA2A1, 0x00969B9A, 0x00858A89, 0x00949998, 0x008D9291, 0x008E9392, 0x00979C9B, 0x00919695, 0x00898E8D, 0x00919695, 0x008E9392, 0x00979C9B, 0x00A8ADAC, 0x00989D9C, 0x00949998, 0x00979C9B, 0x00878C8B, 0x008B908F, 0x009A9F9E, 0x00909594,
        0x00A4A9A8, 0x00A3A8A7, 0x008C8E8E, 0x009A9C9C, 0x009D9D9D, 0x00838383, 0x00969696, 0x009DA2A1, 0x00A7ACAB, 0x00ABB0AF, 0x009DA2A1, 0x009A9F9E, 0x00A1A6A5, 0x00A4A9A8, 0x00B3B8B7, 0xF0F0F1ED, 0xFFFEFFFB, 0xFFFDFEFA, 0xFFFDFEFA, 0xFFFFFFFC,
        0xFFFDFEFA, 0xFFFCFDF9, 0xFFFBFCF8, 0xFFFEFFFD, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFEFFFD, 0xFFFDFEFC, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFBFCFA, 0xFFFEFFFB, 0xFFFEFFFA, 0xFFFCFFF6, 0xF7F8FBF2, 0xF7F9FDF2, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCFCFC, 0xFFFBFAFC, 0xFFFFFEFF, 0xFFFFFDFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF,
        0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFDFF, 0xFFFFFDFF, 0xFFFFFDFF, 0xFFFFFDFF, 0xFFFFFDFF, 0xFFFFFCFF, 0xFFFFFCFF, 0xFFFFFCFF, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFCFBFF, 0xFFFCFBFF, 0xFFFCFBFF, 0xFFFDFCFF, 0xFFFEFDFF,
        0xFFFEFDFF, 0xFFFEFDFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFFFBFF, 0xFFFDF9FE, 0xFFFDF9FE, 0xFFFFFCFF, 0xFFFFFDFF, 0xFFFFFCFE, 0xFFFEFBFD, 0xFFFFFCFE, 0xFFFFFFFE,
        0xFFFFFEFD, 0xFFFFFDFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFDFF, 0xFFFFFEFD, 0xFFFFFFFE, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFFFE, 0xFFFEFEFE, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFCFCFC,
        0xFFFCFCFC, 0xFFFCFBFD, 0xFFFCFBFD, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF,
        0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFEFEFE,
        0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFFFDFF, 0xFFFFFDFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF,
        0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFFFFFE, 0xFFFBFCFA, 0xFFF8F9F7, 0x76AFB0AE, 0x00A7ACAB, 0x00B9BEBD, 0x00B3B8B7, 0x009BA09F, 0x009A9F9E,
        0x00A3A8A7, 0x009CA1A0, 0x00909594, 0x009A9F9D, 0x00868B89, 0x00818684, 0x00898E8C, 0x007F8482, 0x007E8381, 0x008C918F, 0x00858A88, 0x00959A99, 0x00989D9C, 0x00818685, 0x00888D8C, 0x008F9493, 0x00797E7D, 0x00797E7D, 0x00838887, 0x00818684,
        0x008A8F8D, 0x00A0A5A3, 0x00858886, 0x008E918F, 0x008E8F8D, 0x00787977, 0x00838482, 0x00999E9C, 0x00A2A7A5, 0x00A6ABA9, 0x00969B99, 0x009BA09E, 0x00A9AEAC, 0x00A8ADAB, 0x00B2B7B5, 0xF0EDEDED, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFAF8FE, 0xFFFFFEFF, 0xFFFDFDFD, 0xFFFFFFFE, 0xFFFEFFFB, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFE, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFCFF, 0xFFFBFAFE, 0xFFFFFFFE, 0xFFFFFFF9, 0xFFFEFFF7, 0xFFFFFFF9, 0xFFFFFFFB, 0xFFFCFDF9, 0xFFFCFEF8, 0xFFFCFEF8, 0xFFFCFEF8, 0xFFFCFEF8, 0xFFFCFEF8,
        0xFFFCFEF8, 0xFFFCFEF8, 0xFFFCFEF8, 0xFFFFFFFB, 0xFFFFFFFB, 0xFFFFFFFA, 0xFFFFFFFA, 0xFFFFFFFA, 0xFFFFFFF9, 0xFFFFFFF9, 0xFFFFFFF9, 0xFFFFFFFB, 0xFFFFFFFB, 0xFFFFFFFB, 0xFFFFFFFB, 0xFFFFFFFB, 0xFFFFFFFB, 0xFFFFFFFB, 0xFFFFFFFB, 0xFFFFFFF9,
        0xFFFFFFF9, 0xFFFFFFF9, 0xFFFFFFF9, 0xFFFFFFF9, 0xFFFFFFF9, 0xFFFFFFF9, 0xFFFFFFF9, 0xFFFFFFF9, 0xFFFDFFF7, 0xFFFBFEF5, 0xFFFCFFF6, 0xFFFEFFF8, 0xFFFFFFF9, 0xFFFFFFF9, 0xFFFFFFF9, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFC,
        0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFB, 0xFFFFFFFB, 0xFFFFFFFB, 0xFFFFFFFB, 0xFFFFFFFB, 0xFFFFFFFB, 0xFFFFFFFB, 0xFFFFFFFB, 0xFFFFFDFF, 0xFFFFFDFF, 0xFFFFFDFF, 0xFFFFFDFF, 0xFFFFFEFF, 0xFFFFFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFA,
        0xFFFFFDFC, 0xFFFFFDFF, 0xFFFFFDFF, 0xFFFFFDFF, 0xFFFFFDFF, 0xFFFFFDFC, 0xFFFFFEFA, 0xFFFFFEFE, 0xFFFFFEFE, 0xFFFFFEFE, 0xFFFFFEFE, 0xFFFFFEFE, 0xFFFFFEFE, 0xFFFFFEFE, 0xFFFFFEFE, 0xFFFEFFFD, 0xFFFEFFFD, 0xFFFEFFFD, 0xFFFFFFFF, 0xFFFFFEFF,
        0xFFFFFEFF, 0xFFFFFEFF, 0xFFFCFBFF, 0xFFFDFCFF, 0xFFFDFCFF, 0xFFFDFCFF, 0xFFFDFCFF, 0xFFFDFCFF, 0xFFFDFCFF, 0xFFFDFCFF, 0xFFFDFCFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFDFCFF, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFFFEFF,
        0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF,
        0xFFFEFDFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFDFF, 0xFFFFFDFF, 0xFFFFFDFF, 0xFFFFFCFF, 0xFFFFFBFF, 0xFFFFFBFF, 0xFFFFFCFF, 0xFFFFFCFF, 0xFFFFFDFF,
        0xFFFFFDFF, 0xFFFFFDFF, 0xFFFFFDFF, 0xFFFEFCFF, 0xFFFDFBFF, 0xFFFDFBFF, 0xFFFCFAFF, 0xFFFFFEFF, 0xFFFCFBFD, 0xFFFCFBFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFF9F8FC, 0x5FA2A1A5, 0x00A1A6A5, 0x00B4B9B8, 0x00AEB3B2, 0x00A6ABAA, 0x00ACB1B0,
        0x00A4A9A8, 0x00A4A9A8, 0x00B9BEBD, 0x008E9391, 0x007F8482, 0x00747977, 0x00747977, 0x006F7472, 0x00747977, 0x00818684, 0x007B807E, 0x008E9391, 0x00838886, 0x00696E6C, 0x006D7270, 0x00828785, 0x007A7F7D, 0x00767B79, 0x00888D8B, 0x00989D9B,
        0x00878C8A, 0x00929795, 0x00838684, 0x00898C8A, 0x00868785, 0x00818280, 0x007B7C7A, 0x00787D7B, 0x008A8F8D, 0x009CA19F, 0x00959A98, 0x009EA3A1, 0x00A9AEAC, 0x00A0A5A3, 0x76ADB2B0, 0xECEDECF0, 0xFFFDFCFF, 0xFFFFFEFF, 0xFFFBFAFE, 0xFFFBFAFE,
        0xFFFEFDFF, 0xFFFCFBFF, 0xFFFDFCFF, 0xFFFFFDFF, 0xFFFFFDFF, 0xFFFFFDFF, 0xFFFFFDFF, 0xFFFFFDFF, 0xFFFFFDFF, 0xFFFFFDFF, 0xFFFFFDFF, 0xFFFEFAFF, 0xFFFFFDFF, 0xFFFAF9FB, 0xFFFFFFFE, 0xFFF8F9F7, 0xFFFDFCFE, 0xFFFCFAFF, 0xFFFFFBFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFBFF, 0xFFFCFBFF, 0xFFFFFFF9, 0xFFDEE4D1, 0xFFC2CBB0, 0xFFC9D2B7, 0xFFC2CBB1, 0xFFC2CAB3, 0xFFC1C9B2, 0xFFC0C8B1, 0xFFBFC7B0, 0xFFBEC6AF, 0xFFBEC6AF,
        0xFFBEC6AF, 0xFFBFC7B0, 0xFFBFC7B0, 0xFFC3C6B0, 0xFFC3C6B0, 0xFFC3C6B0, 0xFFC3C6B0, 0xFFC3C6B0, 0xFFC3C6B0, 0xFFC4C7B1, 0xFFC4C7B1, 0xFFCCD2C1, 0xFFCCD2C1, 0xFFCDD3C2, 0xFFCDD3C2, 0xFFCDD3C2, 0xFFCCD2C1, 0xFFCBD1C0, 0xFFCAD0BF, 0xFFCFD6C1,
        0xFFCFD6C1, 0xFFCFD6C1, 0xFFCFD6C1, 0xFFCFD6C1, 0xFFCFD6C1, 0xFFCFD6C1, 0xFFCFD6C1, 0xFFD3DAC5, 0xFFD1D8C3, 0xFFCFD6C1, 0xFFD1D8C3, 0xFFD5DCC7, 0xFFD9E0CB, 0xFFDAE1CC, 0xFFDAE1CC, 0xFFDEE2CF, 0xFFDEE2CF, 0xFFDEE2CF, 0xFFDEE2CF, 0xFFDEE2CF,
        0xFFDEE2CF, 0xFFDEE2CF, 0xFFDEE2CF, 0xFFDCE2CF, 0xFFDCE2CF, 0xFFDCE2CF, 0xFFDCE2CF, 0xFFDCE2CF, 0xFFDCE2CF, 0xFFDCE2CF, 0xFFDCE2CF, 0xFFE3E0DB, 0xFFE2E0D8, 0xFFE6E5DB, 0xFFEEEEE2, 0xFFF0F0E2, 0xFFEEEFDF, 0xFFEEF0DD, 0xFFF2F4E1, 0xFFF2F4E0,
        0xFFF0F0E2, 0xFFF0EEE6, 0xFFEAE6E5, 0xFFEAE6E5, 0xFFF0EEE6, 0xFFF0F0E2, 0xFFF2F4E0, 0xFFF1F2E2, 0xFFF1F2E2, 0xFFF1F2E2, 0xFFF1F2E2, 0xFFF1F2E2, 0xFFF1F2E2, 0xFFF1F2E2, 0xFFF1F2E2, 0xFFF6FCEB, 0xFFF6FCEB, 0xFFF4F9EA, 0xFFF2F6EA, 0xFFF4F8ED,
        0xFFF6F9F0, 0xFFF6F8F2, 0xFFF3F5EF, 0xFFF7FAF1, 0xFFF7FAF1, 0xFFF7FAF1, 0xFFF7FAF1, 0xFFF7FAF1, 0xFFF7FAF1, 0xFFF7FAF1, 0xFFF7FAF1, 0xFFF6F9F0, 0xFFF6F9F0, 0xFFF6F9F0, 0xFFF7FAF1, 0xFFF9FCF3, 0xFFFBFEF5, 0xFFFDFFF7, 0xFFFFFFF9, 0xFFFEFFF8,
        0xFFFEFFF8, 0xFFFEFFF8, 0xFFFEFFF8, 0xFFFEFFF8, 0xFFFEFFF8, 0xFFFEFFF8, 0xFFFEFFF8, 0xFFFFFFFB, 0xFFFFFFFB, 0xFFFFFFFB, 0xFFFFFFFB, 0xFFFFFFFB, 0xFFFFFFFB, 0xFFFFFFFB, 0xFFFFFFFB, 0xFFFAFCF6, 0xFFFAFCF6, 0xFFFAFCF6, 0xFFFBFDF7, 0xFFFCFEF8,
        0xFFFEFFFA, 0xFFFFFFFB, 0xFFFFFFFB, 0xFFFFFFFB, 0xFFFFFFFB, 0xFFFFFFFB, 0xFFFFFFFB, 0xFFFFFFFB, 0xFFFFFFFB, 0xFFFFFFFB, 0xFFFFFFFB, 0xFFFFFFF9, 0xFFFFFFF9, 0xFFFFFFF9, 0xFFFFFFF9, 0xFFFFFFF9, 0xFFFFFFF9, 0xFFFFFFF9, 0xFFFFFFF9, 0xFFFFFFFC,
        0xFFFFFFFC, 0xFFFFFFFC, 0xFFFEFFFB, 0xFFFEFFFB, 0xFFFEFFFB, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFB, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFDFEFC, 0xFFFEFFFD, 0xFFFFFFFF, 0xFFF5F5F5, 0x6EAAA9AB, 0x009FA4A3, 0x00ABB0AF, 0x009DA2A1, 0x00989D9C, 0x00A3A8A7,
        0x009DA2A1, 0x00989D9C, 0x00A2A7A6, 0x00848883, 0x00818580, 0x00777B76, 0x00757974, 0x00747873, 0x00777B76, 0x007E827D, 0x00757974, 0x007A807B, 0x00787E79, 0x00656B66, 0x00606661, 0x00797F7A, 0x00787E79, 0x006F7570, 0x00888E89, 0x00A5ABA6,
        0x008C928D, 0x007C827D, 0x00757974, 0x00818580, 0x007D7E7A, 0x007E7F7B, 0x00797A76, 0x00747A75, 0x007E847F, 0x008F9590, 0x008F9590, 0x00A1A7A2, 0x00ABB1AC, 0x009BA19C, 0x6EA9AFAA, 0xFFF9FAF6, 0xFFFEFFFB, 0xFFFFFFFC, 0xFFFDFEFA, 0xFFFCFDF9,
        0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFEFFFB, 0xFFFDFEFA, 0xFFFDFEFA, 0xFFFDFEFA, 0xFFFDFEFA, 0xFFFDFEFA, 0xFFFFFFFE, 0xFFFCFEF8, 0xFFFCFFF5, 0xFFFFFFF7, 0xFFFCFFF6, 0xFFFFFFFF, 0xFFFCF9FF, 0xFFFFFAFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFAFF, 0xFFFDFCFE, 0xF0F7FCED, 0x2698A383, 0x004F5D33, 0x00506031, 0x00425223, 0x00404F23, 0x003B491F, 0x003A481E, 0x0038461C, 0x0036441A, 0x00354319,
        0x00354319, 0x0036441A, 0x0037451B, 0x0039421A, 0x0039421A, 0x003B441C, 0x003C451D, 0x003E471F, 0x003F4820, 0x00404921, 0x00414A22, 0x00465032, 0x00485234, 0x004C5638, 0x004F593B, 0x00515B3D, 0x00525C3E, 0x00525C3E, 0x00525C3E, 0x004E5938,
        0x004E5938, 0x004E5938, 0x004E5938, 0x004E5938, 0x004E5938, 0x004E5938, 0x004E5938, 0x004E5938, 0x004C5736, 0x004B5635, 0x004D5837, 0x00505B3A, 0x00525D3C, 0x00515C3B, 0x004F5A39, 0x00515B37, 0x00505A36, 0x00505A36, 0x004F5935, 0x004F5935,
        0x004E5834, 0x004E5834, 0x004E5834, 0x004E5939, 0x004E5939, 0x00505B3B, 0x00515C3C, 0x00535E3E, 0x00545F3F, 0x00556040, 0x00566141, 0x005A6140, 0x00515835, 0x004F5732, 0x00576038, 0x005F693E, 0x005D683A, 0x00596535, 0x00596533, 0x00576234,
        0x005D663E, 0x00656B4C, 0x005E6249, 0x005E6249, 0x00656B4C, 0x005D663E, 0x00576234, 0x005A6636, 0x005A6636, 0x005A6636, 0x005A6636, 0x005A6636, 0x005A6636, 0x005A6636, 0x005A6636, 0x005A693D, 0x00616F45, 0x00647249, 0x00616E48, 0x005E6948,
        0x00606B4B, 0x00646E50, 0x00677153, 0x005E6949, 0x005E6949, 0x005E6949, 0x005E6949, 0x005E6949, 0x005E6949, 0x005E6949, 0x005E6949, 0x005E6949, 0x005E6949, 0x005E6949, 0x00606B4B, 0x00626D4D, 0x00667151, 0x00697454, 0x006B7656, 0x00687353,
        0x00687353, 0x00687353, 0x00687353, 0x00687353, 0x00687353, 0x00687353, 0x00687353, 0x00687254, 0x00687254, 0x00687254, 0x00687254, 0x00687254, 0x00687254, 0x00687254, 0x00687254, 0x00677153, 0x00677153, 0x00687254, 0x00697355, 0x006B7557,
        0x006E785A, 0x00717B5D, 0x00737D5F, 0x00747E60, 0x00737D5F, 0x00737D5F, 0x00727C5E, 0x00727C5E, 0x00717B5D, 0x00707A5C, 0x00707A5C, 0x00727859, 0x0073795A, 0x00747A5B, 0x00747A5B, 0x0073795A, 0x00717758, 0x006F7556, 0x006E7455, 0x00677056,
        0x00677056, 0x00677056, 0x00697258, 0x006B745A, 0x006F785E, 0x00737C62, 0x00757E64, 0x00778066, 0x007A8369, 0x007D856E, 0x00747B66, 0x00787E6B, 0x00767C6B, 0x047C8271, 0x00787D6E, 0x00949998, 0x00959A99, 0x00828786, 0x00787D7C, 0x007D8281,
        0x00848988, 0x00828786, 0x006F7473, 0x00737772, 0x006F736E, 0x00626661, 0x005E625D, 0x005E625D, 0x00666A65, 0x00747873, 0x00727671, 0x00636A63, 0x006A716A, 0x00616861, 0x005C635C, 0x00666D66, 0x006B726B, 0x006F766F, 0x00798079, 0x00717772,
        0x006F7570, 0x00686E69, 0x00676B66, 0x00666A65, 0x005F605C, 0x00656662, 0x006F706C, 0x006F7570, 0x00696F6A, 0x00707671, 0x00737974, 0x008C928D, 0x009AA09B, 0x008D938E, 0x67A6ACA7, 0x3198A089, 0x13889079, 0x178B937C, 0x1E8F9780, 0x22919982,
        0x359BA38C, 0x3D9EA68F, 0x41A0A891, 0x39A0A98E, 0x3DA1AA8F, 0x41A4AD92, 0x45A5AE93, 0x45A6AF94, 0x45A6AF94, 0x45A5AE93, 0x41A4AD92, 0x4CAAB398, 0x48ABB696, 0x48AEBA96, 0x4CAFBB97, 0x76C0C9AE, 0xFFFFFFF5, 0xFFFFFFFF, 0xFFFDFAFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDF8FF, 0xFFFFFEFF, 0xF7FFFFF2, 0x13929F79, 0x00455722, 0x00566A2F, 0x0045591E, 0x003D5017, 0x003F521B, 0x003D5019, 0x00394C15, 0x00374A13, 0x00354811,
        0x00364912, 0x00384B14, 0x00394C15, 0x00404C1A, 0x00414D1B, 0x00434F1D, 0x0045511F, 0x00485422, 0x004B5725, 0x004D5927, 0x004E5A28, 0x0053603A, 0x0057643E, 0x005E6B45, 0x0064714B, 0x006A7751, 0x006E7B55, 0x006F7C56, 0x00707D57, 0x006F7D53,
        0x006F7D53, 0x006F7D53, 0x006F7D53, 0x006F7D53, 0x006F7D53, 0x006F7D53, 0x006F7D53, 0x006C7A50, 0x006A784E, 0x0069774D, 0x006A784E, 0x006B794F, 0x0069774D, 0x00647248, 0x00606E44, 0x005C693B, 0x005C693B, 0x005B683A, 0x005A6739, 0x00596638,
        0x00586537, 0x00586537, 0x00576436, 0x005C6A41, 0x005D6B42, 0x005F6D44, 0x00616F46, 0x00647249, 0x0067754C, 0x0069774E, 0x006A784F, 0x006D7C43, 0x0055642A, 0x00405013, 0x003F5011, 0x00455714, 0x00465914, 0x0044580F, 0x0043570E, 0x00425510,
        0x00556528, 0x006F7C48, 0x00727C51, 0x00727C51, 0x006F7C48, 0x00556528, 0x00425510, 0x00465A12, 0x00465A12, 0x00465A12, 0x00465A12, 0x00465A12, 0x00465A12, 0x00465A12, 0x00465A12, 0x00415716, 0x00556A2B, 0x00697E40, 0x006E8247, 0x006A7D46,
        0x00687A45, 0x006C7C4C, 0x006F7F4F, 0x00697B46, 0x00697B46, 0x00697B46, 0x00697B46, 0x00697B46, 0x00697B46, 0x00697B46, 0x00697B46, 0x006A7C47, 0x00697B46, 0x00677944, 0x00667843, 0x00657742, 0x00667843, 0x00677944, 0x00677944, 0x00657742,
        0x00657742, 0x00657742, 0x00657742, 0x00657742, 0x00657742, 0x00657742, 0x00657742, 0x00627340, 0x00627340, 0x00627340, 0x00627340, 0x00627340, 0x00627340, 0x00627340, 0x00627340, 0x00637441, 0x00627340, 0x0060713E, 0x005E6F3C, 0x005D6E3B,
        0x005E6F3C, 0x005F703D, 0x005F703D, 0x005D6E3B, 0x005D6E3B, 0x005B6C39, 0x005A6B38, 0x00586936, 0x00576835, 0x00556633, 0x00556633, 0x00576430, 0x00586531, 0x00576430, 0x0054612D, 0x004E5B27, 0x00475420, 0x003F4C18, 0x003B4814, 0x00314112,
        0x002F3F10, 0x002B3B0C, 0x00283809, 0x00263607, 0x00253506, 0x00263607, 0x00273708, 0x00253309, 0x00253309, 0x0029370E, 0x0026330D, 0x002D3915, 0x00222D0C, 0x00495434, 0x00959F81, 0x00A3A8A7, 0x00939897, 0x00858A89, 0x007E8382, 0x006C7170,
        0x00696E6D, 0x00747978, 0x00656A69, 0x00696D68, 0x00696D68, 0x00696D68, 0x006E726D, 0x00696D68, 0x00656964, 0x00696D68, 0x00616560, 0x00535A53, 0x00575E57, 0x005C635C, 0x005E655E, 0x004E554E, 0x00535A53, 0x00646B64, 0x004E554E, 0x005A605B,
        0x00595F5A, 0x005C625D, 0x00676B66, 0x00676B66, 0x00696A66, 0x00636460, 0x00646561, 0x00636964, 0x005E645F, 0x006A706B, 0x006D736E, 0x00838984, 0x00909691, 0x008F9590, 0x00B9BFBA, 0x0048562D, 0x00233108, 0x001F2D04, 0x0025330A, 0x00243209,
        0x0029370E, 0x002A380F, 0x002C3A11, 0x002D3D0D, 0x00324212, 0x00394919, 0x00415121, 0x00475727, 0x00495929, 0x004A5A2A, 0x004A5A2A, 0x00475727, 0x0051632E, 0x004E612A, 0x003D4F1A, 0x0068774B, 0xFFEAF3D8, 0xFFFFFFF8, 0xFFFCFCFC, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFB, 0xFFFFFCFF, 0xFFFAFFFF, 0x1B909C7E, 0x00535C29, 0x00595C2A, 0x00484F1C, 0x003E5013, 0x00374B1E, 0x0035491C, 0x00314419, 0x002E4017, 0x002C3E17,
        0x002B3B19, 0x002B3B19, 0x002B3A1A, 0x002A4218, 0x0030471A, 0x00374A19, 0x003C4B18, 0x00414E1A, 0x0047531F, 0x004A5622, 0x004A5624, 0x004C6529, 0x0056673C, 0x005F654C, 0x00686B55, 0x00717656, 0x006E764D, 0x0069724A, 0x006D7655, 0x006B7955,
        0x006B7955, 0x006B7955, 0x006B7A54, 0x006C7B55, 0x006C7C53, 0x006B7B52, 0x006B7B52, 0x0065794A, 0x0066774C, 0x0065734F, 0x00647151, 0x00657050, 0x00626E4A, 0x005F6B41, 0x005B683A, 0x0058652D, 0x0056632B, 0x00536028, 0x00536028, 0x00546129,
        0x0055622A, 0x00546129, 0x00536028, 0x00576629, 0x0058672E, 0x005B6735, 0x00606A3F, 0x00636E48, 0x0067714D, 0x00687352, 0x00697453, 0x00707D5D, 0x004A5933, 0x003B4C20, 0x003F521F, 0x00475B26, 0x00435625, 0x00536439, 0x0057673E, 0x00374C15,
        0x004C5F2E, 0x00708156, 0x0074825E, 0x006D7B57, 0x0071805A, 0x0048592D, 0x003B4D1E, 0x004A5C27, 0x00445621, 0x004A5C27, 0x00576934, 0x004D5F2A, 0x00465823, 0x0052642F, 0x00536530, 0x003B4F14, 0x005B6D38, 0x0077865A, 0x00727F59, 0x00707C58,
        0x0075815D, 0x006F7D53, 0x00748357, 0x0076825E, 0x00717D59, 0x00727F59, 0x006C7A51, 0x00738256, 0x006E7E4F, 0x00728252, 0x006F7F4F, 0x00728155, 0x00738256, 0x00728155, 0x006F7E52, 0x00707F53, 0x00748357, 0x00768559, 0x00748357, 0x00748258,
        0x00738157, 0x00717F55, 0x00707E54, 0x00707E54, 0x00717F55, 0x00728056, 0x00738157, 0x006C7B4F, 0x00708051, 0x00728253, 0x00718151, 0x0071824F, 0x00738550, 0x0071834E, 0x006D7F4A, 0x006F7F56, 0x00708057, 0x00728259, 0x0073835A, 0x00718158,
        0x006F7F56, 0x006E7E55, 0x006E7E55, 0x006E7C53, 0x006F7D54, 0x00707E55, 0x006F7D54, 0x006B7950, 0x0069774E, 0x0068764D, 0x0068764D, 0x0066744A, 0x0066744A, 0x00627046, 0x005A683F, 0x005F6D44, 0x005B6940, 0x0043502A, 0x003B4822, 0x0036411B,
        0x0039431F, 0x002F391B, 0x00394228, 0x00323C25, 0x00253016, 0x00323E22, 0x00324122, 0x0032401C, 0x00303E1C, 0x00323E20, 0x00374228, 0x0037402B, 0x00464E3D, 0x006F7667, 0x00B2B9AC, 0x00AEB5B8, 0x00949B9E, 0x007F8787, 0x00666E6E, 0x0058605F,
        0x005C6463, 0x005A6360, 0x005C6562, 0x005E655E, 0x00596059, 0x005C635C, 0x005F6560, 0x005D635E, 0x00606563, 0x00616664, 0x005B605E, 0x005E625C, 0x005E625C, 0x005F635D, 0x005B5F59, 0x00636761, 0x005A5E58, 0x005C605A, 0x0060645E, 0x0061665D,
        0x0062675E, 0x00676A61, 0x0063645A, 0x006A695F, 0x00706E63, 0x0069655A, 0x006F6C5E, 0x0062645E, 0x00666862, 0x006A6B67, 0x00717270, 0x007A797B, 0x00868589, 0x00A7A5AB, 0x00CECBD4, 0x0078846E, 0x0027341C, 0x001F2C12, 0x002C3B1C, 0x001E2E0C,
        0x0021330C, 0x002F4118, 0x00273A0F, 0x002E3D1D, 0x00334222, 0x00485737, 0x005F6E4E, 0x00697858, 0x00677656, 0x00657454, 0x00697858, 0x006A7554, 0x006A7751, 0x006D7B51, 0x00617044, 0x00616D49, 0xFFF3F9E6, 0xFFFFFFFE, 0xFFFFFCFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFBF9, 0xFFFFFAFF, 0xFFF9FBFF, 0x2A8C9685, 0x004C542F, 0x00525331, 0x003E4522, 0x002D4015, 0x001E3D1C, 0x001D3C1B, 0x001B3A1B, 0x001A381B, 0x0019361C,
        0x0019361C, 0x0019361D, 0x001A371E, 0x001E3116, 0x0027391C, 0x002E3D1D, 0x0034401C, 0x003A451D, 0x00404A20, 0x00444E23, 0x00495328, 0x004C642E, 0x0051653B, 0x0058654B, 0x00626D53, 0x00677553, 0x0063754E, 0x0062734E, 0x00667559, 0x00697753,
        0x00697753, 0x00697852, 0x00697852, 0x00697852, 0x00697950, 0x0068784F, 0x0068784F, 0x00647549, 0x0063734A, 0x0062704C, 0x00636E4D, 0x00616D49, 0x005F6B41, 0x00596737, 0x00556530, 0x00566226, 0x00535F23, 0x00505C20, 0x004F5B1F, 0x00505C20,
        0x00505C20, 0x004F5B1F, 0x004E5A1E, 0x00526124, 0x00536127, 0x0055622E, 0x00596535, 0x005D693F, 0x00626D45, 0x0065704A, 0x0065714D, 0x0064724E, 0x0046562D, 0x0037481C, 0x00506330, 0x00576A37, 0x003D501F, 0x004E5F33, 0x0048582F, 0x00384C17,
        0x004E6130, 0x006E7F54, 0x006E7C58, 0x00697753, 0x006F7E58, 0x0048592D, 0x003B4D1E, 0x00536334, 0x00586839, 0x005A6A3B, 0x00586839, 0x00506031, 0x00556536, 0x005C6C3D, 0x004A5A2B, 0x00384B14, 0x00586936, 0x00758458, 0x00738158, 0x00707D57,
        0x00748259, 0x006E7D51, 0x00728252, 0x00707E55, 0x006F7D54, 0x00758359, 0x00728056, 0x0077865A, 0x00718054, 0x00758556, 0x00758556, 0x00707F53, 0x00718054, 0x00707F53, 0x006D7C50, 0x006E7D51, 0x00718054, 0x00718054, 0x006E7D51, 0x006E7C52,
        0x006F7D53, 0x00707E54, 0x00717F55, 0x00728056, 0x00728056, 0x00717F55, 0x00707E54, 0x00748259, 0x00758359, 0x00738157, 0x00707E54, 0x00707E54, 0x00728056, 0x00728056, 0x00707E54, 0x006D7D54, 0x006E7E55, 0x006E7E55, 0x006D7D54, 0x006B7B52,
        0x006A7A51, 0x006A7A51, 0x00697950, 0x006E7C53, 0x006E7C53, 0x006D7B52, 0x006B7950, 0x0069774E, 0x0068764D, 0x0069774E, 0x006A784F, 0x00657349, 0x00657349, 0x00647248, 0x005D6B42, 0x005A683F, 0x004C5A31, 0x003C4923, 0x0045522C, 0x00767D62,
        0x008C927B, 0x00929683, 0x009A9E92, 0x00989C91, 0x008A9184, 0x00878E7F, 0x00747C6B, 0x008E9783, 0x0099A28E, 0x00878E7F, 0x006E7469, 0x00797D77, 0x00777B76, 0x007E8080, 0x00AAACAC, 0x00B5BAB9, 0x00A8ADAC, 0x00A7ACAA, 0x00A1A6A4, 0x009CA29D,
        0x009DA39E, 0x00969C97, 0x00949A95, 0x00949C92, 0x008D948D, 0x008D948D, 0x008D948D, 0x00888E89, 0x00868C87, 0x00858A88, 0x00808583, 0x00838988, 0x007E8483, 0x00828887, 0x00808685, 0x00858B8A, 0x00828887, 0x008A908F, 0x008D9392, 0x00808C8C,
        0x00808C8C, 0x00869090, 0x00838D8D, 0x00858D8D, 0x00808888, 0x00787D7E, 0x00808586, 0x00898B85, 0x008A8C86, 0x00838480, 0x00858682, 0x009A9B99, 0x00ADAEAC, 0x00B2B2B2, 0x00B1B1B1, 0x0098A096, 0x00838B80, 0x006F786B, 0x005B6555, 0x006D7766,
        0x0065705C, 0x00606B57, 0x006E7A64, 0x00747E6D, 0x0066705F, 0x007D8776, 0x00919B8A, 0x0086907F, 0x008A9483, 0x0096A08F, 0x008B9584, 0x00768160, 0x006C7953, 0x006A784E, 0x00657448, 0x006A7652, 0xFFF7FDEA, 0xFFFFFFFE, 0xFFFBF8FF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xF0FFFFEE, 0xFFFFFFFC, 0xF7F2FFFD, 0x1E80997F, 0x00344C24, 0x00314522, 0x0028401E, 0x001D3F16, 0x001B3916, 0x001B3916, 0x001A3815, 0x001A3716, 0x00193517,
        0x00193517, 0x00193518, 0x00193518, 0x00143013, 0x001A3618, 0x001C3715, 0x001D3811, 0x00253E12, 0x002C4513, 0x00344C16, 0x003E561C, 0x003D5525, 0x00435831, 0x00516443, 0x005B704F, 0x005C734D, 0x005B734B, 0x005A724F, 0x005B7154, 0x0064724E,
        0x0064734D, 0x0065744E, 0x0065744E, 0x0065754C, 0x0064744B, 0x0064754A, 0x0064754A, 0x00617148, 0x00617148, 0x00616E48, 0x005F6D44, 0x005B6A3E, 0x00576633, 0x00506128, 0x004C5E21, 0x004F5A1B, 0x004E591A, 0x004C5718, 0x004C5718, 0x004D5819,
        0x004F5A1B, 0x004F5A1B, 0x004F5A1B, 0x004B5A1C, 0x004C5B1E, 0x004F5D23, 0x00515F29, 0x00566230, 0x005A6739, 0x005F6B41, 0x00636F45, 0x0063724C, 0x0046572C, 0x002E4011, 0x00516433, 0x00586B3A, 0x00324415, 0x004B5C31, 0x0045552C, 0x002E4011,
        0x004B5C30, 0x006C7C53, 0x006D7C56, 0x006C7B55, 0x006D7D54, 0x00435429, 0x00304213, 0x005E6C42, 0x0056643A, 0x004C5A30, 0x0049572D, 0x00435127, 0x00455329, 0x004B592F, 0x003F4D23, 0x00364714, 0x00566637, 0x00738256, 0x00728056, 0x006F7D53,
        0x00738354, 0x0071824F, 0x0072844F, 0x00708051, 0x006F7F50, 0x00748455, 0x00738256, 0x00748357, 0x006D7C50, 0x00707F53, 0x00728155, 0x00718054, 0x00718054, 0x00707F53, 0x006E7D51, 0x006F7E52, 0x00718054, 0x00707F53, 0x006E7D51, 0x00717F55,
        0x00728056, 0x00738157, 0x00738157, 0x00728056, 0x00717F55, 0x00707E54, 0x00707E54, 0x00717F56, 0x00717F56, 0x006F7C56, 0x006E7B55, 0x006F7B57, 0x00737E5D, 0x00737E5D, 0x00707B5B, 0x00708057, 0x006F7F56, 0x006D7D54, 0x006C7C53, 0x006B7B52,
        0x006A7A51, 0x006A7A51, 0x006A7A51, 0x006D7B52, 0x006C7A51, 0x006A784F, 0x006A784F, 0x006A784F, 0x006A784F, 0x0069774E, 0x0069774E, 0x00657349, 0x00637147, 0x00637147, 0x00616F46, 0x005A683F, 0x00425027, 0x0033401A, 0x0048552F, 0x00555849,
        0x00636559, 0x0060605A, 0x00686967, 0x00757575, 0x00757575, 0x00686B69, 0x004B4F4A, 0x006C706B, 0x008E918F, 0x00B3B5B5, 0x00A5A6AA, 0x00AAAAB0, 0x00AAA9B3, 0x00B1AFBB, 0x00AFADB9, 0x0080827C, 0x007C7E78, 0x008A8C86, 0x0095988F, 0x00989B92,
        0x00999D92, 0x0095998E, 0x0093978C, 0x0082877E, 0x007D8279, 0x007E837A, 0x0081857F, 0x007F837D, 0x007D817C, 0x007E827D, 0x007E827D, 0x00808887, 0x00798180, 0x007F8786, 0x007F8786, 0x007F8786, 0x007E8685, 0x0088908F, 0x0088908F, 0x008B9491,
        0x00878F8E, 0x00878F8E, 0x00868E8D, 0x00858D8D, 0x007D8585, 0x00747C7C, 0x007A8184, 0x00A0A19D, 0x00AFB1AB, 0x00B3B5AF, 0x00ACAFA6, 0x00A9ACA3, 0x00A3A79C, 0x0091958A, 0x007F8378, 0x008D8F90, 0x00B0B2B3, 0x00BABCBD, 0x008C8E8F, 0x009A9B9F,
        0x0095969A, 0x009D9EA2, 0x00A6A7AB, 0x00575A58, 0x004C4F4D, 0x00686B69, 0x00828583, 0x00797C7A, 0x00848785, 0x00989B99, 0x008A8D8B, 0x0075805F, 0x006B7852, 0x0069774D, 0x0069784C, 0x006D7955, 0xFFF4FAE7, 0xFFFEFFFD, 0xFFFCF9FF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xF0F4FEEE, 0xCADAEAF0, 0xA0C4E4F1, 0x006C9892, 0x00305B4E, 0x00284D49, 0x00214B4A, 0x001B4E46, 0x00294D47, 0x002A4E48, 0x00294D47, 0x00294D47, 0x00284C46,
        0x00264A44, 0x00254844, 0x00244743, 0x001B4342, 0x001D4543, 0x0018413C, 0x00143F34, 0x00194331, 0x001B4429, 0x00163E1B, 0x00153C16, 0x003B4E23, 0x003B4F25, 0x00455A33, 0x004C643A, 0x00466135, 0x00486135, 0x0050663C, 0x0051663F, 0x005D6C46,
        0x005F6E48, 0x0061704A, 0x00617148, 0x00617148, 0x00617247, 0x00617247, 0x00617247, 0x00606F49, 0x00616F46, 0x005E6C42, 0x005B6B3C, 0x00576732, 0x00506227, 0x004B5C1C, 0x00475916, 0x004D5819, 0x004C5718, 0x004B5617, 0x004A5516, 0x004B5617,
        0x004C5718, 0x004D5819, 0x004E591A, 0x00495618, 0x00485719, 0x004A591B, 0x004D5C1F, 0x00505F25, 0x0056632F, 0x005B6939, 0x00606D41, 0x0063764B, 0x00405328, 0x00273B0E, 0x00425629, 0x00495D30, 0x002F4217, 0x004E6037, 0x00506239, 0x00314217,
        0x004E5E35, 0x006E7E55, 0x006E7E55, 0x00708057, 0x006F8055, 0x0047582D, 0x00304115, 0x004E5F33, 0x0046572B, 0x0046572B, 0x00546539, 0x0056673B, 0x00536438, 0x0058693D, 0x00546539, 0x00334418, 0x00546539, 0x006F8054, 0x00708155, 0x006C7E4F,
        0x00708352, 0x00728552, 0x00718550, 0x00728554, 0x00708352, 0x00708253, 0x006F8152, 0x006E7F53, 0x006B7C51, 0x006C7D52, 0x006F7F56, 0x00738256, 0x00728155, 0x00718054, 0x00707F53, 0x00728155, 0x00748357, 0x00748357, 0x00738256, 0x006E7F54,
        0x006E7F54, 0x006D7E53, 0x006C7D52, 0x006B7C51, 0x006C7D52, 0x006E7F54, 0x006F8055, 0x006D7F50, 0x006D7E52, 0x006E7F53, 0x006F7F56, 0x0072815B, 0x0073815D, 0x00717F5D, 0x006E7C5A, 0x00708057, 0x006F7F56, 0x006E7E55, 0x006E7E55, 0x006E7E55,
        0x006E7E55, 0x006D7D54, 0x006C7C53, 0x006D7B52, 0x006C7A51, 0x006C7A51, 0x006C7A51, 0x006D7B52, 0x006C7A51, 0x0069774E, 0x0066744B, 0x0067754B, 0x00616F45, 0x00606E44, 0x00637148, 0x00616F46, 0x0045532A, 0x002F3C16, 0x00414E28, 0x00444436,
        0x00535347, 0x0052524C, 0x00565453, 0x00575757, 0x00565755, 0x005B5C58, 0x00575B56, 0x00444444, 0x00585759, 0x00C9C8CA, 0x00F0EEF4, 0x00EBE8F1, 0x00F6F2FD, 0x00FBF7FF, 0x00A7A3AF, 0x00434137, 0x003C3A2F, 0x00403E33, 0x00454338, 0x00424133,
        0x003D3C2E, 0x003A3A2A, 0x00393929, 0x0052564B, 0x004E5247, 0x004F5348, 0x0052554C, 0x004F5249, 0x004B4D47, 0x004A4C46, 0x004D4F49, 0x004E504A, 0x00484A44, 0x004D4F49, 0x004F514B, 0x004A4C46, 0x00474943, 0x004C4E48, 0x004A4C46, 0x00505042,
        0x004B4B3F, 0x004A4A3E, 0x004C4C40, 0x00515046, 0x00525147, 0x00504F45, 0x00535149, 0x00504F4B, 0x0043433D, 0x0035362D, 0x0034352B, 0x00393C2D, 0x003B3E2E, 0x00363A27, 0x00333823, 0x003A393B, 0x006B6A6C, 0x00CDCCD0, 0x00D7D5DB, 0x00E4E1EA,
        0x00E3DFEA, 0x00D0CCD8, 0x006E6A76, 0x00454545, 0x004A4A4A, 0x004F4F4F, 0x00535353, 0x004D4D4D, 0x00474747, 0x00474747, 0x00414141, 0x00636E4D, 0x0066734D, 0x006B794F, 0x006A794D, 0x0066724E, 0xFFECF2DF, 0xFFFEFFFD, 0xFFFFFCFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x81B3C5E4, 0x00819CD4, 0x0076A1E4, 0x00649CD3, 0x00649BCE, 0x006F9EDB, 0x006EA0E2, 0x0066A0DB, 0x005F9CD4, 0x005F9CD4, 0x00609ED4, 0x00609ED4, 0x00609ED4,
        0x005E9CD2, 0x005D9BD1, 0x005C9AD0, 0x006D9AD7, 0x006A99D6, 0x006698D4, 0x006096CD, 0x006195C4, 0x005889AF, 0x003C6B87, 0x00214E63, 0x00314020, 0x002A3B19, 0x0029401A, 0x002A431D, 0x00274119, 0x00344B1F, 0x004A5D2C, 0x00576731, 0x00576640,
        0x005A6943, 0x005D6D44, 0x005F6F46, 0x005F7045, 0x005F7045, 0x00607145, 0x00617246, 0x00616D49, 0x005F6D44, 0x005C6C3D, 0x00596934, 0x00526429, 0x004D5E1F, 0x00465717, 0x00435512, 0x004A5719, 0x00495618, 0x00485517, 0x00465315, 0x00455214,
        0x00455214, 0x00465315, 0x00475416, 0x00475319, 0x00495519, 0x004B5919, 0x004B5B1B, 0x004E5D1F, 0x00536229, 0x005B6735, 0x00606B3D, 0x005F7247, 0x003A4C23, 0x002A3C15, 0x002D3E19, 0x0030401E, 0x00263614, 0x00354523, 0x00384826, 0x002C3A18,
        0x00475531, 0x006C7B55, 0x00708057, 0x00738459, 0x006D7E53, 0x0047582D, 0x0028390E, 0x00314314, 0x00344617, 0x00344617, 0x00394B1C, 0x00364819, 0x00344617, 0x00384A1B, 0x00324415, 0x002F3F16, 0x00506136, 0x006C7D51, 0x00718256, 0x006C7D51,
        0x006E7F53, 0x00718256, 0x006D7E52, 0x00728358, 0x00708156, 0x006E7F54, 0x006F8055, 0x006F8055, 0x00718158, 0x006F7F56, 0x006E7E55, 0x00728155, 0x00707F53, 0x006E7D51, 0x006D7C50, 0x006D7C50, 0x006D7C50, 0x006F7E52, 0x00718054, 0x006C7D52,
        0x006E7F54, 0x00708156, 0x00708156, 0x00708156, 0x006F8055, 0x00718257, 0x00728358, 0x006D804D, 0x006B7E4B, 0x006B7E4D, 0x006D7F50, 0x006F8152, 0x006F8054, 0x006F8054, 0x006E7F54, 0x006C7C53, 0x006D7D54, 0x006E7E55, 0x00708057, 0x00708057,
        0x00708057, 0x006F7F56, 0x006F7F56, 0x00707E55, 0x006E7C53, 0x006D7B52, 0x006D7B52, 0x006D7B52, 0x006C7A51, 0x006A784F, 0x0068764D, 0x0069774D, 0x00657349, 0x00616F45, 0x00627047, 0x00637148, 0x0049572E, 0x002F3C16, 0x003D4A24, 0x0043472E,
        0x00585A46, 0x005E5E50, 0x005B5C52, 0x005B5C53, 0x00575B50, 0x005B5F53, 0x005E6354, 0x00656761, 0x00646660, 0x00D6D8D2, 0x00FFFFFC, 0x00EFF0EE, 0x00FBFCFA, 0x00FFFFFF, 0x00A6A6A6, 0x004C4B3D, 0x00454436, 0x00444335, 0x00474737, 0x00434333,
        0x0040402E, 0x00434331, 0x0041412F, 0x005A5E52, 0x005B5F53, 0x005D6155, 0x005F6358, 0x005F6358, 0x005A5D54, 0x005A5D54, 0x005E6158, 0x00646355, 0x00626153, 0x00605F51, 0x00636254, 0x00626153, 0x00605F51, 0x005F5E50, 0x00616052, 0x00515752,
        0x00545B54, 0x00595D57, 0x005E605A, 0x005F6057, 0x00606158, 0x0067665C, 0x0068675D, 0x0063635D, 0x0047483F, 0x00323329, 0x00323428, 0x003A3D2D, 0x003B3F2C, 0x00393E29, 0x00383E27, 0x004A4D44, 0x007A7C76, 0x00F8FAF4, 0x00FFFFFC, 0x00FAFBF9,
        0x00FFFFFF, 0x00FFFEFF, 0x00888789, 0x0052554C, 0x0062655C, 0x00595C53, 0x0053564D, 0x0055584F, 0x004F5249, 0x004E5148, 0x004F5249, 0x00576241, 0x0067744E, 0x006F7D53, 0x006A794D, 0x00616D49, 0xFFE7EDDA, 0xFFFFFFFE, 0xFFFFFCFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x76AED0FB, 0x006D97DC, 0x005995E9, 0x005AA1EB, 0x0062A8EE, 0x0065A1F3, 0x0063A0F6, 0x00599DEA, 0x005897E7, 0x005998E8, 0x005A9AE8, 0x005C9CEA, 0x005D9EE9,
        0x005D9EE9, 0x005D9EE8, 0x005D9EE8, 0x005E97E2, 0x005995E1, 0x005999E7, 0x005B9DEB, 0x005FA1E8, 0x0063A0DE, 0x004780B3, 0x001B4F7D, 0x001B3027, 0x00142C20, 0x00112E1E, 0x0010301F, 0x0015311E, 0x00243A1D, 0x003C4E1F, 0x004D5E1F, 0x0055653C,
        0x00596940, 0x005D6D44, 0x005F7045, 0x005E6F44, 0x005E6F43, 0x005F7044, 0x00607145, 0x00606D47, 0x00606C42, 0x005C6A3A, 0x00566630, 0x00505F25, 0x0049591C, 0x00455417, 0x00435117, 0x003F4C18, 0x003F4C18, 0x003F4C18, 0x003E4B17, 0x003E4B17,
        0x003F4C18, 0x00414E1A, 0x00424F1B, 0x00484F1C, 0x0048541A, 0x004A5719, 0x004C5A18, 0x004C5C1C, 0x00526026, 0x00586432, 0x005D673C, 0x005C6E45, 0x003A4B26, 0x00364525, 0x00263418, 0x0026331B, 0x002A371D, 0x002B391D, 0x002A381C, 0x003A4628,
        0x00475434, 0x00697852, 0x006E7F54, 0x006E7F53, 0x006A7B4F, 0x00526338, 0x00324219, 0x0032441B, 0x002F4118, 0x002C3E15, 0x0034461D, 0x0031431A, 0x00283A11, 0x002F4118, 0x0035471E, 0x003A4C23, 0x00596B42, 0x00708358, 0x00718558, 0x00677A4F,
        0x00657651, 0x006A7959, 0x00627054, 0x00677656, 0x006C7B5B, 0x006A7A58, 0x006A7B56, 0x00697B54, 0x0071835A, 0x006D7F56, 0x00687B50, 0x006D7C50, 0x006B7A4E, 0x0069784C, 0x00657448, 0x005E6D41, 0x0059683C, 0x005A693D, 0x005D6C40, 0x005A6D42,
        0x005F7247, 0x0065784D, 0x0066794E, 0x0062754A, 0x005B6E43, 0x0055683D, 0x0052653A, 0x00516439, 0x004F6237, 0x004D6134, 0x004F6336, 0x00536738, 0x00576B3C, 0x005F7344, 0x00657A49, 0x0063734A, 0x0066764D, 0x006A7A51, 0x006B7B52, 0x006B7B52,
        0x006A7A51, 0x006A7A51, 0x006B7B52, 0x00728057, 0x00707E55, 0x006D7B52, 0x006B7950, 0x006B7950, 0x006C7A51, 0x006D7B52, 0x006D7B52, 0x006A784E, 0x006B794F, 0x00657349, 0x00606E45, 0x00606E45, 0x0047552C, 0x00313E18, 0x0043502A, 0x004B4F32,
        0x005C5F45, 0x00565844, 0x004B4C3C, 0x00515445, 0x005B5E4F, 0x00595C4C, 0x00515744, 0x005C5F50, 0x005B5E4F, 0x00929488, 0x009C9E92, 0x0094968A, 0x00999A90, 0x00A5A69C, 0x00828379, 0x00656456, 0x00636254, 0x00616151, 0x00636353, 0x005F5F4F,
        0x005A5A48, 0x00595947, 0x004F4F3D, 0x00404334, 0x00494C3D, 0x004F5145, 0x00535549, 0x0057594D, 0x0058594F, 0x00595A50, 0x005E5F55, 0x005A594F, 0x005F5E54, 0x00545349, 0x0057564C, 0x00616056, 0x00616056, 0x0059584E, 0x00646359, 0x005C7687,
        0x00647C8E, 0x006C8190, 0x006C7E89, 0x005C6971, 0x004D585C, 0x00515959, 0x00535859, 0x00545349, 0x0056554B, 0x005D5D51, 0x00616155, 0x005F5F51, 0x005F5F51, 0x00606151, 0x005D5E4E, 0x00626556, 0x0076796A, 0x00AEB1A2, 0x00ADB0A1, 0x00AFB2A3,
        0x00B5B8A9, 0x00B1B4A5, 0x0056584C, 0x00515444, 0x00636656, 0x00606353, 0x005C5F4F, 0x00595C4C, 0x00555848, 0x00595C4C, 0x004E5141, 0x005B6645, 0x006C7953, 0x00717F55, 0x006B7A4E, 0x00636F4B, 0xFFE9EFDC, 0xFFFFFFFE, 0xFFFEFBFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x63A4D2EA, 0x006AA0D5, 0x00569CE2, 0x0052A5E3, 0x0055A5E0, 0x005BA0E5, 0x0069A9F0, 0x0060A5E4, 0x006198E1, 0x00629AE1, 0x00639BE2, 0x00659EE3, 0x0066A0E2,
        0x0067A1E2, 0x0068A3E1, 0x0068A3E1, 0x0065A7DC, 0x00599DD8, 0x00579FDF, 0x00529EE0, 0x00519CDA, 0x0060A3DA, 0x004B88B4, 0x00154C71, 0x00274B63, 0x00264E61, 0x00224E5F, 0x00244F60, 0x002B4E5C, 0x00324F4C, 0x003F5735, 0x004C642A, 0x0056663D,
        0x005A6A41, 0x005F7045, 0x00607146, 0x005E6F43, 0x005D6E42, 0x005D6E42, 0x005F7044, 0x00606B43, 0x005E6B3F, 0x00596835, 0x0054632A, 0x004C5B22, 0x0047541E, 0x00444F1D, 0x00434D1E, 0x0038461C, 0x0039471D, 0x0039471D, 0x0038461C, 0x0037451B,
        0x0037451B, 0x0039471D, 0x003C4A20, 0x00464C1D, 0x00484F1C, 0x00495519, 0x004A5816, 0x004A5B18, 0x004E5C22, 0x00555F30, 0x00596339, 0x00546641, 0x003D4E2D, 0x0046543C, 0x003C4836, 0x00434E3E, 0x00515C4C, 0x00515D49, 0x004C5943, 0x005F6952,
        0x00566244, 0x006A7854, 0x00697A4E, 0x0067794A, 0x006C7E4F, 0x006B7C51, 0x0053633A, 0x004A5541, 0x00495440, 0x004F5A46, 0x0065705C, 0x0065705C, 0x00505B47, 0x004C5743, 0x00515C48, 0x00576940, 0x006A7C53, 0x006D8055, 0x005D7045, 0x0043542F,
        0x003A482C, 0x00414C38, 0x00384134, 0x0036402F, 0x0045503C, 0x0048553D, 0x004B593D, 0x004D5D3B, 0x0063754E, 0x006A7D52, 0x006B7F52, 0x006A794D, 0x0068774B, 0x00657448, 0x005C6B3F, 0x004E5D31, 0x00404F23, 0x003C4B1F, 0x003E4D21, 0x004C5F34,
        0x0053663B, 0x005B6E43, 0x005B6E43, 0x0054673C, 0x00495C31, 0x003F5227, 0x00394C21, 0x002C3822, 0x002A371F, 0x0029361C, 0x002C3B1C, 0x002F3F1D, 0x00354720, 0x00405328, 0x004B5E33, 0x0065754C, 0x00697950, 0x006D7D54, 0x006D7D54, 0x006B7B52,
        0x006A7A51, 0x006C7C53, 0x006F7F56, 0x006B7950, 0x006C7A51, 0x006D7B52, 0x006D7B52, 0x006D7B52, 0x006D7B52, 0x006D7B52, 0x006E7C53, 0x006A784E, 0x006B794F, 0x0066744A, 0x00627047, 0x00616F46, 0x0045532A, 0x002F3C16, 0x0045522C, 0x0044472E,
        0x00595B45, 0x00585848, 0x0046463A, 0x0045443A, 0x004A4B41, 0x00505246, 0x00595C4D, 0x00585A4E, 0x00515347, 0x005B5D51, 0x005F6155, 0x0066685C, 0x006A6C60, 0x00626458, 0x00585A4E, 0x005E5E52, 0x00606054, 0x005C5C4E, 0x005D5D4F, 0x00575848,
        0x00525343, 0x004F5040, 0x003E402D, 0x00414232, 0x004F4F41, 0x00555547, 0x00545446, 0x0057574B, 0x0058584C, 0x0057564C, 0x0058574D, 0x00546062, 0x00647072, 0x00525E60, 0x00556163, 0x006A7678, 0x00667274, 0x00505C5E, 0x00626E70, 0x006D93B3,
        0x006F91AF, 0x007492AB, 0x007D95A7, 0x006C7C88, 0x00515C60, 0x00525758, 0x00555856, 0x00555547, 0x00535345, 0x00525246, 0x00505044, 0x00504F45, 0x0059584E, 0x005E5C54, 0x005A5850, 0x004E4E42, 0x005F5F53, 0x006C6C5E, 0x00616252, 0x0060624F,
        0x005B5D49, 0x005D604A, 0x003E412B, 0x00454636, 0x005D5E4E, 0x00606151, 0x00626353, 0x005E5F4F, 0x005B5C4C, 0x00606151, 0x004D4E3E, 0x00616C4B, 0x006D7A54, 0x006F7D53, 0x006D7C50, 0x0066724E, 0xFFE8EEDB, 0xFFFFFFFE, 0xFFFEFBFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x5FA1CAEA, 0x006EA2DE, 0x005A9EEB, 0x0053A1E8, 0x0057A0E4, 0x00629EEA, 0x006EA6F5, 0x005C97DC, 0x005699E8, 0x00569AE7, 0x00579BE6, 0x00579CE5, 0x00589EE4,
        0x00589FE3, 0x0059A0E3, 0x0059A0E3, 0x0065A0D8, 0x005998D5, 0x00589DE2, 0x00539AE4, 0x005094DD, 0x00629FE1, 0x005187BE, 0x00144474, 0x00104171, 0x00134873, 0x00114972, 0x00154977, 0x00224E77, 0x002D4F5F, 0x00375641, 0x00466532, 0x0058683F,
        0x005C6C43, 0x00617247, 0x00617247, 0x005E6F43, 0x005C6D41, 0x005C6D41, 0x005D6F40, 0x005E6941, 0x005C693B, 0x00576732, 0x00516027, 0x0049581F, 0x0045511D, 0x00434D1F, 0x00434B23, 0x003E4F2A, 0x003D4E29, 0x003B4C27, 0x00364722, 0x0031421D,
        0x002E3F1A, 0x002E3F1A, 0x002F401B, 0x0044481E, 0x00474D1C, 0x004A531A, 0x00495715, 0x004A5818, 0x004B591F, 0x00525C2D, 0x00575F37, 0x004C5D3B, 0x00425135, 0x00535F4B, 0x00545E51, 0x0060695F, 0x00697367, 0x00677164, 0x00596553, 0x005E6752,
        0x00505C40, 0x00687652, 0x006D7E52, 0x00697B4C, 0x006A7C4D, 0x006C7D52, 0x00506037, 0x00535856, 0x00606563, 0x00676C6A, 0x00707573, 0x00727775, 0x00696E6C, 0x005F6462, 0x00515654, 0x005F7148, 0x006F8257, 0x006D8055, 0x005F7148, 0x004D5C3C,
        0x00535F49, 0x006C746A, 0x006C716F, 0x00626A60, 0x0071796E, 0x006A7463, 0x005C6951, 0x004F5E3F, 0x0062744D, 0x00697C51, 0x006C8051, 0x006A794D, 0x0069784C, 0x00657448, 0x0059683C, 0x00445327, 0x00303F13, 0x0027360A, 0x0028370B, 0x00273A0F,
        0x002E4116, 0x0036491E, 0x00384B20, 0x0032451A, 0x00293C11, 0x00213409, 0x001D3005, 0x001B201E, 0x00192019, 0x00192116, 0x001B2514, 0x001B2810, 0x001C2A0E, 0x00243412, 0x002E3F1A, 0x00405027, 0x0044542B, 0x0047572E, 0x0046562D, 0x00425229,
        0x00415128, 0x0045552C, 0x00495930, 0x00616F46, 0x0067754C, 0x006D7B52, 0x00717F56, 0x00717F56, 0x006E7C53, 0x006C7A51, 0x006A784F, 0x0069774D, 0x0067754B, 0x00637147, 0x0065734A, 0x0067754C, 0x0047552C, 0x002B3812, 0x00424F29, 0x00474735,
        0x00555446, 0x005B594F, 0x00595651, 0x005E5B57, 0x00575652, 0x0051514B, 0x005C5D54, 0x0054554C, 0x00484940, 0x004F5047, 0x0053544B, 0x0047483F, 0x004F5047, 0x00525349, 0x0053544A, 0x005D5F53, 0x00606256, 0x00595B4F, 0x00575A4B, 0x00535647,
        0x00535647, 0x00525545, 0x003E4131, 0x00474838, 0x00585949, 0x005D5D4F, 0x00575749, 0x00575749, 0x0057574B, 0x00535347, 0x00525246, 0x004D6271, 0x00667B8A, 0x00516675, 0x00546978, 0x006F8493, 0x00647988, 0x003F5463, 0x00536877, 0x00557795,
        0x004A6883, 0x004F687C, 0x006B7D88, 0x00697275, 0x0053554F, 0x00585449, 0x005E5748, 0x00525343, 0x004F5040, 0x00545446, 0x0058574D, 0x0057554D, 0x00595651, 0x005B5854, 0x00575352, 0x0057544F, 0x00504E46, 0x0049483E, 0x004A4A3C, 0x004B4D3A,
        0x00464933, 0x00464A31, 0x0032371C, 0x00404034, 0x005E5E52, 0x005A5A4E, 0x0058584C, 0x005A5A4E, 0x0057574B, 0x005A5A4E, 0x004E4E42, 0x00606B4A, 0x006A7751, 0x006C7A50, 0x006E7D51, 0x0067734F, 0xFFE4EAD7, 0xFFFEFFFD, 0xFFFFFCFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x6EA9CBE9, 0x00659ED6, 0x0059A1EE, 0x005DA2EB, 0x005EA3E8, 0x005AA5F1, 0x005AA5F1, 0x00579DE0, 0x005C9CE3, 0x005D9DE4, 0x0060A0E7, 0x0060A0E7, 0x005F9FE6,
        0x005E9EE5, 0x005E9EE5, 0x005E9EE5, 0x0061A0E4, 0x00599ADE, 0x00589BE0, 0x005A9DE2, 0x00599ADE, 0x0064A3E0, 0x004D8AC2, 0x00094279, 0x001C4064, 0x00224567, 0x00193E60, 0x00113E64, 0x0017496D, 0x00204B5A, 0x00395440, 0x005D6939, 0x005A6D4C,
        0x00576B41, 0x005D703F, 0x00657244, 0x00626C48, 0x00626B4A, 0x005E6F44, 0x00566C38, 0x00576E38, 0x00596A37, 0x00515C2E, 0x004F572F, 0x00525535, 0x0052553B, 0x00464933, 0x00595E49, 0x006C6554, 0x00706958, 0x00666250, 0x005D5B49, 0x003A3A28,
        0x00424431, 0x004E523F, 0x003C402D, 0x003C441F, 0x003E481D, 0x00415017, 0x00465616, 0x00495919, 0x004F5B1F, 0x00545D2A, 0x00575E31, 0x00506435, 0x004D5A40, 0x008C918F, 0x009B9EA6, 0x00989CA1, 0x009DA5A4, 0x009DA5A5, 0x009BA2A5, 0x008F9689,
        0x00556145, 0x006A7B4F, 0x00647746, 0x00697A4F, 0x006B7955, 0x0066754F, 0x005C6D42, 0x007F8979, 0x00A9AEB1, 0x009DA4AD, 0x00A4B0B0, 0x00A6B3B1, 0x009CA4AB, 0x00A0A6A5, 0x00717C68, 0x005E6E4C, 0x006B7B59, 0x006E7D5D, 0x00556347, 0x005F6A56,
        0x006A7268, 0x007C8180, 0x00787B80, 0x006C6B75, 0x008D8F90, 0x00656B60, 0x00353F28, 0x00505D3D, 0x006B7955, 0x0065734F, 0x006B7955, 0x006D7A4E, 0x00697648, 0x00617141, 0x005D703F, 0x003D5025, 0x001C2D0B, 0x001D2B13, 0x001C2A18, 0x00232819,
        0x001E2217, 0x001C1D19, 0x001C1C1C, 0x001D1D1D, 0x001D1E1A, 0x001C2015, 0x00202516, 0x0017240C, 0x0017230D, 0x001C2615, 0x001C2616, 0x001B2515, 0x001B2514, 0x00192410, 0x001D2913, 0x00232B1A, 0x00202A1D, 0x002C3A34, 0x003C4F52, 0x00657984,
        0x006E8190, 0x00657887, 0x00617483, 0x00617265, 0x0030452C, 0x002C451F, 0x00384F29, 0x00344929, 0x0036492E, 0x00445736, 0x005B7246, 0x0067784D, 0x0067784C, 0x00647647, 0x00647647, 0x0064754A, 0x0044532D, 0x00293616, 0x003E4A2E, 0x003A3F2A,
        0x00515542, 0x005D614E, 0x005A5D4D, 0x005B5E4F, 0x005C5E52, 0x005B5C52, 0x005C5D53, 0x00545442, 0x00484836, 0x00484836, 0x004A4A38, 0x00424230, 0x0041412F, 0x00494937, 0x004D4D3B, 0x00555940, 0x00575945, 0x005A5A4E, 0x0057554D, 0x00524F4A,
        0x0054524A, 0x004F4F41, 0x0040422F, 0x00474739, 0x005A5A4E, 0x0057574B, 0x0059594D, 0x00525147, 0x0055544A, 0x00525048, 0x00514F47, 0x00465D4F, 0x005F8290, 0x00495A63, 0x0050525C, 0x007A8CAB, 0x00727C8D, 0x0056544C, 0x0057676D, 0x0064808B,
        0x0055737E, 0x0054747F, 0x004D6C75, 0x00697D82, 0x00555A5B, 0x005E534F, 0x0067544D, 0x00525244, 0x00515145, 0x00545349, 0x00545349, 0x00515046, 0x0057574B, 0x005B5C4C, 0x00555744, 0x004B4C38, 0x00474735, 0x00504F41, 0x00545247, 0x004C4A3F,
        0x004B4A3C, 0x00464634, 0x00363723, 0x0042432F, 0x005B5B4B, 0x00555549, 0x00585550, 0x0056534F, 0x00595854, 0x0055554F, 0x004D4E45, 0x00606D47, 0x006F7D54, 0x00738157, 0x00707D57, 0x00677252, 0xFFE7EDDA, 0xFFFFFFFC, 0xFFFFFEFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x6EA9CBE9, 0x00669ED9, 0x0059A1EE, 0x005DA2EB, 0x005FA4EA, 0x005AA5F1, 0x0059A5F1, 0x00579CE1, 0x005C9CE3, 0x005E9EE5, 0x0060A0E7, 0x0060A0E7, 0x005F9FE6,
        0x005E9EE5, 0x005E9EE5, 0x005E9EE5, 0x0064A3E7, 0x005E9FE4, 0x005A9DE2, 0x005B9EE3, 0x00599ADE, 0x005F9EDB, 0x004985C0, 0x000F487F, 0x000B3969, 0x000B3864, 0x000C3762, 0x0015426D, 0x001C4D6D, 0x001E454E, 0x00364C33, 0x005F6835, 0x00526445,
        0x00566942, 0x00617344, 0x0069764A, 0x00636C4B, 0x005D6546, 0x005D6D44, 0x00607544, 0x00576C3B, 0x00586839, 0x00555F35, 0x004D5330, 0x00686A4D, 0x004E503A, 0x00252714, 0x00565949, 0x00A09988, 0x00938C7B, 0x009B9785, 0x006E6C5A, 0x00262614,
        0x004A4C39, 0x00676B58, 0x00494D3A, 0x003C4223, 0x003F4722, 0x00424E1C, 0x00445316, 0x00465517, 0x004C5B1E, 0x00555F2A, 0x00596230, 0x004D6132, 0x00445137, 0x00969B99, 0x00C2C5CD, 0x00C2C7CA, 0x00B3B9B8, 0x00A9B1B0, 0x00B1B8BB, 0x00A2A99C,
        0x00546044, 0x0068794D, 0x006D804F, 0x006B7C51, 0x006B7955, 0x00677650, 0x00495A2F, 0x00808A7A, 0x00CFD4D7, 0x00D6DDE6, 0x00D4E0E0, 0x00D4E1DF, 0x00D2DAE1, 0x00C2C8C7, 0x006B7662, 0x00607348, 0x006B7E53, 0x006E8156, 0x005D6F48, 0x00617050,
        0x00748169, 0x007C8676, 0x00687065, 0x005B6359, 0x006B7565, 0x004F5C42, 0x002C3C1A, 0x0041532A, 0x0065784D, 0x006B7E53, 0x0064764D, 0x0064744B, 0x0065764B, 0x005F7045, 0x0056673C, 0x00475630, 0x003A462A, 0x0039422E, 0x00383F32, 0x00373C2D,
        0x001F2317, 0x00171913, 0x001C1D1B, 0x001A1B19, 0x001A1C16, 0x00272B1F, 0x0034392A, 0x003F4730, 0x00373E29, 0x00363C2B, 0x0034392A, 0x00353A2B, 0x00353B2A, 0x002F3621, 0x00303821, 0x003F4534, 0x003E463B, 0x006E7976, 0x008E9DA0, 0x009BACB5,
        0x0098A9B6, 0x0098A7B7, 0x0098A7B7, 0x0094A0A2, 0x006D7C74, 0x005F725D, 0x005C6D58, 0x00505E52, 0x00515F54, 0x00576553, 0x0056674C, 0x006A7B50, 0x006A7B4F, 0x0067784C, 0x0068794D, 0x0068794E, 0x00475531, 0x002B3818, 0x00404C30, 0x003F412E,
        0x00565845, 0x005E5F4F, 0x00565648, 0x0057574B, 0x005F5E54, 0x00615F57, 0x005F5D55, 0x004F4E40, 0x004D4C3E, 0x00504F41, 0x00545345, 0x00525143, 0x00525143, 0x00535244, 0x00525143, 0x00575945, 0x00555646, 0x0055544A, 0x00524F4A, 0x00524F4A,
        0x0057564C, 0x00535345, 0x00454734, 0x003E3E30, 0x00525244, 0x00515143, 0x0058584C, 0x0056564A, 0x005A594F, 0x0057564C, 0x0055544A, 0x0054655A, 0x006A8691, 0x00576669, 0x00505455, 0x00627086, 0x005B646E, 0x0058564C, 0x00667276, 0x006A8FB1,
        0x005B81A3, 0x005D87A4, 0x00628AA3, 0x006C8D9D, 0x00495E66, 0x00464E4E, 0x00555352, 0x00545448, 0x00505044, 0x00505044, 0x00505044, 0x00505044, 0x00545446, 0x00565747, 0x0050523F, 0x00585945, 0x00575745, 0x005C5B4D, 0x005B594E, 0x00545247,
        0x00555446, 0x004F4F3D, 0x003A3B27, 0x00464733, 0x005E5E4E, 0x0059594D, 0x0059574F, 0x0053504B, 0x00575751, 0x0054554C, 0x004E4F45, 0x005F6C46, 0x006D7B52, 0x00717F55, 0x006F7C56, 0x00667151, 0xFFE7EDDA, 0xFFFFFFFC, 0xFFFFFEFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x6EAACCEA, 0x00669ED9, 0x0059A1EF, 0x005BA2EC, 0x005FA4EA, 0x005BA5F3, 0x0059A4F2, 0x00579CE1, 0x005A9CE3, 0x005C9EE5, 0x005EA0E7, 0x005EA0E7, 0x005D9FE6,
        0x005C9EE5, 0x005B9DE4, 0x005C9EE5, 0x005F9EE2, 0x005B9CE1, 0x00589AE1, 0x00599EE4, 0x00589CDF, 0x005B9BDB, 0x005A96D1, 0x00427EB4, 0x003A77B9, 0x003C77B5, 0x00427BB3, 0x004D82B5, 0x00497B9F, 0x0038606C, 0x003C5541, 0x00566238, 0x0057684D,
        0x005D6E4C, 0x005F7045, 0x005F6A44, 0x00626A4C, 0x00676E53, 0x00616F4B, 0x00596D40, 0x0056663D, 0x0057643E, 0x00585F3E, 0x00505235, 0x00595843, 0x0093917F, 0x0029291B, 0x0057594D, 0x00BFB8A9, 0x00BFB8A9, 0x00C5C0B1, 0x005A5748, 0x003B3B2B,
        0x00909181, 0x00616454, 0x00232616, 0x00373C27, 0x003E4628, 0x00444E24, 0x00424F1B, 0x00435215, 0x0049581B, 0x00515F25, 0x0059642C, 0x00495B2C, 0x003E4A2E, 0x00939994, 0x00C0C3C8, 0x00B2B7BA, 0x009BA1A0, 0x009AA09F, 0x00B1B8BB, 0x009BA295,
        0x00505C40, 0x00627347, 0x006C7F4E, 0x00697A4F, 0x00677551, 0x00697852, 0x004E5F34, 0x007E8576, 0x00CCD0D1, 0x00C9CED7, 0x00BAC5C3, 0x00B9C4C2, 0x00C4CACF, 0x00BDC2C0, 0x00636C57, 0x00566B3A, 0x00617645, 0x006B814D, 0x00617645, 0x00495D30,
        0x0051633C, 0x00505F3F, 0x003A482C, 0x0037462A, 0x00425332, 0x003F512C, 0x002C4015, 0x00293E11, 0x003C5124, 0x0041552A, 0x0033471D, 0x00354625, 0x00364725, 0x002E3E1C, 0x002B3818, 0x003F482D, 0x00525742, 0x00515143, 0x00504F45, 0x00444A39,
        0x00232819, 0x0014180D, 0x001A1D14, 0x00191C13, 0x0022261B, 0x003C4132, 0x004C5241, 0x004E503C, 0x004C4E3B, 0x00545446, 0x00535347, 0x004D4D3F, 0x00474838, 0x003F412D, 0x00454930, 0x00414435, 0x0050564B, 0x00939C99, 0x00ABB6BA, 0x00A6B2BC,
        0x009DA8B6, 0x009AA5B3, 0x00A0A9B7, 0x00AEB4C7, 0x00A6AFB8, 0x00A4B1AF, 0x00A7B1B1, 0x00A0A8AF, 0x009FA6AF, 0x00959D9C, 0x006F7B6F, 0x006A7B50, 0x00697A4F, 0x00647549, 0x00647549, 0x0065764B, 0x00475531, 0x002E3A1C, 0x00455036, 0x00424333,
        0x00575848, 0x005E5E50, 0x00555549, 0x0056554B, 0x00605E56, 0x00636159, 0x005D5A55, 0x00626056, 0x0068665C, 0x006A685E, 0x006B695F, 0x006D6B61, 0x006C6A60, 0x0069675D, 0x006A685E, 0x005D5D51, 0x0059584E, 0x0055534B, 0x0054524A, 0x0056544C,
        0x0059594D, 0x00545545, 0x00484A36, 0x00454636, 0x00595A4A, 0x00575749, 0x005B5B4D, 0x00555549, 0x0056564A, 0x00545349, 0x0055544A, 0x004B564C, 0x005A6D70, 0x0057615B, 0x0051564D, 0x00505C60, 0x004B5150, 0x00514F44, 0x00595F5E, 0x005F7CA1,
        0x006282A6, 0x006487A8, 0x005F839B, 0x00557483, 0x00455B60, 0x0046544E, 0x0051594E, 0x00555549, 0x00515145, 0x00525244, 0x00535345, 0x00525343, 0x00545545, 0x00575848, 0x00555744, 0x00565743, 0x00575745, 0x005D5C4E, 0x005C5A4F, 0x0059574C,
        0x005E5D4F, 0x00545442, 0x003C3D29, 0x003F402C, 0x00585848, 0x0058584C, 0x005A594F, 0x00535248, 0x0056584C, 0x00505344, 0x00484B3B, 0x00606D47, 0x006B7950, 0x006F7D53, 0x006E7B55, 0x00667151, 0xFFE7EDDA, 0xFFFFFFFC, 0xFFFFFEFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x6BA8CBEC, 0x00649ED9, 0x0058A2F0, 0x005CA3ED, 0x005EA4EA, 0x005AA5F3, 0x0059A4F2, 0x00569DE1, 0x005B9CE6, 0x005C9DE7, 0x005E9FE9, 0x005E9FE9, 0x005D9EE8,
        0x005B9CE6, 0x005B9CE6, 0x005B9CE6, 0x0062A3E8, 0x005EA1E6, 0x00589DE3, 0x005BA0E6, 0x00589BE0, 0x005797D7, 0x0063A2DC, 0x0067A3D9, 0x005A9CDD, 0x0062A0E0, 0x00629CD7, 0x005489BB, 0x003B6A8A, 0x00284C56, 0x00274435, 0x00344A2D, 0x003E4D38,
        0x003E4D31, 0x0034421E, 0x0037401F, 0x0052583F, 0x006D725D, 0x00636F51, 0x004A5C35, 0x00596646, 0x00677153, 0x003C3F26, 0x005E5D49, 0x005A5546, 0x009E9A8F, 0x00727066, 0x0035362D, 0x00BFB7AA, 0x00CDC5B8, 0x00C5BFB2, 0x004C493B, 0x006D6C5E,
        0x00ACAC9E, 0x002F3223, 0x00202314, 0x00282A1E, 0x00323623, 0x003B4324, 0x00404A1F, 0x0042501A, 0x004B591F, 0x00556427, 0x005C6B2E, 0x00596C3B, 0x004E5A3E, 0x009A9E99, 0x00ABAEB3, 0x00979A9E, 0x00919895, 0x00999F9E, 0x00AEB3B6, 0x00969D90,
        0x00626E52, 0x00708155, 0x006E8150, 0x006D7E53, 0x00667450, 0x006C7B55, 0x00637449, 0x00848C7B, 0x00BFC3C4, 0x00B3B9C0, 0x00B1BCBA, 0x00B0BBB8, 0x00B2B8BD, 0x00B4B9B7, 0x0068715C, 0x0066774C, 0x006A7B4F, 0x00708253, 0x006B7E4D, 0x003E5021,
        0x003D4D24, 0x003B4925, 0x002E3B1B, 0x00293D1A, 0x002F441E, 0x002F441E, 0x00253A14, 0x001C300D, 0x001C300D, 0x001D300F, 0x0017290A, 0x00172A0F, 0x0017280D, 0x0017250D, 0x001C2510, 0x003E422F, 0x005A5A4C, 0x005D584F, 0x006B635C, 0x005D6050,
        0x00484B3B, 0x00303324, 0x002B2E1F, 0x002D3021, 0x00373A2B, 0x004C4F3F, 0x00565949, 0x00565442, 0x004F4C3D, 0x00585547, 0x00575348, 0x00504D3F, 0x00484634, 0x003D3C27, 0x0045462C, 0x0049493D, 0x0070736A, 0x00ACB2B1, 0x00AEB7BB, 0x00B2BBC5,
        0x00AFB7C4, 0x00A7ADBA, 0x00B1B4C2, 0x00A7ACC1, 0x00AEB6C3, 0x00AAB4BB, 0x00AFB6BF, 0x00ADB2C1, 0x00B0B5C4, 0x00A4AAAF, 0x006A756D, 0x0067774E, 0x0067784D, 0x00647549, 0x0065764A, 0x0064744B, 0x0043512D, 0x00273315, 0x003A452B, 0x003D3E2E,
        0x004D4E3E, 0x00555547, 0x00505044, 0x00515046, 0x0056554B, 0x0056544C, 0x00504D48, 0x004C4941, 0x00524F47, 0x004F4C44, 0x004D4A42, 0x00504D45, 0x004C4941, 0x00504D45, 0x00625F57, 0x0059574F, 0x0057554D, 0x0057564C, 0x0059584E, 0x005C5C50,
        0x005D5E4E, 0x005A5C49, 0x00535541, 0x00575946, 0x006A6B5B, 0x00676858, 0x00696A5A, 0x00606052, 0x00616153, 0x00646458, 0x006A6A5E, 0x00596156, 0x005A655B, 0x005D6455, 0x00646A59, 0x00656C5F, 0x0064685C, 0x0069695B, 0x0060625C, 0x00505C62,
        0x005B676D, 0x005A696C, 0x00596766, 0x0055615B, 0x005F6657, 0x00686752, 0x006E6B4F, 0x00606054, 0x005E5E50, 0x005F6050, 0x005E604D, 0x005A5C48, 0x00565844, 0x00585A47, 0x005B5C4C, 0x005C5D49, 0x00585846, 0x00575648, 0x00565449, 0x0057554A,
        0x005E5D4F, 0x00585846, 0x00474834, 0x0052533F, 0x00636353, 0x00626254, 0x00626256, 0x005E5E50, 0x00676B58, 0x00616750, 0x00595F46, 0x0064714B, 0x006D7B52, 0x006F7D53, 0x006F7C56, 0x00687353, 0xFFE8EEDB, 0xFFFFFFFC, 0xFFFFFEFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x6BA8CBEC, 0x00649DDA, 0x0058A1F1, 0x005AA2EF, 0x005EA3EC, 0x005AA5F3, 0x0058A5F4, 0x00579DE3, 0x00599DE6, 0x005B9FE8, 0x005CA0E9, 0x005CA0E9, 0x005B9FE8,
        0x00599DE6, 0x00599DE6, 0x00599DE6, 0x005FA0E5, 0x0060A2E9, 0x00579BE4, 0x00569BE4, 0x00589DE2, 0x005D9DDE, 0x005896D2, 0x004782BA, 0x004F7CA2, 0x005581A6, 0x00547D9E, 0x0041637A, 0x00253F46, 0x00182B22, 0x001E3019, 0x002A3A1B, 0x00566355,
        0x00435139, 0x00344022, 0x00394025, 0x00474B38, 0x004D5041, 0x00434D36, 0x003A4A28, 0x00525B41, 0x004F553E, 0x00575844, 0x00858071, 0x007D776A, 0x00716C63, 0x00A4A199, 0x00595651, 0x00999184, 0x00A1998C, 0x00A59F92, 0x007A7769, 0x008F8E80,
        0x00727264, 0x000E1102, 0x002F3223, 0x0021241B, 0x002A2F20, 0x00363C25, 0x003C4622, 0x00414C1E, 0x0046541E, 0x00505E24, 0x00576629, 0x005A6A3A, 0x004F593B, 0x00989C96, 0x00A6A7AB, 0x00989C9D, 0x00A3A8A6, 0x00A4ABA8, 0x00AAAFB0, 0x008E9588,
        0x005F6B4F, 0x00728357, 0x006D804F, 0x006D7E53, 0x006B7955, 0x006F7E58, 0x0064754A, 0x008C9281, 0x00C0C4C5, 0x00B4B7BF, 0x00B4BFBC, 0x00B3BEBB, 0x00B7BCBF, 0x00BCC2BD, 0x00737B64, 0x00687654, 0x006A7854, 0x0066754F, 0x00576640, 0x002B3915,
        0x002E3B1B, 0x002B371B, 0x001B250E, 0x002F4122, 0x00324427, 0x002C3C24, 0x00303F2A, 0x003C4A38, 0x00384535, 0x002E3B2B, 0x00323F31, 0x00384A33, 0x0031402B, 0x00333D2C, 0x0032392C, 0x00404137, 0x00514E46, 0x00655F58, 0x008B837C, 0x006F7263,
        0x00696C5D, 0x004E5141, 0x004C4F3F, 0x00575A4A, 0x00525545, 0x00595C4D, 0x0066695A, 0x00737061, 0x00595648, 0x00555146, 0x00514D42, 0x00524F41, 0x004F4E3A, 0x003D3D25, 0x00434528, 0x0046473D, 0x00797B75, 0x00B1B7B6, 0x00ADB5BC, 0x00B3B9C4,
        0x00B1B7C4, 0x00ABAFBA, 0x00B4B6C1, 0x00AFB7C4, 0x00B3BDC4, 0x00A8B4B6, 0x00ABB3BA, 0x00AAAFBE, 0x00AEB4BF, 0x00A4ACAB, 0x00687565, 0x0065754C, 0x0068784F, 0x00697A4F, 0x006C7D52, 0x0068784F, 0x00404E2C, 0x001C280C, 0x002B351E, 0x001E1F0B,
        0x00222210, 0x00272715, 0x002A2A1A, 0x0029281A, 0x0029271C, 0x0028261C, 0x0026241A, 0x00232117, 0x0026241A, 0x00222016, 0x00222016, 0x00232117, 0x001B190F, 0x0029271D, 0x004D4B41, 0x002D2D21, 0x002D2D1F, 0x002C2D1D, 0x002C2E1B, 0x002B2D19,
        0x00292B17, 0x00292B17, 0x002C2E1A, 0x00323420, 0x003E402D, 0x00373926, 0x003D3F2C, 0x00383929, 0x00393A2A, 0x0038382A, 0x003A3A2C, 0x003A3F30, 0x00333521, 0x00303421, 0x00363C29, 0x00393C23, 0x003C3E2A, 0x00434839, 0x003C3C2C, 0x0043462C,
        0x003D4027, 0x00363723, 0x0041412F, 0x00484634, 0x0048432E, 0x003F381F, 0x00453A1F, 0x00343329, 0x00333325, 0x00323420, 0x0032361D, 0x0034381F, 0x00333620, 0x00333522, 0x00343525, 0x003C3D29, 0x002E2E1C, 0x00242315, 0x00211F14, 0x00232116,
        0x00272618, 0x00282816, 0x00242511, 0x00252513, 0x002C2C1C, 0x002B2C1C, 0x00323323, 0x0040422F, 0x00636950, 0x006F7758, 0x00707958, 0x006A7751, 0x00707E55, 0x00707E54, 0x00707D57, 0x006A7555, 0xFFE8EEDB, 0xFFFEFFFB, 0xFFFEFDFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x67A6CBED, 0x00639FDB, 0x0057A2F1, 0x005AA2EF, 0x005DA5ED, 0x0058A5F4, 0x0058A5F4, 0x00559DE3, 0x00599CE7, 0x005B9EE9, 0x005DA0EB, 0x005C9FEA, 0x005B9EE9,
        0x00599CE7, 0x00589BE6, 0x00589BE6, 0x005597DE, 0x005BA0E6, 0x005398E1, 0x005196DF, 0x005CA1E7, 0x0063A5E6, 0x004584C0, 0x000D4A82, 0x002A4756, 0x00223F4E, 0x00263E4A, 0x0033413F, 0x00393E29, 0x00454422, 0x004F532A, 0x00515931, 0x00263129,
        0x00273321, 0x00465137, 0x006A6F5A, 0x0065675B, 0x00494A40, 0x00394130, 0x003A482C, 0x00373E29, 0x00292E19, 0x00686654, 0x00989384, 0x00978E84, 0x007F786F, 0x00A3A098, 0x0094928A, 0x007B7268, 0x007D746A, 0x00888277, 0x00A19D92, 0x0097958A,
        0x006C6C60, 0x004D4F43, 0x001D1F13, 0x0023261D, 0x0024281C, 0x002B311E, 0x00373F21, 0x003D4822, 0x00424D1F, 0x004B5923, 0x0055642B, 0x004A5A2A, 0x00404A2C, 0x00999B95, 0x00AFB0B4, 0x00A3A5A6, 0x00A9AFAA, 0x00AAAFAD, 0x00B5B9BA, 0x008A9184,
        0x00465236, 0x0067784C, 0x006D804F, 0x006B7C51, 0x00717F5B, 0x006B7A54, 0x004D5E33, 0x00747A67, 0x00C1C3C3, 0x00BDC1C6, 0x00BCC5C2, 0x00BBC5BF, 0x00C1C6C9, 0x00BEC2BD, 0x00575F48, 0x00636E4D, 0x00717C5B, 0x00687450, 0x00475231, 0x002E381A,
        0x004B533C, 0x00686E5D, 0x006E7266, 0x005D6953, 0x00677160, 0x00656E61, 0x00666D66, 0x006E746F, 0x00666C67, 0x005D635E, 0x00646B64, 0x00616C58, 0x005D6756, 0x006C7366, 0x0071746B, 0x0060605A, 0x0054514C, 0x005E5B53, 0x00747268, 0x00737169,
        0x00706F65, 0x0059594B, 0x00656656, 0x00767767, 0x00606052, 0x005F5E54, 0x0076746C, 0x006E6D5F, 0x00535146, 0x00535146, 0x00504E43, 0x004F4E40, 0x00494A36, 0x0036391F, 0x003F4425, 0x00444940, 0x00747A75, 0x00AFB7B7, 0x00B5BFC6, 0x00B1BAC4,
        0x00A8AEB9, 0x00AEB0BB, 0x00B2B3BD, 0x00A9B3BA, 0x00ADB9BB, 0x00A8B4B4, 0x00B0B8BF, 0x00B0B6C3, 0x00B2B9C2, 0x00A5B0A8, 0x006A7A63, 0x00677650, 0x0068784F, 0x0067784D, 0x0068794E, 0x0066754F, 0x0042502E, 0x00232F13, 0x00343E27, 0x00494C33,
        0x0043462D, 0x00444630, 0x00484935, 0x00474735, 0x00474735, 0x004A4A3A, 0x004B4B3B, 0x004C4C3A, 0x004A4A38, 0x00434331, 0x003F3F2D, 0x00353523, 0x00222210, 0x002E2E1C, 0x00565644, 0x00434630, 0x0042462D, 0x003E4328, 0x003C4124, 0x003A3F24,
        0x00373B22, 0x003D3F2B, 0x00484939, 0x003F412D, 0x00444632, 0x00383A26, 0x00424431, 0x00464835, 0x00484A37, 0x003F4030, 0x00383929, 0x00353B28, 0x003D3B1D, 0x003D422D, 0x00424C3C, 0x00424125, 0x00393D24, 0x00394434, 0x003B3D20, 0x00363C1D,
        0x0040452A, 0x00434531, 0x00444535, 0x004E4E42, 0x0049493D, 0x00474739, 0x00505141, 0x004A493F, 0x0048483A, 0x0041442E, 0x003E4326, 0x00444A2B, 0x00494E33, 0x00454734, 0x00414133, 0x0051523E, 0x00474735, 0x00414032, 0x00444237, 0x00464439,
        0x00454436, 0x00454533, 0x00454632, 0x00464634, 0x00454535, 0x003D3E2E, 0x003D3F2C, 0x00444731, 0x00666E4F, 0x006E7953, 0x006E7A50, 0x006E7B55, 0x00728057, 0x00707E54, 0x00717E58, 0x006B7656, 0xFFE9EFDC, 0xFFFEFFFB, 0xFFFDFCFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x6BA7CCEE, 0x00639EDC, 0x0057A2F1, 0x005AA2EF, 0x005DA4EE, 0x0059A6F5, 0x0056A5F4, 0x00559DE5, 0x00599DE8, 0x005A9EE9, 0x005CA0EB, 0x005B9FEA, 0x005A9EE9,
        0x00589CE7, 0x00579BE6, 0x00579BE6, 0x005C9EE5, 0x005DA1EA, 0x00579CE5, 0x00569BE4, 0x00599EE4, 0x005C9EDF, 0x004584C1, 0x0014508B, 0x00285576, 0x001B4667, 0x00163B55, 0x001E343A, 0x00292F1E, 0x003D3E1E, 0x004A4E2B, 0x003F4C2C, 0x0028312E,
        0x00364033, 0x004B543F, 0x004A4D3D, 0x0037382F, 0x00373731, 0x0031382B, 0x001C2911, 0x00282F1A, 0x002D2F1C, 0x002F2D1B, 0x00787162, 0x00978F82, 0x00958F84, 0x009F9A91, 0x0086847A, 0x00877E75, 0x00867D74, 0x00857E75, 0x00908B82, 0x008E8C82,
        0x009B9A90, 0x00A7A89E, 0x004A4B41, 0x0024281C, 0x001C2014, 0x001E2413, 0x002D351E, 0x003B4324, 0x00424D25, 0x00515D2D, 0x00626E3C, 0x00566734, 0x00424C2E, 0x009D9F99, 0x00BBBABE, 0x00AFB1B1, 0x00B4B8B3, 0x00B4BAB5, 0x00C6CBCA, 0x0092998C,
        0x00445034, 0x006B7C50, 0x00738655, 0x006F8055, 0x006D7B57, 0x005B6A44, 0x0044552A, 0x00898D7A, 0x00D1D3D3, 0x00C7CACF, 0x00BFC9C3, 0x00BDC7C1, 0x00C8CBCF, 0x00C9CDC8, 0x00626851, 0x005B6A3E, 0x006F7E52, 0x0067754B, 0x00404E25, 0x003D4827,
        0x005F684E, 0x009AA08F, 0x00C1C5BA, 0x00AEB5A0, 0x00B6BCAB, 0x00B7BBB0, 0x009FA09C, 0x007F807E, 0x00747571, 0x0073766D, 0x006A6E62, 0x005F644F, 0x00686B5B, 0x00808177, 0x007E7E78, 0x0053524E, 0x00474741, 0x0065675B, 0x00737667, 0x00736F6E,
        0x00706D68, 0x005A5A4E, 0x0068685A, 0x00737365, 0x0059594D, 0x00595651, 0x006C6867, 0x006B6B5F, 0x0059584E, 0x0067665C, 0x0066665A, 0x005E5F4F, 0x0051543E, 0x003C4124, 0x004C5332, 0x004A524B, 0x00828B88, 0x00ABB7B7, 0x00AFBBC1, 0x00B1BCC4,
        0x00A7B0BA, 0x00B3B8C1, 0x00B7BAC2, 0x00AFB8C1, 0x00AFBABE, 0x00AAB5B9, 0x00AEB4BF, 0x00ACB0C2, 0x00AFB5C2, 0x00A2ACA6, 0x006D7D66, 0x00687751, 0x0067774E, 0x0064744B, 0x0064744B, 0x0064734D, 0x00445131, 0x00293519, 0x003E4831, 0x0047492B,
        0x00414325, 0x00414326, 0x0045462C, 0x0044442C, 0x00484732, 0x004B4A35, 0x00494834, 0x00474B2E, 0x0045492C, 0x0043472A, 0x0043472A, 0x003C4023, 0x002F3316, 0x003D4124, 0x005F6346, 0x0059603D, 0x0058603B, 0x00555E36, 0x00576038, 0x005A613E,
        0x00585D42, 0x005C5E4B, 0x0069695D, 0x0051543E, 0x00545741, 0x00484B35, 0x00545642, 0x005B5D49, 0x00616350, 0x005C5E4B, 0x00595B48, 0x00414C32, 0x0058522D, 0x00575B48, 0x005B665E, 0x00666148, 0x0052553F, 0x00435544, 0x004B5029, 0x00535843,
        0x006E7161, 0x0076786C, 0x00595A50, 0x00565950, 0x0042483D, 0x00455040, 0x0052604E, 0x006B6961, 0x006D6E5E, 0x0060644B, 0x004F5635, 0x004D5433, 0x004F5437, 0x004C4E3A, 0x0049493B, 0x004C4D39, 0x004D4D3B, 0x00504F41, 0x00555348, 0x0057554A,
        0x00555446, 0x00525240, 0x0050513D, 0x00535341, 0x00525242, 0x0050523F, 0x004C4E3A, 0x004D5237, 0x006A7450, 0x006E7B4F, 0x006C7A4A, 0x006F7C56, 0x00717F56, 0x006E7C52, 0x00707D57, 0x006B7656, 0xFFE9EFDC, 0xFFFEFFFB, 0xFFFDFCFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x6BA7CCEE, 0x00639EDC, 0x0058A2F4, 0x0058A2F0, 0x005DA4EE, 0x0059A6F5, 0x0056A5F6, 0x00559DE5, 0x00599DE8, 0x005B9FEA, 0x005CA0EB, 0x005CA0EB, 0x005A9EE9,
        0x00589CE7, 0x00579BE6, 0x00579BE6, 0x005D9FE6, 0x00569AE3, 0x00579BE6, 0x005CA3ED, 0x00569CE2, 0x005697DB, 0x005F9EDB, 0x005793CE, 0x003C85C9, 0x00448BCE, 0x004584BE, 0x00305B7C, 0x00192F34, 0x001E2D1F, 0x00243625, 0x00122C1F, 0x001F2726,
        0x00404A3E, 0x00464E3D, 0x00212415, 0x0020201A, 0x005F5D5C, 0x00646A5F, 0x00232F19, 0x00272C17, 0x00232512, 0x0033311F, 0x004D4637, 0x008A8275, 0x00918B7E, 0x00928E83, 0x008D8B80, 0x00867D74, 0x00898077, 0x008B847B, 0x0079746B, 0x00838177,
        0x009D9C92, 0x00B0B1A7, 0x00A4A59B, 0x00333A2B, 0x0024291A, 0x001E2413, 0x002A311C, 0x00363D22, 0x003B4521, 0x004B552B, 0x005E693B, 0x00606F3C, 0x00394424, 0x00898C83, 0x00ACABAD, 0x00AEB0B0, 0x00BABEB9, 0x00B2B8B3, 0x00B9BEBD, 0x00858C7F,
        0x00404C30, 0x006A7B4F, 0x006F8251, 0x006F8055, 0x0063714D, 0x004B5A34, 0x00526338, 0x00868A77, 0x00C5C7C7, 0x00C0C3C8, 0x00CAD4CE, 0x00C6D0CA, 0x00BEC2C3, 0x00B7BBB5, 0x00555B42, 0x00657841, 0x00748750, 0x0072844F, 0x00536334, 0x004F5D34,
        0x00444E30, 0x005C624F, 0x007C8172, 0x00979B82, 0x00A1A390, 0x00B9B9AD, 0x00ACAAA2, 0x0086837E, 0x008C8B81, 0x00929383, 0x006F715D, 0x00676652, 0x008F8F7F, 0x00C3C1B7, 0x00B8B5B1, 0x00676662, 0x00484B42, 0x006A7162, 0x006F7864, 0x006D6869,
        0x006D6A66, 0x005A594F, 0x00626254, 0x0068685A, 0x0059584E, 0x00615E5A, 0x00696465, 0x006A6C60, 0x0053544A, 0x005E5F55, 0x005D5F53, 0x00565949, 0x00494F38, 0x0031391B, 0x00404928, 0x00636E66, 0x00A7B5B1, 0x00B4C1C3, 0x00A0AEB4, 0x00B1BEC6,
        0x00ABB6BE, 0x00AFB7BE, 0x00B4BAC1, 0x00B2BAC7, 0x00B1BAC3, 0x00B0B9C3, 0x00AFB3C5, 0x00ABACC6, 0x00AFB3C6, 0x009EA6A6, 0x006B7967, 0x0066754F, 0x00687751, 0x0068784F, 0x006A7A51, 0x00687751, 0x00435030, 0x00222D13, 0x00333D26, 0x003F4320,
        0x003D411E, 0x00404323, 0x00424426, 0x00434528, 0x00494A30, 0x004B4B33, 0x0043432B, 0x00424825, 0x00404623, 0x003F4522, 0x00414724, 0x003D4320, 0x00383E1B, 0x00484E2B, 0x00636946, 0x00626C41, 0x005E693B, 0x00596436, 0x005B6638, 0x005C653D,
        0x0052573A, 0x004D4F3C, 0x00545349, 0x004E5239, 0x00535640, 0x00454832, 0x004A4D37, 0x00494B37, 0x004E503C, 0x0050523F, 0x00565845, 0x003F4D31, 0x00524C23, 0x003D4332, 0x00404B49, 0x005A543D, 0x004F523C, 0x003D5341, 0x004B5225, 0x004D4A3B,
        0x005D5A4C, 0x00666257, 0x00524E43, 0x00595A4A, 0x00313823, 0x00313F23, 0x00475A39, 0x005A5850, 0x00656656, 0x005C6146, 0x00444B28, 0x0039401D, 0x003D4225, 0x00434531, 0x0049493B, 0x00484935, 0x004D4D3B, 0x004D4C3E, 0x004A483D, 0x004A483D,
        0x004C4B3D, 0x004C4C3A, 0x004B4C38, 0x004F4F3F, 0x00505040, 0x00515340, 0x004B4E38, 0x00484D30, 0x0066714B, 0x006E7B4D, 0x0071814C, 0x006E7B55, 0x006F7D54, 0x006C7A50, 0x006F7C56, 0x006B7656, 0xFFE9EFDC, 0xFFFEFFFB, 0xFFFEFDFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x4C97C1EB, 0x00629FE1, 0x0056A0F2, 0x005EA2ED, 0x0064A6ED, 0x005DA5F3, 0x005BA5F7, 0x00579BE6, 0x00589BE6, 0x005C9FEA, 0x00599DE8, 0x005DA1EC, 0x005CA0EB,
        0x00569DE7, 0x005AA1EB, 0x00579EE8, 0x00619FE5, 0x0063A3EA, 0x005D9EE8, 0x005697E1, 0x005A9AE1, 0x00629FE3, 0x00629DDB, 0x006097D4, 0x005D9CCF, 0x006396D5, 0x005993C7, 0x004B90C2, 0x003C73A6, 0x00274A4E, 0x00314B23, 0x0024381B, 0x001B1F13,
        0x00262919, 0x002C2E1A, 0x004A4D34, 0x002A2E15, 0x00454B34, 0x0047503B, 0x001E2A16, 0x00262913, 0x002E301C, 0x00323421, 0x00757666, 0x00848478, 0x0086857B, 0x008D8B83, 0x00908D88, 0x00938D82, 0x00888178, 0x008C877E, 0x00807B72, 0x007D7A72,
        0x009F9C94, 0x00AAA7A2, 0x00999691, 0x006A6860, 0x00252713, 0x00262C15, 0x0026281C, 0x002D3320, 0x003C4A20, 0x00445522, 0x00536439, 0x00626946, 0x00404724, 0x00464D2A, 0x004A5130, 0x00606746, 0x00717758, 0x00666C4D, 0x00646A4B, 0x006A715C,
        0x00464F34, 0x00798463, 0x00727F59, 0x0067754C, 0x00505C38, 0x00606B4B, 0x005A6348, 0x00686B5C, 0x00585B4B, 0x006F7360, 0x008F947F, 0x008B907B, 0x00696D5A, 0x00636656, 0x00525546, 0x0061704A, 0x006F7E58, 0x006E7E55, 0x0066744B, 0x004D5B31,
        0x0039461A, 0x00303D0F, 0x003C491B, 0x00576732, 0x0051622F, 0x004A5B2F, 0x0043572D, 0x003E5431, 0x00395133, 0x00314A30, 0x002A442C, 0x00314C2A, 0x00385030, 0x00405639, 0x00425038, 0x00454E3A, 0x00525546, 0x00636156, 0x007D786F, 0x0077746C,
        0x00726F67, 0x005A584E, 0x006A685D, 0x00666557, 0x005B5A4C, 0x00626252, 0x006F6F5D, 0x0067655A, 0x00545247, 0x00656359, 0x006D6B61, 0x005B594E, 0x00484836, 0x003A3D24, 0x00424629, 0x00687069, 0x00A9B1B0, 0x00ABB3BA, 0x00AAB2BF, 0x00B7BDC8,
        0x00BDC5C5, 0x00ABB4A7, 0x00979E89, 0x00889A6B, 0x00869470, 0x0096A488, 0x00AFBAAA, 0x00B9BDC8, 0x00A9A9C7, 0x00A2ADB1, 0x00667E5B, 0x0068754F, 0x006B7B52, 0x00697C51, 0x00667A50, 0x0062754E, 0x00424F2F, 0x00262D12, 0x00383B25, 0x003C3E21,
        0x003E4022, 0x00414424, 0x00434724, 0x00434724, 0x00424426, 0x0043442A, 0x0044442C, 0x00404526, 0x00444629, 0x0045442A, 0x00454128, 0x00424022, 0x003B3F1C, 0x00495329, 0x00637042, 0x005D6C40, 0x005B6B3C, 0x00586936, 0x005A6B38, 0x005B6A3E,
        0x004E5939, 0x00434A35, 0x0044483C, 0x004A5443, 0x00444B3C, 0x005A6739, 0x0055632D, 0x0042452F, 0x004D5040, 0x003E492F, 0x00485046, 0x004C5834, 0x004A5D26, 0x0047532F, 0x003E4433, 0x004D563C, 0x00424934, 0x00545D43, 0x004D6126, 0x00475630,
        0x00414B34, 0x00494F44, 0x00474C43, 0x0058614C, 0x00515D3F, 0x00596646, 0x00455135, 0x004B514C, 0x0069735C, 0x005C6C3D, 0x00475924, 0x0039461A, 0x00404627, 0x0045482F, 0x004B4D37, 0x004B4E38, 0x004C4E3A, 0x004D4F3B, 0x004C4E3B, 0x004B4D3A,
        0x004B4C3C, 0x004C4D3D, 0x004E4E40, 0x004D4C38, 0x0051503C, 0x004C4C3A, 0x00494B37, 0x004D533A, 0x00687353, 0x00697650, 0x0066774C, 0x006E7C52, 0x006F7E52, 0x00707F53, 0x00728056, 0x00677252, 0xFFE6ECD9, 0xFFFFFFFC, 0xFFFEFDFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x4C97C1EB, 0x0060A0E1, 0x0056A0F2, 0x005EA2ED, 0x0064A6ED, 0x005BA5F3, 0x005BA5F7, 0x00579BE6, 0x00589BE6, 0x005C9FEA, 0x00599DE8, 0x005CA0EB, 0x005A9EE9,
        0x00549BE5, 0x00579EE8, 0x00559CE6, 0x005B99DF, 0x005B9BE2, 0x005A9BE5, 0x005899E3, 0x005E9EE5, 0x00619EE2, 0x004C87C5, 0x003067A4, 0x0030699C, 0x003764A1, 0x00477EB1, 0x005798CB, 0x005388BB, 0x003A5A60, 0x003C5431, 0x0031442B, 0x00212519,
        0x00363929, 0x00363824, 0x005C5F46, 0x003B3E25, 0x00313720, 0x00303924, 0x001C2814, 0x00292C16, 0x00222410, 0x003C3E2B, 0x00828373, 0x008C8C80, 0x00919086, 0x0087857D, 0x007E7B76, 0x00969085, 0x00898279, 0x0089847B, 0x00807B72, 0x007A776F,
        0x00928F87, 0x00A09D98, 0x009F9C97, 0x007D7B73, 0x00353723, 0x002B311A, 0x00232519, 0x00242A17, 0x0038461C, 0x00475825, 0x005E6C42, 0x00616A42, 0x004B532E, 0x004B532E, 0x00424A25, 0x003D4421, 0x004B522F, 0x00444B2A, 0x004D5433, 0x00646D53,
        0x00636D4F, 0x006C7854, 0x0068764D, 0x00556339, 0x0058653F, 0x00465130, 0x003F4A2A, 0x00686E57, 0x004C5239, 0x004D5439, 0x00575E43, 0x00565D42, 0x004D5439, 0x00595F46, 0x00545A43, 0x0065764B, 0x006D7E53, 0x0075865B, 0x006A784F, 0x004F5C36,
        0x00353F1B, 0x00343E1A, 0x003F4925, 0x00455127, 0x003B461E, 0x002F3C16, 0x00263412, 0x001C2B0C, 0x00142308, 0x0012220A, 0x0015250E, 0x000F2209, 0x0016260E, 0x00121F09, 0x0018230F, 0x00424837, 0x00575A4B, 0x004E4E42, 0x00555348, 0x00626055,
        0x00636156, 0x00545247, 0x00666459, 0x005F5D52, 0x00514F44, 0x0057554A, 0x00656358, 0x006C6A5F, 0x0059574C, 0x006B695F, 0x00727066, 0x00605E53, 0x004B4B39, 0x003B3E25, 0x00424629, 0x0069706B, 0x00A6AEAE, 0x00A4ACB3, 0x00B1BAC4, 0x00B7BFC6,
        0x009BA59F, 0x007F8A76, 0x00768062, 0x00738459, 0x006E7C58, 0x0070805E, 0x008A9880, 0x00ABB2B5, 0x00B2B4CC, 0x009FAAAE, 0x00667E5C, 0x0068754F, 0x006B7B52, 0x00687B50, 0x0065794F, 0x0062754E, 0x00424F2F, 0x00262D12, 0x00383B25, 0x003B3D20,
        0x003D3F21, 0x003F4222, 0x003F4320, 0x00414522, 0x00434527, 0x0045462C, 0x0046462E, 0x00404427, 0x00434528, 0x00444329, 0x00454128, 0x00424022, 0x003B3F1C, 0x00485228, 0x005F6F40, 0x005C6B3F, 0x0059693A, 0x00556633, 0x00576737, 0x0058663C,
        0x00505B3B, 0x0049503B, 0x004E5246, 0x003E4838, 0x00464D3E, 0x00515E32, 0x0055632D, 0x00434630, 0x00484B3B, 0x00465137, 0x004B5349, 0x00525D3D, 0x00526330, 0x00434E2D, 0x003E4236, 0x004C533E, 0x003B4130, 0x00525944, 0x004F622B, 0x00485632,
        0x003F4932, 0x004E534A, 0x00474C43, 0x005C6551, 0x005F6B4D, 0x005C684A, 0x00465236, 0x004C524D, 0x0068725B, 0x005B6B3C, 0x00475924, 0x0039461A, 0x00404627, 0x0045482F, 0x004B4D37, 0x00484B35, 0x00494B37, 0x004B4D39, 0x004B4D39, 0x004A4C39,
        0x004A4C39, 0x004B4C3C, 0x004C4D3D, 0x004C4B37, 0x00504F3B, 0x004C4C3A, 0x004A4C38, 0x004E543B, 0x006A7555, 0x006B7852, 0x0068794E, 0x006D7B51, 0x006E7D51, 0x006F7E52, 0x00717F55, 0x00687353, 0xFFE7EDDA, 0xFFFFFFFC, 0xFFFFFEFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x4896C2EB, 0x005F9FE0, 0x0056A0F2, 0x005CA3ED, 0x0062A7ED, 0x005BA5F3, 0x005BA5F7, 0x00549BE5, 0x00589BE6, 0x005C9FEA, 0x00589CE7, 0x005B9FEA, 0x00599DE8,
        0x005299E3, 0x00559CE6, 0x005299E3, 0x0062A0E6, 0x005E9EE5, 0x005C9DE7, 0x00579BE4, 0x005B9DE4, 0x005F9EE2, 0x00417CBA, 0x000F4885, 0x00093B69, 0x00123872, 0x003B6C9E, 0x005794C6, 0x005584BA, 0x003B5A63, 0x003B5232, 0x00344530, 0x004A4E42,
        0x00696C5C, 0x004C4D39, 0x005D6047, 0x0045482F, 0x00333922, 0x00353E29, 0x00202B17, 0x00292B15, 0x0030311D, 0x004A4A38, 0x00777767, 0x008C8A7F, 0x009B998F, 0x0087847C, 0x00898580, 0x00908A7F, 0x00867F76, 0x0088837A, 0x0089847B, 0x00838078,
        0x008A877F, 0x009A9792, 0x00ABA8A3, 0x0094928A, 0x00464834, 0x00353822, 0x002D2F23, 0x00292D1A, 0x0037451B, 0x00435421, 0x005D6B41, 0x006A7449, 0x005A643A, 0x00555F35, 0x00535D33, 0x00454E26, 0x0059623A, 0x0048502B, 0x00545C37, 0x00566141,
        0x00636F4B, 0x006D7B52, 0x004D5B31, 0x00546337, 0x00505E34, 0x00606E45, 0x005F6C46, 0x0068724E, 0x00545E3A, 0x0057613D, 0x005A6440, 0x005B6541, 0x005D6743, 0x00626C48, 0x005B6541, 0x00657845, 0x00677A49, 0x00708155, 0x005F6C46, 0x00535E3E,
        0x003F452C, 0x00424732, 0x003E422F, 0x00474F31, 0x00434A2F, 0x00464D32, 0x004E5239, 0x004C4F39, 0x00434531, 0x003F412D, 0x00434532, 0x00414637, 0x003B4031, 0x00333829, 0x0036392A, 0x004B4E3F, 0x00575A4B, 0x004E4E40, 0x004E4E40, 0x00474735,
        0x00505040, 0x004F4F3F, 0x00676658, 0x00626055, 0x00555349, 0x005B5850, 0x006D6964, 0x00666459, 0x00555348, 0x0067655B, 0x00706E64, 0x005E5C51, 0x00494937, 0x00383B22, 0x003F4326, 0x00686E6D, 0x00AAB1B4, 0x00A8B0B7, 0x00B4BDC6, 0x00A9B3B3,
        0x00788577, 0x00687758, 0x00707E54, 0x006B7A54, 0x0072815B, 0x00687A51, 0x00687A55, 0x00848F85, 0x00B2B7C6, 0x009EAAAC, 0x00677D60, 0x0068754F, 0x006A7A51, 0x00677A4F, 0x0065794F, 0x0062754E, 0x00414E2E, 0x00262D12, 0x00393C26, 0x003A3C1F,
        0x003C3E20, 0x003C3F1F, 0x003B3F1C, 0x003E421F, 0x00454729, 0x0048492F, 0x0047472F, 0x00404528, 0x0041442A, 0x00434228, 0x00454128, 0x00414024, 0x003C401D, 0x00465228, 0x005D6C40, 0x005B693F, 0x0059693A, 0x00556535, 0x00576737, 0x0059673D,
        0x00515C3C, 0x004D5340, 0x0053574B, 0x00414A3D, 0x004B5245, 0x00546036, 0x0055622E, 0x00464834, 0x004E5142, 0x00454F38, 0x004D534E, 0x004F583D, 0x00526233, 0x0040492E, 0x0041433D, 0x00515647, 0x00494D42, 0x005A5F50, 0x004C5C2C, 0x00465430,
        0x003F4833, 0x0050554C, 0x004A4E48, 0x00636B5A, 0x00697559, 0x005F6B4D, 0x00465137, 0x004E544F, 0x0067715A, 0x005A6A3B, 0x00465823, 0x00384519, 0x003F4526, 0x00464930, 0x004B4D37, 0x00464733, 0x00484935, 0x004A4B37, 0x004A4B37, 0x004A4B37,
        0x00494A36, 0x00494A36, 0x004A4B37, 0x004A4934, 0x004F4E3A, 0x004B4C38, 0x00494B37, 0x004E543B, 0x006B7656, 0x006C7953, 0x006A7B50, 0x006E7C52, 0x006E7D51, 0x006E7D51, 0x00717F55, 0x00697454, 0xFFE9EFDC, 0xFFFFFFFC, 0xFFFFFEFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x4896C2EB, 0x005F9FE0, 0x0054A0F2, 0x005BA2EC, 0x0062A7ED, 0x005BA5F3, 0x0059A5F7, 0x00549BE5, 0x00579AE5, 0x005C9FEA, 0x00589CE7, 0x005B9FEA, 0x00599DE8,
        0x00539AE4, 0x00569DE7, 0x00539AE4, 0x005C9DE2, 0x00599BE2, 0x00599DE6, 0x00579BE4, 0x005A9CE3, 0x0063A2E6, 0x004784C2, 0x00124B88, 0x00154470, 0x001D4078, 0x004A78A8, 0x005C97C9, 0x00507EB4, 0x003C5962, 0x003D5336, 0x00394937, 0x0064665A,
        0x00878878, 0x00585945, 0x005C5C44, 0x004B4E35, 0x003B3E28, 0x00444B36, 0x0028331F, 0x002E301A, 0x00333420, 0x004A4A38, 0x00737363, 0x00817F74, 0x0086847A, 0x007B7870, 0x00898580, 0x00898378, 0x00847D74, 0x008A857C, 0x00959087, 0x008F8C84,
        0x0088857D, 0x0095928D, 0x00B2AFAA, 0x00A3A098, 0x004D4E3A, 0x00343721, 0x003C3C30, 0x00333724, 0x0039451B, 0x003C4D1A, 0x005A683E, 0x00667345, 0x00687547, 0x006C794B, 0x00727F53, 0x00515E32, 0x00626E44, 0x00566238, 0x0078845A, 0x00717E58,
        0x006D7B52, 0x00515F35, 0x0057663A, 0x004B5A2E, 0x00657448, 0x006E7D51, 0x006F7E52, 0x00718152, 0x006B7A4E, 0x00748258, 0x00748259, 0x00748259, 0x0078865C, 0x0077865A, 0x00708051, 0x006E844A, 0x006A7E49, 0x00647647, 0x00404C28, 0x004B543A,
        0x00555848, 0x00787970, 0x0083837D, 0x006C705D, 0x006E705D, 0x00727461, 0x00777765, 0x00777563, 0x00706C5A, 0x006B6453, 0x00696251, 0x006D6964, 0x005B5850, 0x006C6961, 0x006E6D63, 0x0056564A, 0x00505344, 0x00505343, 0x00434636, 0x0042442E,
        0x004C4D39, 0x0050503E, 0x006A695B, 0x0067655B, 0x005A5651, 0x005B5653, 0x006C6766, 0x00666459, 0x00545247, 0x0068665C, 0x00716F65, 0x00605E53, 0x004D4D3B, 0x003E4128, 0x0045492C, 0x00666B6C, 0x00AEB4B9, 0x00ACB4BB, 0x00B0BAC1, 0x0096A29C,
        0x00697962, 0x006B7D54, 0x00738550, 0x00717F5B, 0x0075845E, 0x00708455, 0x00657B4B, 0x00687762, 0x00A7AEB7, 0x009EAAAC, 0x006B8067, 0x00697650, 0x00697950, 0x0066794E, 0x0065794F, 0x0062754E, 0x00414E2E, 0x00262D12, 0x003A3D27, 0x00393B1E,
        0x003C3E20, 0x003C3F1F, 0x00393D1A, 0x003C401D, 0x00444628, 0x0047482E, 0x0045452D, 0x00414629, 0x0042452B, 0x0042422A, 0x0045432B, 0x00434226, 0x003D4222, 0x0047522A, 0x005C6B3F, 0x005C6A40, 0x005B6A3E, 0x00596939, 0x005B6B3B, 0x005B693F,
        0x00525D3D, 0x004C523F, 0x0052564B, 0x00485246, 0x004C544A, 0x00546239, 0x00505E2E, 0x00454838, 0x0055594D, 0x003D4834, 0x004E5552, 0x00464F3A, 0x003C4C23, 0x003E4732, 0x00444745, 0x00464C41, 0x00464A44, 0x004C5247, 0x0045562A, 0x00455331,
        0x004C5541, 0x00525650, 0x00494D48, 0x00616958, 0x00646F55, 0x00677357, 0x0049533C, 0x00525853, 0x0067715A, 0x00586839, 0x00465823, 0x00374418, 0x003F4526, 0x00464930, 0x004B4D37, 0x00444531, 0x00464733, 0x00484A34, 0x00494B35, 0x00474933,
        0x00464832, 0x00454731, 0x0045482F, 0x00464530, 0x004B4A35, 0x00494A36, 0x00474A34, 0x004D5439, 0x006A7554, 0x006C7A51, 0x006B7C50, 0x00707E54, 0x006F7E52, 0x006E7D51, 0x00717F55, 0x00687353, 0xFFE8EEDB, 0xFFFFFFFC, 0xFFFFFEFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x4593C1EA, 0x005D9FE0, 0x00539FF1, 0x0059A2EC, 0x0061A6EC, 0x005AA5F3, 0x0059A5F7, 0x00529BE5, 0x00579AE5, 0x005C9FEA, 0x00599DE8, 0x005CA0EB, 0x005B9FEA,
        0x00559CE6, 0x0059A0EA, 0x00569DE7, 0x005C9DE2, 0x005A9CE3, 0x005B9FE8, 0x00589DE6, 0x00599EE4, 0x0061A0E4, 0x00427FBD, 0x000D4683, 0x00154674, 0x00163B75, 0x00426FA2, 0x005792C4, 0x004F7DB3, 0x003D5A63, 0x00415636, 0x003F4E39, 0x005E6054,
        0x007D7E6E, 0x0062614D, 0x006B6B53, 0x005A5A42, 0x003A3D27, 0x00474E39, 0x0038412D, 0x003A3924, 0x002A2915, 0x0042402E, 0x00827F70, 0x0089857A, 0x007E7970, 0x007E7871, 0x00817B76, 0x00888277, 0x00857E75, 0x00858077, 0x008F8A81, 0x008B8880,
        0x00827F77, 0x00928F8A, 0x00B0ADA8, 0x0099968E, 0x00464733, 0x002E301A, 0x00444438, 0x00393B28, 0x003B471D, 0x00404F1C, 0x00647046, 0x006B7949, 0x006C7A4A, 0x006D7A4C, 0x00748153, 0x004B582C, 0x00576438, 0x004E5B2F, 0x007D895F, 0x00717F55,
        0x0067754B, 0x0046542A, 0x005B693F, 0x0057653B, 0x00718054, 0x00758556, 0x00718151, 0x00708050, 0x00728155, 0x0076845B, 0x0077835F, 0x00727E5A, 0x0075835A, 0x0077865A, 0x00798959, 0x0070854E, 0x0070844F, 0x0066774B, 0x00404C28, 0x004B543A,
        0x00555849, 0x008A8B82, 0x00B1B0AC, 0x00B1B5A2, 0x00B6BAA7, 0x00B5B7A4, 0x00A7A795, 0x00949280, 0x00817F6D, 0x00736F5D, 0x006B6453, 0x005C5853, 0x0059564E, 0x007F7C74, 0x00848379, 0x005E5E52, 0x00575A4B, 0x00535646, 0x00353828, 0x0041432D,
        0x00474834, 0x004C4C3A, 0x00676658, 0x0067655B, 0x005D5954, 0x00595451, 0x00686362, 0x0067655A, 0x00545247, 0x0066645A, 0x006F6D63, 0x005E5C51, 0x004C4C3A, 0x003E4128, 0x00464A2D, 0x00686D70, 0x00A9AFB4, 0x00A9B0B9, 0x00ADB8BC, 0x008B9791,
        0x0063735B, 0x006B7E53, 0x006C7F48, 0x00748260, 0x0063724C, 0x006A7F4E, 0x006A814D, 0x00617159, 0x009FA7AE, 0x009EAAAC, 0x006C8069, 0x00697650, 0x0068784F, 0x0065784D, 0x0065794F, 0x0062754E, 0x00404D2D, 0x00262D12, 0x003B3E28, 0x003A3C1F,
        0x003C3E20, 0x003C3F1F, 0x003A3E1B, 0x003C401D, 0x00414325, 0x0043442A, 0x0042422A, 0x0041482D, 0x0044472E, 0x0045452D, 0x0048462E, 0x0045462C, 0x003F4424, 0x0046542B, 0x005B6C41, 0x005D6B42, 0x005D6C40, 0x005B6B3C, 0x005C6C3D, 0x005B6940,
        0x00525C3E, 0x004E5443, 0x00565A4F, 0x00586157, 0x00676E67, 0x00525E3A, 0x00556234, 0x004B4E3F, 0x0054574E, 0x00535D4C, 0x006B7170, 0x005A634F, 0x00374620, 0x004B5440, 0x00505253, 0x0051554F, 0x006D706E, 0x005A5E58, 0x0046562D, 0x00424F2F,
        0x00505847, 0x00525651, 0x006A6D6B, 0x007A8172, 0x00535D46, 0x00606B51, 0x004B543F, 0x00585E59, 0x0068725B, 0x00576738, 0x00465823, 0x00364317, 0x003F4526, 0x00474A31, 0x004A4C36, 0x00474632, 0x00494834, 0x004A4934, 0x004A4A32, 0x0047472F,
        0x0044452B, 0x00424329, 0x00424427, 0x0043432B, 0x00494833, 0x00464832, 0x00454832, 0x004C5338, 0x006A7554, 0x006C7A51, 0x006A7B4F, 0x00717F55, 0x00718054, 0x006F7E52, 0x00717F55, 0x00677252, 0xFFE6ECD9, 0xFFFFFFFC, 0xFFFEFDFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x4593C1EA, 0x005D9FE0, 0x0051A0F1, 0x0059A2EC, 0x0060A6EC, 0x0059A4F2, 0x0056A5F6, 0x00529BE5, 0x00589BE6, 0x005C9FEA, 0x005A9EE9, 0x005DA1EC, 0x005CA0EB,
        0x00569DE7, 0x005AA1EB, 0x00589FE9, 0x0065A8ED, 0x005EA3E9, 0x005A9FE8, 0x00589DE6, 0x005A9FE5, 0x005E9FE3, 0x004483C0, 0x001B5793, 0x001B5186, 0x00174281, 0x0037699E, 0x00508FC2, 0x005282B6, 0x003E5B60, 0x0040522D, 0x0038452B, 0x00616155,
        0x00777767, 0x0064634F, 0x00626048, 0x0056563E, 0x0042442E, 0x00545944, 0x004A533F, 0x0033321D, 0x003B3A26, 0x00393725, 0x005C594A, 0x00827E73, 0x008A857C, 0x00868079, 0x0087817C, 0x00857F74, 0x00847D74, 0x007D786F, 0x00817C73, 0x00817E76,
        0x00838078, 0x0096938E, 0x00A8A5A0, 0x007A746D, 0x00474834, 0x0040422C, 0x0058564B, 0x003E402D, 0x00454F25, 0x00485724, 0x0069754B, 0x006C7C4D, 0x0069794A, 0x00677748, 0x006D7C50, 0x004F5E32, 0x0059673D, 0x004B592F, 0x00738157, 0x006E7D51,
        0x0069774D, 0x0058653F, 0x004F5C36, 0x0065724C, 0x006A784E, 0x00758556, 0x00697949, 0x0057683D, 0x005C6B45, 0x00596547, 0x00657056, 0x005F6A50, 0x00556143, 0x00586741, 0x00617247, 0x006D804F, 0x006B7D4E, 0x006E7F54, 0x00636F4B, 0x00626B50,
        0x0050563F, 0x00676A5A, 0x00878A7B, 0x007B8567, 0x008B9479, 0x00929B80, 0x00889177, 0x007A826B, 0x00747B66, 0x00717863, 0x006E7461, 0x00707566, 0x009CA192, 0x00BCC1B2, 0x00959889, 0x00555849, 0x00444738, 0x004C4C3E, 0x00505042, 0x00444432,
        0x00464636, 0x004B4B3B, 0x00656456, 0x0069675C, 0x00626056, 0x005C5951, 0x006B6762, 0x0069675C, 0x00555348, 0x0066645A, 0x006D6B61, 0x005B594E, 0x00474735, 0x00393C23, 0x00414528, 0x00696E6F, 0x00A5ABB0, 0x00ACB3BC, 0x00B2BCC3, 0x008B9693,
        0x005C6C55, 0x0065774E, 0x00758653, 0x0073815F, 0x006B7955, 0x006F8354, 0x005E7443, 0x00596853, 0x009CA3AC, 0x00A3AEB2, 0x00697D66, 0x00697650, 0x0067774E, 0x0064774C, 0x0065794F, 0x0061744D, 0x003F4C2C, 0x00262D12, 0x003D402A, 0x003B3D20,
        0x003B3D1F, 0x003C3F1F, 0x003B3F1C, 0x003B3F1C, 0x003C3E20, 0x003F4026, 0x0042422A, 0x0042492E, 0x00454930, 0x00484732, 0x00494833, 0x0046472D, 0x003F4526, 0x0047542E, 0x005C6D42, 0x005F6D44, 0x005D6B41, 0x005A6A3B, 0x0059693A, 0x0058663D,
        0x00535D3F, 0x00555B4A, 0x0061645B, 0x00B3BDB7, 0x00BDC3BE, 0x005F6D4B, 0x005A663C, 0x004D4F43, 0x00575B55, 0x009CA696, 0x00C9D0D3, 0x0068735F, 0x003D4E29, 0x004C5743, 0x004B4F50, 0x00767D76, 0x00D1D6D4, 0x008E958E, 0x0036481F, 0x00505C3E,
        0x004C5344, 0x00636664, 0x00C3C6C4, 0x00CCD3C6, 0x00535C47, 0x00505A43, 0x005A634F, 0x005E645F, 0x0069735C, 0x00586839, 0x00475924, 0x00364317, 0x003E4425, 0x00474A31, 0x004A4C36, 0x00494834, 0x004A4935, 0x004A4934, 0x00484830, 0x0045462C,
        0x00424427, 0x00404224, 0x00404323, 0x0042422A, 0x00474631, 0x00454731, 0x00454930, 0x004B5335, 0x00697551, 0x006C7A50, 0x006A7C4D, 0x00717F55, 0x00718054, 0x00718054, 0x00717F55, 0x00657050, 0xFFE3E9D6, 0xFFFEFFFB, 0xFFFEFDFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x4593C1EA, 0x005A9EDF, 0x0051A0F1, 0x0057A2EC, 0x0060A6EC, 0x0057A5F2, 0x0056A5F6, 0x004F9AE4, 0x00599CE7, 0x005DA0EB, 0x005A9EE9, 0x005DA1EC, 0x005CA0EB,
        0x00569DE7, 0x0059A0EA, 0x00579EE8, 0x0061A4E9, 0x005BA0E6, 0x00569BE4, 0x00569BE4, 0x005CA1E7, 0x0062A3E7, 0x005B9AD7, 0x004C88C4, 0x004888C2, 0x004C80C3, 0x00538CC4, 0x005092C7, 0x00497CAE, 0x003B595A, 0x0044572C, 0x00374221, 0x00323226,
        0x00454535, 0x00403F2B, 0x0035331B, 0x003C3A22, 0x00393B25, 0x004F543F, 0x005B6450, 0x00696651, 0x00807C69, 0x00787462, 0x00656051, 0x007A7469, 0x00908980, 0x008A827B, 0x008D8480, 0x00888277, 0x008E877E, 0x00878279, 0x00878279, 0x0088857D,
        0x00908D85, 0x009A9792, 0x00928F8A, 0x00655F58, 0x00686753, 0x0073755F, 0x00747267, 0x003F3F2D, 0x004D572D, 0x0055612F, 0x006B754B, 0x00647347, 0x006D7B51, 0x00748258, 0x006D7B51, 0x004F5D34, 0x0057653C, 0x00505D37, 0x0077845E, 0x00748258,
        0x0067754C, 0x00485430, 0x00566141, 0x00576241, 0x007B8862, 0x00728155, 0x00617141, 0x004B5937, 0x00505B41, 0x0048503F, 0x00676D62, 0x00646A5F, 0x0048503F, 0x00444F35, 0x004C5A38, 0x00707F59, 0x00677650, 0x006D7C56, 0x00727E5A, 0x00626D4C,
        0x004F5738, 0x0051593A, 0x00596142, 0x004E5F34, 0x00506037, 0x004A5C35, 0x003D4E2C, 0x00324425, 0x00304328, 0x0032472E, 0x00344831, 0x002B3E25, 0x0036462E, 0x002D3A24, 0x00202B17, 0x00404635, 0x005B5E4F, 0x00535347, 0x004E4C41, 0x00504E43,
        0x00504E43, 0x00555348, 0x006A685D, 0x0069675C, 0x00615F54, 0x0059574C, 0x0069675C, 0x006E6C61, 0x005B594E, 0x006D6B61, 0x00747268, 0x00615F54, 0x004D4D3B, 0x003D4027, 0x0045492C, 0x00686D6E, 0x00A6ACB1, 0x00AEB5BE, 0x00B5BEC7, 0x009AA4A4,
        0x00667363, 0x005B6A4A, 0x00707F53, 0x00697755, 0x006E7C58, 0x0063764B, 0x004A5E34, 0x006A7769, 0x00A4A9B8, 0x00A1ACB0, 0x00697E65, 0x00697650, 0x0066764D, 0x0063764B, 0x0064784E, 0x0061744D, 0x003F4C2C, 0x00252C11, 0x003D402A, 0x003D3F22,
        0x003A3C1E, 0x003A3D1D, 0x003B3F1C, 0x00393D1A, 0x0037391B, 0x003D3E24, 0x0046462E, 0x0040462D, 0x00454930, 0x00484A34, 0x004A4934, 0x0044472E, 0x003E4425, 0x0046532D, 0x005A6D42, 0x005D6B42, 0x005D6B41, 0x005A693D, 0x0059683C, 0x0058653F,
        0x00545D42, 0x00585E4D, 0x00666960, 0x00E1EAE7, 0x00D8DFDC, 0x00647151, 0x00546239, 0x004C5045, 0x00636762, 0x00AEB8AB, 0x00EDF3F8, 0x006F7A66, 0x00556740, 0x005E6955, 0x005A5F5E, 0x008D958B, 0x00F1F7F2, 0x00A5ADA3, 0x0046592E, 0x00626E52,
        0x00565D4E, 0x006F7171, 0x00D4D6D6, 0x00DAE0D5, 0x0057604B, 0x00525B46, 0x006A735F, 0x00636964, 0x006B755E, 0x00586839, 0x00485A25, 0x00364317, 0x003E4425, 0x00474A31, 0x00494B35, 0x004C4835, 0x004C4835, 0x004B4833, 0x0049482E, 0x00464529,
        0x00434424, 0x00424321, 0x00424321, 0x0043432B, 0x00484830, 0x00464832, 0x00464A31, 0x004C5436, 0x006A7652, 0x006D7B51, 0x006C7E4F, 0x006F7D53, 0x00707F53, 0x00718054, 0x00707E54, 0x00636E4E, 0xFFE1E7D4, 0xFFFDFEFA, 0xFFFFFEFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x4593C1EA, 0x005A9EDF, 0x0051A0F1, 0x0056A1EB, 0x0060A6EC, 0x0057A5F2, 0x0056A5F6, 0x004F9AE4, 0x005A9DE8, 0x005EA1EC, 0x005A9EE9, 0x005DA1EC, 0x005B9FEA,
        0x00549BE5, 0x00579EE8, 0x00559CE6, 0x005C9FE4, 0x005CA1E7, 0x005BA0E9, 0x0058A0E8, 0x00599FE5, 0x005B9CE0, 0x005E9DDA, 0x0064A0DC, 0x004F96D5, 0x0065A0E6, 0x005897D1, 0x003379AE, 0x00255A8C, 0x002E4B48, 0x004A5C2D, 0x003A451F, 0x00535347,
        0x005F5F4F, 0x006B6754, 0x005F5D45, 0x0058563E, 0x00343620, 0x003C412C, 0x006A705D, 0x006F6C57, 0x00676350, 0x00969280, 0x008E897A, 0x00696358, 0x00807970, 0x00958D86, 0x00928985, 0x00938D82, 0x00A09990, 0x009E9990, 0x009C978E, 0x0099968E,
        0x009D9A92, 0x0097948F, 0x0076736E, 0x0069635C, 0x008F8E7A, 0x00A3A28D, 0x00848277, 0x00363624, 0x004D572D, 0x005E6A38, 0x006F794F, 0x006E7C52, 0x006F7D54, 0x006A784F, 0x0056643B, 0x00424F29, 0x00515E38, 0x00495531, 0x00636F4B, 0x006F7D53,
        0x004C5933, 0x00566141, 0x00566042, 0x00555F41, 0x00626E4A, 0x0077855B, 0x005B6B3C, 0x004F5A40, 0x005B6450, 0x005C6158, 0x00919492, 0x00919492, 0x0061665D, 0x004C5541, 0x0049543A, 0x006C7959, 0x00667452, 0x00707E5C, 0x006E7A56, 0x0046532D,
        0x003D4820, 0x003E4A20, 0x00344016, 0x00384C17, 0x002E4410, 0x0022390C, 0x001E360C, 0x001C3612, 0x00173315, 0x00112E14, 0x000B2910, 0x0015300E, 0x00183010, 0x000E2407, 0x0017250D, 0x00404935, 0x00555849, 0x004B493E, 0x00514C43, 0x004B4840,
        0x004E4B43, 0x00555349, 0x0069675C, 0x00676658, 0x00605F51, 0x00595949, 0x006D6D5B, 0x006A685D, 0x0058564B, 0x006B695F, 0x00747268, 0x00626055, 0x004D4D3B, 0x003E4128, 0x0044482B, 0x00696F6E, 0x00A6ADB0, 0x00A8AFB8, 0x00B3BCC6, 0x00B1BABD,
        0x007D897D, 0x004B593D, 0x004C5933, 0x005A6844, 0x00505E3C, 0x00394B24, 0x00425331, 0x0096A199, 0x00B3B7C9, 0x0097A1A8, 0x006E836A, 0x00697650, 0x0066764D, 0x0062754A, 0x0064784E, 0x0061744D, 0x003E4B2B, 0x00252C11, 0x003E412B, 0x003E4023,
        0x00393B1D, 0x00383B1B, 0x003B3F1C, 0x00383C19, 0x00343618, 0x003D3E24, 0x004A4A32, 0x003F452C, 0x00454832, 0x00484A34, 0x004A4934, 0x0043462D, 0x003C4223, 0x0045522C, 0x005A6C43, 0x005B6842, 0x005D6B41, 0x005C6B3F, 0x005D6C40, 0x005B6842,
        0x00555E43, 0x00575C4D, 0x0064675E, 0x00848D8A, 0x00818786, 0x004C583A, 0x00536138, 0x00565950, 0x00606361, 0x005F695D, 0x008D9398, 0x0055614B, 0x004C5E35, 0x005E6A54, 0x005B605E, 0x005B6358, 0x00868D86, 0x005F675D, 0x0053673A, 0x00596549,
        0x005E6558, 0x005C5E5E, 0x00787A7B, 0x007E8479, 0x00424B37, 0x0057604B, 0x005F6756, 0x00666C67, 0x006C765F, 0x0059693A, 0x00485A25, 0x00364317, 0x003E4425, 0x00474A31, 0x00484A34, 0x004B4734, 0x004B4734, 0x004B4833, 0x0048472D, 0x00454527,
        0x00434424, 0x00434422, 0x00444622, 0x0044442C, 0x004A4A32, 0x00474A31, 0x00474B32, 0x004E5638, 0x006C7854, 0x006E7C52, 0x006D7F50, 0x006C7A50, 0x006F7E52, 0x00707F53, 0x00707E54, 0x00626D4D, 0xFFE0E6D3, 0xFFFEFFFB, 0xFFFFFEFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x4594C2EB, 0x005DA1E2, 0x0053A2F3, 0x005AA3ED, 0x0061A6EC, 0x005AA4F2, 0x005BA5F7, 0x00589CE7, 0x005A9EE9, 0x005B9FEA, 0x005DA1EC, 0x005CA0EB, 0x005B9FEA,
        0x005A9EE9, 0x005A9EE9, 0x005A9EE9, 0x0062A1EB, 0x005A9EE9, 0x00559EE8, 0x004F9BE3, 0x005AA2E8, 0x0067A4E6, 0x005587C3, 0x00406BA4, 0x003D6B94, 0x00466F8F, 0x00406272, 0x00344E4E, 0x00172C1D, 0x001A2D14, 0x00556748, 0x003F5330, 0x00616363,
        0x008A8985, 0x00949288, 0x008D8A7B, 0x006A6653, 0x003E3D29, 0x003A3A28, 0x00727461, 0x0087857D, 0x007B7A70, 0x00707064, 0x003F3E30, 0x00383826, 0x00605F4A, 0x007E7E66, 0x0082826A, 0x00807D79, 0x009D9A96, 0x00BFBBBA, 0x00ACA9A5, 0x009B9991,
        0x00858676, 0x0061644E, 0x003C4126, 0x00625F5A, 0x007E7D73, 0x00B1B1A3, 0x00464B36, 0x0042492E, 0x00656E4D, 0x00606D47, 0x006C7A51, 0x006B7C51, 0x006C7D51, 0x006E7E55, 0x00303C20, 0x00383F32, 0x00585E53, 0x004A543D, 0x0054623E, 0x00687652,
        0x00444E37, 0x007E8479, 0x006B7265, 0x00535E44, 0x005B6A44, 0x006D7D54, 0x00677551, 0x00516D6E, 0x00678A98, 0x005B7D94, 0x00638095, 0x00557892, 0x00527B94, 0x005E7D7C, 0x00586342, 0x0067784C, 0x006D7E53, 0x006B7A54, 0x004B5937, 0x005C684A,
        0x00535E44, 0x004C563F, 0x00313A25, 0x00474B32, 0x004E5338, 0x004E5338, 0x00505538, 0x00505637, 0x00454B2C, 0x003E4524, 0x003E4524, 0x00494B3F, 0x00585A4E, 0x00434539, 0x00454539, 0x004E4D43, 0x00545248, 0x004F4D43, 0x00535147, 0x00484A3E,
        0x004B4D41, 0x0054554B, 0x0064655B, 0x0068695F, 0x00595A51, 0x0057584F, 0x00696A61, 0x00656456, 0x005A594B, 0x006B6B5B, 0x00757563, 0x00646551, 0x004D4F39, 0x0042442E, 0x00464930, 0x006F7374, 0x00A9ACB0, 0x00B0B3BB, 0x00B7B9C3, 0x00B6BBC4,
        0x00B0B6BD, 0x00868F92, 0x004E5957, 0x0037453F, 0x0036453D, 0x005A6961, 0x00919D9D, 0x00A6AFB9, 0x00A8B1BB, 0x0099A7A3, 0x006D806D, 0x00687A51, 0x006A7C53, 0x00667851, 0x00697755, 0x00697656, 0x00424C2E, 0x00212A0F, 0x00394228, 0x003C441C,
        0x003B4020, 0x00353920, 0x00393C2C, 0x00393C33, 0x00757672, 0x00BDC0BE, 0x00C2C7C5, 0x0062654F, 0x003D3F29, 0x0042422A, 0x0048472B, 0x0048482A, 0x003C4121, 0x004A5430, 0x005E6D47, 0x005D694B, 0x00667452, 0x005B6B42, 0x005B6C41, 0x00576640,
        0x005B664C, 0x0061675C, 0x00535654, 0x00353B36, 0x00414C38, 0x00566742, 0x004D5F36, 0x00536242, 0x00626E58, 0x00414D37, 0x003F4C34, 0x004B5D36, 0x004F5C42, 0x004B5348, 0x00737B70, 0x0049553F, 0x00364525, 0x004B5B39, 0x00556445, 0x003E4F2A,
        0x006B7564, 0x00666B69, 0x0040493C, 0x0043542F, 0x00576B3E, 0x00455435, 0x005D655B, 0x007A7E7F, 0x00656D5C, 0x005F6D44, 0x00455525, 0x003D4822, 0x00454930, 0x004F4F3D, 0x00484838, 0x004E4C34, 0x0048462E, 0x0054513C, 0x003D3C28, 0x0043422D,
        0x00414228, 0x00393E1E, 0x003A401D, 0x003D4526, 0x00474F31, 0x004A5136, 0x004F583E, 0x004F583E, 0x00657155, 0x006F7C5C, 0x006A7854, 0x00707E5A, 0x00707F59, 0x0073835A, 0x0073825C, 0x00606C4E, 0xFFDEE6D5, 0xFFFDFFFE, 0xFFFDFDFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x4594C2EB, 0x005DA1E2, 0x0054A3F4, 0x005AA3ED, 0x0061A6EC, 0x005AA4F2, 0x005BA5F7, 0x00589CE7, 0x005A9EE9, 0x005CA0EB, 0x005DA1EC, 0x005CA0EB, 0x005B9FEA,
        0x005A9EE9, 0x005A9EE9, 0x005B9FEA, 0x005F9EE8, 0x00589CE7, 0x0057A0EA, 0x0054A0E8, 0x005BA3E9, 0x00609DDF, 0x00467AB6, 0x002F5C95, 0x00687284, 0x005B6471, 0x00444B4E, 0x00393D37, 0x002B2E1F, 0x00313522, 0x00616750, 0x00444C35, 0x003E423C,
        0x006C7065, 0x00929383, 0x007F7E6A, 0x00505038, 0x006B6B53, 0x007F826C, 0x00676C57, 0x005D5D51, 0x00818173, 0x00646456, 0x002D2D1D, 0x00323222, 0x00363624, 0x004A4836, 0x0062614D, 0x00646652, 0x00838572, 0x00939385, 0x00757569, 0x0067675B,
        0x004D4D3F, 0x00323421, 0x002C2E1A, 0x0054524A, 0x0098988C, 0x00656656, 0x002F341F, 0x006C7358, 0x0065704F, 0x006D7A54, 0x00738158, 0x00728358, 0x006F8054, 0x006A7A51, 0x00465236, 0x00697063, 0x0081877C, 0x005F6952, 0x0053613D, 0x006B7955,
        0x004F5942, 0x00979D92, 0x0092998C, 0x0059644A, 0x005B6A44, 0x0076865D, 0x005E6C48, 0x00577677, 0x00779BAB, 0x006F94AA, 0x007494AB, 0x006D92AC, 0x00719DB5, 0x00709291, 0x00586644, 0x00728357, 0x006D7E53, 0x00677551, 0x00434F31, 0x00545E47,
        0x004A5142, 0x00757B70, 0x0081867D, 0x0070725E, 0x00747662, 0x006F715D, 0x006B6D59, 0x006A6C58, 0x00636551, 0x00585A46, 0x0052553F, 0x00555848, 0x00707364, 0x00757869, 0x00767668, 0x005E5E52, 0x00555348, 0x00514F45, 0x004F4D43, 0x00525244,
        0x004C4C3E, 0x00545448, 0x006A6A5E, 0x00717066, 0x00605F55, 0x005E5C54, 0x0074726A, 0x006E6C61, 0x00565449, 0x00525143, 0x00565646, 0x0051513F, 0x00454632, 0x003D3F29, 0x00454731, 0x006A6E6F, 0x00AAADB1, 0x00B4B7BF, 0x00B3B5BF, 0x00AEB3BC,
        0x00B4BAC1, 0x00B3BCBF, 0x00ABB5B5, 0x00A9B6B4, 0x00A5B3AD, 0x00AAB8B2, 0x00B1BCC0, 0x00AEB6C3, 0x00B1B9C6, 0x009DAAA8, 0x00647665, 0x00687A51, 0x006A7C53, 0x00667851, 0x00687654, 0x00687555, 0x00424C2E, 0x00212A0F, 0x003A4329, 0x00394119,
        0x003A3F1F, 0x003C4027, 0x00393C2D, 0x00A5A89F, 0x00FFFFFC, 0x00FDFFFC, 0x00C3C8C6, 0x00585B45, 0x003F412B, 0x0044442C, 0x0046452B, 0x00464628, 0x003B4020, 0x0048522E, 0x005F6E48, 0x005B6947, 0x0064734D, 0x005F7045, 0x00637449, 0x00586642,
        0x00555F48, 0x0071766D, 0x005F6161, 0x002F362F, 0x003B4534, 0x00505E42, 0x004A583C, 0x006A7463, 0x006B7369, 0x00353D32, 0x00374130, 0x00495A35, 0x00515C48, 0x00585E59, 0x00757A79, 0x00576053, 0x0035422A, 0x00445236, 0x0057644A, 0x004C5645,
        0x00737876, 0x0066696D, 0x00363E34, 0x00394828, 0x0061734C, 0x005E6A54, 0x006F7473, 0x0085898A, 0x00555D4C, 0x0057653C, 0x00495929, 0x003B4620, 0x003F432A, 0x004B4B39, 0x00484838, 0x0046472D, 0x0052523A, 0x00454632, 0x00474735, 0x006A6A58,
        0x00383A26, 0x00252910, 0x00282D12, 0x00363C25, 0x00454A35, 0x00464B36, 0x00484F3A, 0x004E563F, 0x006C785C, 0x00758361, 0x006D7C56, 0x00707E5A, 0x00707F59, 0x0073835A, 0x0073825C, 0x00606C4E, 0xFFDEE6D5, 0xFFFCFFFD, 0xFFFDFDFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x4594C2EB, 0x005CA0E1, 0x0054A3F4, 0x005BA4EE, 0x0062A7ED, 0x005BA5F3, 0x005CA6F8, 0x00589CE7, 0x005B9FEA, 0x005CA0EB, 0x005DA1EC, 0x005DA1EC, 0x005B9FEA,
        0x005A9EE9, 0x005A9EE9, 0x005B9FEA, 0x005FA0EA, 0x005A9EE9, 0x0059A2EC, 0x0056A0E8, 0x005BA1E7, 0x005F9FE0, 0x00528AC5, 0x004A7BB3, 0x005282AC, 0x004D7B9D, 0x00466F86, 0x0046656E, 0x003B5349, 0x003B4B33, 0x00676F4A, 0x00555C2F, 0x00293323,
        0x00404935, 0x0051553C, 0x0043472A, 0x00555739, 0x00ADB293, 0x00BCC1A4, 0x006C755A, 0x004D523D, 0x00505540, 0x008C8E7B, 0x00757666, 0x00403F31, 0x00333224, 0x00363429, 0x00383429, 0x00414728, 0x00383D22, 0x00555842, 0x00838474, 0x008A8A7E,
        0x00515145, 0x003A3A2C, 0x005F6050, 0x00A9A99D, 0x00727264, 0x003A3E2B, 0x004D533A, 0x006E785A, 0x00697453, 0x00798660, 0x006C7C53, 0x0067784D, 0x00708155, 0x006D7D54, 0x004A563A, 0x00666D60, 0x006E7469, 0x0058624B, 0x005D6B47, 0x00697753,
        0x004D5740, 0x007B8176, 0x007B8275, 0x0049543A, 0x00596842, 0x0074845B, 0x005A6844, 0x004F7275, 0x00719AA9, 0x006F98AF, 0x007499AF, 0x006F97B3, 0x00709FBA, 0x00668C8C, 0x00465938, 0x0067784D, 0x006B7B52, 0x006F7D5B, 0x004B573B, 0x004D5642,
        0x00444A3F, 0x00858983, 0x00A7AAA8, 0x00B4B9A4, 0x00B1B5A2, 0x00A0A491, 0x00878A7A, 0x00797C6D, 0x006E7162, 0x00616357, 0x005B5D51, 0x00505742, 0x00727663, 0x008C907D, 0x008B8E7E, 0x00606052, 0x00535345, 0x00535146, 0x0049473C, 0x004C4D3D,
        0x004B4C3C, 0x00535444, 0x00626254, 0x00636355, 0x0057574B, 0x005A5A4E, 0x006F6F63, 0x006D6B61, 0x0058564C, 0x004D4B40, 0x004E4D3F, 0x00535343, 0x004C4C3A, 0x00424230, 0x004C4D39, 0x004B504F, 0x00989C9D, 0x00B6BABF, 0x00BABDC5, 0x00B4B9C2,
        0x00AEB4BB, 0x00AEB7BA, 0x00BAC4C4, 0x00B0BBBF, 0x00B1BDBD, 0x00AFBBBB, 0x00A9B2BB, 0x00A4ABBC, 0x00B0B7C6, 0x00A0ACAC, 0x00657668, 0x00697B52, 0x006A7C53, 0x00667851, 0x00687654, 0x00687555, 0x00424C2E, 0x00222B10, 0x003A4329, 0x00404722,
        0x003B4021, 0x0050533D, 0x00333627, 0x00888B82, 0x00BDBFB9, 0x00B9BDB8, 0x00565C57, 0x00464834, 0x0042442E, 0x0047472F, 0x0046452B, 0x00464628, 0x003A3F1F, 0x0046502C, 0x00606E4A, 0x005E6E45, 0x00607146, 0x005A6B3F, 0x00607047, 0x005C6949,
        0x006B7460, 0x00B5B9B3, 0x00939596, 0x00667060, 0x004C5842, 0x0057644C, 0x005C6656, 0x00A1A6A5, 0x00A3A6AA, 0x00606563, 0x00525B4E, 0x0052633E, 0x00535E4A, 0x007E8283, 0x00A9ACB1, 0x00828883, 0x00505B47, 0x00505D43, 0x00576549, 0x005C6061,
        0x00B0B1BB, 0x009EA0A8, 0x004D554A, 0x00445333, 0x00657553, 0x006D7766, 0x009B9EA2, 0x00B9BDBE, 0x00545D49, 0x004F5D34, 0x004C5C2C, 0x0038431B, 0x003C4027, 0x00474735, 0x00484836, 0x004D5237, 0x0050533D, 0x00383C29, 0x005D6051, 0x0092968A,
        0x00363A2E, 0x002F3425, 0x00323A29, 0x0055564C, 0x00505147, 0x0043443A, 0x00494E3F, 0x00565D48, 0x006B775B, 0x006B7955, 0x006C7D52, 0x006F7D59, 0x006F7E58, 0x0073835A, 0x0072815B, 0x005F6B4D, 0xFFDDE5D4, 0xFFFCFFFD, 0xFFFCFCFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x4593C1EA, 0x005CA0E1, 0x0054A3F4, 0x005BA4EE, 0x0063A8EE, 0x005BA5F3, 0x005CA6F8, 0x00589CE7, 0x005B9FEA, 0x005CA0EB, 0x005EA2ED, 0x005DA1EC, 0x005CA0EB,
        0x005B9FEA, 0x005B9FEA, 0x005CA0EB, 0x005FA3EC, 0x005B9FEA, 0x005BA2EC, 0x00569EE6, 0x00599EE4, 0x0063A3E4, 0x00639FDA, 0x0069A1D8, 0x00499EE2, 0x004C9CDB, 0x004C97CB, 0x004585A7, 0x0031636F, 0x00294B40, 0x00556A49, 0x005B6A3E, 0x004C5B40,
        0x00333F23, 0x00444D2C, 0x00464E29, 0x003A411C, 0x007C845F, 0x0098A180, 0x00505B3B, 0x00586042, 0x0040482A, 0x004C5239, 0x00888A76, 0x00959686, 0x00615F54, 0x00535048, 0x003D3934, 0x00393C26, 0x0030321F, 0x00525244, 0x00818076, 0x008B8981,
        0x00828177, 0x0096968A, 0x00B8B8AA, 0x005F6350, 0x00373C27, 0x00454B34, 0x005F684D, 0x006D7858, 0x007C8864, 0x00708057, 0x006E7F54, 0x006C7D52, 0x00728357, 0x006F7F56, 0x00445034, 0x00555C4F, 0x0051574C, 0x00434D36, 0x00596743, 0x00667450,
        0x00454F38, 0x0052584D, 0x004F5649, 0x003F4A30, 0x0065744E, 0x00718158, 0x0065734F, 0x005C8286, 0x0075A1B2, 0x00719DB5, 0x00789EB6, 0x006E9AB7, 0x006D9FBB, 0x006B9294, 0x005A6F4F, 0x006D7F56, 0x006C7E57, 0x00697A55, 0x004F5E3E, 0x004A583C,
        0x0058654D, 0x005F6A56, 0x005D6756, 0x00778065, 0x00828B70, 0x008A9379, 0x00848C75, 0x007F8671, 0x00787E6B, 0x006E7463, 0x006F7465, 0x00737C61, 0x0097A086, 0x00B2BAA3, 0x009FA48F, 0x00595D4A, 0x00464737, 0x004F4F41, 0x00535347, 0x00494B37,
        0x004C4E3A, 0x004E503D, 0x004E503D, 0x004E4F3F, 0x004F5040, 0x00535444, 0x0059594B, 0x0057554B, 0x00514F45, 0x004D4B40, 0x004E4D3F, 0x00555545, 0x004B4B3B, 0x0040402E, 0x004F4F3D, 0x003E443F, 0x00888D8C, 0x00AEB3B6, 0x00B5B8C0, 0x00B9BFC6,
        0x00B2B8BF, 0x00A8B1B5, 0x00B0B9BC, 0x00B1BAC3, 0x00AEB9BD, 0x00ACB7BB, 0x00ACB5BF, 0x00A7ADC0, 0x00A9B0C1, 0x0098A4A4, 0x00657668, 0x00677950, 0x006A7C53, 0x00667851, 0x00697755, 0x00697656, 0x00424C2E, 0x00212A0F, 0x00394228, 0x00414724,
        0x00373B1E, 0x0051543E, 0x0056594A, 0x0094978E, 0x00A8AAA4, 0x00A9ADA7, 0x00525952, 0x00323420, 0x0042432F, 0x004A4934, 0x0048472D, 0x0048472B, 0x003C4122, 0x00444D2C, 0x00606E4A, 0x00637546, 0x005F7142, 0x00596A3E, 0x005B6A44, 0x005F6B4D,
        0x00929A89, 0x00FDFFFC, 0x00BBBDBE, 0x00647151, 0x0052603E, 0x00616D51, 0x007C8376, 0x00F1F3F4, 0x00DDDEE2, 0x006A6F66, 0x00505944, 0x005D6E42, 0x005C674D, 0x00B6BAB5, 0x00FDFFFF, 0x00A3A89F, 0x00626D53, 0x004E5C3A, 0x0042502C, 0x006F6E77,
        0x00FBFAFF, 0x00D3D5D5, 0x0059624D, 0x0052613B, 0x0061704A, 0x006B745F, 0x00D2D5D3, 0x00FAFFFE, 0x00626B57, 0x004C5A30, 0x004B5B2B, 0x0037421A, 0x003F4429, 0x00484935, 0x00484836, 0x00424B30, 0x002D351E, 0x00393E2F, 0x00555A51, 0x005F635D,
        0x00414742, 0x00999F9A, 0x00777E77, 0x00878585, 0x00747271, 0x0052514D, 0x0045483F, 0x00535946, 0x006E7A5C, 0x006B7A54, 0x006D7E52, 0x006F7D59, 0x006F7E58, 0x0073835A, 0x0072815B, 0x005F6B4D, 0xFFDDE5D4, 0xFFFCFFFD, 0xFFFCFCFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x4192C0E9, 0x005CA0E1, 0x0054A3F4, 0x005CA5EF, 0x0064A9EF, 0x005CA6F4, 0x005DA7F9, 0x00599DE8, 0x005CA0EB, 0x005DA1EC, 0x005EA2ED, 0x005EA2ED, 0x005CA0EB,
        0x005B9FEA, 0x005B9FEA, 0x005CA0EB, 0x005CA1EA, 0x00599DE8, 0x005CA0EB, 0x005A9FE8, 0x005BA0E6, 0x005EA0E1, 0x005494CE, 0x00508EC4, 0x00568CC1, 0x00558EC2, 0x005A93C6, 0x005C90BE, 0x005682A1, 0x00486873, 0x005C7169, 0x00606C5A, 0x00495C3B,
        0x00586944, 0x005B6940, 0x00556137, 0x00596339, 0x00515C34, 0x0053603A, 0x0064724E, 0x0076835D, 0x006E7A56, 0x00586041, 0x003C4328, 0x00868874, 0x00BCBDAD, 0x00A2A095, 0x008D8B81, 0x0083807C, 0x00706C6B, 0x007B7776, 0x00AEAAA9, 0x00D6D3CE,
        0x00D1D0C6, 0x00919282, 0x00464834, 0x00363C25, 0x00494F36, 0x0050593E, 0x006C7757, 0x00778261, 0x0074835D, 0x00718158, 0x00738459, 0x0074855A, 0x006D7E52, 0x006A7A51, 0x00414D31, 0x004E5548, 0x00454B40, 0x00404A33, 0x0055633F, 0x00667450,
        0x00414B34, 0x00595F54, 0x004E5548, 0x00323D23, 0x005D6C46, 0x006E7E55, 0x00687652, 0x005C8287, 0x006F9AAD, 0x006994AF, 0x006C94AD, 0x006591B0, 0x006B9DB9, 0x006A9396, 0x005E7457, 0x006C7E57, 0x006F815A, 0x006F815A, 0x00687A53, 0x0051633A,
        0x007F9168, 0x005D6F46, 0x0055673E, 0x0073805A, 0x0076835D, 0x007A8662, 0x00747F5E, 0x00747F5E, 0x00758060, 0x00717B5D, 0x007C8668, 0x006B7957, 0x006D7858, 0x00677153, 0x005E674D, 0x004D533C, 0x00555946, 0x00515242, 0x00454537, 0x0052553C,
        0x004D5037, 0x00474933, 0x00444630, 0x00484935, 0x004E4F3B, 0x0050513D, 0x004D4D3B, 0x004C4A3F, 0x004E4C41, 0x004E4D3F, 0x004C4C3C, 0x00515141, 0x00484836, 0x003E3F2B, 0x0050513D, 0x00454D43, 0x00838984, 0x00AEB3B4, 0x00B0B4B9, 0x00B6BCC3,
        0x00B7BDC4, 0x00B0B9BD, 0x00B5BEC1, 0x00B2BBC5, 0x00ADB7BE, 0x00ABB6BA, 0x00ADB6C0, 0x00A9AFC2, 0x00A8AFBE, 0x0098A5A3, 0x006D7F6E, 0x0066784F, 0x00697B52, 0x00677952, 0x006B7957, 0x006A7757, 0x00434D2F, 0x0020290E, 0x00374026, 0x00414627,
        0x003D4026, 0x003F412D, 0x00434637, 0x00787C71, 0x0093968D, 0x005A5F56, 0x00151D12, 0x00232512, 0x0042432F, 0x004B4A35, 0x004B4931, 0x004B4A2E, 0x003F4425, 0x00444D2C, 0x00606E4A, 0x00617344, 0x00627347, 0x005F7045, 0x00576541, 0x00566147,
        0x00969E8D, 0x00FDFFF9, 0x00A0A3A1, 0x004F6132, 0x005A6C3D, 0x005B6A44, 0x006F7863, 0x00F8FCF6, 0x00D7DBD5, 0x0057604B, 0x0055633F, 0x005F723F, 0x005C6A48, 0x00AEB5A6, 0x00FDFFF8, 0x007B846F, 0x004D5B37, 0x00435429, 0x004D5E33, 0x006E716F,
        0x00FDFFFB, 0x00C8D0BF, 0x0052603E, 0x005F7142, 0x00647549, 0x00626E52, 0x00D3DACD, 0x00FBFFFF, 0x005F6853, 0x004B592F, 0x004C5D2A, 0x003A461C, 0x0044492E, 0x004A4B37, 0x00494A36, 0x0039412A, 0x004E5441, 0x00767D70, 0x003B3F39, 0x000E1311,
        0x00676C6A, 0x00FAFFFE, 0x00878E8B, 0x00858284, 0x00A9A6A8, 0x00A2A09F, 0x006C6F66, 0x00505645, 0x006A7658, 0x006F7F56, 0x00718354, 0x006F7D59, 0x006F7E58, 0x0073835A, 0x0072815B, 0x00606C4E, 0xFFDEE6D5, 0xFFFCFFFD, 0xFFFDFDFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x4192C0E9, 0x005B9FE0, 0x0054A3F4, 0x005DA6F0, 0x0064A9EF, 0x005DA7F5, 0x005DA7F9, 0x00599DE8, 0x005CA0EB, 0x005EA2ED, 0x005FA3EE, 0x005EA2ED, 0x005DA1EC,
        0x005CA0EB, 0x005CA0EB, 0x005DA1EC, 0x005FA4ED, 0x00599DE8, 0x005A9DE8, 0x005A9EE7, 0x0061A3EA, 0x005EA0E1, 0x003F84BD, 0x002A6EA3, 0x003773A1, 0x002B6B9B, 0x002A6C9D, 0x00316F98, 0x00477990, 0x004F7171, 0x006A7A62, 0x007D8059, 0x00718862,
        0x0074885E, 0x007D8E63, 0x00818E62, 0x00818E62, 0x0076845A, 0x0076855F, 0x00788964, 0x006E7C52, 0x00808E64, 0x007A8761, 0x006D7655, 0x00596143, 0x00575B42, 0x009A9C88, 0x00B5B7A4, 0x009B9894, 0x00A3A09C, 0x00A7A4A0, 0x00AFACA7, 0x00919185,
        0x005E604D, 0x003D4227, 0x003C4223, 0x00575F41, 0x00505A3C, 0x00495434, 0x00586342, 0x0052613B, 0x004C5C33, 0x0055683D, 0x004D6035, 0x004F6035, 0x00495A2E, 0x004E5E35, 0x00485438, 0x0062695C, 0x00565C51, 0x005D6750, 0x00566440, 0x006C7A56,
        0x0058624B, 0x00989E93, 0x00959C8F, 0x00586349, 0x0062714B, 0x0077875E, 0x0062704C, 0x00587C84, 0x006E99AE, 0x006E96B3, 0x007095B1, 0x006C95B6, 0x0071A3C1, 0x00648A8F, 0x004B5E43, 0x00687A51, 0x0071835A, 0x00798B62, 0x0074865D, 0x003F5128,
        0x00677950, 0x004A5C33, 0x0056693E, 0x00687652, 0x0066754F, 0x006A7953, 0x0065744E, 0x006F7F56, 0x0078885F, 0x006D7E53, 0x00708156, 0x006D7D54, 0x006F7E58, 0x006A7554, 0x005C6648, 0x00475036, 0x004F543F, 0x004B4F3C, 0x00505343, 0x004C5033,
        0x0045482E, 0x0045482E, 0x00484B31, 0x0042452C, 0x003E4128, 0x00484A34, 0x0053553F, 0x00505040, 0x00535343, 0x00535341, 0x0050513D, 0x00555741, 0x004D4F39, 0x0040432A, 0x004C4F35, 0x00424A3F, 0x007B827B, 0x00BAC0BF, 0x00BCC1C4, 0x00B1B7BE,
        0x00B0B6BD, 0x00ADB5BC, 0x00AFB8BC, 0x00A6AFB9, 0x00AAB5B9, 0x00A9B4B8, 0x00A7B0B9, 0x00A4ABBA, 0x00A7B0BA, 0x0095A39D, 0x00667964, 0x0066784F, 0x00697B52, 0x00677952, 0x006B7957, 0x006A7757, 0x00434D2F, 0x0020290E, 0x00374026, 0x00414528,
        0x00404329, 0x004C4E3A, 0x002A2D1E, 0x00303429, 0x007E8178, 0x00494F44, 0x00151E11, 0x00232512, 0x00454533, 0x004A4935, 0x004C4A32, 0x004B4A30, 0x00414528, 0x00464F2E, 0x00606E4C, 0x005E6F44, 0x0063734A, 0x005C6A46, 0x004D5A3A, 0x00404B31,
        0x006F7864, 0x00BCC3B4, 0x006F7669, 0x00677748, 0x00576737, 0x004E5C32, 0x0050593E, 0x00A2A798, 0x00A2A798, 0x00636D4F, 0x00606F43, 0x00455526, 0x004B5636, 0x00808673, 0x00C7CDBA, 0x006E785A, 0x004F5D34, 0x0039471E, 0x0045512D, 0x00595E4F,
        0x00B9BFAC, 0x008E977C, 0x0046532D, 0x0057663A, 0x005C6A41, 0x00535C41, 0x009AA08D, 0x00BCC1BF, 0x0049523D, 0x004E5D31, 0x0050612E, 0x003E4A20, 0x00474C2F, 0x004C4D39, 0x004C4D39, 0x00444835, 0x00787D6E, 0x00AAAEA3, 0x00939490, 0x00888B89,
        0x00878B86, 0x00A5ACA5, 0x00565D56, 0x00656362, 0x009B9998, 0x00AEADA9, 0x007E8277, 0x00555B48, 0x00657153, 0x006A7A51, 0x00708155, 0x00707E5A, 0x00707F59, 0x0073835A, 0x0073825C, 0x00606C4E, 0xFFDEE6D5, 0xFFFDFFFE, 0xFFFDFDFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x4191BFE8, 0x005B9FE0, 0x0054A3F4, 0x005DA6F0, 0x0065AAF0, 0x005DA7F5, 0x005DA7F9, 0x00599DE8, 0x005DA1EC, 0x005EA2ED, 0x005FA3EE, 0x005FA3EE, 0x005DA1EC,
        0x005CA0EB, 0x005CA0EB, 0x005DA1EC, 0x005FA7EF, 0x005B9FEA, 0x005B9EE9, 0x005A9BE5, 0x0062A2E9, 0x005DA1E2, 0x003D84BD, 0x00216A9E, 0x001C72A8, 0x001771A8, 0x001D77AE, 0x002277A5, 0x003D8099, 0x0049756F, 0x00617552, 0x00797F48, 0x006D855D,
        0x00798F65, 0x00778B5E, 0x00708051, 0x00808F63, 0x0078865D, 0x006D7E59, 0x00728361, 0x007A8A5B, 0x00718054, 0x00758359, 0x00738158, 0x007F8A64, 0x00737C5B, 0x00696F50, 0x00666C4D, 0x003A4021, 0x00393E21, 0x002D3217, 0x003C4027, 0x0044492E,
        0x004B5132, 0x004F5633, 0x00545D35, 0x004C5736, 0x00667150, 0x00717D59, 0x00586642, 0x0062714B, 0x0064764D, 0x005C6F44, 0x005D7045, 0x00607146, 0x005E6F43, 0x0057673E, 0x00727E62, 0x0091988B, 0x00757B70, 0x008B957E, 0x0055633F, 0x00677551,
        0x005F6952, 0x006E7469, 0x0062695C, 0x004F5A40, 0x0045542E, 0x005C6C43, 0x0052603C, 0x0050717A, 0x00648AA2, 0x00658BAB, 0x006A8CAA, 0x00648AAC, 0x006491B2, 0x0052767C, 0x00404F34, 0x005D7245, 0x00596D42, 0x00586B44, 0x00526342, 0x00314024,
        0x004D5A44, 0x0045513F, 0x00424D3D, 0x004C5941, 0x0048553B, 0x00465438, 0x003A4929, 0x004F603B, 0x0071835A, 0x0073865B, 0x00778B5E, 0x00728357, 0x006B7C51, 0x00677650, 0x00616C4B, 0x004C553A, 0x0050563F, 0x00474B38, 0x00484C39, 0x00444628,
        0x00424426, 0x004A4C2F, 0x004D4F32, 0x00404127, 0x0037381E, 0x0044452B, 0x0054553B, 0x004C4D39, 0x004D4F39, 0x004E503A, 0x004B4E35, 0x004D5036, 0x00474B2E, 0x003C4122, 0x00424728, 0x00434C3F, 0x006B7369, 0x00B7BEBB, 0x00BDC2C5, 0x00A5ABB2,
        0x00A2A8AF, 0x00A7AFB6, 0x00A9B2B6, 0x00A1AAB3, 0x00ACB8BA, 0x00AFBBBB, 0x00AFB9C0, 0x00AEB6C3, 0x00B0BAC1, 0x009CACA1, 0x006C8266, 0x00687A51, 0x006A7C53, 0x00667851, 0x00697755, 0x00687555, 0x00424C2E, 0x00212A0F, 0x00394228, 0x0043472A,
        0x0033361D, 0x0040422F, 0x002D2F23, 0x001B1F14, 0x00676B60, 0x00545B4E, 0x00182114, 0x002E2F1F, 0x004B4B39, 0x00474632, 0x00494631, 0x0046452B, 0x00404427, 0x00485031, 0x0062704E, 0x0062704C, 0x0062704E, 0x004F5C3C, 0x00485438, 0x003E492F,
        0x004A543D, 0x00707A63, 0x005B654E, 0x005B6547, 0x0044502C, 0x004E5A36, 0x004E573D, 0x00575C4D, 0x006A6F60, 0x0060694E, 0x004D5B31, 0x00565F45, 0x00555B4A, 0x005E6256, 0x007A806F, 0x00616A4F, 0x00535E3E, 0x00475036, 0x00484E3D, 0x004E5441,
        0x006D755E, 0x00535C41, 0x003C4628, 0x00434C31, 0x004B533C, 0x00494F3E, 0x0065695D, 0x00767B79, 0x003C4530, 0x0057663A, 0x0051632E, 0x003F4C20, 0x00474C2F, 0x004D4F39, 0x004E4F3B, 0x00545446, 0x0057564C, 0x0067685F, 0x00B3B3AD, 0x00DCDED8,
        0x00666960, 0x004A4E42, 0x00818677, 0x0054554C, 0x0057584F, 0x005B5C52, 0x004F5445, 0x004F5641, 0x006F7B5D, 0x006E7D57, 0x006F8054, 0x00717F5B, 0x0071805A, 0x0074845B, 0x0074835D, 0x00616D4F, 0xFFDFE7D6, 0xFFFDFFFE, 0xFFFDFDFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x4191BFE8, 0x005B9FE0, 0x0054A3F4, 0x005DA6F0, 0x0065AAF0, 0x005EA8F6, 0x005EA8FA, 0x00599DE8, 0x005DA1EC, 0x005EA2ED, 0x005FA3EE, 0x005FA3EE, 0x005EA2ED,
        0x005CA0EB, 0x005DA1EC, 0x005DA1EC, 0x0059A1E9, 0x005CA0EB, 0x0060A3EE, 0x005D9CE6, 0x005E9EE5, 0x005B9FE0, 0x003D87BF, 0x002470A4, 0x003A76A0, 0x003375A6, 0x003079B3, 0x002872AC, 0x003878A8, 0x003C6C84, 0x004F6C69, 0x006B7967, 0x00708A62,
        0x00697F55, 0x00798D60, 0x007A8B5F, 0x00748357, 0x006F7F56, 0x00778863, 0x00697A59, 0x006E8051, 0x00748455, 0x00738256, 0x00738256, 0x0078845A, 0x00747F57, 0x00858E66, 0x00757E56, 0x0074834A, 0x0067753F, 0x005D6939, 0x006B754A, 0x005F693F,
        0x00677147, 0x00737D52, 0x006C764B, 0x00616D49, 0x005E6A46, 0x00586642, 0x0055643E, 0x005F6F46, 0x004A5D32, 0x0054673C, 0x0054673C, 0x004F6035, 0x005C6D41, 0x0047572E, 0x00626E52, 0x006A7164, 0x00464C41, 0x00949E87, 0x00677551, 0x00687652,
        0x00768069, 0x00464C41, 0x003E4538, 0x00808B71, 0x0061704A, 0x0055653C, 0x0052603C, 0x0052707B, 0x00587C94, 0x00547798, 0x005A7998, 0x00507498, 0x00517C9D, 0x0050717A, 0x0055624A, 0x005A7040, 0x00586C41, 0x00576846, 0x004C5A42, 0x00495346,
        0x00626867, 0x007F8388, 0x006E707B, 0x00788076, 0x00798176, 0x00727C6B, 0x0054604A, 0x005B6A4B, 0x007A8A68, 0x0074865D, 0x006F8257, 0x00738758, 0x006F8054, 0x0076865D, 0x006E7C58, 0x004E583A, 0x004A5339, 0x00454A35, 0x00484C39, 0x00494C2C,
        0x00454828, 0x00484A2C, 0x00494B2D, 0x0045472A, 0x0045472A, 0x00494A30, 0x0046472D, 0x004A4D34, 0x00494C33, 0x004A4D33, 0x0043472A, 0x00414627, 0x00404525, 0x003C4121, 0x00464C29, 0x00475141, 0x005B6358, 0x00A7AEA9, 0x00B2B7BA, 0x00969CA3,
        0x0090969D, 0x00939BA2, 0x008E969D, 0x00909AA1, 0x0096A2A4, 0x009AA7A5, 0x00A0ABAF, 0x00A2ABB4, 0x00A3AEB2, 0x0093A496, 0x006B8164, 0x006A7C53, 0x006B7D54, 0x00657750, 0x00677553, 0x00667353, 0x00414B2D, 0x00222B10, 0x003B442A, 0x004A4D33,
        0x00454731, 0x0040422F, 0x0064665A, 0x0071756A, 0x0074786D, 0x0060675A, 0x001E2818, 0x00383929, 0x004F4F3D, 0x00454430, 0x0046432E, 0x00414026, 0x003E4225, 0x004A5233, 0x00647250, 0x006B7858, 0x00636F51, 0x00475337, 0x004F5A40, 0x00505A43,
        0x003E492F, 0x00445034, 0x005C684A, 0x004D5243, 0x005E6550, 0x00677056, 0x00555B48, 0x0044483D, 0x0052564B, 0x005B624D, 0x00667150, 0x00666960, 0x005F605C, 0x005A5B59, 0x004D5146, 0x00555C47, 0x00525A43, 0x0065695E, 0x00606060, 0x00545A47,
        0x004E5540, 0x00424934, 0x00515746, 0x00595D51, 0x005F615B, 0x00555751, 0x0052534F, 0x00595E5C, 0x00404A33, 0x005F6E42, 0x004F612C, 0x003D4A1E, 0x00474C2F, 0x004E503A, 0x0050523C, 0x004E4C42, 0x00545149, 0x00514E49, 0x006F6C67, 0x00737169,
        0x002B2D21, 0x00393C2C, 0x005E634E, 0x00434637, 0x00454839, 0x004E5142, 0x00474D3C, 0x004A523B, 0x00717D5F, 0x0072815B, 0x00708156, 0x00717F5B, 0x0071805A, 0x0075855C, 0x0074835D, 0x00616D4F, 0xFFDFE7D6, 0xFFFDFFFE, 0xFFFDFDFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x3189BDF2, 0x00659FDA, 0x0061A7EA, 0x005EABF4, 0x0057A7F4, 0x0058A6F2, 0x0063AAF4, 0x00579CE2, 0x005C9FEA, 0x0062A5F0, 0x005FA2ED, 0x005DA0EB, 0x005EA1EC,
        0x005B9EE9, 0x005C9FEA, 0x0060A3EE, 0x005FA0F1, 0x005B9DEC, 0x005FA3EE, 0x005DA3E9, 0x005EA5E5, 0x005EA2DD, 0x004686BC, 0x003372A5, 0x002D7CA5, 0x00327EAF, 0x003379B4, 0x003D7CB6, 0x004C81A6, 0x004D7A7D, 0x00587B59, 0x00719158, 0x0074895C,
        0x00728858, 0x00798D5E, 0x007A8F5E, 0x00748A56, 0x00748853, 0x00768A55, 0x00728651, 0x0074855A, 0x00738459, 0x00728358, 0x00718257, 0x00718257, 0x00738459, 0x0074855A, 0x0075865B, 0x0076875C, 0x00738459, 0x0076875C, 0x0077885D, 0x00728358,
        0x0074855A, 0x00798A5F, 0x0077885D, 0x007D8C66, 0x0076855F, 0x007A8963, 0x007A8963, 0x0073825C, 0x0075845E, 0x00778660, 0x0072815B, 0x007A8963, 0x0074835D, 0x006A7953, 0x0061704A, 0x005D6C46, 0x005D6C46, 0x0061704A, 0x0064734D, 0x006D7D54,
        0x00526239, 0x004D5D34, 0x005C6C43, 0x006E7E55, 0x005E6E45, 0x0056663D, 0x0053633A, 0x005D6D5C, 0x00586857, 0x00485847, 0x00738372, 0x00586857, 0x00465645, 0x00879786, 0x00637362, 0x00576B3E, 0x00576A3F, 0x005E6F4A, 0x00566546, 0x005E6A54,
        0x00818B7B, 0x00848C82, 0x006F766F, 0x0081857F, 0x008E938A, 0x005E6556, 0x00838C77, 0x00778365, 0x0074825E, 0x0076865D, 0x00718256, 0x0077875E, 0x0078885F, 0x0077875E, 0x0073835A, 0x006D7D54, 0x0068784F, 0x0065754C, 0x0064744B, 0x0062744D,
        0x0061734C, 0x0060724B, 0x005F714A, 0x005E7049, 0x005E7049, 0x005E7049, 0x005E7049, 0x0061724D, 0x0061724D, 0x0061724D, 0x0060714C, 0x0060714C, 0x005F704B, 0x005F704B, 0x005F704B, 0x00606F53, 0x00667559, 0x00758468, 0x007E8D71, 0x007B8A6E,
        0x0079886C, 0x007A896D, 0x00758468, 0x00778863, 0x00768762, 0x00758661, 0x00758661, 0x00768762, 0x00758661, 0x0072835E, 0x0070815C, 0x006E8156, 0x006F8257, 0x00697B54, 0x006A7A58, 0x006A795A, 0x00414E34, 0x001F2C14, 0x0037432D, 0x00404B2B,
        0x00394228, 0x00757A6B, 0x00ABAEA5, 0x008C8F86, 0x005E6354, 0x004E573D, 0x003F4A2A, 0x0045482F, 0x0040432A, 0x003E4127, 0x0042452B, 0x00404427, 0x003D4124, 0x004F5336, 0x006B7051, 0x006E8059, 0x00617051, 0x003F4A36, 0x005E665B, 0x004C5449,
        0x0036402F, 0x003B482E, 0x00627151, 0x00565F4A, 0x00868F7A, 0x005C6550, 0x004B543F, 0x00353E29, 0x0057604B, 0x0067705B, 0x00B4BDA8, 0x00B8BDBB, 0x00697167, 0x003A4630, 0x00465236, 0x005A6648, 0x008C947D, 0x00999E8F, 0x004F514B, 0x004E593F,
        0x00303C20, 0x005E6851, 0x007D8477, 0x00B1B3B3, 0x00686C67, 0x0057604C, 0x0035431F, 0x00505E42, 0x004C5A38, 0x005C6A40, 0x00525E2E, 0x00444E20, 0x004F502E, 0x004D4931, 0x004F4638, 0x00454A2D, 0x004B5033, 0x004F5437, 0x004A4F32, 0x00404528,
        0x00393E21, 0x003A3F22, 0x003E4326, 0x004F493E, 0x00534D40, 0x004F4C3D, 0x00454733, 0x00555E44, 0x006F7B5D, 0x0071815F, 0x006F815C, 0x0072805C, 0x0073825C, 0x0074845B, 0x00798862, 0x00657153, 0xFFDDE5D4, 0xFFFDFFFE, 0xFFFDFDFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x2684B4EE, 0x00699FDE, 0x0065A4E8, 0x005BA2EC, 0x0062ADF9, 0x0062AAF7, 0x0066AAF3, 0x005E9EE5, 0x005EA5EF, 0x0061A8F2, 0x0061A8F2, 0x0061A8F2, 0x0062A9F3,
        0x005EA5EF, 0x005CA3ED, 0x005AA1EB, 0x0064A7EC, 0x0060A5EA, 0x0061A8EB, 0x0059A1E1, 0x005CA5DF, 0x005EA4D9, 0x004789BA, 0x0030719E, 0x004F7E82, 0x0053828A, 0x0050808C, 0x00517F8A, 0x005D8688, 0x00638174, 0x00687E62, 0x0072805C, 0x0071855B,
        0x006E8257, 0x0072855A, 0x0075885D, 0x0073865B, 0x0078895E, 0x007B8C61, 0x0077885D, 0x0074855A, 0x00738459, 0x00738459, 0x00728358, 0x00738459, 0x00738459, 0x0075865B, 0x0075865B, 0x0075865B, 0x00738459, 0x0077885D, 0x0078895E, 0x0074855A,
        0x0076875C, 0x007A8B60, 0x0078895E, 0x0072815B, 0x0072815B, 0x0074835D, 0x0073825C, 0x006F7E58, 0x006F7E58, 0x0071805A, 0x0073825C, 0x0073825C, 0x0072815B, 0x0071805A, 0x00707F59, 0x00707F59, 0x00707F59, 0x00707F59, 0x00707F59, 0x0075845E,
        0x0071805A, 0x0071805A, 0x006A7953, 0x006E7D57, 0x0066754F, 0x0063724C, 0x00596842, 0x007F8E79, 0x00384732, 0x001D2C17, 0x0035442F, 0x000E1D08, 0x003C4B36, 0x009DAC97, 0x00586752, 0x005D7045, 0x00596B42, 0x005A6B46, 0x00495838, 0x00455238,
        0x005C6852, 0x00606A59, 0x00515B4B, 0x00575E4F, 0x00717968, 0x005E6752, 0x0069745A, 0x00606D4D, 0x00707E5A, 0x0073835A, 0x00728358, 0x006F7F56, 0x00718158, 0x0073835A, 0x0074845B, 0x0073835A, 0x00728259, 0x00728259, 0x0073835A, 0x0072845D,
        0x0071835C, 0x0070825B, 0x006F815A, 0x006E8059, 0x006E8059, 0x006E8059, 0x006E8059, 0x0071825D, 0x0071825D, 0x0071825D, 0x0071825D, 0x0071825D, 0x0071825D, 0x0071825D, 0x0071825D, 0x006C7D5C, 0x006D7E5D, 0x00738463, 0x00778867, 0x00738463,
        0x00738463, 0x00768766, 0x00738463, 0x0073845F, 0x0072835E, 0x0071825D, 0x0071825D, 0x0071825D, 0x0071825D, 0x006F805B, 0x006D7E59, 0x006A7D52, 0x006E8156, 0x006B7D56, 0x006C7C5A, 0x006D7C5D, 0x00425034, 0x001F2C14, 0x0039462E, 0x0047492B,
        0x003E3E26, 0x00575445, 0x00716C63, 0x00615C53, 0x004C493A, 0x00484830, 0x00454729, 0x00474A31, 0x0044472D, 0x003F4228, 0x00404329, 0x00414528, 0x003E4225, 0x004F5435, 0x006E7354, 0x006F8158, 0x006D7D5B, 0x0055624A, 0x00828C7B, 0x00909A8A,
        0x0067735D, 0x004E5D3E, 0x0071825D, 0x00616C52, 0x00717C62, 0x005D684E, 0x00606B51, 0x004F5A40, 0x006F7A60, 0x0079846A, 0x0097A288, 0x00CAD1CA, 0x0098A292, 0x0055624A, 0x00667353, 0x006C7959, 0x00737C61, 0x009FA592, 0x00868A7E, 0x00677355,
        0x00485535, 0x00707C60, 0x00959D8C, 0x00EBEFE9, 0x00A7ACA3, 0x006B755E, 0x00475630, 0x005C6B4C, 0x004F5D3B, 0x005D6B41, 0x00525F31, 0x003F481D, 0x00484C29, 0x004E4C34, 0x00504938, 0x004C4D39, 0x004F503C, 0x0051523E, 0x004F503C, 0x004A4B37,
        0x00464733, 0x00464733, 0x00464733, 0x00514C3D, 0x004E4C3A, 0x00484935, 0x00454930, 0x00566042, 0x006D7B59, 0x006B7C57, 0x00687B54, 0x0073815D, 0x0073825C, 0x00728259, 0x00778660, 0x00657153, 0xFFDDE5D4, 0xFFFDFFFE, 0xFFFCFCFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x67A6C4ED, 0x5099BCE8, 0x0085B1E0, 0x006091C1, 0x006FA4D6, 0x0070A4D3, 0x006E9FCD, 0x006F9CC8, 0x00629DCB, 0x00609BC9, 0x00649FCD, 0x00649FCD, 0x0069A4D2,
        0x0069A4D2, 0x006AA5D3, 0x0069A4D2, 0x0073A1DB, 0x006E9DDA, 0x006EA0DC, 0x00679BD7, 0x006B9DD7, 0x006898CC, 0x005987B6, 0x004D7AA5, 0x00788767, 0x00768A67, 0x00728B69, 0x006A8563, 0x00758D6D, 0x007A8C6F, 0x0082886F, 0x007D7F69, 0x00778B61,
        0x0073875D, 0x0072845D, 0x0072845D, 0x006F805B, 0x0072805E, 0x0073815F, 0x00717E5E, 0x0074855A, 0x0074855A, 0x0074855A, 0x0074855A, 0x0074855A, 0x0075865B, 0x0075865B, 0x0075865B, 0x0074855A, 0x0074855A, 0x0077885D, 0x00798A5F, 0x0076875C,
        0x0077885D, 0x00798A5F, 0x0077885D, 0x0073825C, 0x0076855F, 0x0073825C, 0x0071805A, 0x0073825C, 0x0071805A, 0x0072815B, 0x0075845E, 0x00707F59, 0x0071805A, 0x0074835D, 0x0075845E, 0x0075845E, 0x0074835D, 0x0071805A, 0x006F7E58, 0x006A7854,
        0x0074825E, 0x007A8864, 0x006F7D59, 0x00707E5A, 0x0073815D, 0x0075835F, 0x006D7B57, 0x0059664C, 0x005A674D, 0x0049563C, 0x004A573D, 0x0049563C, 0x00566349, 0x00707D63, 0x005C694F, 0x0076885F, 0x0074865F, 0x00758760, 0x00657651, 0x005A6A48,
        0x00657454, 0x006A795A, 0x00637253, 0x005D694B, 0x00727E60, 0x00758262, 0x00677553, 0x005F6D49, 0x0072815B, 0x006F7E58, 0x006F7F56, 0x00708057, 0x00718158, 0x0073835A, 0x0074845B, 0x0074845B, 0x0075855C, 0x0075855C, 0x0076865D, 0x0071835A,
        0x0071835A, 0x00708259, 0x006F8158, 0x006E8057, 0x006E8057, 0x006F8158, 0x006F8158, 0x0070825B, 0x0070825B, 0x0071835C, 0x0071835C, 0x0072845D, 0x0072845D, 0x0073855E, 0x0073855E, 0x0073845F, 0x0070815C, 0x0071825D, 0x0071825D, 0x006E7F5A,
        0x0070815C, 0x0072835E, 0x0071825D, 0x0073855E, 0x0072845D, 0x0070825B, 0x0070825B, 0x0071835C, 0x0071835C, 0x0071835C, 0x0070825B, 0x006A7D52, 0x006F8257, 0x006C7E57, 0x006D7E59, 0x006F7E5E, 0x00425132, 0x001D2B0F, 0x0039462C, 0x00504E30,
        0x004C482F, 0x004C4534, 0x004E4639, 0x004F473A, 0x004D4635, 0x004B472E, 0x004C4A2C, 0x0041462B, 0x00494E33, 0x00474C2F, 0x0042472A, 0x00404627, 0x003B4122, 0x004E5435, 0x00757C5B, 0x006D8154, 0x00758760, 0x00707F60, 0x0079866C, 0x00717E66,
        0x00667458, 0x00748462, 0x0081936C, 0x007A8767, 0x006A7757, 0x005B6848, 0x00697656, 0x00697656, 0x00798666, 0x006A7757, 0x00596646, 0x00828C7B, 0x007B8771, 0x00687758, 0x006C7A56, 0x00788662, 0x006F7A5A, 0x006D765C, 0x00818873, 0x0062704E,
        0x00485632, 0x00616F4B, 0x004A553B, 0x007C8374, 0x00767D6E, 0x00687456, 0x004E5F34, 0x00546141, 0x0045532F, 0x005F6D43, 0x00667347, 0x004D572C, 0x00474D2A, 0x004A4B31, 0x004C4B37, 0x004C493A, 0x004B4839, 0x004B4839, 0x004D4A3B, 0x004E4B3C,
        0x004E4B3C, 0x004C493A, 0x004A4738, 0x004E4D38, 0x004A4D34, 0x00484D32, 0x00474F31, 0x005C6746, 0x0073825C, 0x0072845B, 0x0073855C, 0x0073815D, 0x0073825C, 0x00718158, 0x0076855F, 0x00647052, 0xFFDDE5D4, 0xFFFDFFFE, 0xFFFBFBFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFF8FFFF, 0xFBF3FEFF, 0x00BCCDD0, 0x005E7676, 0x006B8585, 0x006C8783, 0x006B827D, 0x00708681, 0x006A8784, 0x00678481, 0x006E8B88, 0x00688582, 0x006D8A87,
        0x006B8885, 0x006B8885, 0x006B8885, 0x006D8E7F, 0x0065877C, 0x00658983, 0x00648985, 0x006A8D89, 0x005D7F78, 0x005C7D6F, 0x00638372, 0x007B845C, 0x0074815B, 0x00788964, 0x0070815F, 0x00798A69, 0x00768363, 0x0083896A, 0x007E8364, 0x00768C5C,
        0x00758A5D, 0x0075895C, 0x0074865D, 0x0071835C, 0x0074825E, 0x00768462, 0x00768462, 0x0074855A, 0x0074855A, 0x0075865B, 0x0075865B, 0x0075865B, 0x0076875C, 0x0075865B, 0x0075865B, 0x0074855A, 0x0075865B, 0x0077885D, 0x00798A5F, 0x0077885D,
        0x0074855A, 0x00728358, 0x006F8055, 0x0076855F, 0x0075845E, 0x006F7E58, 0x00707F59, 0x0072815B, 0x0071805A, 0x0072815B, 0x006F7E58, 0x006F815A, 0x006E8059, 0x006D7F58, 0x006C7E57, 0x006B7D56, 0x006B7D56, 0x006A7C55, 0x006A7C55, 0x006A7A58,
        0x006B7B59, 0x006E7E5C, 0x006E7E5C, 0x0070805E, 0x0071815F, 0x0071815F, 0x006E7E5C, 0x006D7B59, 0x0073815F, 0x006B7957, 0x00677553, 0x0072805E, 0x006D7B59, 0x00657351, 0x00707E5C, 0x0070825B, 0x0073855E, 0x007A8C65, 0x00778962, 0x006F815A,
        0x0071835A, 0x0074865D, 0x00708259, 0x0075865B, 0x0076865D, 0x007D8D64, 0x00728259, 0x0074845B, 0x007A8A61, 0x0075845E, 0x0076855F, 0x0073835A, 0x0073835A, 0x0073835A, 0x0073835A, 0x0073835A, 0x00728259, 0x00728259, 0x00728259, 0x00708259,
        0x006F8158, 0x006F8158, 0x006E8057, 0x006D7F56, 0x006D7F56, 0x006E8057, 0x006E8057, 0x006F815A, 0x006F815A, 0x006F815A, 0x0070825B, 0x0070825B, 0x0070825B, 0x0070825B, 0x0071835C, 0x006F8158, 0x006D7F56, 0x006D7F56, 0x006E8057, 0x006F8158,
        0x00708259, 0x00708259, 0x006E8057, 0x0073855E, 0x0071835C, 0x006F815A, 0x006F815A, 0x0070825B, 0x0071835C, 0x0071835C, 0x0071835C, 0x006C7F54, 0x00708358, 0x006C7E55, 0x0070825B, 0x00778765, 0x004E5D3D, 0x00283718, 0x003F4E2F, 0x00454A2B,
        0x00474B2E, 0x0043452F, 0x0040412D, 0x00464733, 0x00484A34, 0x0043472A, 0x00414627, 0x00394123, 0x00434B2D, 0x003E4627, 0x003D4526, 0x0047502F, 0x00454E2D, 0x00505938, 0x006F7857, 0x006C8051, 0x0073865B, 0x00798B64, 0x00758464, 0x006E7D5D,
        0x00748462, 0x007C8E67, 0x005E7146, 0x006A7854, 0x005B6945, 0x004A5834, 0x004D5B37, 0x0065734F, 0x006A7854, 0x005F6D49, 0x00566440, 0x00647157, 0x00546344, 0x0072835E, 0x0083936A, 0x007A8A61, 0x006B7852, 0x005B6645, 0x00727C5E, 0x0052603C,
        0x004D5E33, 0x00697A4E, 0x00566440, 0x0078826B, 0x00747E67, 0x00677553, 0x004A5C2D, 0x005E6C48, 0x0053623C, 0x00697A4F, 0x00768559, 0x00616D43, 0x004A5430, 0x0043482B, 0x00494D34, 0x004B4A35, 0x004A4934, 0x004B4A35, 0x004D4C37, 0x00504F3A,
        0x0051503B, 0x00504F3A, 0x004E4D38, 0x00494E31, 0x004B5132, 0x0047502F, 0x00424C28, 0x0055623C, 0x006E7E55, 0x00728358, 0x00718459, 0x0075835F, 0x0074835D, 0x00718158, 0x0076855F, 0x00647052, 0xFFDDE5D4, 0xFFFDFFFE, 0xFFFCFCFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xF0FFFFED, 0xF7FFFFF1, 0x00C9D2B8, 0x00596646, 0x00778863, 0x007F916A, 0x006F7F56, 0x0064754A, 0x00646F49, 0x00646F49, 0x006E7953, 0x00646F49, 0x006D7852,
        0x0068734D, 0x0065704A, 0x0069744E, 0x00728A62, 0x00637A5A, 0x00576F57, 0x00506758, 0x00556D61, 0x00435849, 0x003E543C, 0x0040563A, 0x002D4435, 0x002C4138, 0x00405251, 0x003D4F50, 0x00506059, 0x004B5D46, 0x00697B52, 0x00768A55, 0x00708753,
        0x00738A56, 0x00748958, 0x00728657, 0x006F8354, 0x00708155, 0x00728357, 0x0076875C, 0x0074855A, 0x0074855A, 0x0074855A, 0x0075865B, 0x0075865B, 0x0075865B, 0x0075865B, 0x0075865B, 0x0074855A, 0x0075865B, 0x0076875C, 0x0077885D, 0x0076875C,
        0x00708156, 0x0066774C, 0x00607146, 0x005C6B45, 0x005B6A44, 0x00576640, 0x005B6A44, 0x00596842, 0x00576640, 0x005E6D47, 0x00576640, 0x00556740, 0x0054663F, 0x0052643D, 0x0052643D, 0x0052643D, 0x0054663F, 0x00566841, 0x00586A43, 0x00586846,
        0x00546442, 0x00526240, 0x00576745, 0x00596947, 0x00586846, 0x00546442, 0x00546442, 0x005D6C46, 0x0051603A, 0x00586741, 0x005D6C46, 0x005F6E48, 0x005E6D47, 0x0051603A, 0x00586741, 0x005B6C47, 0x0060724B, 0x006A7C55, 0x0073855C, 0x00718459,
        0x006E8156, 0x006E8255, 0x006A7E51, 0x00748657, 0x00708253, 0x00718256, 0x00738458, 0x00798A5F, 0x0075855C, 0x0078885F, 0x0074845B, 0x0073835A, 0x00728259, 0x00728259, 0x0073835A, 0x0073835A, 0x0074845B, 0x0074845B, 0x0074845B, 0x00708259,
        0x00708259, 0x006F8158, 0x006F8158, 0x006F8158, 0x006F8158, 0x006F8158, 0x00708259, 0x00708259, 0x00708259, 0x00708259, 0x00708259, 0x006F8158, 0x006F8158, 0x006F8158, 0x006F8158, 0x006D8055, 0x006C7F54, 0x006B7E53, 0x006C7F54, 0x006F8257,
        0x00708358, 0x006F8257, 0x006E8156, 0x006F8158, 0x006D7F56, 0x006B7D54, 0x006B7D54, 0x006C7E55, 0x006D7F56, 0x006D7F56, 0x006D7F56, 0x006F8257, 0x00708358, 0x006B7D54, 0x006E8059, 0x0073855E, 0x004C5D38, 0x0021310F, 0x002B3B19, 0x002A3B1A,
        0x0029391A, 0x0028371B, 0x0026351A, 0x0026351A, 0x0028371B, 0x0029391A, 0x00273817, 0x002E3919, 0x002E3919, 0x00273211, 0x00394423, 0x00626D4C, 0x00707C58, 0x006E7A56, 0x00788460, 0x00728657, 0x00768A5D, 0x0076895E, 0x007F916A, 0x008D9F78,
        0x00768861, 0x005F7148, 0x0053663B, 0x00627249, 0x006A7A51, 0x0066764D, 0x005C6C43, 0x00697950, 0x005F6F46, 0x005E6E45, 0x00697950, 0x00627151, 0x00677755, 0x00798B64, 0x007E8E65, 0x005B6C41, 0x00616F46, 0x0073805A, 0x0046532D, 0x0035441E,
        0x00617246, 0x00647746, 0x0046572C, 0x006B7858, 0x00636F53, 0x005D6C46, 0x00617443, 0x0054643B, 0x005C6C43, 0x006B7C51, 0x00738459, 0x00728057, 0x005F6B47, 0x00434E2E, 0x00374123, 0x003D4320, 0x003F4522, 0x00414724, 0x00424825, 0x00424825,
        0x00424825, 0x00434926, 0x00444A27, 0x003C4824, 0x003F4B27, 0x003B4723, 0x0036431D, 0x00515F36, 0x00728259, 0x0077885D, 0x0074855A, 0x00768460, 0x0075845E, 0x0073835A, 0x00778660, 0x00657153, 0xFFDDE5D4, 0xFFFDFFFE, 0xFFFDFDFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFF9FFF7, 0xFFFBFFF5, 0x00CBD8C0, 0x00566746, 0x0080946A, 0x007F9368, 0x0052673A, 0x002C4114, 0x0039471E, 0x0036441B, 0x003A481F, 0x0028360D, 0x003C4A21,
        0x0039471E, 0x0035431A, 0x00404E25, 0x00697870, 0x005B6B6A, 0x00566673, 0x00677690, 0x0098A5C5, 0x009AA8C4, 0x009DAAC0, 0x0096A3B3, 0x0089A6B4, 0x00849EAF, 0x00869AB3, 0x005D6D84, 0x00596871, 0x0046594A, 0x00667E54, 0x00789459, 0x00778B60,
        0x00798D62, 0x00778B5E, 0x0074885B, 0x00748859, 0x00748657, 0x00748657, 0x00778A59, 0x00738459, 0x00738459, 0x00738459, 0x00738459, 0x0074855A, 0x0074855A, 0x0074855A, 0x0075865B, 0x0074855A, 0x0075865B, 0x0074855A, 0x0075865B, 0x0076875C,
        0x006C7D52, 0x005B6C41, 0x00506136, 0x00505F39, 0x0056653F, 0x0051603A, 0x0056653F, 0x0055643E, 0x004F5E38, 0x00586741, 0x0054633D, 0x004F613A, 0x004F613A, 0x0050623B, 0x0051633C, 0x0051633C, 0x0052643D, 0x0053653E, 0x0053653E, 0x004D5F38,
        0x0052643D, 0x0051633C, 0x0052643D, 0x004F613A, 0x00556740, 0x0053653E, 0x0052643D, 0x004D5F36, 0x0056683F, 0x00576940, 0x004C5E35, 0x0053653C, 0x0052643B, 0x00475930, 0x005A6C43, 0x004F613A, 0x00586A43, 0x0063754E, 0x0072845B, 0x0076885F,
        0x0073855C, 0x0074865D, 0x00718459, 0x006F8054, 0x00748559, 0x00708155, 0x00738458, 0x00738459, 0x00708156, 0x00798A5F, 0x006F8055, 0x0076865D, 0x0075855C, 0x0074845B, 0x0074845B, 0x0075855C, 0x0076865D, 0x0076865D, 0x0076865D, 0x006F8257,
        0x006E8156, 0x006E8156, 0x006D8055, 0x006D8055, 0x006E8156, 0x006E8156, 0x006F8257, 0x006F8158, 0x006E8057, 0x006E8057, 0x006D7F56, 0x006D7F56, 0x006C7E55, 0x006C7E55, 0x006C7E55, 0x00738459, 0x00728358, 0x006D7E53, 0x006B7C51, 0x006F8055,
        0x00708156, 0x006F8055, 0x00718257, 0x00708259, 0x006F8158, 0x006D7F56, 0x006D7F56, 0x006E8057, 0x006E8057, 0x006E8057, 0x006D7F56, 0x006F8257, 0x006E8156, 0x006C7E55, 0x006E8057, 0x00708259, 0x0051633C, 0x002A3C15, 0x00293B14, 0x00213917,
        0x001E3614, 0x001F3715, 0x00213917, 0x001C3412, 0x001C3412, 0x00203816, 0x00203816, 0x002B3615, 0x002B3615, 0x00283312, 0x003D4925, 0x0067734F, 0x0078855F, 0x0073805A, 0x0074815B, 0x0074885B, 0x0074885B, 0x0075885D, 0x007C8F64, 0x006E8057,
        0x005A6C43, 0x0055673E, 0x0061734C, 0x0058683F, 0x00607047, 0x0066764D, 0x005E6E45, 0x005E6E45, 0x0056663D, 0x005A6A41, 0x005E6E45, 0x0070815C, 0x00879873, 0x007C8E67, 0x00606F49, 0x005E6E45, 0x006B7950, 0x0056643A, 0x002E3C12, 0x006B7955,
        0x005C6D41, 0x003C4F1C, 0x003C4E1F, 0x006B7955, 0x006C7959, 0x00606F49, 0x00546637, 0x005B6C40, 0x00708156, 0x0074855A, 0x006F7F56, 0x00798862, 0x006F805B, 0x00465634, 0x00243412, 0x002E3A10, 0x00313D13, 0x00333F15, 0x00333F15, 0x00303C12,
        0x00303C12, 0x00323E14, 0x00354117, 0x00303E1A, 0x00303E1A, 0x002D3C16, 0x002E3D17, 0x004D5C36, 0x0074815B, 0x0077855C, 0x00717F56, 0x00768460, 0x0076855F, 0x0074845B, 0x00778660, 0x00636F51, 0xFFDBE3D2, 0xFFFDFFFE, 0xFFFDFDFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFF8FEFF, 0xFFF8FEFD, 0x00C5CEC1, 0x00505D43, 0x007F8F6D, 0x007F916A, 0x0055693F, 0x002E441A, 0x00586A45, 0x0051633E, 0x004A5C37, 0x0031431E, 0x004C5E39,
        0x00435530, 0x0031431E, 0x003B4D28, 0x006A7E61, 0x00556855, 0x00576968, 0x008899A6, 0x00D2E3F8, 0x00D3E5F6, 0x00D3E5F0, 0x00CADDE2, 0x00D5E2FA, 0x00DAE7FD, 0x00CDD7E9, 0x0079828B, 0x00626D6A, 0x00485644, 0x00627554, 0x00667C52, 0x005D6A54,
        0x005B6951, 0x00536046, 0x00526142, 0x005A6A48, 0x005E6D47, 0x005B6C41, 0x005B6C41, 0x00738459, 0x00728358, 0x00728358, 0x00718257, 0x00718257, 0x00728358, 0x00738459, 0x0074855A, 0x00738459, 0x0075865B, 0x00728358, 0x0075865B, 0x0078895E,
        0x006A7B50, 0x00536439, 0x0045562B, 0x0031401A, 0x003D4C26, 0x002A3913, 0x002D3C16, 0x003C4B25, 0x0032411B, 0x002E3D17, 0x002C3B15, 0x002C3F18, 0x002D4019, 0x002F421B, 0x002F421B, 0x002F421B, 0x002E411A, 0x002C3F18, 0x002B3E17, 0x002D4116,
        0x0033471C, 0x00304419, 0x00304419, 0x00293D12, 0x0031451A, 0x002D4116, 0x002B3F14, 0x0030461C, 0x002B4117, 0x002D4319, 0x002A4016, 0x00263C12, 0x002C4218, 0x002C4218, 0x0023390F, 0x003A4C23, 0x004B5D34, 0x005B6D44, 0x006E8059, 0x0074865F,
        0x0070815C, 0x00748560, 0x00728260, 0x00707F59, 0x0074835D, 0x00718158, 0x0078885F, 0x00718257, 0x0076875B, 0x007B8C60, 0x0077885C, 0x0078885F, 0x0076865D, 0x0074845B, 0x0073835A, 0x0074845B, 0x0075855C, 0x0074845B, 0x0073835A, 0x00718459,
        0x00708358, 0x00708358, 0x00708358, 0x00708358, 0x00708358, 0x00718459, 0x00718459, 0x0071835A, 0x00708259, 0x00708259, 0x00708259, 0x00708259, 0x00708259, 0x00708259, 0x00708259, 0x0073835A, 0x0074845B, 0x006E7E55, 0x006C7C53, 0x00708057,
        0x00708057, 0x00708057, 0x0074845B, 0x0073855C, 0x0072845B, 0x0071835A, 0x0071835A, 0x0071835A, 0x0071835A, 0x006F8158, 0x006E8057, 0x006D8055, 0x006C7F54, 0x00708358, 0x00718459, 0x0074875C, 0x006B7E53, 0x00596C41, 0x00596C41, 0x005A6D4C,
        0x005A6E4B, 0x005B704A, 0x005C714B, 0x005C714B, 0x005A6F49, 0x00586C49, 0x00596C4B, 0x005C6A46, 0x00606E4A, 0x005F6D49, 0x0063724C, 0x00707F59, 0x0074835D, 0x00708057, 0x00728259, 0x0071835A, 0x00708259, 0x00708358, 0x0072855A, 0x0056693E,
        0x005E7047, 0x005B6C47, 0x0053643F, 0x0063724C, 0x0064734D, 0x00606F49, 0x00576640, 0x00576640, 0x005C6B45, 0x0061704A, 0x00606F49, 0x006C7E57, 0x0060714C, 0x00576843, 0x0054623E, 0x00677551, 0x0058653F, 0x003B491F, 0x00637147, 0x006A7856,
        0x0036471C, 0x003F521F, 0x00647746, 0x0065734F, 0x00536040, 0x0055633F, 0x005C6D42, 0x006E8051, 0x0078895D, 0x00728358, 0x006A7C55, 0x0073845F, 0x00758762, 0x00657752, 0x0052643F, 0x005A6943, 0x005B6A44, 0x005B6A44, 0x005B6A44, 0x005A6943,
        0x005A6943, 0x005B6A44, 0x005D6C46, 0x00586944, 0x00576843, 0x00576843, 0x00596743, 0x006A7854, 0x007C8864, 0x0077835F, 0x0076825E, 0x0074825E, 0x0075845E, 0x0074845B, 0x0076855F, 0x00606C4E, 0xFFD8E0CF, 0xFFFCFFFD, 0xFFFDFDFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFBFF, 0xFFFBF8FA, 0x00D3D1C6, 0x0063634B, 0x008D916E, 0x00838B62, 0x005D673D, 0x003C481E, 0x0064764F, 0x0060724B, 0x005B6D46, 0x00455730, 0x00687A53,
        0x00566841, 0x0032441D, 0x0033451E, 0x0079815C, 0x00535C42, 0x00565D58, 0x00989EA9, 0x00E3E9FC, 0x00CBD2E3, 0x00C1C8D1, 0x00C2C9CC, 0x00C8C6DA, 0x00E4E2EE, 0x00DBDCDA, 0x00767969, 0x005C6249, 0x0040492F, 0x004B543F, 0x003A4531, 0x005B625F,
        0x00515952, 0x00424A3F, 0x003E4837, 0x0048553D, 0x004C583C, 0x0043512F, 0x003F4D29, 0x00738459, 0x00728358, 0x00708156, 0x00708156, 0x00708156, 0x00718257, 0x00738459, 0x0074855A, 0x00738459, 0x0074855A, 0x00718257, 0x0074855A, 0x00798A5F,
        0x006A7B50, 0x004F6035, 0x003F5025, 0x004A5933, 0x0056653F, 0x0033421C, 0x0036451F, 0x00576640, 0x004A5933, 0x0035441E, 0x0031401A, 0x002D4019, 0x002E411A, 0x002F421B, 0x0030431C, 0x0031441D, 0x0030431C, 0x0030431C, 0x002F421B, 0x00324818,
        0x00324818, 0x002D4313, 0x00344A1A, 0x00304616, 0x00354B1B, 0x002F4515, 0x00304616, 0x002D451B, 0x0030481E, 0x002B4319, 0x002D451B, 0x002D451B, 0x00284016, 0x002B4319, 0x002A4218, 0x00314419, 0x00495C31, 0x005E7047, 0x0073855E, 0x00778765,
        0x00707F5F, 0x00738263, 0x00728162, 0x00798765, 0x00707E5C, 0x006E7C58, 0x00798862, 0x006E7F54, 0x0075865A, 0x006F8152, 0x00738556, 0x00728259, 0x00708057, 0x006F7F56, 0x006F7F56, 0x00728259, 0x0074845B, 0x0074845B, 0x0073835A, 0x006E8156,
        0x006E8156, 0x006D8055, 0x006D8055, 0x006D8055, 0x006E8156, 0x006F8257, 0x006F8257, 0x006E8156, 0x006E8156, 0x006E8156, 0x006F8257, 0x006F8257, 0x006F8257, 0x00708358, 0x00708358, 0x006E7D57, 0x0072815B, 0x006F7E58, 0x006F7E58, 0x0074835D,
        0x0073825C, 0x0071805A, 0x0075845E, 0x00708358, 0x00708358, 0x006F8257, 0x006F8257, 0x006F8257, 0x006E8156, 0x006C7F54, 0x006A7D52, 0x0071835A, 0x006D8055, 0x006F8257, 0x006A7D52, 0x006A7D52, 0x006F8257, 0x006F8257, 0x0074875C, 0x00778262,
        0x007B8665, 0x0075815D, 0x00727F59, 0x00798660, 0x00798561, 0x00747F5E, 0x00778262, 0x00748560, 0x00768762, 0x00748560, 0x0071835C, 0x0072845D, 0x0072845B, 0x00708259, 0x00708259, 0x0070825B, 0x007E9067, 0x0062744B, 0x00576A3F, 0x004D5F36,
        0x005F714A, 0x0050603E, 0x005C6B4B, 0x00505E3A, 0x00667450, 0x00687652, 0x0064724E, 0x0065734F, 0x00667450, 0x00606E4A, 0x00667450, 0x00657750, 0x0060714C, 0x00647452, 0x00707E5C, 0x00485634, 0x0035421C, 0x00606E45, 0x006B794F, 0x00334020,
        0x003E4F24, 0x00607340, 0x005A6D3C, 0x0055633F, 0x00717D5F, 0x0072805E, 0x006A7A51, 0x006D804F, 0x006A7B4F, 0x006A7A51, 0x006D7F58, 0x006A7C57, 0x00647651, 0x00667B55, 0x006D825B, 0x006D7D5E, 0x006B7B5C, 0x006A7A5B, 0x006A7A5B, 0x006C7C5D,
        0x006D7D5E, 0x006D7D5E, 0x006C7C5D, 0x006C7E59, 0x006D7E5C, 0x00748462, 0x00748462, 0x00768462, 0x00747F5E, 0x006D7857, 0x00768160, 0x0072805C, 0x0074835D, 0x0074845B, 0x0075845E, 0x005E6A4C, 0xFFD5DDCC, 0xFFFAFDFB, 0xFFFDFDFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFF, 0xFFFBFBFB, 0x00C8CFBA, 0x0058693D, 0x00819267, 0x00808F70, 0x00566742, 0x00395117, 0x0062744D, 0x0034461F, 0x0064764F, 0x00394B24, 0x0053653E,
        0x00596B44, 0x0031431C, 0x00384A23, 0x00658054, 0x00617957, 0x00576958, 0x00A2AFAD, 0x00D7E1E8, 0x00CFD8E1, 0x00C5D0D4, 0x00B1BDBD, 0x00C9CDDF, 0x00D1D4E2, 0x00D3D5DD, 0x009B9D9D, 0x00757A71, 0x00757F6E, 0x0056664E, 0x0062755A, 0x009C9DA1,
        0x00787A7B, 0x00666868, 0x006C6F6D, 0x005D615B, 0x008D9289, 0x007F8679, 0x00373E31, 0x0076875B, 0x00708155, 0x006F8054, 0x00728357, 0x00728357, 0x00748559, 0x0075865A, 0x00738458, 0x0076875C, 0x00728358, 0x00738459, 0x00728259, 0x007A8A61,
        0x0064744B, 0x00505F39, 0x0041502A, 0x0034461F, 0x005E7049, 0x00556740, 0x00263811, 0x004A5C35, 0x00697B54, 0x00384A23, 0x002D3F18, 0x002E4519, 0x002B4216, 0x002A4115, 0x002F461A, 0x00334A1E, 0x0031481C, 0x002D4418, 0x002D4418, 0x002F4417,
        0x002E4316, 0x00314619, 0x00314619, 0x002E4316, 0x0033481B, 0x00364B1E, 0x00304518, 0x00314619, 0x002D4417, 0x002C4317, 0x002C4317, 0x002A4218, 0x00294117, 0x00274217, 0x00264018, 0x002F4319, 0x004F6339, 0x00576940, 0x0076885F, 0x0072845B,
        0x0075855C, 0x0073835A, 0x0077875E, 0x0076875C, 0x0075865B, 0x0074855A, 0x0074855A, 0x0074855A, 0x0074855A, 0x0075865B, 0x0076875C, 0x0076865D, 0x0076865D, 0x0074845B, 0x0073835A, 0x0073835A, 0x00728259, 0x00728259, 0x00728259, 0x00708057,
        0x00708057, 0x00718158, 0x00708057, 0x00708057, 0x006F7F56, 0x006E7E55, 0x006D7D54, 0x006C7E55, 0x006C7E55, 0x006D7F56, 0x006D7F56, 0x006E8057, 0x006F8158, 0x006F8158, 0x00708259, 0x00708057, 0x00708057, 0x00708057, 0x00708057, 0x00718158,
        0x00718158, 0x00718158, 0x00718158, 0x00728259, 0x00718158, 0x00718158, 0x00708057, 0x00708057, 0x00708057, 0x00708057, 0x00708057, 0x006E7D57, 0x0073835A, 0x00718158, 0x006D7F56, 0x0072855A, 0x00718459, 0x006D8255, 0x00708558, 0x00748153,
        0x00738354, 0x00718054, 0x006E7F54, 0x006B7D54, 0x0071845D, 0x006D7F5A, 0x006C7E59, 0x006A825A, 0x006E835C, 0x00697E57, 0x006E815A, 0x0073845F, 0x00738361, 0x00758262, 0x006D795B, 0x00758861, 0x006B7E57, 0x006A7D56, 0x00556841, 0x0053663F,
        0x00546740, 0x00546740, 0x004C5F38, 0x006B7E57, 0x004B5E37, 0x003F522B, 0x00566942, 0x00586B44, 0x003F522B, 0x00566942, 0x00556841, 0x003A4B29, 0x005D6E4C, 0x0052643F, 0x003E502B, 0x00576A43, 0x0055693F, 0x00586C42, 0x003D5126, 0x00333F21,
        0x006B7955, 0x004A5B30, 0x00606D47, 0x00768161, 0x006E7756, 0x00738052, 0x0065773C, 0x00606C50, 0x005E6B4B, 0x005B6945, 0x005A6B40, 0x005A6B3F, 0x005A6B3F, 0x0058693E, 0x0056663D, 0x005A6844, 0x00586642, 0x00596743, 0x005C6A46, 0x005D6B47,
        0x005B6945, 0x005D6B47, 0x00616F4B, 0x0063714F, 0x005C6A48, 0x006D7B59, 0x00667654, 0x00697A55, 0x0071835E, 0x006D8059, 0x00667A50, 0x006D7E59, 0x006E8059, 0x006E8057, 0x00728259, 0x00616E4E, 0xFFD1D8C3, 0xFFFFFFF9, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFF, 0xFFFDFDFD, 0x00CAD1BC, 0x0056673B, 0x007B8C61, 0x00798869, 0x0050613C, 0x00324A10, 0x006C7E57, 0x0053653E, 0x0062744D, 0x00364821, 0x005E7049,
        0x0060724B, 0x002B3D16, 0x0033451E, 0x006E8461, 0x004F6249, 0x005C6A5F, 0x00AEB7BB, 0x00DAE0ED, 0x00C7CDDA, 0x00C9CFDA, 0x00CAD2D9, 0x00C9CFDC, 0x00DEE3EC, 0x00CFD2D6, 0x00909391, 0x00ADB3A8, 0x0076816D, 0x003D4D35, 0x006F8366, 0x00ABAFAA,
        0x008C908A, 0x005D6259, 0x00646A5F, 0x00818879, 0x00A8B09F, 0x00848D79, 0x00555E49, 0x005C6D41, 0x007A8B5F, 0x0078895D, 0x006C7D51, 0x0077885C, 0x0077885C, 0x006E7F53, 0x0076875B, 0x0077885D, 0x00738459, 0x0075865B, 0x0073835A, 0x007B8B62,
        0x0066764D, 0x0051603A, 0x0043522C, 0x00263811, 0x0043552E, 0x005F714A, 0x0041532C, 0x002B3D16, 0x00566841, 0x005C6E47, 0x00283A13, 0x0031481C, 0x0030471B, 0x002F461A, 0x0030471B, 0x0030471B, 0x002E4519, 0x002E4519, 0x002F461A, 0x00304419,
        0x00304419, 0x0031451A, 0x0031451A, 0x002F4318, 0x0031451A, 0x0032461B, 0x00304419, 0x0034491C, 0x0035491E, 0x002E4519, 0x002B4216, 0x002C441A, 0x002A4218, 0x00253F17, 0x00274119, 0x002F4319, 0x004F6339, 0x00576940, 0x0075875E, 0x0071835A,
        0x0075855C, 0x0073835A, 0x0076865D, 0x0075865B, 0x0074855A, 0x0074855A, 0x0074855A, 0x0074855A, 0x0074855A, 0x0074855A, 0x0075865B, 0x0074845B, 0x0073835A, 0x0073835A, 0x00728259, 0x00728259, 0x00728259, 0x00728259, 0x0073835A, 0x0073835A,
        0x0073835A, 0x0073835A, 0x0073835A, 0x00728259, 0x00718158, 0x00718158, 0x00708057, 0x006D7F56, 0x006D7F56, 0x006E8057, 0x006E8057, 0x006F8158, 0x00708259, 0x00708259, 0x00708259, 0x00708057, 0x00708057, 0x00708057, 0x00708057, 0x00718158,
        0x00718158, 0x00718158, 0x00718158, 0x00728259, 0x00718158, 0x00718158, 0x00708057, 0x00708057, 0x00708057, 0x00708057, 0x00708057, 0x006E7E55, 0x006D7D54, 0x006F7F56, 0x0071835A, 0x006F815A, 0x00667851, 0x0063764F, 0x006C7E59, 0x0076875C,
        0x0063734A, 0x006D7C56, 0x006B7C57, 0x007D8F68, 0x0064764D, 0x006F8257, 0x007C9063, 0x006D7F56, 0x006E8156, 0x006F8257, 0x006A7C53, 0x0070825B, 0x006E7C5A, 0x005F6B4D, 0x00697559, 0x00697A58, 0x0060714F, 0x00617250, 0x00485937, 0x004F603E,
        0x00536442, 0x004D5E3C, 0x00586947, 0x004A5B39, 0x00415230, 0x00465735, 0x00556644, 0x00495A38, 0x00374826, 0x00586947, 0x00586947, 0x00455536, 0x00556546, 0x00485938, 0x00455634, 0x00586A45, 0x00536540, 0x0053663F, 0x0051643D, 0x00536040,
        0x0053623C, 0x005D6E43, 0x00707C58, 0x00687156, 0x005B6247, 0x004E5931, 0x0062723D, 0x005C6544, 0x0058633D, 0x00535F35, 0x00505D2F, 0x004E5C2C, 0x004C5A2A, 0x00495628, 0x00465327, 0x00465228, 0x00445026, 0x00455127, 0x0048542A, 0x0049552B,
        0x0048542A, 0x004A562C, 0x004F5B31, 0x00515F35, 0x0057653C, 0x00586342, 0x005C684A, 0x00606C4E, 0x00637252, 0x00667752, 0x00687A51, 0x006B7C57, 0x006C7E57, 0x006C7E55, 0x00707F59, 0x005F6C4C, 0xFFD0D6C3, 0xFFFEFFFA, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFDFF, 0xFFFEFEFE, 0x00C9D0BB, 0x00596A3E, 0x00819267, 0x007F8E6F, 0x00566742, 0x00344C12, 0x0063754E, 0x0060724B, 0x00576942, 0x003B4D26, 0x005E7049,
        0x0061734C, 0x00364821, 0x003B4D26, 0x00727F65, 0x0047523E, 0x005E655E, 0x00A4A7AC, 0x00EAEAF6, 0x00E1E1ED, 0x00D4D5DF, 0x00D1D3DB, 0x00D2DBDE, 0x00D8DDDE, 0x00D1D6D4, 0x006B6E65, 0x00808576, 0x0067735D, 0x0057664A, 0x00455A3A, 0x004B5440,
        0x00656E5A, 0x00565F4A, 0x00505A43, 0x004F5A40, 0x00586448, 0x00546042, 0x006D7A5A, 0x004F6034, 0x0068794D, 0x007A8B5F, 0x0077885C, 0x00728357, 0x00748559, 0x0076875B, 0x00738458, 0x0077885D, 0x0074855A, 0x0076875C, 0x0074845B, 0x007C8C63,
        0x0067774E, 0x0053623C, 0x0045542E, 0x0050623B, 0x00253710, 0x004B5D36, 0x006A7C55, 0x002E4019, 0x0032441D, 0x00687A53, 0x004D5F38, 0x002D4116, 0x002E4217, 0x002F4318, 0x002E4217, 0x002C4015, 0x002E4217, 0x0031451A, 0x0032461B, 0x0032461B,
        0x0033471C, 0x0032461B, 0x0032461B, 0x0032461B, 0x0031451A, 0x00304419, 0x0032461B, 0x00304419, 0x0033471C, 0x002B4216, 0x00283E14, 0x002D4319, 0x002A421A, 0x00273F17, 0x00294119, 0x002E4218, 0x004F6339, 0x0056683F, 0x0075875E, 0x00708259,
        0x0074845B, 0x00728259, 0x0075855C, 0x00738459, 0x00738459, 0x00738459, 0x0074855A, 0x0074855A, 0x00738459, 0x00738459, 0x00738459, 0x00728259, 0x00718158, 0x00718158, 0x00718158, 0x00718158, 0x00728259, 0x0073835A, 0x0073835A, 0x0073835A,
        0x0073835A, 0x0073835A, 0x0073835A, 0x0073835A, 0x00728259, 0x00718158, 0x00708057, 0x006E8057, 0x006E8057, 0x006F8158, 0x006F8158, 0x00708259, 0x00708259, 0x0071835A, 0x0071835A, 0x00708057, 0x00708057, 0x00708057, 0x00708057, 0x00718158,
        0x00718158, 0x00718158, 0x00718158, 0x00728259, 0x00718158, 0x00718158, 0x00708057, 0x00708057, 0x00708057, 0x00708057, 0x00708057, 0x00718256, 0x006F8055, 0x006E7E55, 0x00657651, 0x00546442, 0x00495839, 0x0048573B, 0x004D5C40, 0x00526643,
        0x004C5F3E, 0x004A593D, 0x0049573B, 0x00617050, 0x0067774E, 0x00718151, 0x006F824B, 0x00778157, 0x00758256, 0x007A875B, 0x006E7D51, 0x00728259, 0x00647250, 0x00445236, 0x005D6A52, 0x003F4E33, 0x00445338, 0x004E5D42, 0x002F3E23, 0x00455439,
        0x0047563B, 0x002D3C21, 0x00505F44, 0x00526146, 0x00324126, 0x00707F64, 0x004A593E, 0x00314025, 0x004D5C41, 0x00324126, 0x0047563B, 0x0064715B, 0x0035432B, 0x00445338, 0x005E6D51, 0x00334324, 0x00425332, 0x005D6E4C, 0x00455732, 0x005A6846,
        0x004A5A31, 0x00607146, 0x005B6645, 0x00575F48, 0x00797E69, 0x00636B4C, 0x004D592F, 0x00586136, 0x00525C2E, 0x004C5824, 0x00495620, 0x0047541C, 0x0045521A, 0x00424E1A, 0x00404B19, 0x00434C19, 0x00434C19, 0x00444D1A, 0x00454E1B, 0x00464F1C,
        0x00464F1C, 0x0049521F, 0x004D5623, 0x00485620, 0x005B6638, 0x004C5332, 0x005A6049, 0x00595E49, 0x005C654B, 0x00646F4F, 0x00707D57, 0x00697957, 0x006A7C55, 0x006B7D54, 0x006F7E58, 0x005E6B4B, 0xFFCFD5C2, 0xFFFEFFFA, 0xFFFFFEFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFF, 0xFFFEFEFE, 0x00C6CDB8, 0x0056673B, 0x007E8F64, 0x007A896A, 0x0051623D, 0x002D450B, 0x00354720, 0x00364821, 0x0031431C, 0x002D3F18, 0x00354720,
        0x003B4D26, 0x002E4019, 0x002D3F18, 0x006E7A5C, 0x006F7A60, 0x008E9685, 0x009BA097, 0x00DBDEDC, 0x00DEE1DF, 0x00D1D4D2, 0x00DCE0DB, 0x00D0DBD3, 0x00EDF6EC, 0x00CBD2C5, 0x006C7261, 0x00ABB39C, 0x00879377, 0x00637453, 0x007C8F6E, 0x00717F5D,
        0x00717F5D, 0x006A7856, 0x0074825E, 0x0073825C, 0x0073825C, 0x005D6D44, 0x00526239, 0x00516237, 0x00516237, 0x0067784D, 0x007A8B60, 0x0075865B, 0x00738459, 0x0077885D, 0x00738459, 0x0076875C, 0x0074855A, 0x0076875C, 0x0074845B, 0x007B8B62,
        0x0066764D, 0x0053623C, 0x0045542E, 0x0071835C, 0x004A5C35, 0x0031431C, 0x00556740, 0x005C6E47, 0x0030421B, 0x003B4D26, 0x006E8059, 0x003A4E24, 0x00384C22, 0x00384C22, 0x00364A20, 0x0033471D, 0x0035491F, 0x00374B21, 0x0033471D, 0x0033471D,
        0x0034481E, 0x0032461C, 0x0033471D, 0x0035491F, 0x0033471D, 0x0031451B, 0x0035491F, 0x0033471C, 0x0032461B, 0x0031451B, 0x002E441A, 0x002D421B, 0x002F441D, 0x002B431B, 0x00263D17, 0x002E4218, 0x004E6238, 0x0056683F, 0x0074865D, 0x00708259,
        0x0073835A, 0x00718158, 0x0074845B, 0x00718257, 0x00728358, 0x00738459, 0x00738459, 0x00738459, 0x00738459, 0x00728358, 0x00718257, 0x0073835A, 0x00728259, 0x00728259, 0x00718158, 0x00728259, 0x00728259, 0x0073835A, 0x0073835A, 0x00718158,
        0x00728259, 0x00728259, 0x00728259, 0x00718158, 0x00708057, 0x006F7F56, 0x006F7F56, 0x006E8057, 0x006E8057, 0x006F8158, 0x006F8158, 0x006F8158, 0x00708259, 0x00708259, 0x00708259, 0x00708057, 0x00708057, 0x00708057, 0x00708057, 0x00718158,
        0x00718158, 0x00718158, 0x00718158, 0x00728259, 0x00718158, 0x00718158, 0x00708057, 0x00708057, 0x00708057, 0x00708057, 0x00708057, 0x006E7F53, 0x00748559, 0x0075855C, 0x0061724D, 0x004E5D3E, 0x00525F45, 0x005C6953, 0x005A6652, 0x004A5E41,
        0x0055684D, 0x00495942, 0x00616E58, 0x0049573B, 0x0052613B, 0x00556633, 0x0076874E, 0x007A7E5A, 0x00767E55, 0x00778156, 0x00738052, 0x00758359, 0x005E6C4A, 0x00414E34, 0x0057624E, 0x00202C18, 0x003C4834, 0x004A5642, 0x001E2A16, 0x00424E3A,
        0x00434F3B, 0x00182410, 0x00525E4A, 0x0047533F, 0x0027331F, 0x00606C58, 0x00384430, 0x002C3824, 0x005F6B57, 0x0036422E, 0x00333F2B, 0x00636E5E, 0x002E3A28, 0x003D4935, 0x005A6850, 0x0026351A, 0x00425233, 0x00576847, 0x00495A38, 0x0052603C,
        0x0053633A, 0x00536439, 0x00505B3B, 0x00636956, 0x00929586, 0x00868C75, 0x0049532F, 0x005C6330, 0x00555D28, 0x004E571E, 0x004B5618, 0x00495416, 0x00465014, 0x00444D15, 0x00444C17, 0x00444B12, 0x00454C13, 0x00454C13, 0x00464D14, 0x00464D14,
        0x00474E15, 0x00495017, 0x004C531A, 0x004E5D1F, 0x00485321, 0x00464B2B, 0x007B7D6A, 0x00707062, 0x00555946, 0x004E5638, 0x0075805A, 0x00697957, 0x006A7B56, 0x006B7D56, 0x006F7E58, 0x005F6B4D, 0xFFD0D6C3, 0xFFFEFFFA, 0xFFFFFEFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFDFF, 0xFFFFFFFF, 0x00C7CEB9, 0x0057683C, 0x007B8C61, 0x00788768, 0x005F704B, 0x00486026, 0x00495B34, 0x00485A33, 0x00455730, 0x0050623B, 0x00475932,
        0x00475932, 0x004B5D36, 0x004B5D36, 0x006E7C53, 0x007A8761, 0x008F9A7A, 0x006E775C, 0x00858E74, 0x00818972, 0x007D856E, 0x00929B81, 0x00809079, 0x0078846E, 0x0078826B, 0x00676E53, 0x00777F61, 0x00687555, 0x00657553, 0x006E835D, 0x0075865B,
        0x00718257, 0x0078895E, 0x007F9064, 0x006E7F53, 0x00738458, 0x00728357, 0x00637448, 0x0056673C, 0x00516237, 0x004E5F34, 0x00637449, 0x007D8E63, 0x0078895E, 0x006D7E53, 0x0078895E, 0x0074855A, 0x00728358, 0x0075865B, 0x0073835A, 0x007A8A61,
        0x0064744B, 0x0051603A, 0x0045542E, 0x006F815A, 0x0072845D, 0x003E5029, 0x0031431C, 0x005D6F48, 0x004D5F38, 0x002D3F18, 0x00475932, 0x0063754C, 0x005D6F46, 0x005E7047, 0x00607249, 0x00607249, 0x0063754C, 0x0064764D, 0x005E7047, 0x005F724B,
        0x0060734C, 0x0060734C, 0x0061744D, 0x0062754E, 0x0062754E, 0x0062754E, 0x0063764F, 0x0062744B, 0x005C6E45, 0x0060744A, 0x0061744D, 0x005A6D46, 0x005A6F49, 0x005A6F49, 0x004A5F39, 0x002E4218, 0x004E6238, 0x0056683F, 0x0074865D, 0x006F8158,
        0x0073835A, 0x00708057, 0x0073835A, 0x00718257, 0x00718257, 0x00728358, 0x00738459, 0x00738459, 0x00728358, 0x00718257, 0x00718257, 0x0076865D, 0x0075855C, 0x0074845B, 0x0073835A, 0x00728259, 0x00728259, 0x00728259, 0x00728259, 0x00728259,
        0x00728259, 0x00728259, 0x00728259, 0x00728259, 0x00718158, 0x00708057, 0x006F7F56, 0x006D7F56, 0x006E8057, 0x006E8057, 0x006E8057, 0x006E8057, 0x006E8057, 0x006E8057, 0x006E8057, 0x00708057, 0x00708057, 0x00708057, 0x00708057, 0x00718158,
        0x00718158, 0x00718158, 0x00718158, 0x00728259, 0x00718158, 0x00718158, 0x00708057, 0x00708057, 0x00708057, 0x00708057, 0x00708057, 0x006E7F53, 0x00748559, 0x0075855C, 0x0061724D, 0x004D5C3D, 0x00515E44, 0x005B6852, 0x005A6652, 0x00617459,
        0x00607058, 0x0045553E, 0x0065725C, 0x005B6A4F, 0x00667555, 0x004F5F36, 0x00455728, 0x004C5136, 0x00555B3C, 0x005E6941, 0x00728155, 0x0079875D, 0x005D6B49, 0x0048523B, 0x004B5544, 0x001E281B, 0x00475144, 0x004F594C, 0x001A2417, 0x00465043,
        0x00495346, 0x001E281B, 0x00626C5F, 0x004A5447, 0x00263023, 0x005A6457, 0x002E382B, 0x002A3427, 0x00687265, 0x00323C2F, 0x00283225, 0x00646E62, 0x00283225, 0x003A4535, 0x005C6854, 0x00233217, 0x00425233, 0x00566746, 0x00495A38, 0x004E5C38,
        0x0058683F, 0x0054653A, 0x00545F3F, 0x00494F3C, 0x003A3D2E, 0x00434932, 0x0049532F, 0x005E672F, 0x00576027, 0x00505A1E, 0x004D581A, 0x004A5517, 0x00485216, 0x0049521A, 0x004C5320, 0x004B511A, 0x004C521B, 0x004C521B, 0x004C521B, 0x004C521B,
        0x004C521B, 0x004B511A, 0x004A5019, 0x00445316, 0x004C5725, 0x004F5434, 0x00595B48, 0x0048483C, 0x005F6350, 0x005C6446, 0x0067714D, 0x006B7A5A, 0x006C7D58, 0x006D7F58, 0x00717F5B, 0x00606C4E, 0xFFD1D7C6, 0xFFFFFFFC, 0xFFFFFEFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFCFF, 0xFFFFFFFF, 0x00C9D0BB, 0x005A6B3F, 0x007A8B60, 0x007A896A, 0x00788964, 0x00748C52, 0x007B8D66, 0x007B8D66, 0x00758760, 0x007C8E67, 0x007F916A,
        0x00778962, 0x00778962, 0x007F916A, 0x00829367, 0x00708155, 0x007B8C61, 0x00708156, 0x0077875E, 0x0071805A, 0x0072815B, 0x007C8B65, 0x006A7B5A, 0x006F7F5D, 0x00727D5C, 0x006C7652, 0x0069734F, 0x0077845E, 0x00788A63, 0x0072855E, 0x00788A5B,
        0x00748657, 0x00738556, 0x00728455, 0x006A7B4F, 0x00748559, 0x007B8C60, 0x0077885C, 0x0065754C, 0x0054643B, 0x004A5A31, 0x0055653C, 0x00697950, 0x0075855C, 0x0074845B, 0x00718158, 0x00728358, 0x00708156, 0x0074855A, 0x00728259, 0x0078885F,
        0x0063734A, 0x0051603A, 0x0045542E, 0x006D7F58, 0x00788A63, 0x00465831, 0x002F411A, 0x00576942, 0x0051633C, 0x002F411A, 0x00374922, 0x0061734A, 0x00576940, 0x005A6C43, 0x00607249, 0x005E7047, 0x00607249, 0x0062744B, 0x005D6F46, 0x00576944,
        0x00576944, 0x005A6C47, 0x00596B46, 0x00576944, 0x005B6D48, 0x005E704B, 0x00596B46, 0x005D6F46, 0x00596B42, 0x0060724B, 0x0062754E, 0x005C6E49, 0x0060724D, 0x005C714B, 0x004B5F3C, 0x002F4319, 0x004F6339, 0x0056683F, 0x0074865D, 0x006F8158,
        0x00728259, 0x00708057, 0x0073835A, 0x00718257, 0x00728358, 0x00728358, 0x00728358, 0x00728358, 0x00728358, 0x00728358, 0x00718257, 0x0077875E, 0x0076865D, 0x0075855C, 0x0074845B, 0x0073835A, 0x00728259, 0x00728259, 0x00728259, 0x0075855C,
        0x0075855C, 0x0075855C, 0x0075855C, 0x0074845B, 0x0073835A, 0x00728259, 0x00728259, 0x006D7F56, 0x006D7F56, 0x006D7F56, 0x006D7F56, 0x006D7F56, 0x006D7F56, 0x006D7F56, 0x006D7F56, 0x00708057, 0x00708057, 0x00708057, 0x00708057, 0x00718158,
        0x00718158, 0x00718158, 0x00718158, 0x00728259, 0x00718158, 0x00718158, 0x00708057, 0x00708057, 0x00708057, 0x00708057, 0x00708057, 0x00728357, 0x006F8055, 0x006E7E55, 0x00647550, 0x00536341, 0x00475637, 0x0047563A, 0x004B5A3E, 0x0048563A,
        0x004B593D, 0x004B5A3E, 0x0049583C, 0x00536449, 0x00506146, 0x00495941, 0x00182A13, 0x003A4339, 0x00414D3B, 0x00415031, 0x004D5F38, 0x0053633A, 0x00404E2C, 0x003D452E, 0x00434938, 0x00151F13, 0x00374135, 0x003E483C, 0x00151F13, 0x003A4438,
        0x003B4539, 0x001A2418, 0x004E584C, 0x003C463A, 0x001A2418, 0x00545E52, 0x00252F23, 0x001D271B, 0x005A6458, 0x00202A1E, 0x00293327, 0x00596258, 0x00182216, 0x002F3A2A, 0x0056634D, 0x00202F14, 0x003B4C2B, 0x00536442, 0x0040522D, 0x00515F3D,
        0x004B5B32, 0x0055663B, 0x0065704F, 0x007D856E, 0x006E735E, 0x004D5536, 0x004B572D, 0x005A642F, 0x00525D25, 0x004C581E, 0x004B571B, 0x004A561C, 0x004D5722, 0x00565F2D, 0x0061683B, 0x005E683A, 0x005E683A, 0x005E683A, 0x005E683A, 0x005E683A,
        0x005C6638, 0x00566032, 0x004F592B, 0x004C5925, 0x003D471C, 0x00515738, 0x006F745F, 0x00666A57, 0x00686F5A, 0x005E684A, 0x00737F5B, 0x006D7C5C, 0x006E7E5C, 0x006F805B, 0x0072805C, 0x00616D51, 0xFFD1D7C6, 0xFFFFFFFC, 0xFFFFFEFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFF, 0xFFFFFFFF, 0x00C3CAB5, 0x0057683C, 0x0076875C, 0x00738263, 0x00758661, 0x00789056, 0x00758760, 0x0074865F, 0x0074865F, 0x006F815A, 0x007D8F68,
        0x00768861, 0x0071835C, 0x007B8D66, 0x007B8D66, 0x0070825B, 0x0076885F, 0x007F9267, 0x007C8F64, 0x0073855C, 0x00798B64, 0x007C8E67, 0x00798D62, 0x007B8E63, 0x007E8C62, 0x00828E64, 0x00808C62, 0x0078865C, 0x0072855A, 0x0072865B, 0x00718354,
        0x00728357, 0x00718256, 0x0075865A, 0x0078895E, 0x0078895E, 0x0073835A, 0x0073835A, 0x0076865D, 0x005C6C43, 0x0057673E, 0x0055653C, 0x004F5F36, 0x0065754C, 0x00798960, 0x006D7D54, 0x00718257, 0x00708156, 0x0074855A, 0x0073835A, 0x0078885F,
        0x0063734A, 0x0051603A, 0x0045542E, 0x006B7D56, 0x006C7E57, 0x0033451E, 0x0040522B, 0x006A7C55, 0x003B4D26, 0x002A3C15, 0x005E7049, 0x0061734C, 0x00556740, 0x00596B44, 0x0060724B, 0x00576942, 0x0052643D, 0x00596B44, 0x005A6C45, 0x00596A48,
        0x00576846, 0x005D6E4C, 0x005B6C4A, 0x00536442, 0x005D6E4C, 0x00637452, 0x00556644, 0x0054643B, 0x00596842, 0x00576942, 0x00566841, 0x00586A45, 0x005A6C47, 0x00526341, 0x00455936, 0x0030441A, 0x0050643A, 0x00576940, 0x0075875E, 0x00708259,
        0x0073835A, 0x00708057, 0x0073835A, 0x00728358, 0x00728358, 0x00728358, 0x00718257, 0x00718257, 0x00728358, 0x00728358, 0x00728358, 0x0075855C, 0x0074845B, 0x0073835A, 0x00728259, 0x00728259, 0x00728259, 0x00728259, 0x0073835A, 0x0075855C,
        0x0075855C, 0x0075855C, 0x0075855C, 0x0075855C, 0x0074845B, 0x0073835A, 0x00728259, 0x006F8158, 0x006F8158, 0x006E8057, 0x006E8057, 0x006E8057, 0x006E8057, 0x006E8057, 0x006E8057, 0x00708057, 0x00708057, 0x00708057, 0x00708057, 0x00718158,
        0x00718158, 0x00718158, 0x00718158, 0x00728259, 0x00718158, 0x00718158, 0x00708057, 0x00708057, 0x00708057, 0x00708057, 0x00708057, 0x006F7F56, 0x006E7E55, 0x006F7F56, 0x00708259, 0x006D7F58, 0x0063754E, 0x0060734C, 0x00697B56, 0x00565C3D,
        0x00303A16, 0x002A3913, 0x00374924, 0x004D6242, 0x003C4F3E, 0x00465753, 0x00213235, 0x0027373E, 0x003F504C, 0x00495D4A, 0x004B603F, 0x0052653E, 0x0043512F, 0x00333922, 0x00404131, 0x00192317, 0x001E281C, 0x00242E22, 0x00131D11, 0x00273125,
        0x00232D21, 0x00121C10, 0x00252F23, 0x001E281C, 0x00202A1E, 0x00283226, 0x00212B1F, 0x00162014, 0x00283226, 0x001E281C, 0x00172115, 0x00293327, 0x001D271A, 0x001B2715, 0x002E3B25, 0x00324125, 0x00435432, 0x00445730, 0x004D6137, 0x004E5B3B,
        0x0051603A, 0x0066774C, 0x005D6945, 0x0060694E, 0x0061684D, 0x00545F37, 0x0053632E, 0x00566031, 0x004D5826, 0x0044501C, 0x00424F19, 0x00424E1A, 0x00485224, 0x005A6239, 0x006D744F, 0x00667452, 0x00677553, 0x00667452, 0x00657351, 0x00667452,
        0x0062704E, 0x00566442, 0x004A5836, 0x003A4721, 0x003A4622, 0x00424C2E, 0x004D583E, 0x00576248, 0x00637155, 0x00667555, 0x006B7C57, 0x006F7E5E, 0x006F7F5D, 0x006F805B, 0x0072805E, 0x00616D51, 0xFFD0D5C6, 0xFFFEFFFD, 0xFFFFFEFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFF, 0xFFFBFBFB, 0x00BCC3AE, 0x0058693D, 0x007E8F64, 0x00798869, 0x00778863, 0x00758D53, 0x00798B64, 0x0074865F, 0x0081936C, 0x0072845D, 0x007C8E67,
        0x007A8C65, 0x00788A63, 0x007B8D66, 0x00718366, 0x007E9071, 0x00708461, 0x00728761, 0x00748963, 0x00748963, 0x00748865, 0x006F8261, 0x006F8555, 0x00728455, 0x00788859, 0x00778156, 0x007F895E, 0x00738256, 0x00798A5F, 0x006E8257, 0x00748559,
        0x00738458, 0x00738459, 0x0074845B, 0x00718158, 0x006B7A54, 0x006D7C56, 0x0075835F, 0x007A8A61, 0x00728259, 0x005F6F46, 0x004F5F36, 0x004D5D34, 0x0056663D, 0x0068784F, 0x00798960, 0x00718257, 0x00718257, 0x0075865B, 0x0073835A, 0x00798960,
        0x0063734A, 0x0052613B, 0x0046552F, 0x006E8059, 0x00394B24, 0x002C3E17, 0x006A7C55, 0x0054663F, 0x00273912, 0x0054663F, 0x005F714A, 0x0032411B, 0x00283711, 0x0032411B, 0x003D4C26, 0x0035441E, 0x0033421C, 0x0042512B, 0x004C5B35, 0x00364725,
        0x00334422, 0x003C4D2B, 0x00384927, 0x002C3D1B, 0x00384927, 0x00415230, 0x002D3E1C, 0x00404F29, 0x004B5A34, 0x003F512A, 0x00364722, 0x003E502B, 0x003A4B29, 0x002A3B19, 0x00243815, 0x0030441A, 0x0050643A, 0x00576940, 0x0075875E, 0x00708259,
        0x0073835A, 0x00708057, 0x0073835A, 0x00738459, 0x00728358, 0x00728358, 0x00718257, 0x00718257, 0x00728358, 0x00728358, 0x00738459, 0x00728259, 0x00728259, 0x00718158, 0x00718158, 0x00718158, 0x00728259, 0x0073835A, 0x0073835A, 0x0073835A,
        0x0073835A, 0x0073835A, 0x0073835A, 0x0073835A, 0x00728259, 0x00718158, 0x00708057, 0x00708259, 0x00708259, 0x00708259, 0x006F8158, 0x006F8158, 0x006F8158, 0x006F8158, 0x006F8158, 0x00708057, 0x00708057, 0x00708057, 0x00708057, 0x00718158,
        0x00718158, 0x00718158, 0x00718158, 0x00728259, 0x00718158, 0x00718158, 0x00708057, 0x00708057, 0x00708057, 0x00708057, 0x00708057, 0x006F7E58, 0x0074845B, 0x00718158, 0x006C7E55, 0x00708358, 0x006E8156, 0x00697E51, 0x006D8255, 0x00434724,
        0x00343C14, 0x002C390D, 0x0036491E, 0x002D4222, 0x00405447, 0x0065777E, 0x005B6C7F, 0x00586C7D, 0x006C8287, 0x006E8577, 0x0051694B, 0x0050653F, 0x00465432, 0x002E341B, 0x004D4D3B, 0x00384235, 0x001D271A, 0x001E281B, 0x001C2619, 0x00212B1E,
        0x001B2518, 0x001B2518, 0x00192316, 0x001D271A, 0x00192316, 0x00202A1D, 0x001F291C, 0x001B2518, 0x002A3427, 0x001A2417, 0x001C2619, 0x001A2418, 0x001C2619, 0x001D2917, 0x00233119, 0x002D3D1E, 0x00495B36, 0x0052663C, 0x00455A2D, 0x00525E40,
        0x00495733, 0x00617247, 0x0076835D, 0x00707B5B, 0x005D6645, 0x00626F41, 0x005B6D32, 0x00566035, 0x004A5527, 0x003D4919, 0x00354111, 0x00323D0F, 0x00384218, 0x004E5532, 0x00646B4A, 0x0065765B, 0x0065765B, 0x0064755A, 0x00637459, 0x0064755A,
        0x005F7055, 0x004F6045, 0x00405136, 0x00344022, 0x00414D2F, 0x00394527, 0x003B4A2B, 0x00556445, 0x00617251, 0x0070815F, 0x006A7B59, 0x006F7E5F, 0x006F7F5D, 0x006F805B, 0x0072805E, 0x00606C50, 0xFFCFD4C5, 0xFFFDFEFC, 0xFFFEFCFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFF, 0xFFFFFFFE, 0x00BAC1AC, 0x00586839, 0x0078875B, 0x00838E6E, 0x0066724E, 0x005E7138, 0x0063734A, 0x0064744B, 0x0063734A, 0x005F6F46, 0x005E6E45,
        0x0067774E, 0x00607047, 0x00627249, 0x00708565, 0x004F6247, 0x003D4D3B, 0x0069786A, 0x0049584A, 0x00354631, 0x0033462B, 0x003B502F, 0x00364236, 0x002E3A2E, 0x00354234, 0x00485442, 0x004A5840, 0x00455434, 0x00697C51, 0x00748859, 0x0076895E,
        0x0074865D, 0x0073855C, 0x00708259, 0x00758760, 0x006D7F58, 0x006F805B, 0x00768762, 0x0076855F, 0x00788761, 0x0074835D, 0x005E6D47, 0x0052613B, 0x004F5E38, 0x0054633D, 0x0072815B, 0x0074835D, 0x006F7E58, 0x0075845E, 0x006E7D57, 0x007B8A64,
        0x00677650, 0x00495832, 0x00485731, 0x00424D25, 0x00364119, 0x0065734A, 0x00627047, 0x002C3C13, 0x0047572E, 0x0063754C, 0x003D4F26, 0x002C4016, 0x00283C12, 0x00475B31, 0x00586B44, 0x0051643D, 0x0041532E, 0x005F714C, 0x00485A35, 0x003A4C27,
        0x004C5E39, 0x0051643D, 0x004F6339, 0x00394D23, 0x005A6E43, 0x005B7043, 0x00455A2D, 0x0055673E, 0x0055673E, 0x0042562C, 0x00455831, 0x00566B44, 0x00536842, 0x003A512B, 0x00233A14, 0x002C4016, 0x004D6137, 0x0054683E, 0x0072865C, 0x006A7E54,
        0x0070845A, 0x0072865C, 0x006F8359, 0x0070825B, 0x0071835C, 0x0071835C, 0x0072845D, 0x0072845D, 0x0073855E, 0x0073855E, 0x0073855E, 0x00758458, 0x00748357, 0x00748258, 0x00738157, 0x00738158, 0x00748259, 0x00748259, 0x0074815B, 0x00728259,
        0x00728259, 0x0073835A, 0x0074845B, 0x0074845B, 0x0073835A, 0x00728259, 0x00728259, 0x0074855A, 0x0074855A, 0x00738459, 0x00728358, 0x00728358, 0x00728358, 0x00738459, 0x00738459, 0x006B7D54, 0x006D7F56, 0x006E8057, 0x00708259, 0x0071835A,
        0x00708259, 0x006F8158, 0x006F8158, 0x006E8156, 0x006E8156, 0x006F8257, 0x00708358, 0x00708358, 0x006F8257, 0x006E8156, 0x006D8055, 0x0070825B, 0x0071835C, 0x0070825B, 0x006D7F58, 0x006E8059, 0x006F815A, 0x006D7F58, 0x00687A53, 0x00343E14,
        0x00374325, 0x00314129, 0x003C4C2D, 0x00627351, 0x005C6F5E, 0x006A859A, 0x006281B8, 0x006F8AAC, 0x006D8896, 0x002E4739, 0x00435A34, 0x004C6033, 0x003C4A28, 0x00262F22, 0x00474F4F, 0x00465141, 0x00434E3E, 0x003A4535, 0x00475242, 0x00333E2E,
        0x00354030, 0x00434E3E, 0x00323D2D, 0x00363F2B, 0x00414A36, 0x0038412D, 0x003F4631, 0x003F4631, 0x003F452E, 0x002C321B, 0x00232912, 0x00272916, 0x00282C19, 0x00242A13, 0x002C3219, 0x00343E20, 0x005F6A49, 0x004C5B35, 0x0051603A, 0x00495E3D,
        0x00465C39, 0x005B6E47, 0x006D7E53, 0x006A7749, 0x00657246, 0x005F6F46, 0x00546740, 0x00596338, 0x004F5B37, 0x00465540, 0x00495B54, 0x00879A9D, 0x009CACB3, 0x00A7B1BB, 0x00A7B0B9, 0x00ADBCBE, 0x00ADBCBE, 0x00ADBCBE, 0x00ACBBBD, 0x00AAB9BB,
        0x00A7B6B8, 0x00A4B3B5, 0x00A2B1B3, 0x00A4B2B8, 0x00A1AFB5, 0x00A4B2B8, 0x00A3B1B7, 0x00A8B6BC, 0x00AFBDC3, 0x00ACBAC0, 0x00AEBCC2, 0x00BCC3C6, 0x007F8C7C, 0x006D7F5A, 0x0076885F, 0x00616D4F, 0xFFCFD3C7, 0xFFFFFFFE, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFAFC, 0xFFFDFEFC, 0x00BAC1AC, 0x005C6C3D, 0x007B8A5E, 0x007C8767, 0x004E5A36, 0x003A4D14, 0x00314118, 0x00304017, 0x00324219, 0x00314118, 0x0033431A,
        0x002D3D14, 0x002D3D14, 0x0035451C, 0x00667960, 0x0050604E, 0x00616F64, 0x00828D8A, 0x00838E8C, 0x007E8A84, 0x00758377, 0x00778776, 0x006E796F, 0x00869187, 0x00879086, 0x00555F52, 0x003B4832, 0x004A593A, 0x0073855E, 0x0073875A, 0x0071835C,
        0x00788A63, 0x00778962, 0x00798B64, 0x007C8E65, 0x007D8F66, 0x0075875E, 0x0074875C, 0x0074835D, 0x006C7B55, 0x007A8963, 0x00788761, 0x005A6943, 0x004D5C36, 0x00505F39, 0x004F5E38, 0x0073825C, 0x0071805A, 0x007B8A64, 0x00778660, 0x00707F59,
        0x0064734D, 0x00586741, 0x0035441E, 0x002B3B12, 0x0054643B, 0x005C6C43, 0x0033451C, 0x0036481F, 0x005D6F46, 0x0052663C, 0x002B3F15, 0x002B3F15, 0x002E4218, 0x00465932, 0x004F623B, 0x00475934, 0x003B4D28, 0x00586A45, 0x003B4C2A, 0x00283B14,
        0x00485B34, 0x003B4F25, 0x00394D23, 0x0040542A, 0x004B5F35, 0x0032461C, 0x0033471D, 0x00586A41, 0x0045572E, 0x002C3F18, 0x003E512A, 0x005B704A, 0x00556A44, 0x00384F29, 0x00253B18, 0x00364A20, 0x0051653B, 0x0055693F, 0x0074885E, 0x0071855B,
        0x00778B61, 0x0074885E, 0x006D8157, 0x0071835C, 0x0072845D, 0x0072845D, 0x0072845D, 0x0072845D, 0x0072845D, 0x0071835C, 0x0071835C, 0x0075865A, 0x0074855A, 0x0074855A, 0x00738459, 0x00728259, 0x00728259, 0x0072815B, 0x0073825C, 0x00728358,
        0x00728358, 0x00738459, 0x00738459, 0x00738459, 0x00738459, 0x00728358, 0x00728358, 0x00708358, 0x006F8257, 0x006F8257, 0x006F8257, 0x006F8257, 0x00708358, 0x00718459, 0x00718459, 0x00708259, 0x0071835A, 0x0071835A, 0x0071835A, 0x0071835A,
        0x00708259, 0x006F8158, 0x006E8057, 0x00708259, 0x00708259, 0x00708259, 0x00708259, 0x00708259, 0x006F8158, 0x006F8158, 0x006E8057, 0x0070825B, 0x0071835C, 0x0070825B, 0x006E8059, 0x006F815A, 0x0070825B, 0x006D7F58, 0x00687A53, 0x00464C35,
        0x00687265, 0x00717F74, 0x004D5D46, 0x00455837, 0x003F5640, 0x0063818C, 0x007399C3, 0x007192B3, 0x00708F9E, 0x00436051, 0x005A734D, 0x0065794C, 0x00586642, 0x002E3827, 0x00434A45, 0x00455040, 0x00333E2E, 0x00343F2F, 0x00404B3B, 0x00323D2D,
        0x003B4636, 0x00414C3C, 0x003D4838, 0x00414A36, 0x00404935, 0x003D4632, 0x00454C37, 0x003A412C, 0x00353A25, 0x00272D16, 0x00292F18, 0x002C2F1F, 0x00292D1A, 0x0030361F, 0x00232C12, 0x004A5436, 0x0053613F, 0x004B5935, 0x004C5B35, 0x004E6342,
        0x004B603A, 0x005A6A41, 0x00677448, 0x00657042, 0x00606D3F, 0x00606F43, 0x0057683D, 0x005C653A, 0x005D6945, 0x006C7963, 0x0075867D, 0x00B7C6C8, 0x00D4E2E8, 0x00DFE9F0, 0x00E4EDF1, 0x00DAE6E8, 0x00DBE7E9, 0x00DBE7E9, 0x00DDE9EB, 0x00DDE9EB,
        0x00DDE9EB, 0x00DCE8EA, 0x00DBE7E9, 0x00DDE8EC, 0x00D9E4E8, 0x00DDE8EC, 0x00DDE8EC, 0x00DFEAEE, 0x00E2EDF1, 0x00D9E4E8, 0x00D7E2E6, 0x00D9E0E3, 0x008F9C8C, 0x006E805B, 0x0072845B, 0x005F6B4D, 0xFFD0D4C8, 0xFFFFFFFE, 0xFFFFFDFD, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFF, 0xFFFEFFFD, 0x00B9C0AB, 0x005B6B3C, 0x007C8B5F, 0x007C8767, 0x004A5632, 0x0032450C, 0x00526239, 0x0055653C, 0x0047572E, 0x0034441B, 0x0056663D,
        0x0048582F, 0x0034441B, 0x003E4E25, 0x00889782, 0x00505D4F, 0x005E6764, 0x00959BA2, 0x00D4D8E3, 0x00DEE2ED, 0x00D0D6DD, 0x00D3D9DE, 0x00DFE8E5, 0x00E2E9E6, 0x00C7CEC9, 0x00717A70, 0x00505A4A, 0x004E5B43, 0x00647250, 0x0064734D, 0x006C795F,
        0x005D6B4F, 0x00485738, 0x00556444, 0x00556641, 0x00586A43, 0x004F6138, 0x005B6E43, 0x0075855C, 0x0077875E, 0x0075855C, 0x0078885F, 0x00718158, 0x005E6E45, 0x0054643B, 0x00516138, 0x00586741, 0x00788761, 0x0073825C, 0x0071805A, 0x007E8D67,
        0x0065744E, 0x00505F39, 0x003F4E28, 0x00374922, 0x0061734C, 0x00455831, 0x0023360F, 0x004E633C, 0x005B7049, 0x002E461E, 0x00233B13, 0x002F4319, 0x002C3F18, 0x00384B24, 0x004B5E37, 0x0052643F, 0x00475934, 0x00576846, 0x00314220, 0x002C4015,
        0x0043572C, 0x004C6036, 0x0051643D, 0x00465932, 0x00566843, 0x00516240, 0x004B5C3A, 0x005A6C43, 0x00465831, 0x002E411A, 0x003E512A, 0x00576C46, 0x004F643E, 0x00384E2B, 0x00283E1B, 0x002A3D16, 0x004A5D36, 0x00576A43, 0x0073865F, 0x006D8059,
        0x0071845D, 0x0073865F, 0x00748760, 0x0071835C, 0x0071835C, 0x0072845D, 0x0072845D, 0x0071835C, 0x0070825B, 0x006F815A, 0x006E8059, 0x0075865B, 0x0074855A, 0x00738459, 0x00728259, 0x00728259, 0x0071805A, 0x0071805A, 0x0072815B, 0x006E8255,
        0x006E8255, 0x006F8356, 0x006F8356, 0x006F8356, 0x006F8356, 0x006E8255, 0x006E8255, 0x006E8156, 0x006E8156, 0x006E8156, 0x006E8156, 0x006F8257, 0x00708358, 0x00718459, 0x00718459, 0x0072845B, 0x0072845B, 0x0071835A, 0x0071835A, 0x00708259,
        0x006F8158, 0x006F8158, 0x006E8057, 0x0072845B, 0x0072845B, 0x0071835A, 0x00708259, 0x00708259, 0x00708259, 0x00708259, 0x00708259, 0x0070825B, 0x0070825B, 0x006F815A, 0x006E8059, 0x0070825B, 0x0072845D, 0x006E8059, 0x00687A53, 0x003C403B,
        0x00939A9D, 0x00AEBABE, 0x005B6C5F, 0x003C4E31, 0x004B644A, 0x00729696, 0x00749FBA, 0x007298BA, 0x00779BAB, 0x00527365, 0x00647E5A, 0x00667B4E, 0x00586741, 0x002E3821, 0x00444D40, 0x00353F2F, 0x00273121, 0x002D3727, 0x002C3626, 0x00283222,
        0x00333D2D, 0x002B3525, 0x00353F2F, 0x00353D2C, 0x00333B2A, 0x00363F2B, 0x00414734, 0x00363D28, 0x00373C27, 0x002C311C, 0x002B311A, 0x00252818, 0x002B2F1C, 0x00222914, 0x002C351B, 0x00343E20, 0x0052603E, 0x0045532F, 0x0055643E, 0x004A5F3E,
        0x004D5F38, 0x005D673C, 0x005C6637, 0x00535E30, 0x004E5B2F, 0x00556236, 0x00566035, 0x004C562B, 0x004E5938, 0x006A7660, 0x00717C72, 0x00B3BDBD, 0x00D7E0E3, 0x00D8E0E0, 0x00D4DCDC, 0x00DDE4E7, 0x00DCE3E6, 0x00DAE1E4, 0x00DAE1E4, 0x00DBE2E5,
        0x00DAE1E4, 0x00D8DFE2, 0x00D6DDE0, 0x00D9E1E1, 0x00D9E1E1, 0x00DFE7E7, 0x00DCE4E4, 0x00D9E1E1, 0x00DAE2E2, 0x00D8E0E0, 0x00DEE6E6, 0x00E4EBEE, 0x0094A191, 0x006E805B, 0x00708259, 0x005F6B4D, 0xFFD3D7CB, 0xFFFFFFFE, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFF, 0xFFFFFFFE, 0x00B9C0AB, 0x005A6A3B, 0x007B8A5E, 0x007E8969, 0x00515D39, 0x003D5017, 0x0068784F, 0x005E6E45, 0x00607047, 0x003B4B22, 0x00617148,
        0x0065754C, 0x0048582F, 0x00405027, 0x007C8E71, 0x0051604B, 0x00515C54, 0x009FA5AA, 0x00DBDEEC, 0x00CFD2E1, 0x00C1C4D2, 0x00C8CCD7, 0x00CACFD0, 0x00DADFE0, 0x00C9CFCE, 0x00636964, 0x00474F44, 0x00434C38, 0x00445034, 0x003F4D2B, 0x006E736A,
        0x005B6057, 0x00363D30, 0x003E4635, 0x0039432C, 0x00475337, 0x003C4929, 0x00475533, 0x006E7E55, 0x0078885F, 0x006B7B52, 0x00708057, 0x007D8D64, 0x006F7F56, 0x005D6D44, 0x00526239, 0x00586741, 0x005E6D47, 0x006D7C56, 0x007F8E68, 0x00788761,
        0x005E6D47, 0x004F5E38, 0x003C4B25, 0x00445932, 0x00485D36, 0x002D421B, 0x002C441C, 0x00506840, 0x00415931, 0x001B350D, 0x0028421A, 0x00293C15, 0x002B3E17, 0x003A4D26, 0x0052643F, 0x00536540, 0x0040512F, 0x00586947, 0x004E5F3D, 0x00384C21,
        0x003F5328, 0x0055693F, 0x00566942, 0x0032441F, 0x004D5E3D, 0x005E6F4E, 0x00455536, 0x0051633C, 0x0054663F, 0x00455831, 0x003F512C, 0x00425731, 0x003E522F, 0x00334926, 0x00253B18, 0x002D4019, 0x004C5F38, 0x005E714A, 0x00748760, 0x006C7F58,
        0x006B7E57, 0x006F825B, 0x0073865F, 0x006F815A, 0x0070825B, 0x0071835C, 0x0071835C, 0x0071835C, 0x0070825B, 0x006F815A, 0x006E8059, 0x00718459, 0x00718459, 0x00708259, 0x006F8158, 0x006F815A, 0x006F815A, 0x006F815A, 0x006F805B, 0x006D8255,
        0x006E8356, 0x006E8356, 0x006E8356, 0x006E8356, 0x006E8356, 0x006E8356, 0x006D8255, 0x006F8158, 0x006F8158, 0x006F8158, 0x006F8158, 0x00708259, 0x00708259, 0x0071835A, 0x0072845B, 0x006F8158, 0x006F8158, 0x006F8158, 0x006F8158, 0x006F8158,
        0x006F8158, 0x00708259, 0x00708259, 0x0073855C, 0x0072845B, 0x0071835A, 0x00708259, 0x00708259, 0x00708259, 0x00708259, 0x0071835A, 0x0070825B, 0x0070825B, 0x006F815A, 0x006F815A, 0x0071835C, 0x0073855E, 0x006F815A, 0x00687A53, 0x00393E3C,
        0x00616C70, 0x0069767E, 0x0045544C, 0x004B5E43, 0x00556E54, 0x00769897, 0x00759FB6, 0x006B97B6, 0x00749BA9, 0x0046685D, 0x005B7654, 0x0062774A, 0x004F5F36, 0x002E3A1C, 0x004D5642, 0x003C4636, 0x003D4737, 0x00424C3C, 0x00353F2F, 0x00384232,
        0x00404A3A, 0x00313B2B, 0x003D4737, 0x00293120, 0x00363E2D, 0x00313928, 0x003C422F, 0x003B412E, 0x00424732, 0x00393E29, 0x00252A15, 0x002E3121, 0x00212716, 0x002E3520, 0x00262F15, 0x003C482C, 0x004C5939, 0x00586944, 0x00546540, 0x004A5D3C,
        0x0056643B, 0x0063693A, 0x00505829, 0x003D491F, 0x0030411C, 0x003C4B25, 0x00434F25, 0x00435128, 0x00424D2D, 0x0067705C, 0x0071796F, 0x00B5BBBA, 0x00D8DEDD, 0x00BCC3C0, 0x00A4ABA6, 0x009CA0A1, 0x00989C9D, 0x00949899, 0x00929697, 0x00929697,
        0x00919596, 0x008E9293, 0x008B8F90, 0x009BA09E, 0x009FA4A2, 0x00A8ADAB, 0x00A1A6A4, 0x00979C9A, 0x009DA2A0, 0x00ADB2B0, 0x00C5CAC8, 0x00DCE3E6, 0x008F9C8C, 0x006D7F5A, 0x0073855C, 0x00616D4F, 0xFFD2D6CA, 0xFFFFFFFE, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCFBFD, 0xFFFEFFFD, 0x00BBC2AD, 0x005C6C3D, 0x007A895D, 0x007B8666, 0x004D5935, 0x003A4D14, 0x00596940, 0x00394920, 0x00607047, 0x00425229, 0x004B5B32,
        0x005C6C43, 0x0047572E, 0x00304017, 0x00687B54, 0x00677758, 0x005B6755, 0x00AFB6B3, 0x00DADEE3, 0x00C6C9D1, 0x00BEC2C7, 0x00B8BCC1, 0x00CACFD2, 0x00D2D7DA, 0x00CED2D3, 0x00818684, 0x0081867D, 0x00666E5D, 0x005C654B, 0x00677252, 0x00919296,
        0x00848687, 0x00545656, 0x004F534D, 0x005C6257, 0x00818879, 0x005D6652, 0x0037402B, 0x0074845B, 0x0073835A, 0x00728259, 0x0076865D, 0x006F7F56, 0x00718158, 0x0075855C, 0x00596940, 0x00596842, 0x004B5A34, 0x005E6D47, 0x0076855F, 0x00778660,
        0x006A7953, 0x004F5E38, 0x0042512B, 0x002A3F19, 0x00283D17, 0x0020350F, 0x00233A14, 0x002E451F, 0x00283F19, 0x001E3711, 0x00223B15, 0x002A3D16, 0x00283A15, 0x00293B16, 0x0032441F, 0x002F401E, 0x0020310F, 0x00344524, 0x00364726, 0x002B3E17,
        0x0032451E, 0x0032441F, 0x002E401B, 0x00253614, 0x00334423, 0x00334423, 0x00273718, 0x0030421B, 0x0041522D, 0x003B4D28, 0x0030421D, 0x002B3F1C, 0x002D411E, 0x002D4221, 0x00243918, 0x003A4C27, 0x004B5D38, 0x00596B46, 0x006E805B, 0x006F815C,
        0x0070825D, 0x006D7F5A, 0x006D7F5A, 0x006F815A, 0x0070825B, 0x0070825B, 0x0070825B, 0x0070825B, 0x0070825B, 0x006F815A, 0x006E8059, 0x006E8258, 0x006E8258, 0x006D8157, 0x006D8059, 0x006D8059, 0x006D7F5A, 0x006E805B, 0x006F815C, 0x006C8357,
        0x006C8357, 0x006C8357, 0x006C8357, 0x006C8357, 0x006C8357, 0x006C8357, 0x006C8357, 0x006E8258, 0x006E8258, 0x006E8258, 0x006D8157, 0x006E8258, 0x006E8258, 0x006F8359, 0x006F8359, 0x006D7F56, 0x006D7F56, 0x006D7F56, 0x006D7F56, 0x006E8057,
        0x006F8158, 0x00708259, 0x00708259, 0x0072845D, 0x0071835C, 0x0070825B, 0x006F815A, 0x006F815A, 0x006F815A, 0x0070825B, 0x0070825B, 0x006F815A, 0x0070825B, 0x006F815A, 0x006F815A, 0x0070825B, 0x0072845D, 0x006F815A, 0x006A7C55, 0x00434F3B,
        0x006E7D75, 0x00778584, 0x005C6A5F, 0x004B5941, 0x00314630, 0x00658286, 0x0081A6C2, 0x007099B0, 0x007398A0, 0x00385649, 0x005B7452, 0x006D8055, 0x00546239, 0x00313D1F, 0x004B543F, 0x003D4737, 0x00313B2B, 0x00364030, 0x00323C2C, 0x00313B2B,
        0x00353F2F, 0x00323C2C, 0x00323C2C, 0x00282F20, 0x003E4536, 0x00303827, 0x003A402F, 0x003B412E, 0x003F4330, 0x00393E29, 0x00232813, 0x0024291A, 0x001E2413, 0x00222815, 0x001C260F, 0x003A462A, 0x00485737, 0x004C5C3A, 0x0041522D, 0x00596B4C,
        0x00667046, 0x00666A39, 0x00454C21, 0x00314324, 0x00243D29, 0x00304830, 0x0035492C, 0x00324321, 0x002A371D, 0x00566050, 0x006A706B, 0x00B3B8B7, 0x00D6DCDB, 0x00B2B9B4, 0x008E9991, 0x00989C9D, 0x0095999A, 0x00929697, 0x00929697, 0x0095999A,
        0x0095999A, 0x00939798, 0x00919596, 0x00939896, 0x00959A98, 0x009CA19F, 0x00929795, 0x00898E8C, 0x00939896, 0x00AFB4B2, 0x00D1D6D4, 0x00DBE2E5, 0x008E9B8B, 0x006E805B, 0x0075875E, 0x00647052, 0xFFD2D6CA, 0xFFFEFFFD, 0xFFFFFEFE, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFAFC, 0xFFFDFEFC, 0x00BBC2AD, 0x005C6C3D, 0x007A895D, 0x007A8565, 0x004E5A36, 0x003B4E15, 0x005F6F46, 0x00495930, 0x005E6E45, 0x004B5B32, 0x005F6F46,
        0x005C6C43, 0x0035451C, 0x00304017, 0x0063774C, 0x005D6E4C, 0x0053604A, 0x00A3ACA2, 0x00DCE2E1, 0x00CDD2D3, 0x00C8CECD, 0x00BDC4C1, 0x00CCCFD3, 0x00CDD0D4, 0x00D3D7D8, 0x00A8ABA9, 0x00B9BEB5, 0x00787E6B, 0x00535C41, 0x00636E4E, 0x00939492,
        0x008C8D89, 0x00686A64, 0x0062655C, 0x0073776B, 0x00959A8B, 0x007D8372, 0x005D6350, 0x00697A4F, 0x0075865B, 0x00798A5F, 0x0074855A, 0x006D7E53, 0x00728358, 0x00798A5F, 0x00728358, 0x00596842, 0x0053623C, 0x00505F39, 0x005A6943, 0x0074835D,
        0x007B8A64, 0x00576640, 0x0054633D, 0x004D5E39, 0x00576843, 0x00556742, 0x0052643F, 0x004E633D, 0x004F643E, 0x00536A44, 0x00526943, 0x005B6D48, 0x00556742, 0x004E603B, 0x00475836, 0x004D5E3C, 0x004D5E3D, 0x00455635, 0x00364726, 0x0039492A,
        0x0039492A, 0x003A4A2B, 0x00485938, 0x004E5F3D, 0x004B5C3A, 0x00465735, 0x004D5F3A, 0x0051623D, 0x00566742, 0x0050623D, 0x00526341, 0x00526643, 0x004F6241, 0x004F6443, 0x004A5F3E, 0x00495B36, 0x00546641, 0x0061734E, 0x006F815C, 0x006F815C,
        0x006E805B, 0x006B7D58, 0x006C7E59, 0x006E8059, 0x006D7F58, 0x006B7D56, 0x006A7C55, 0x00687A53, 0x00667851, 0x00657750, 0x0064764F, 0x0061774D, 0x0061774D, 0x0060754E, 0x0060754E, 0x0060754F, 0x0060754F, 0x00617650, 0x00617552, 0x005F774F,
        0x005F774F, 0x005E764E, 0x005E764E, 0x005E764E, 0x005E764E, 0x005F774F, 0x005F774F, 0x0061754B, 0x0060744A, 0x0060744A, 0x0060744A, 0x0061754B, 0x0062764C, 0x0063774D, 0x0064784E, 0x0065774E, 0x0066784F, 0x00677950, 0x00697B52, 0x006A7C53,
        0x006B7D54, 0x006C7E55, 0x006C7E55, 0x006E8059, 0x006E8059, 0x006E8059, 0x006E8059, 0x006E8059, 0x006E8059, 0x006E8059, 0x006F815A, 0x006F815A, 0x0070825B, 0x0070825B, 0x006E8059, 0x006E8059, 0x0070825B, 0x006F815A, 0x006C7E57, 0x005D6F48,
        0x0099A991, 0x00A6B7AA, 0x007E8A78, 0x005A664A, 0x003D4D35, 0x00708888, 0x008BABC2, 0x007E9FAE, 0x00789697, 0x00445B4C, 0x00647756, 0x0064744B, 0x0046522E, 0x00283418, 0x00424D39, 0x003A4132, 0x00171E0F, 0x001D2415, 0x0022291A, 0x001D2415,
        0x001F2617, 0x0022291A, 0x001C2314, 0x00171E0F, 0x0022291A, 0x001F2617, 0x00292F1E, 0x00262C1B, 0x002E321F, 0x002C301D, 0x00272B18, 0x0024291A, 0x00333A2B, 0x001F2814, 0x002E3821, 0x002F3D21, 0x00526142, 0x00485937, 0x005A6B49, 0x0065785D,
        0x006A734B, 0x005F6231, 0x003A451F, 0x00375445, 0x00345C5B, 0x003E6563, 0x003E6056, 0x002F452C, 0x00283826, 0x005F6A60, 0x00808584, 0x00C5C8CC, 0x00DEE3E4, 0x00B4BFBC, 0x008E9D95, 0x00949A99, 0x00929897, 0x00929897, 0x00939998, 0x00959B9A,
        0x00979D9C, 0x00959B9A, 0x00949A99, 0x00979E9B, 0x00939A97, 0x00959C99, 0x008D9491, 0x00888F8C, 0x00949B98, 0x00ADB4B1, 0x00CDD4D1, 0x00E1E8EB, 0x008E9B8B, 0x006A7C57, 0x0074865D, 0x00667254, 0xFFD5D9CD, 0xFFFFFFFE, 0xFFFFFEFE, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFF, 0xFFFFFFFE, 0x00B9C0AB, 0x005A6A3B, 0x007A895D, 0x007D8868, 0x00515D39, 0x003D5017, 0x0066764D, 0x0068784F, 0x0055653C, 0x004E5E35, 0x006E7E55,
        0x005F6F46, 0x0037471E, 0x003D4D24, 0x00687757, 0x005A674D, 0x00868F82, 0x00A4A9A7, 0x00E1E5E6, 0x00C9CCD0, 0x00C1C6C5, 0x00C0C5C3, 0x00BEC2C3, 0x00DCE0E1, 0x00D0D2D2, 0x0070746F, 0x0084887D, 0x00616853, 0x00576143, 0x00616C4B, 0x00525B41,
        0x005B644A, 0x00596248, 0x00565F44, 0x00535C41, 0x00576045, 0x005F694B, 0x006D7759, 0x00495A2F, 0x0064754A, 0x00718257, 0x00718257, 0x0078895E, 0x00728358, 0x0068794E, 0x0075865B, 0x0074835D, 0x005B6A44, 0x0056653F, 0x005C6B45, 0x0056653F,
        0x00707F59, 0x0072815B, 0x005A6943, 0x00515F3D, 0x00576543, 0x0053613F, 0x0051613F, 0x004F5F3D, 0x004B5B39, 0x004F603E, 0x004F603E, 0x00455732, 0x004C5E39, 0x00556644, 0x00495A38, 0x004B5C3B, 0x004B5C3B, 0x002E3F1E, 0x00223213, 0x001F2B17,
        0x0014210B, 0x00253419, 0x00455536, 0x004B5C3A, 0x00485A35, 0x004C6036, 0x00506439, 0x004E5F3A, 0x004D5E39, 0x004A5B39, 0x00536442, 0x00526544, 0x004B5E3D, 0x004B603F, 0x004B6040, 0x00516240, 0x00586947, 0x00647553, 0x006C7D5B, 0x006A7B59,
        0x00667755, 0x00647553, 0x00697A58, 0x00677952, 0x0064764F, 0x0060724B, 0x005A6C45, 0x00556740, 0x0050623B, 0x004E6039, 0x004D5F38, 0x00465E34, 0x00455D35, 0x00445C34, 0x00435B33, 0x00425933, 0x00415832, 0x00415734, 0x00415734, 0x003E5634,
        0x003E5634, 0x003D5533, 0x003C5432, 0x003C5432, 0x003D5533, 0x003E5634, 0x003E5634, 0x0041562F, 0x0041562F, 0x00425730, 0x00435831, 0x00455A33, 0x00475C35, 0x00485D36, 0x00495E37, 0x0052643B, 0x0054663D, 0x00586A41, 0x005C6E45, 0x00607249,
        0x0064764D, 0x0066784F, 0x00677950, 0x006A7B56, 0x006A7B56, 0x006B7C57, 0x006C7D58, 0x006D7E59, 0x006D7E59, 0x006D7E59, 0x006D7E59, 0x006E8059, 0x0070825B, 0x0070825B, 0x006D7F58, 0x006C7E57, 0x006E8059, 0x006F815A, 0x006E8059, 0x00455526,
        0x003B4B2C, 0x00404E3C, 0x00444E37, 0x00656D48, 0x005B6945, 0x005F7668, 0x0066858E, 0x00789195, 0x00667C77, 0x0051624D, 0x00687555, 0x00505B35, 0x00404B2B, 0x002A371F, 0x00475444, 0x003E4536, 0x002E3526, 0x00394031, 0x00282F20, 0x00333A2B,
        0x00383F30, 0x00282F20, 0x00343B2C, 0x002E3526, 0x0022291A, 0x003A4132, 0x00393E2F, 0x002C3221, 0x00494C3C, 0x003E422F, 0x003C402D, 0x00363D30, 0x00303728, 0x002E3625, 0x00303C26, 0x00354228, 0x00435334, 0x005C6D4C, 0x006D7E5C, 0x0065785F,
        0x00677048, 0x005A5D30, 0x00364529, 0x00446A6A, 0x00467E91, 0x004F8498, 0x00477882, 0x00334F3C, 0x002D4337, 0x006C7977, 0x009CA0A5, 0x00D9DCE4, 0x00DEE4E9, 0x00ACBAB8, 0x0080928B, 0x008D9594, 0x008D9594, 0x008E9695, 0x008F9796, 0x008F9796,
        0x008F9796, 0x008E9695, 0x008D9594, 0x00929A9A, 0x008D9595, 0x008D9595, 0x00878F8F, 0x00838B8B, 0x008F9797, 0x00A9B1B1, 0x00C8D0D0, 0x00DEE5E8, 0x008D9A8A, 0x006A7C57, 0x0074865D, 0x00647052, 0xFFD3D7CB, 0xFFFFFFFE, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFF, 0xFFFFFFFE, 0x00B7BEA9, 0x0059693A, 0x007B8A5E, 0x007C8767, 0x00495531, 0x0030430A, 0x0036461D, 0x003C4C23, 0x00293910, 0x0033431A, 0x0035451C,
        0x0036461D, 0x003D4D24, 0x002D3D14, 0x0069755F, 0x005F6959, 0x00BEC4BF, 0x009FA2A6, 0x00E8EAF2, 0x00E3E5ED, 0x00D8DBDF, 0x00D3D8D7, 0x00DCE1E0, 0x00F0F5F4, 0x00CED1CF, 0x00686C66, 0x008C9084, 0x00757D66, 0x00707B5B, 0x0076805C, 0x006D7D4E,
        0x006F7F50, 0x00707F53, 0x006D7C50, 0x00738157, 0x0068764C, 0x005B693F, 0x00505E35, 0x00536439, 0x00516237, 0x006B7C51, 0x0077885D, 0x00728358, 0x00728358, 0x00708156, 0x00738459, 0x0074835D, 0x0071805A, 0x0055643E, 0x0054633D, 0x0054633D,
        0x0064734D, 0x0076855F, 0x007A8963, 0x00798261, 0x007A8362, 0x00737E5D, 0x00778261, 0x00768462, 0x00748260, 0x00768664, 0x006E7E5C, 0x0072845F, 0x006B7C5A, 0x0070815F, 0x00657654, 0x00687958, 0x005F704F, 0x002D3D1E, 0x00203011, 0x001A2417,
        0x0015210F, 0x00212E18, 0x00455438, 0x00667755, 0x006E8258, 0x006B8053, 0x006C8252, 0x006B7C57, 0x006E7E5C, 0x00687957, 0x00617250, 0x004A5D3C, 0x00344726, 0x00304525, 0x002F4424, 0x00364725, 0x00354624, 0x003F502E, 0x004E5F3D, 0x005C6D4B,
        0x00627351, 0x00617250, 0x00627351, 0x0060724B, 0x005B6D46, 0x0054663F, 0x004B5D36, 0x0043552E, 0x003D4F28, 0x00394B24, 0x00374922, 0x002E461E, 0x002C441C, 0x002B431B, 0x00283F19, 0x00263D17, 0x00253B18, 0x00243A17, 0x00243A17, 0x00203717,
        0x00203717, 0x001F3616, 0x001E3515, 0x001E3515, 0x001F3616, 0x00203717, 0x00203717, 0x00263B14, 0x00273C15, 0x00283D16, 0x002A3F18, 0x002D421B, 0x0030451E, 0x00334821, 0x00344922, 0x003E5027, 0x0041532A, 0x00485A31, 0x00506239, 0x00576940,
        0x005D6F46, 0x0061734A, 0x0063754C, 0x00677853, 0x00687954, 0x006A7B56, 0x006B7C57, 0x006C7D58, 0x006C7D58, 0x006C7D58, 0x006C7D58, 0x006D7F58, 0x0070825B, 0x0070825B, 0x006C7E57, 0x006A7C55, 0x006C7E57, 0x006F815A, 0x0070825B, 0x004E5B2D,
        0x004C5939, 0x00646F5B, 0x004E573C, 0x005C653A, 0x004B582A, 0x00243B1F, 0x00163730, 0x005D6F6E, 0x00405045, 0x004D5A42, 0x00697251, 0x004E5532, 0x00586244, 0x00434F3B, 0x0059685A, 0x00232A1B, 0x0042493A, 0x00515849, 0x00212819, 0x00454C3D,
        0x00515849, 0x00272E1F, 0x004C5344, 0x00434A3D, 0x00252C1D, 0x00505748, 0x003B4031, 0x00232918, 0x00555848, 0x00363A27, 0x00272B18, 0x005B6255, 0x003A4132, 0x002B3322, 0x0057634D, 0x00354228, 0x005D6D4E, 0x006A7B5A, 0x006C7D5B, 0x0062745D,
        0x00676F4A, 0x005B5F35, 0x00394C33, 0x0049777F, 0x004888A7, 0x004B8AAC, 0x00417A90, 0x00426152, 0x00304840, 0x00647173, 0x0091969F, 0x00CDD1DC, 0x00D1D9E0, 0x00AABAB9, 0x00819890, 0x0085908E, 0x00879290, 0x00899492, 0x008B9694, 0x008B9694,
        0x008B9694, 0x008A9593, 0x008A9593, 0x00899295, 0x00858E91, 0x00889194, 0x00818A8D, 0x007C8588, 0x00899295, 0x00A7B0B3, 0x00CCD5D8, 0x00D9E0E3, 0x008E9B8B, 0x0070825D, 0x00778960, 0x00606C4E, 0xFFCACEC2, 0xFFFAFBF9, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCF5FF, 0xFFFFFFF8, 0x00BEC6A7, 0x0058673B, 0x00808E64, 0x0071805A, 0x00596940, 0x00425327, 0x003E5027, 0x003F5128, 0x00405229, 0x0042542B, 0x0041532A,
        0x003F5128, 0x0042542B, 0x0041532A, 0x00667157, 0x00656F58, 0x007B856E, 0x00929B86, 0x00A6AF9A, 0x00969F8A, 0x0099A38C, 0x00ADB7A0, 0x00A1A893, 0x009DA58E, 0x0097A085, 0x00667151, 0x005D6945, 0x0066744B, 0x00738256, 0x0078875B, 0x00768958,
        0x00728455, 0x00738556, 0x00738459, 0x00708057, 0x0073825C, 0x00707E5A, 0x0064724E, 0x00495930, 0x00526239, 0x004E5E35, 0x006B7B52, 0x0074845B, 0x0076865D, 0x0076865D, 0x00728259, 0x00718257, 0x00728358, 0x0074855A, 0x00596940, 0x00596940,
        0x00506037, 0x005F6E48, 0x00778660, 0x0071835C, 0x006F815A, 0x006E8059, 0x006E8059, 0x0070825B, 0x0071835C, 0x0072845D, 0x0071835C, 0x00737F5B, 0x00707F59, 0x00697B52, 0x00677B51, 0x00657851, 0x00566442, 0x00272F11, 0x0024280F, 0x001A200F,
        0x00262D18, 0x002D361B, 0x00374424, 0x00687652, 0x00697A55, 0x006A7A58, 0x006D7D5B, 0x00778058, 0x00596241, 0x00525F47, 0x004F5E50, 0x0044564F, 0x00354B49, 0x00233D3D, 0x00264242, 0x00173E4D, 0x000F2E37, 0x00213633, 0x00293725, 0x003B4527,
        0x003E4C28, 0x004C5F38, 0x005F774F, 0x00577149, 0x0053693F, 0x004C5D31, 0x00495525, 0x0043501C, 0x00394D18, 0x00314B15, 0x002B4914, 0x00273D20, 0x0021371B, 0x001B2F18, 0x00182B18, 0x0018291B, 0x0018281D, 0x0015241C, 0x0013211B, 0x001A1E19,
        0x001A1E19, 0x00191D18, 0x00191D18, 0x001A1E19, 0x001B1F1A, 0x001C201B, 0x001D211C, 0x001B2B1A, 0x001A2A18, 0x00192D16, 0x001D3317, 0x001E3715, 0x001F3A13, 0x00254116, 0x002B4A1D, 0x00384B12, 0x003A4D14, 0x003D5017, 0x00465922, 0x00536431,
        0x005F6D43, 0x00636F4B, 0x00636D4F, 0x00667752, 0x00687954, 0x00697A55, 0x006A7B56, 0x006A7B56, 0x006B7C57, 0x006D7E59, 0x006F805B, 0x006E8059, 0x006E8059, 0x006E8059, 0x006E8059, 0x006E8059, 0x006D7F58, 0x006D7F58, 0x006D7F58, 0x006E7F5A,
        0x006E7E5C, 0x00829270, 0x007D8D6B, 0x00697858, 0x003A4929, 0x00253415, 0x00334223, 0x003E4B31, 0x00384727, 0x00485A33, 0x005E7146, 0x004F603B, 0x00465339, 0x004A5346, 0x00888E89, 0x00192D1A, 0x00506451, 0x00687C69, 0x001B2F1C, 0x005C705D,
        0x00627663, 0x00172B18, 0x00627663, 0x005E6D58, 0x0023311F, 0x00768472, 0x00505E4C, 0x001C2919, 0x00818E7E, 0x00455244, 0x00233022, 0x00818C7C, 0x00374331, 0x00313E28, 0x0078876C, 0x004A5A3B, 0x006C7D5B, 0x00677954, 0x006B7E57, 0x00718260,
        0x005D6B47, 0x003B4C2B, 0x00304B3B, 0x00557F84, 0x00558A9F, 0x004B839C, 0x0052869D, 0x003E6C74, 0x00273F33, 0x00505945, 0x00727D7A, 0x009AA8AE, 0x00DDE5E5, 0x00B9C0BD, 0x00849094, 0x008A9390, 0x0087908D, 0x00848D8A, 0x00868F8C, 0x008A9390,
        0x008D9693, 0x008C9592, 0x008A9390, 0x0087988F, 0x0086978E, 0x00879790, 0x007F8D87, 0x00778581, 0x00879290, 0x00AAB5B3, 0x00CAD5D3, 0x00DEE4DF, 0x00848E7E, 0x00667556, 0x0075855C, 0x0062714B, 0xFFC5CDB6, 0xFFFDFEFA, 0xFFFEFAFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFAFF, 0xFFFFFFF9, 0x00B9C1A2, 0x00536236, 0x007D8B61, 0x00788761, 0x0077875E, 0x0076875B, 0x00778960, 0x00798B62, 0x00788A61, 0x0076885F, 0x0075875E,
        0x0076885F, 0x0075875E, 0x00708259, 0x00798763, 0x0073815F, 0x00717F5D, 0x006C7959, 0x0073815F, 0x006B7955, 0x006F7E58, 0x007A8A61, 0x00717A5F, 0x00677153, 0x00707B5B, 0x00687450, 0x006A7751, 0x006A784E, 0x00718054, 0x007B8A5E, 0x00738655,
        0x00738655, 0x00768859, 0x0076875B, 0x00728358, 0x0077875E, 0x00798960, 0x0074835D, 0x00617148, 0x004E5E35, 0x005A6A41, 0x0048582F, 0x006E7E55, 0x0077875E, 0x006F7F56, 0x0073835A, 0x0074855A, 0x00738459, 0x00798A5F, 0x0068784F, 0x0056663D,
        0x00506037, 0x005F6E48, 0x0076855F, 0x0072845D, 0x0070825B, 0x006F815A, 0x006F815A, 0x0070825B, 0x0071835C, 0x0071835C, 0x0071835C, 0x0076825E, 0x0072815B, 0x006B7D54, 0x006A7E54, 0x00657851, 0x00586644, 0x00384022, 0x00454930, 0x003D4332,
        0x00313823, 0x001F280D, 0x004A5737, 0x00697753, 0x0062734E, 0x00667654, 0x00687856, 0x006A7C53, 0x00556644, 0x003B4E39, 0x004E635B, 0x006F878D, 0x007D97A7, 0x007E9EB1, 0x007799B0, 0x006B90AC, 0x00638297, 0x0060757D, 0x003D4943, 0x00293120,
        0x00232E14, 0x00394829, 0x00526445, 0x00485D3C, 0x00455634, 0x003D4B29, 0x0038421E, 0x00343E1A, 0x002F3D19, 0x002C3D1B, 0x00283E1B, 0x0020331A, 0x001C2E17, 0x00172813, 0x00152514, 0x00162418, 0x0016231B, 0x0014201A, 0x00111C19, 0x00191C1A,
        0x00191C1A, 0x00181B19, 0x00181B19, 0x00181B19, 0x00191C1A, 0x001A1D1B, 0x001B1E1C, 0x00171E1B, 0x00141E18, 0x00162117, 0x001A2719, 0x00192A15, 0x001A2D14, 0x001D3316, 0x0023391C, 0x0037461A, 0x00384818, 0x003D4F1A, 0x00455821, 0x004D5F2A,
        0x00556536, 0x005C6943, 0x00616C4C, 0x0063744F, 0x00657651, 0x00677853, 0x00677853, 0x00687954, 0x00697A55, 0x006B7C57, 0x006D7E59, 0x006E8059, 0x006E8059, 0x006E8059, 0x006E8059, 0x006E8059, 0x006E8059, 0x006D7F58, 0x006D7F58, 0x006F815A,
        0x006B7D56, 0x00768762, 0x0070815C, 0x006B7B59, 0x00536341, 0x004C5C3A, 0x005B6A4A, 0x00627152, 0x004F5F3D, 0x00596B42, 0x0063764B, 0x004E6039, 0x004E5C40, 0x00717B6A, 0x00B0B8AE, 0x002D3621, 0x0077806B, 0x008D9681, 0x0019220D, 0x00606954,
        0x005E6752, 0x00222B16, 0x00707964, 0x005D6A54, 0x001F2C16, 0x0087947E, 0x0047533F, 0x00313D29, 0x00ABB7A5, 0x00505C4A, 0x00313D2B, 0x007E8A78, 0x002B3723, 0x0054614B, 0x00B6C5AA, 0x00506041, 0x006A7B59, 0x006F815C, 0x006B7E57, 0x005D6E4C,
        0x004C5A36, 0x00394A29, 0x003A5545, 0x005C868B, 0x005E93A8, 0x00558DA6, 0x005589A0, 0x00416F77, 0x00273F33, 0x004F5844, 0x00717C79, 0x0098A6AC, 0x00DDE5E5, 0x00BBC2BF, 0x00859195, 0x00879191, 0x00889292, 0x00889292, 0x00899393, 0x008A9494,
        0x008B9595, 0x008B9595, 0x008C9696, 0x00859490, 0x0081908C, 0x00808F8B, 0x007D8A88, 0x00788583, 0x00869090, 0x00ABB5B5, 0x00CED8D8, 0x00E0E7E0, 0x008F9988, 0x006F7E5E, 0x0075855C, 0x005E6C48, 0xFFC3CAB5, 0xFFFFFFFC, 0xFFFFFCFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFF9FF, 0xFFFFFFF7, 0x00BAC2A3, 0x0057663A, 0x007B895F, 0x0073825C, 0x00728259, 0x0078895D, 0x006C7E55, 0x00708259, 0x0071835A, 0x006F8158, 0x0072845B,
        0x00778960, 0x0076885F, 0x0073855C, 0x0078895D, 0x00798A5F, 0x0076865D, 0x00718158, 0x007C8D62, 0x007E9061, 0x00809360, 0x007D925B, 0x0084906C, 0x007B8862, 0x007F8C66, 0x007E8C63, 0x007A885E, 0x007B895F, 0x007A895D, 0x00768559, 0x00768958,
        0x00758857, 0x00758758, 0x00728455, 0x006E7F53, 0x006F8055, 0x00728358, 0x006F8055, 0x0076865D, 0x005E6E45, 0x004B5B32, 0x00596940, 0x0046562D, 0x006E7E55, 0x007E8E65, 0x006F7F56, 0x0074855A, 0x00728358, 0x007A8B60, 0x0075855C, 0x00516138,
        0x00506037, 0x005F6E48, 0x00788761, 0x0073855E, 0x0071835C, 0x0070825B, 0x0070825B, 0x0071835C, 0x0071835C, 0x0071835C, 0x0070825B, 0x0074805C, 0x006F7E58, 0x006C7E55, 0x006C8056, 0x00657851, 0x00566442, 0x003D4527, 0x00555940, 0x00656B5A,
        0x00282F1A, 0x00353E23, 0x00233010, 0x00576541, 0x0070815C, 0x006D7D5B, 0x00697957, 0x006C8357, 0x00556D4B, 0x002F4735, 0x00435D5D, 0x006F8C9B, 0x007090AD, 0x00688CB0, 0x00648BB2, 0x006B8FB3, 0x0064829F, 0x00617587, 0x004D595F, 0x00515853,
        0x00515849, 0x0045513B, 0x0035422A, 0x00324524, 0x002D3C1D, 0x00273317, 0x00252D16, 0x00272D1A, 0x00262E1D, 0x00222C1C, 0x001D2A1C, 0x001D2716, 0x001A2413, 0x00172111, 0x00161E13, 0x00161E14, 0x00161C17, 0x00151A18, 0x00131817, 0x00181A1A,
        0x00181A1A, 0x00171919, 0x00171919, 0x00171919, 0x00181A1A, 0x00191B1B, 0x001A1C1C, 0x0015141D, 0x0015151B, 0x0015191A, 0x00181D1B, 0x001A211A, 0x00192317, 0x001B2518, 0x001E2919, 0x00273016, 0x00293414, 0x00314014, 0x003B4D18, 0x0042551E,
        0x00485926, 0x00546238, 0x00606C48, 0x0062734E, 0x00647550, 0x00667752, 0x00677853, 0x00687954, 0x00697A55, 0x006B7C57, 0x006C7D58, 0x006E8059, 0x006E8059, 0x006E8059, 0x006E8059, 0x006E8059, 0x006E8059, 0x006E8059, 0x006E8059, 0x00718459,
        0x006C7E55, 0x00708259, 0x006A7C53, 0x0074865F, 0x006F815A, 0x0072835E, 0x007C8D68, 0x00758563, 0x006E7F5A, 0x0073865B, 0x0065794C, 0x004D5F36, 0x004C5B3B, 0x0096A38B, 0x00EAF4E3, 0x003E3F25, 0x00BDBEA4, 0x00DCDDC3, 0x0043442A, 0x00727359,
        0x00626349, 0x0033341A, 0x0067684E, 0x00495539, 0x00424E32, 0x008E9A7E, 0x00364127, 0x003B462C, 0x00959F88, 0x004B553E, 0x00444E37, 0x00535F4B, 0x0028351F, 0x004C5A42, 0x008D9C80, 0x003C4C2D, 0x006F805E, 0x006E805B, 0x00677954, 0x00526341,
        0x0045532F, 0x003A4B2A, 0x003B5646, 0x00578186, 0x005D92A7, 0x005B93AC, 0x005589A0, 0x0044727A, 0x00273F33, 0x004E5743, 0x00707B78, 0x0096A4AA, 0x00DDE5E5, 0x00BDC4C1, 0x00869296, 0x007D898D, 0x007F8B8F, 0x00828E92, 0x00879397, 0x008B979B,
        0x00899599, 0x00849094, 0x00808C90, 0x00808E8D, 0x00808E8D, 0x00818E90, 0x007E8A8C, 0x00768284, 0x00828B8E, 0x00AAB3B6, 0x00D0D9DC, 0x00B9C1B6, 0x00818C78, 0x00707F5F, 0x00778660, 0x005F6D4B, 0xFFC3CAB5, 0xFFFFFFFC, 0xFFFFFCFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFF9FF, 0xFFFFFFF9, 0x00BAC2A3, 0x0058673B, 0x007B895F, 0x0076855F, 0x0073835A, 0x0077885C, 0x00788A61, 0x00798B62, 0x007B8D64, 0x0076885F, 0x00788A61,
        0x007B8D64, 0x00788A61, 0x007D8F66, 0x00778B5E, 0x00778960, 0x00758661, 0x00778666, 0x00778765, 0x006E8057, 0x00708554, 0x00728953, 0x00728259, 0x00708057, 0x0073835A, 0x0077875E, 0x00738459, 0x0075865B, 0x00798A5F, 0x00718257, 0x00738556,
        0x00728455, 0x00728455, 0x00728357, 0x00728357, 0x00738458, 0x00738458, 0x00718256, 0x00718158, 0x007A8A61, 0x005C6C43, 0x004B5B32, 0x00596940, 0x0054643B, 0x006F7F56, 0x007B8B62, 0x00728358, 0x00718257, 0x00738459, 0x0077875E, 0x004E5E35,
        0x00526239, 0x005C6B45, 0x007C8B65, 0x0073855E, 0x0072845D, 0x0071835C, 0x0071835C, 0x0071835C, 0x0072845D, 0x0071835C, 0x006F815A, 0x00727E5A, 0x006F7E58, 0x006A7C53, 0x006B7F55, 0x00667952, 0x00596745, 0x003C4426, 0x004F533A, 0x002B3120,
        0x00353C27, 0x00343D22, 0x003C4929, 0x003E4C28, 0x0061724D, 0x006A7A58, 0x00657553, 0x0071835A, 0x005A6B4A, 0x00334633, 0x002F4441, 0x00637E88, 0x007D9DB0, 0x006E91AB, 0x007BA0BC, 0x006B90AA, 0x00658499, 0x00566D7C, 0x0039484B, 0x0038433B,
        0x003D4736, 0x00455036, 0x003D492B, 0x002E4017, 0x00273511, 0x00202C0E, 0x00242B16, 0x002A2E22, 0x00292E25, 0x00222620, 0x00171D18, 0x00202418, 0x001E2216, 0x001B1F14, 0x00191C13, 0x00191B15, 0x00191A18, 0x00191A18, 0x00191919, 0x00191B1B,
        0x00191B1B, 0x00181A1A, 0x00181A1A, 0x00181A1A, 0x00191B1B, 0x00191B1B, 0x00191B1B, 0x001C181E, 0x001C181D, 0x001E1B1D, 0x001F1F1F, 0x0021221E, 0x001F241B, 0x001E2419, 0x001E2419, 0x001F211B, 0x001F2514, 0x00273211, 0x00344414, 0x003C4F18,
        0x0041531E, 0x004E5E2F, 0x005C6A41, 0x0063744F, 0x00657651, 0x00687954, 0x00697A55, 0x006A7B56, 0x006B7C57, 0x006D7E59, 0x006E7F5A, 0x006D7F58, 0x006D7F58, 0x006D7F58, 0x006E8059, 0x006E8059, 0x006E8059, 0x006E8059, 0x006E8059, 0x00708457,
        0x006F8356, 0x00708358, 0x00677A4F, 0x00708259, 0x006D7F56, 0x006D7F56, 0x006C7E57, 0x0070815C, 0x00788A63, 0x00718459, 0x00586B40, 0x0054663D, 0x00425230, 0x00748266, 0x00BBC8B0, 0x003C3E20, 0x00838567, 0x00828466, 0x003D3F21, 0x00838567,
        0x00737557, 0x00434527, 0x004B4D2F, 0x003B4625, 0x00525D3C, 0x00C0CBAB, 0x00535E3E, 0x00374123, 0x00626C4E, 0x002B3419, 0x00565F44, 0x008C9A82, 0x00324028, 0x0037462B, 0x00617054, 0x003B4B2C, 0x006B7C5B, 0x00687957, 0x004F613C, 0x00495A38,
        0x004B5935, 0x00435433, 0x00375242, 0x004F797E, 0x00598EA3, 0x005991AA, 0x0054889F, 0x0045737B, 0x00253D31, 0x004E5743, 0x00717C79, 0x0094A2A8, 0x00DEE6E6, 0x00C0C7C4, 0x00869296, 0x00708087, 0x00708087, 0x0074848B, 0x007F8F96, 0x008999A0,
        0x0088989F, 0x007B8B92, 0x006E7E85, 0x00778389, 0x00818D93, 0x00869296, 0x00808B8F, 0x00758084, 0x00848D91, 0x00B0B9BC, 0x00CFD8DB, 0x00899382, 0x006E7B63, 0x006E7D5D, 0x00788761, 0x00606D4D, 0xFFC3C9B6, 0xFFFFFFFC, 0xFFFCFAFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFAFF, 0xFFFFFFF9, 0x00BBC3A4, 0x0059683C, 0x007D8B61, 0x007A8963, 0x006A7A51, 0x00607145, 0x0061734A, 0x005F7148, 0x00607249, 0x005C6E45, 0x005F7148,
        0x005F7148, 0x005A6C43, 0x0066784F, 0x0072835E, 0x00637253, 0x005B6751, 0x006C7666, 0x005D6757, 0x0038442E, 0x00303F20, 0x00394A25, 0x002F3C1C, 0x002F3D1B, 0x003A4826, 0x004B5935, 0x0054623E, 0x0051603A, 0x006D7D54, 0x0076865D, 0x00718158,
        0x0073835A, 0x0075855C, 0x0076875C, 0x0077885D, 0x0075865B, 0x0074855A, 0x0075865B, 0x0075855C, 0x0074845B, 0x0078885F, 0x0058683F, 0x0058683F, 0x0053633A, 0x00526239, 0x0074845B, 0x00738459, 0x0076875C, 0x00708156, 0x0074845B, 0x00506037,
        0x0056663D, 0x005A6943, 0x007E8D67, 0x0074865F, 0x0072845D, 0x0071835C, 0x0072845D, 0x0072845D, 0x0072845D, 0x0071835C, 0x0070825B, 0x0076825E, 0x0072815B, 0x006B7D54, 0x006A7E54, 0x006A7D56, 0x00616F4D, 0x003B4325, 0x003F432A, 0x003F4534,
        0x00414833, 0x00454E33, 0x00354222, 0x004B5935, 0x00374823, 0x00667654, 0x006F7F5D, 0x00717853, 0x00626A4B, 0x005E6851, 0x004E5B4D, 0x00889B92, 0x00ADC4BF, 0x006C8783, 0x0063817C, 0x00618383, 0x00658483, 0x005A746E, 0x00314538, 0x001D2C17,
        0x001C2B0C, 0x003D4C26, 0x00526036, 0x003D5019, 0x00374717, 0x002F3E18, 0x002C371D, 0x002C3423, 0x00292F24, 0x0025291E, 0x001F2318, 0x0026271D, 0x0024251B, 0x0022231A, 0x001F1F19, 0x001D1D17, 0x001D1C18, 0x001F1E1A, 0x00211F1E, 0x001A1D1B,
        0x001B1E1C, 0x001B1E1C, 0x001C1F1D, 0x001C1F1D, 0x001B1E1C, 0x001A1D1B, 0x001A1D1B, 0x00221F1B, 0x00221F1B, 0x0024211C, 0x0024251C, 0x0027291D, 0x00262B1C, 0x00242A19, 0x00212716, 0x00262527, 0x0023261D, 0x00283019, 0x0033401A, 0x003B4B1B,
        0x0040511E, 0x004B5B2B, 0x00576738, 0x0062734E, 0x00647550, 0x00677853, 0x00697A55, 0x006A7B56, 0x006B7C57, 0x006C7D58, 0x006E7F5A, 0x006D7F58, 0x006D7F58, 0x006D7F58, 0x006E8059, 0x006E8059, 0x006E8059, 0x006F815A, 0x006F815A, 0x00697D50,
        0x006E8255, 0x006F8257, 0x00687B50, 0x0071835A, 0x006D7F56, 0x00708259, 0x006D7F58, 0x0070815C, 0x006A7C55, 0x00586A41, 0x004A5C33, 0x005B6D46, 0x0042532E, 0x00404F2F, 0x00516041, 0x00576541, 0x004C5A36, 0x002A3814, 0x00465430, 0x006A7854,
        0x00485632, 0x003E4C28, 0x00586642, 0x004C5834, 0x00515D39, 0x007A8662, 0x00606B4A, 0x005A6544, 0x00515C3C, 0x00566141, 0x003C4727, 0x00324126, 0x0048573B, 0x00657458, 0x00546445, 0x005B6C4B, 0x00657655, 0x0050613F, 0x004C5D3B, 0x00435432,
        0x00576541, 0x004E5F3E, 0x00385343, 0x00517B80, 0x005B90A5, 0x00578FA8, 0x0053879E, 0x00437179, 0x0021392D, 0x004E5743, 0x00737E7B, 0x0093A1A7, 0x00DDE5E5, 0x00C2C9C6, 0x00859195, 0x00728289, 0x00718188, 0x0074848B, 0x007F8F96, 0x008999A0,
        0x008999A0, 0x007E8E95, 0x0073838A, 0x00758088, 0x00828D95, 0x00879399, 0x00808B8F, 0x00768185, 0x0090999C, 0x00BBC5C5, 0x00C4CECE, 0x007A876F, 0x006F7D61, 0x0071815F, 0x0075835F, 0x005D694B, 0xFFC1C7B6, 0xFFFFFFFC, 0xFFFFFEFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCF5FF, 0xFFFFFFF9, 0x00BAC2A3, 0x005E6D41, 0x00808E64, 0x0075845E, 0x004E5E35, 0x00314216, 0x0031431A, 0x002D3F16, 0x002E4017, 0x00293B12, 0x00304219,
        0x0033451C, 0x00273910, 0x0031431A, 0x006A7959, 0x0047543C, 0x00444C41, 0x008A8E8F, 0x00A6A9AD, 0x00919695, 0x00899187, 0x008F9989, 0x008D9787, 0x008E9887, 0x007B8672, 0x00536048, 0x004E5C40, 0x00435232, 0x006E7F5A, 0x0073845F, 0x00768462,
        0x007A8866, 0x007B8967, 0x007A8864, 0x00798862, 0x0075845E, 0x0076865D, 0x007C8C63, 0x007A8A61, 0x006D7D54, 0x0073835A, 0x007F8F66, 0x004F5F36, 0x0056663D, 0x0055653C, 0x0054643B, 0x00718257, 0x0076875C, 0x00738459, 0x0073835A, 0x0053633A,
        0x0058683F, 0x005B6A44, 0x007D8C66, 0x0073855E, 0x0072845D, 0x0072845D, 0x0072845D, 0x0073855E, 0x0073855E, 0x0072845D, 0x0070825B, 0x0074805C, 0x0074835D, 0x00708259, 0x0070845A, 0x006F825B, 0x005F6D4B, 0x002C3416, 0x00262A11, 0x00272D1C,
        0x00202712, 0x001E270C, 0x00364323, 0x00475531, 0x004C5D38, 0x00425230, 0x005A6A48, 0x007D845F, 0x00686D4D, 0x00697153, 0x005A6349, 0x0077846A, 0x007C8B6F, 0x002F4424, 0x002D4221, 0x00456046, 0x00486349, 0x00445A41, 0x002E4428, 0x002C3E1F,
        0x0031431C, 0x004E5F33, 0x00586B3A, 0x0048581B, 0x0043531E, 0x0037471E, 0x002A371D, 0x001F2918, 0x001C2316, 0x00212415, 0x00272818, 0x0027281E, 0x0027281E, 0x0026271D, 0x0023241A, 0x00202118, 0x00202118, 0x0023241B, 0x0026271E, 0x001B1F19,
        0x001C201A, 0x001F231D, 0x0020241E, 0x0020241E, 0x001E221C, 0x001B1F19, 0x001A1E18, 0x00212016, 0x00212016, 0x00202216, 0x00232617, 0x00252B1A, 0x00282E1D, 0x00232C18, 0x001E2713, 0x00222123, 0x0020211D, 0x00222718, 0x002A3319, 0x00323E1A,
        0x003A491D, 0x00475727, 0x00536431, 0x005E6F4A, 0x0061724D, 0x00647550, 0x00677853, 0x00687954, 0x00687954, 0x006A7B56, 0x006B7C57, 0x006C7E57, 0x006D7F58, 0x006D7F58, 0x006D7F58, 0x006E8059, 0x006F815A, 0x006F815A, 0x006F815A, 0x006B7E53,
        0x006F8158, 0x00708259, 0x006C7E55, 0x00758760, 0x006D7F58, 0x00748560, 0x00758661, 0x00728260, 0x00637351, 0x005D6D4B, 0x00556543, 0x00566644, 0x00516040, 0x00526141, 0x00546343, 0x005D724C, 0x00637852, 0x004E633D, 0x00617650, 0x0040552F,
        0x002C411B, 0x00485D37, 0x005B704A, 0x003A4824, 0x0043512D, 0x00616F4B, 0x00505E3C, 0x00687654, 0x005C6949, 0x005A6747, 0x00667353, 0x00627253, 0x00455536, 0x00667657, 0x006E7F5E, 0x00687958, 0x00536443, 0x00506140, 0x00475837, 0x00536442,
        0x0064724E, 0x00516241, 0x00344F3F, 0x004E787D, 0x00588DA2, 0x00558DA6, 0x005589A0, 0x00416F77, 0x001D3529, 0x004E5743, 0x00747F7C, 0x00909EA4, 0x00DCE4E4, 0x00C5CCC9, 0x00879397, 0x007D8D93, 0x007E8E94, 0x00809096, 0x00839399, 0x0086969C,
        0x0088989E, 0x0088989E, 0x0088989E, 0x00869199, 0x008A969C, 0x00899599, 0x00828E90, 0x00778383, 0x0097A2A0, 0x00BDC8C5, 0x00AAB5B2, 0x00707F60, 0x00707F5F, 0x00728260, 0x00748260, 0x005D694D, 0xFFC1C7B6, 0xFFFFFFFC, 0xFFFFFEFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFF9FF, 0xFFFFFFF8, 0x00B3BB9C, 0x005D6C40, 0x007F8D63, 0x0075845E, 0x004B5B32, 0x00314216, 0x0053653C, 0x004F6138, 0x00495B32, 0x003C4E25, 0x00495B32,
        0x00506239, 0x0036481F, 0x00304219, 0x006E8258, 0x00425135, 0x00414B3F, 0x00A4A8AD, 0x00DEE0EB, 0x00DCDEE8, 0x00D6DBDE, 0x00D8DFDC, 0x00DEE1E5, 0x00E9EEED, 0x00C0C6C1, 0x0061695E, 0x00515C48, 0x003C492F, 0x006A7959, 0x005B6B49, 0x005D684E,
        0x00586349, 0x00505C40, 0x00505C3E, 0x00596646, 0x005A6846, 0x00596745, 0x005E6C48, 0x00708057, 0x007B8B62, 0x0074845B, 0x006E7E55, 0x007B8B62, 0x0055653C, 0x005C6C43, 0x004A5A31, 0x00617247, 0x00697A4F, 0x0076875C, 0x0074845B, 0x0053633A,
        0x0055653C, 0x00606F49, 0x00788761, 0x0072845D, 0x0072845D, 0x0072845D, 0x0073855E, 0x0074865F, 0x0074865F, 0x0073855E, 0x0071835C, 0x00727E5A, 0x0073825C, 0x0072845B, 0x0073875D, 0x006D8059, 0x00586644, 0x00293113, 0x002A2E15, 0x00212716,
        0x00252C17, 0x00262F14, 0x003D4A2A, 0x0062704C, 0x0042532E, 0x0050603E, 0x00485836, 0x00677950, 0x006B7A54, 0x006C7A58, 0x00748161, 0x00798666, 0x00616F4D, 0x00475630, 0x00506037, 0x004C5D32, 0x00606F49, 0x006C7C5A, 0x00677758, 0x00687958,
        0x005D6F4A, 0x005F7247, 0x00506435, 0x0045521C, 0x003D4A1C, 0x002F3C1C, 0x001F2B19, 0x00162014, 0x00171C13, 0x001F2115, 0x00262517, 0x001F2619, 0x0021281B, 0x00232A1D, 0x0022291C, 0x001F2619, 0x001E2518, 0x0020271A, 0x00232A1D, 0x001A2114,
        0x001D2417, 0x0021281B, 0x00232A1D, 0x00232A1D, 0x001F2619, 0x001B2215, 0x00181F12, 0x001B1C13, 0x001A1D14, 0x001A1D14, 0x001D2116, 0x0021271C, 0x00262D20, 0x00212A1D, 0x001A2316, 0x001A1B17, 0x001A1B17, 0x001C1F16, 0x001D2213, 0x00222A13,
        0x002F3B17, 0x00425222, 0x0051642D, 0x005D6E49, 0x0060714C, 0x00647550, 0x00667752, 0x00687954, 0x00687954, 0x006A7B56, 0x006B7C57, 0x006C7E57, 0x006C7E57, 0x006D7F58, 0x006D7F58, 0x006E8059, 0x006F815A, 0x006F815A, 0x006F815A, 0x0072845D,
        0x0072845D, 0x006E7F5A, 0x006C7D58, 0x006D7D5B, 0x00546442, 0x0050603E, 0x004C5B3B, 0x00475636, 0x00495839, 0x00556445, 0x004D5B3F, 0x0039472B, 0x00404F30, 0x00455435, 0x00536242, 0x00364725, 0x004B5C3A, 0x004E5F3D, 0x00455634, 0x00354624,
        0x00445533, 0x00546543, 0x00364725, 0x00344621, 0x00566745, 0x00475836, 0x00354624, 0x00596A49, 0x003B4C2B, 0x002E3E1F, 0x002D3D1E, 0x004C5D3C, 0x005D6E4D, 0x00657655, 0x00647554, 0x00586948, 0x00546544, 0x00506140, 0x00556645, 0x00657654,
        0x00606E4A, 0x00455635, 0x002E4939, 0x00487277, 0x0054899E, 0x00548CA5, 0x005589A0, 0x003F6D75, 0x001B3327, 0x004D5642, 0x00737E7B, 0x008C9AA0, 0x00DAE2E2, 0x00C8CFCC, 0x008B979B, 0x008A969A, 0x008B979B, 0x008C989C, 0x008B979B, 0x00899599,
        0x008B979B, 0x008F9B9F, 0x0094A0A4, 0x0094A0A6, 0x008F9B9F, 0x008D9A9C, 0x00889494, 0x0073817D, 0x00919D97, 0x00B9C6BE, 0x009CAA9F, 0x00677755, 0x006F805B, 0x0071825D, 0x00758361, 0x00606B51, 0xFFC2C7B8, 0xFFFFFFFC, 0xFFFDFCFE, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFAFF, 0xFFFDFEF5, 0x00AEB697, 0x005C6B3F, 0x007F8D63, 0x0074835D, 0x004C5C33, 0x0038491D, 0x0062744B, 0x005F7148, 0x00576940, 0x00475930, 0x005A6C43,
        0x00687A51, 0x0046582F, 0x0032441B, 0x00677D4C, 0x004D5F3A, 0x00596454, 0x00B9BEC1, 0x00E1E2F0, 0x00CFD0DE, 0x00C0C4C9, 0x00BCC1C2, 0x00CBCADA, 0x00DCDCE8, 0x00C0C3C8, 0x00646967, 0x005B6457, 0x002C3822, 0x004E5C40, 0x00394828, 0x00616A55,
        0x004E5742, 0x00364029, 0x00354026, 0x00465236, 0x004A5638, 0x00424F2F, 0x003E4B2B, 0x00728259, 0x0073835A, 0x0078885F, 0x0078885F, 0x0073835A, 0x0078885F, 0x005A6A41, 0x00526239, 0x00506136, 0x0058693E, 0x0076875C, 0x0075855C, 0x00506037,
        0x00516138, 0x0065744E, 0x0074835D, 0x0072845D, 0x0071835C, 0x0072845D, 0x0073855E, 0x00758760, 0x00758760, 0x0074865F, 0x0072845D, 0x0077835F, 0x0072815B, 0x006E8057, 0x006D8157, 0x00667952, 0x00566442, 0x003B4325, 0x0050543B, 0x004D5342,
        0x002A311C, 0x00363F24, 0x004C5939, 0x00697753, 0x0061724D, 0x00455533, 0x0050603E, 0x00395629, 0x00668156, 0x005E7451, 0x00657758, 0x005D6D4E, 0x00465536, 0x00576543, 0x0047532F, 0x00464E1F, 0x0060693E, 0x00707A56, 0x006B7759, 0x006A795D,
        0x00607051, 0x005E6F4D, 0x00495B34, 0x00444B1E, 0x00373E1B, 0x00252E19, 0x001C251B, 0x001C2320, 0x00212422, 0x0027241F, 0x0029251A, 0x00192011, 0x001D2415, 0x0022291A, 0x00232A1B, 0x00202718, 0x001E2615, 0x00202817, 0x00222A19, 0x001A2112,
        0x001D2415, 0x00212819, 0x00242B1C, 0x00242B1C, 0x00202718, 0x001B2213, 0x00171E0F, 0x00171816, 0x00181917, 0x00161917, 0x00181B19, 0x001E241F, 0x00232924, 0x00212722, 0x0019201B, 0x001D2116, 0x0020221C, 0x001F201C, 0x001A1C16, 0x00191F0E,
        0x00263111, 0x003D4D1E, 0x004E6128, 0x005F704B, 0x0062734E, 0x00667752, 0x00697A55, 0x006A7B56, 0x006B7C57, 0x006C7D58, 0x006D7E59, 0x006C7E57, 0x006C7E57, 0x006D7F58, 0x006D7F58, 0x006E8059, 0x006F815A, 0x006F815A, 0x0070825B, 0x006E7F5A,
        0x006D7D5B, 0x006C7C5A, 0x006F7F5D, 0x006D7C5C, 0x00465535, 0x00364526, 0x002B3A1B, 0x003B4A2B, 0x004B593D, 0x0059664C, 0x0059664E, 0x004A573F, 0x00455238, 0x001F2E0F, 0x00202F0F, 0x00434C2B, 0x00444D2C, 0x005E6746, 0x004F5837, 0x00454E2D,
        0x0037401F, 0x003F4827, 0x003A4322, 0x00435734, 0x00495D3A, 0x005A6D4C, 0x00344726, 0x00384A2B, 0x00435536, 0x00384A2B, 0x002E4023, 0x003E4F2D, 0x00556644, 0x00556645, 0x006A7B5A, 0x00475837, 0x00556645, 0x00586948, 0x00657655, 0x00617250,
        0x004C5A36, 0x00354625, 0x002E4939, 0x004B757A, 0x00558A9F, 0x00568EA7, 0x0052869D, 0x003F6D75, 0x00193125, 0x004D5642, 0x00727D7A, 0x0089979D, 0x00D8E0E0, 0x00C9D0CD, 0x008E9A9E, 0x008D999B, 0x008D999B, 0x008C989A, 0x008B9799, 0x008B9799,
        0x008C989A, 0x008C989A, 0x008D999B, 0x00929EA2, 0x008B989A, 0x008F9D9C, 0x008C9997, 0x006F7D77, 0x008A988D, 0x00BBC9BD, 0x00A1AFA3, 0x006E7F5A, 0x00758661, 0x00748560, 0x00768363, 0x00626D53, 0xFFC2C7B8, 0xFFFFFFFC, 0xFFFDFCFE, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFDFF, 0xFBFAFEF3, 0x00B2BC9E, 0x005B6940, 0x007B8862, 0x0075815D, 0x004D5B31, 0x00405020, 0x005B6D44, 0x0033451C, 0x005D6F46, 0x0044562D, 0x0035471E,
        0x00687A51, 0x004E6037, 0x00304219, 0x006E8559, 0x005A6E4B, 0x00667462, 0x00C0C9C6, 0x00D9E0E3, 0x00C3C9CE, 0x00BCC4C3, 0x00B4BEB8, 0x00CCD0D5, 0x00D6DBDE, 0x00C4CBC8, 0x00818A80, 0x00697563, 0x00637159, 0x004D5D3E, 0x00728362, 0x00A2A39A,
        0x0077786F, 0x00606158, 0x0063645B, 0x006A6B62, 0x0097988F, 0x0086877E, 0x003B3C33, 0x00728358, 0x0076875C, 0x0074855A, 0x00728358, 0x006F8055, 0x007A8B60, 0x007B8C61, 0x0054653A, 0x004E6039, 0x004C5E37, 0x005B6D46, 0x006E8059, 0x0051633C,
        0x00556740, 0x005C6E47, 0x00788A63, 0x0074875C, 0x0074865D, 0x0073855C, 0x0072845B, 0x0072845D, 0x0072845D, 0x0073845F, 0x00748560, 0x00788964, 0x006D7F58, 0x0072815B, 0x0074825E, 0x00757F61, 0x00586049, 0x00404536, 0x0066675D, 0x0066695A,
        0x003A402D, 0x00353E24, 0x004B5537, 0x00687654, 0x006E7C5A, 0x00627151, 0x00435233, 0x004D603F, 0x00435A2E, 0x002E431D, 0x00334030, 0x00465246, 0x004C5C44, 0x003F5035, 0x003A4739, 0x003B4D4E, 0x0034493A, 0x00354F2B, 0x00647D51, 0x005F7349,
        0x0063724C, 0x00626E44, 0x0052612E, 0x0038402F, 0x001A2112, 0x001A2015, 0x00262B22, 0x001C251B, 0x003A483C, 0x002B412F, 0x0027402C, 0x00384232, 0x00384232, 0x003B4534, 0x00363E2D, 0x00353E2A, 0x003E4431, 0x003B422D, 0x003A412C, 0x003C4834,
        0x00394531, 0x00303C28, 0x0036422E, 0x00384430, 0x002E3A26, 0x002D3925, 0x002D3925, 0x0024331E, 0x002B3A25, 0x002B3A25, 0x00263520, 0x002C3B26, 0x00364530, 0x00303F2A, 0x0021301B, 0x001B3821, 0x00203320, 0x0033372B, 0x0023241B, 0x00192117,
        0x00141F15, 0x002D3125, 0x00555244, 0x00626E50, 0x0063714F, 0x00606F49, 0x006E8057, 0x00697C51, 0x00697B52, 0x00677954, 0x006B7C5A, 0x00687A55, 0x006A7C57, 0x006C7E59, 0x006D7F5A, 0x006D7F5A, 0x006D7F5A, 0x006E805B, 0x006F815C, 0x00757F5B,
        0x00677954, 0x006A845C, 0x006B8353, 0x00718151, 0x0049532F, 0x00444D43, 0x004C5864, 0x0064696A, 0x0042504C, 0x003A4830, 0x007B7C55, 0x005B583C, 0x00414A47, 0x00344647, 0x002C3A2F, 0x00415150, 0x00445139, 0x005D6739, 0x00404A20, 0x00394833,
        0x00384847, 0x00414E50, 0x003E4A44, 0x003C484C, 0x0049573B, 0x005B653B, 0x004A513C, 0x00404C4C, 0x00405553, 0x003D524A, 0x00202F27, 0x003D5035, 0x004A5F3F, 0x00526643, 0x0060754E, 0x004E613A, 0x00485A35, 0x0071815F, 0x006F7E5E, 0x004A593D,
        0x0046562D, 0x003A4E23, 0x0029462F, 0x004B747D, 0x0050829E, 0x00558DA6, 0x00538A97, 0x00426F7A, 0x0020382E, 0x004D5544, 0x0076817E, 0x0086939B, 0x00DAE1E4, 0x00C8CECD, 0x00879399, 0x007D9095, 0x007C8F94, 0x007F9297, 0x00879A9F, 0x0090A3A8,
        0x008FA2A7, 0x0085989D, 0x007B8E93, 0x00829096, 0x007F8D93, 0x00869598, 0x007F8B8F, 0x00717E80, 0x00859193, 0x009AA6A8, 0x00919D9D, 0x006D7F5A, 0x006D7F5A, 0x006B7C57, 0x00758464, 0x00647157, 0xFFBEC5B6, 0xFFFAFEF9, 0xFFFCFEFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFDFF, 0xFFFDFFF6, 0x00B1BB9D, 0x005A683F, 0x007D8A64, 0x00798561, 0x004E5C32, 0x003B4B1B, 0x0061734A, 0x0056683F, 0x00596B42, 0x0042542B, 0x0052643B,
        0x00697B52, 0x00405229, 0x00304219, 0x00677856, 0x00516045, 0x00646E62, 0x00BFC4C5, 0x00D4D6E0, 0x00C5C7D1, 0x00CCD0D5, 0x00C7CCCD, 0x00C9CAD4, 0x00D9DBE3, 0x00C9CCD0, 0x00707573, 0x0071796E, 0x00515B4A, 0x00505C46, 0x00626F55, 0x00989B8B,
        0x00898C7C, 0x006A6D5D, 0x00636656, 0x00747767, 0x00949787, 0x00838676, 0x005F6252, 0x005F7045, 0x0076875C, 0x0074855A, 0x006C7D52, 0x0074855A, 0x0078895E, 0x0075865B, 0x00718257, 0x005C6E47, 0x0051633C, 0x0050623B, 0x005B6D46, 0x0043552E,
        0x0052643D, 0x005E7049, 0x00798B64, 0x0074875C, 0x0074865D, 0x0073855C, 0x0073855C, 0x0073855E, 0x0073855E, 0x00748560, 0x00758661, 0x00768762, 0x00768762, 0x007B8A64, 0x0072815B, 0x00717C5B, 0x0060694E, 0x00444C35, 0x004E5441, 0x003F4534,
        0x003B422D, 0x00424B30, 0x004B5636, 0x00677551, 0x00788662, 0x00768664, 0x005F6F4D, 0x00435536, 0x004F653B, 0x00405431, 0x004D5A4C, 0x005E695F, 0x004A5A43, 0x001F2F17, 0x00344034, 0x0048595C, 0x00384C3F, 0x002E4624, 0x00637B53, 0x00637550,
        0x00667452, 0x0063704A, 0x004D5A2E, 0x00202718, 0x001B2116, 0x00171C13, 0x00191F1A, 0x00212823, 0x005B695E, 0x006A7C6F, 0x00728876, 0x0056685B, 0x00677A6B, 0x00748778, 0x00697A6C, 0x00647665, 0x006E7E6D, 0x00697967, 0x00637361, 0x006F7C6C,
        0x00657262, 0x00606D5D, 0x00697666, 0x00677464, 0x00637060, 0x006A7767, 0x00677464, 0x00617160, 0x00647463, 0x00637362, 0x00627261, 0x0060705F, 0x00596958, 0x00465645, 0x00334332, 0x005D7965, 0x006F7E70, 0x0060635A, 0x0023251F, 0x00161D18,
        0x000D1810, 0x0012170E, 0x00373229, 0x00515D3F, 0x00687555, 0x00677551, 0x0066784F, 0x0061734A, 0x00677952, 0x00687A55, 0x006B7C5A, 0x00697B56, 0x006B7D58, 0x006D7F5A, 0x006E805B, 0x006D7F5A, 0x006D7F5A, 0x006E805B, 0x006F815C, 0x0076815B,
        0x006A7C57, 0x00678159, 0x00698355, 0x0067784C, 0x003F4B2D, 0x004D5C58, 0x00516374, 0x00566578, 0x00465F69, 0x003B5347, 0x00697656, 0x00464F3A, 0x003A5056, 0x00405A6B, 0x003F565E, 0x003A525E, 0x0035493D, 0x00475837, 0x00354728, 0x00496058,
        0x004D6571, 0x00425969, 0x00465B63, 0x00364D55, 0x00435A44, 0x00384C29, 0x0038483D, 0x00526572, 0x003E5967, 0x003A575E, 0x003F565E, 0x00394C31, 0x00516646, 0x00526643, 0x00546942, 0x004D6039, 0x004E603B, 0x00657553, 0x00536242, 0x00415034,
        0x004A5A31, 0x0043572C, 0x002A4730, 0x0049727B, 0x004F819D, 0x00548CA5, 0x00528996, 0x00416E79, 0x0020382E, 0x004B5342, 0x0075807D, 0x0085929A, 0x00DAE1E4, 0x00CCD2D1, 0x008B979D, 0x0072858A, 0x00718489, 0x0075888D, 0x007F9297, 0x008A9DA2,
        0x008A9DA2, 0x007E9196, 0x0072858A, 0x0078868C, 0x007C8A90, 0x00859497, 0x00808C90, 0x00758284, 0x00849092, 0x0096A2A4, 0x00929E9E, 0x00728361, 0x00748661, 0x00748560, 0x00758563, 0x005D6A50, 0xFFB9C0B1, 0xFFFCFFFB, 0xFFFDFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFCFF, 0xF7F9FDF2, 0x00ADB799, 0x005A683F, 0x00818E68, 0x007F8B67, 0x00515F35, 0x00374717, 0x00586A41, 0x0064764D, 0x004C5E35, 0x003B4D24, 0x005A6C43,
        0x00596B42, 0x0036481F, 0x0032441B, 0x006D795D, 0x0057604C, 0x0062675E, 0x00BABCBD, 0x00E5E4ED, 0x00D8D7E0, 0x00D0D1D5, 0x00C7C9CA, 0x00D8D5DE, 0x00E5E3E9, 0x00C6C5C7, 0x005D5E5C, 0x0091948B, 0x005B6051, 0x005B6150, 0x00575E49, 0x0041482D,
        0x005F664B, 0x005F664B, 0x0052593E, 0x0051583D, 0x005E654A, 0x00656C51, 0x00747B60, 0x0058693E, 0x00627348, 0x0077885D, 0x00798A5F, 0x006E7F54, 0x00718257, 0x0077885D, 0x0077885D, 0x006E8059, 0x005D6F48, 0x004B5D36, 0x004D5F38, 0x00374922,
        0x0052643D, 0x005E7049, 0x00768861, 0x0074875C, 0x0073855C, 0x0073855C, 0x0073855C, 0x0074865F, 0x00758760, 0x00758661, 0x00768762, 0x00758563, 0x00758661, 0x00798B64, 0x0073835A, 0x0076865D, 0x00707C58, 0x004D5838, 0x003B4527, 0x00404732,
        0x00485137, 0x00525D3D, 0x005A6844, 0x006F7F56, 0x0071835A, 0x0073855E, 0x00748560, 0x005A694E, 0x00495B36, 0x004E5E3F, 0x00798278, 0x00616863, 0x00434F3D, 0x002A3622, 0x00575F58, 0x0078848A, 0x00536459, 0x002B4124, 0x00657956, 0x00657556,
        0x00657155, 0x005F694B, 0x0038421E, 0x00181E13, 0x00262A24, 0x00191F1A, 0x00131918, 0x000B1312, 0x00313D37, 0x003D4C44, 0x00455649, 0x0020392F, 0x002E473D, 0x003B5349, 0x002F473B, 0x002B4135, 0x00344B3D, 0x00334A3C, 0x00324639, 0x003C4A3F,
        0x002F3D32, 0x002F3D32, 0x0039473C, 0x00324035, 0x00313F34, 0x003C4A3F, 0x00334136, 0x00324237, 0x00304035, 0x002F3F34, 0x00324237, 0x0035453A, 0x0035453A, 0x00334338, 0x00334338, 0x00263D2E, 0x002F3A30, 0x00343531, 0x000C0F0D, 0x00071210,
        0x00121D1A, 0x00171B16, 0x00201A15, 0x00333E24, 0x00606C4E, 0x00667452, 0x0063754E, 0x00697B52, 0x006C7E57, 0x00697B56, 0x006B7C5A, 0x006B7D58, 0x006D7F5A, 0x006E805B, 0x006E805B, 0x006E805B, 0x006D7F5A, 0x006E805B, 0x006F815C, 0x00778058,
        0x006E8059, 0x00667F59, 0x006D855B, 0x00677A53, 0x0041533C, 0x00667C81, 0x0067859E, 0x00617BA3, 0x005C819B, 0x00416662, 0x00577056, 0x00344B3C, 0x00406171, 0x00597FA1, 0x006183A1, 0x005F809A, 0x003B5758, 0x00435A44, 0x00374F3D, 0x00547176,
        0x006F8DA8, 0x006786A5, 0x00718FAA, 0x004F6F7A, 0x00395946, 0x003E5A3D, 0x005E7674, 0x007894AC, 0x006085A1, 0x006A8EA6, 0x0054738C, 0x003B4E33, 0x00506545, 0x00546845, 0x00596E47, 0x004F623B, 0x003F512C, 0x004A5A38, 0x00475636, 0x00425135,
        0x0057673E, 0x004F6338, 0x002D4A33, 0x0049727B, 0x004F819D, 0x00538BA4, 0x00518895, 0x0044717C, 0x00223A30, 0x004A5241, 0x00747F7C, 0x00849199, 0x00D9E0E3, 0x00CDD3D2, 0x008D999F, 0x00718489, 0x00718489, 0x0075888D, 0x007F9297, 0x008A9DA2,
        0x008A9DA2, 0x007F9297, 0x0075888D, 0x007B898F, 0x00829096, 0x00879699, 0x00838F93, 0x007E8B8D, 0x00919D9F, 0x00ABB7B9, 0x00B7C3C3, 0x006E7E5F, 0x006D7E5D, 0x00768664, 0x00778765, 0x005B694D, 0xFFB5BDAC, 0xFFFBFFFA, 0xFFFDFEFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFDFF, 0xFFFFFFF8, 0x00B1BB9D, 0x005C6A41, 0x00808D67, 0x007A8662, 0x004D5B31, 0x00314111, 0x002D3F16, 0x0036481F, 0x002A3C13, 0x0024360D, 0x0033451C,
        0x0034461D, 0x002C3E15, 0x00304219, 0x00707859, 0x00686E55, 0x00646855, 0x00AEAFA5, 0x00F3F3ED, 0x00E9E9E3, 0x00D7D8CF, 0x00DCDDD3, 0x00E6E6E0, 0x00EBECE3, 0x00C7C8BE, 0x00696C5D, 0x00B5B9A6, 0x00868C75, 0x007C8269, 0x00787F64, 0x007F8D64,
        0x0079875E, 0x00717F56, 0x006F7D54, 0x00738158, 0x0076845B, 0x0065734A, 0x004E5C33, 0x0054653A, 0x004E5F34, 0x006D7E53, 0x007B8C61, 0x00708156, 0x00738459, 0x0075865B, 0x00718257, 0x00788A63, 0x006A7C55, 0x0051633C, 0x004E6039, 0x00364821,
        0x00556740, 0x005D6F48, 0x0071835C, 0x0072855A, 0x0072845B, 0x0072845B, 0x0073855C, 0x0074865F, 0x0074865F, 0x00758661, 0x00768762, 0x00748564, 0x006F815C, 0x0074865D, 0x0072855A, 0x0076875B, 0x0076875C, 0x00627047, 0x0053603A, 0x00525A43,
        0x00545D42, 0x005E6C4A, 0x00707F59, 0x00798C61, 0x0072855A, 0x006E8258, 0x0075895F, 0x0079876F, 0x006C7D5B, 0x00425135, 0x00545C55, 0x004E5552, 0x00364131, 0x001C2816, 0x00787F7A, 0x00B4BEC5, 0x007D8B80, 0x00314429, 0x00596A49, 0x004A573D,
        0x004B5440, 0x00535A45, 0x002A3318, 0x00171913, 0x00222621, 0x001B2120, 0x00232D2D, 0x000F1919, 0x00172220, 0x00232D27, 0x002C372F, 0x00283A33, 0x00253730, 0x00293B34, 0x00283930, 0x00283930, 0x002C3D32, 0x002C3C31, 0x00314136, 0x002D3933,
        0x0026322C, 0x0027332D, 0x00313D37, 0x002C3832, 0x0028342E, 0x002F3B35, 0x0026322C, 0x002E3A34, 0x002B3731, 0x0028342E, 0x0025312B, 0x0024302A, 0x0028342E, 0x00323E38, 0x003C4842, 0x0028392E, 0x001C241D, 0x00202321, 0x00121718, 0x00202D2F,
        0x00253332, 0x00161B19, 0x00181310, 0x001A230E, 0x004E593F, 0x00546141, 0x005A6B46, 0x0070825B, 0x006E8059, 0x00677954, 0x006D7E5C, 0x006C7E59, 0x006E805B, 0x006F815C, 0x006F815C, 0x006E805B, 0x006D7F5A, 0x006E805B, 0x006E805B, 0x00788159,
        0x006F815A, 0x00687F59, 0x00688058, 0x00647855, 0x00405644, 0x00607F88, 0x006C93B3, 0x006F8FC0, 0x006F98B8, 0x00466E6C, 0x00516D4F, 0x0038533F, 0x004E7282, 0x006893BA, 0x006C93BA, 0x006F91AF, 0x00314E52, 0x003D5340, 0x00324836, 0x003D575D,
        0x006E8EAB, 0x006F93B7, 0x007699BB, 0x00628589, 0x0041634B, 0x002F4E2D, 0x003C5551, 0x007492AB, 0x006D93B3, 0x006E94B2, 0x006384A5, 0x003D5035, 0x00455A3A, 0x00516542, 0x005E734C, 0x0050633C, 0x003C4E29, 0x00485836, 0x004F5E3E, 0x00556448,
        0x00627249, 0x0052663B, 0x002D4A33, 0x004B747D, 0x005284A0, 0x00548CA5, 0x00528996, 0x004A7782, 0x00273F35, 0x004A5241, 0x00737E7B, 0x00828F97, 0x00D6DDE0, 0x00CDD3D2, 0x008C989E, 0x007C8F94, 0x007C8F94, 0x007E9196, 0x0084979C, 0x008A9DA2,
        0x008A9DA2, 0x0086999E, 0x00819499, 0x00849298, 0x0089979D, 0x00869598, 0x007D898D, 0x007A8789, 0x008C989A, 0x00ADB9BB, 0x00C8D4D4, 0x0085937B, 0x006E7D61, 0x00748462, 0x00778863, 0x005D6C4D, 0xFFB5BDAC, 0xFFFAFEF9, 0xFFFCFDFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFDFF, 0xFFFFFFF8, 0x00B1BB9D, 0x005C6A41, 0x007D8A64, 0x00798561, 0x005C6A40, 0x004A5A2A, 0x004B5D34, 0x0045572E, 0x004B5D34, 0x0046582F, 0x003E5027,
        0x0041532A, 0x0042542B, 0x0046582F, 0x00717D53, 0x006E7953, 0x005D6645, 0x007A8263, 0x009EA688, 0x008C9476, 0x00878F71, 0x009DA586, 0x008D9577, 0x008C9476, 0x00868E6F, 0x00515A39, 0x007B8561, 0x006D7852, 0x006D7850, 0x007B865E, 0x00738256,
        0x00707F53, 0x0079885C, 0x007D8C60, 0x0077865A, 0x0077865A, 0x00758458, 0x00667549, 0x004D5E33, 0x004B5C31, 0x0054653A, 0x00637449, 0x00798A5F, 0x007D8E63, 0x006F8055, 0x0077885D, 0x00768861, 0x006F815A, 0x00566841, 0x0051633C, 0x00374922,
        0x00576942, 0x005D6F48, 0x0072845D, 0x00718459, 0x0071835A, 0x0072845B, 0x0073855C, 0x0073855E, 0x0074865F, 0x00748560, 0x00748560, 0x00718260, 0x0072845F, 0x00768A60, 0x00708457, 0x006D8154, 0x0077885C, 0x00798960, 0x00788761, 0x0078826B,
        0x00768266, 0x00768462, 0x00768861, 0x0073865B, 0x00768A5F, 0x0075895F, 0x0070845A, 0x006F7C64, 0x00798967, 0x00475539, 0x004C534C, 0x00515654, 0x003F4939, 0x00151F0E, 0x005F6560, 0x006F7679, 0x00505C50, 0x00253419, 0x00687859, 0x0064705A,
        0x006E7566, 0x0072796A, 0x003C4530, 0x00191A16, 0x001B201E, 0x00212929, 0x003B4749, 0x00182426, 0x000B1515, 0x00111815, 0x00171B16, 0x00141B14, 0x000E150E, 0x00151A11, 0x00171C13, 0x001B1F14, 0x001A1E13, 0x0013170C, 0x00181A0E, 0x00131B14,
        0x00141C15, 0x00111912, 0x00161E17, 0x00171F18, 0x00121A13, 0x00141C15, 0x00121A13, 0x000D1711, 0x00101A14, 0x00121C16, 0x00111B15, 0x00101A14, 0x00111B15, 0x00111B15, 0x00111B15, 0x000E1C11, 0x00171D18, 0x00191B1B, 0x001A2124, 0x00516364,
        0x00415352, 0x000D1312, 0x00201B1A, 0x00151D0C, 0x004F5843, 0x004E5A3E, 0x004B5B39, 0x00697A55, 0x00687A53, 0x00677954, 0x0070815F, 0x006D7F5A, 0x006E805B, 0x006F815C, 0x006F815C, 0x006E805B, 0x006E805B, 0x006E805B, 0x006F815C, 0x00788159,
        0x006D7E59, 0x006C805D, 0x00657A54, 0x006C7D5B, 0x00475F4D, 0x00567983, 0x00719EBF, 0x007693C0, 0x007AA2BB, 0x0054786C, 0x00657D55, 0x00506649, 0x0060818A, 0x00729BBC, 0x006D93B5, 0x007C9BB2, 0x00465D59, 0x00546347, 0x00465539, 0x00495E5B,
        0x00819DB5, 0x007A9BBC, 0x00769AB8, 0x00799490, 0x00476443, 0x00466038, 0x003E5448, 0x00768FA3, 0x007DA0BA, 0x00789CB4, 0x006E8CA7, 0x004C5F44, 0x00495E3E, 0x00556946, 0x00596E47, 0x004C5F38, 0x004A5C37, 0x00536341, 0x004A5939, 0x00657458,
        0x00607047, 0x00465A2F, 0x0027442D, 0x004B747D, 0x005385A1, 0x00558DA6, 0x00548B98, 0x004B7883, 0x00294137, 0x0048503F, 0x00727D7A, 0x00818E96, 0x00D4DBDE, 0x00CFD5D4, 0x008E9AA0, 0x0085989D, 0x0085989D, 0x0085989D, 0x0084979C, 0x0085989D,
        0x0085989D, 0x00879A9F, 0x00889BA0, 0x00829096, 0x0087959B, 0x00839295, 0x007B878B, 0x00778486, 0x00859193, 0x00A9B5B7, 0x00CDD9D9, 0x00BAC6B4, 0x007D8B73, 0x00728161, 0x00768861, 0x00606F4F, 0xFFB5BEAA, 0xFFFCFFFB, 0xFFFDFDFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBF9FF, 0xFFFDFFF6, 0x00ACB698, 0x0059673E, 0x007C8963, 0x007F8B67, 0x0076845A, 0x00748454, 0x0076885F, 0x006D7F56, 0x00788A61, 0x0076885F, 0x0073855C,
        0x00788A61, 0x0072845B, 0x00788A61, 0x007B885C, 0x00727F53, 0x006B784C, 0x00717E52, 0x00738054, 0x00667347, 0x00748155, 0x00808D61, 0x00778758, 0x00687849, 0x00778758, 0x006C7C4D, 0x00657546, 0x006E7E4F, 0x00788859, 0x00809061, 0x007B8D5E,
        0x0077895A, 0x00758758, 0x00728455, 0x007A8C5D, 0x00798B5C, 0x00798B5C, 0x00748657, 0x005F7045, 0x004D5E33, 0x00495A2F, 0x0055663B, 0x00697A4F, 0x0077885D, 0x0077885D, 0x0076875C, 0x0070825B, 0x006D7F58, 0x0052643D, 0x004E6039, 0x0033451E,
        0x00576942, 0x005E7049, 0x00798B64, 0x00718459, 0x0072845B, 0x0072845B, 0x0073855C, 0x0074865F, 0x0074865F, 0x00748560, 0x0073845F, 0x006E835D, 0x00748760, 0x0074885D, 0x006F8358, 0x00718459, 0x00788A61, 0x00768460, 0x00697656, 0x0069725D,
        0x00646F55, 0x00647353, 0x0070815C, 0x006D8157, 0x0071855B, 0x006F825B, 0x006B805A, 0x00707D63, 0x006B7C57, 0x00455435, 0x004D554B, 0x003C423D, 0x00242E1D, 0x001B2612, 0x005D645D, 0x006F7574, 0x004F5A4A, 0x00223112, 0x00647353, 0x00626E58,
        0x007B8275, 0x00787F72, 0x00313928, 0x00181A14, 0x001A201B, 0x0025302E, 0x00415150, 0x001A2A29, 0x000F1A18, 0x00171B16, 0x001D1D17, 0x00353426, 0x00343325, 0x00383527, 0x00322F20, 0x00332E1F, 0x00383422, 0x00322E1C, 0x00302C1A, 0x00282F20,
        0x00293021, 0x001F2617, 0x001D2415, 0x001E2516, 0x00192011, 0x001C2314, 0x001D2415, 0x001C2217, 0x001B2116, 0x00191F14, 0x001A2015, 0x001E2419, 0x0022281D, 0x0022281D, 0x001F251A, 0x001E271D, 0x00191D17, 0x00141917, 0x000C1818, 0x003C5250,
        0x00374C4A, 0x000C1512, 0x00231E1B, 0x001B2215, 0x00626A59, 0x005F6952, 0x004E5D3D, 0x00697A55, 0x00697A55, 0x006C7E59, 0x006D7F5A, 0x006C7E59, 0x006D7F5A, 0x006F815C, 0x006F815C, 0x006E805B, 0x006E805B, 0x006E805B, 0x006F815C, 0x0073805A,
        0x006C7C5A, 0x0070815F, 0x006A7C55, 0x0075835F, 0x004F644E, 0x0056797D, 0x007BAAC5, 0x007794B9, 0x007EA4B6, 0x005A7A69, 0x00708155, 0x00596947, 0x00678488, 0x007BA3BC, 0x00749CB5, 0x0085A1B2, 0x005B7067, 0x0054633D, 0x00414E28, 0x004F6055,
        0x008AA4B4, 0x007799B6, 0x007BA0BC, 0x00768D88, 0x003D5533, 0x0061754A, 0x00576A5B, 0x007A94A2, 0x0081A2B6, 0x007DA1B3, 0x006A899E, 0x0055684D, 0x004C6141, 0x005E724F, 0x005F744D, 0x004B5E37, 0x004A5C37, 0x00536341, 0x00505F3F, 0x00637256,
        0x0053633A, 0x00394D22, 0x00234029, 0x0048717A, 0x005284A0, 0x00578FA8, 0x00558C99, 0x0047747F, 0x00263E34, 0x00444C3B, 0x00707B78, 0x00808D95, 0x00D4DBDE, 0x00D4DAD9, 0x00929EA4, 0x00879A9F, 0x00879A9F, 0x00879A9F, 0x00879A9F, 0x0086999E,
        0x00879A9F, 0x00879A9F, 0x00889BA0, 0x0086949A, 0x0086949A, 0x00839295, 0x007C888C, 0x00778486, 0x00879395, 0x00B0BCBE, 0x00DAE6E6, 0x00D3DDD1, 0x007E8A76, 0x006F7E5E, 0x00768861, 0x00637351, 0xFFB7C0AB, 0xFFFDFFFC, 0xFFFDFCFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFDFF, 0xFFFFFFF8, 0x00ADB799, 0x005C6A41, 0x007D8A64, 0x007D8965, 0x007A885E, 0x007F8F5F, 0x00788A61, 0x0073855C, 0x0075875E, 0x0076885F, 0x00778960,
        0x00788A61, 0x0073855C, 0x0074865D, 0x007A8963, 0x0073835A, 0x00798A5F, 0x007E8F63, 0x00809263, 0x007B8D5E, 0x0087986C, 0x007F9064, 0x00839867, 0x00778B5C, 0x007A8E5F, 0x00819566, 0x00728659, 0x00768A5D, 0x00788B60, 0x0072855A, 0x00798A5F,
        0x00798A5F, 0x0078895E, 0x006F8055, 0x0076875C, 0x00728358, 0x0075865B, 0x0076875C, 0x0077885D, 0x005C6D42, 0x00536439, 0x0056673C, 0x00526338, 0x0066774C, 0x007D8E63, 0x00728358, 0x0071835C, 0x006D7F58, 0x004F613A, 0x004D5F38, 0x0032441D,
        0x00576942, 0x005D6F48, 0x007B8D66, 0x0073865B, 0x0074865D, 0x0075875E, 0x0075875E, 0x00758760, 0x00758760, 0x00748560, 0x00748560, 0x0070865C, 0x006F855B, 0x006E8257, 0x00708459, 0x0070835C, 0x00627151, 0x004A583C, 0x0037442C, 0x00283221,
        0x002B3721, 0x00313F23, 0x004D5E3D, 0x0062744F, 0x006F815C, 0x00687C59, 0x006B7F5C, 0x00667556, 0x0073855C, 0x0050603E, 0x00646D60, 0x00788076, 0x005B6751, 0x005D6A52, 0x00A8B0A5, 0x00B6BDB6, 0x0088937F, 0x003E4E2C, 0x00566644, 0x003F4C34,
        0x006A7366, 0x007C8578, 0x00424C3C, 0x0014180D, 0x00131A13, 0x00182620, 0x00304340, 0x00122320, 0x000F1B15, 0x0022241E, 0x003F3D33, 0x0050533A, 0x0044472E, 0x003B3E25, 0x0033331B, 0x0036371D, 0x00403F25, 0x003D3C20, 0x003D3C20, 0x003F422C,
        0x003D402A, 0x00353822, 0x00343721, 0x0030331D, 0x002F321C, 0x00373A24, 0x00343721, 0x002A2E1B, 0x00232714, 0x001F2310, 0x00212512, 0x00272B18, 0x002F3320, 0x003F4330, 0x004D513E, 0x002C3528, 0x000F140B, 0x00181E19, 0x00162521, 0x002F4844,
        0x002E4842, 0x00111B15, 0x0015110C, 0x0021271C, 0x00666D5E, 0x00626B56, 0x00526142, 0x006F7F5D, 0x006C7D58, 0x006D7F5A, 0x006A7C57, 0x006A7C57, 0x006C7E59, 0x006E805B, 0x006F815C, 0x006E805B, 0x006E805B, 0x006F815C, 0x0070825D, 0x00728260,
        0x006D7E5D, 0x006D7E5C, 0x00717F56, 0x00737C54, 0x00415237, 0x00547370, 0x0078A4B5, 0x006D93B3, 0x00759DAF, 0x004C6D5E, 0x00606F49, 0x0048563A, 0x005B797E, 0x007AA3BC, 0x00709CB3, 0x0080A1B4, 0x005D766C, 0x004C5E37, 0x00394822, 0x00435A4C,
        0x007E9FAF, 0x007097B7, 0x0076A3C4, 0x006B8488, 0x00546D53, 0x00546C49, 0x0033483F, 0x007995A6, 0x00769DB3, 0x006D98A9, 0x007A9FB3, 0x004B5E43, 0x004E6343, 0x00667A57, 0x00627750, 0x004E613A, 0x004B5D38, 0x0050603E, 0x00556444, 0x0057664A,
        0x0048582F, 0x00394D22, 0x0027442D, 0x00466F78, 0x004F819D, 0x005991AA, 0x00538A97, 0x0045727D, 0x00263E34, 0x00424A39, 0x006F7A77, 0x00808D95, 0x00D4DBDE, 0x00D5DBDA, 0x00939FA5, 0x00819499, 0x00819499, 0x0084979C, 0x008A9DA2, 0x008FA2A7,
        0x008EA1A6, 0x00879A9F, 0x00819499, 0x0088969C, 0x00849298, 0x00829194, 0x007D898D, 0x00738082, 0x00808C8E, 0x00ACB8BA, 0x00D5E1E1, 0x00D2DAD3, 0x00788472, 0x00707F5F, 0x00788A61, 0x0063744F, 0xFFB7C0AB, 0xFFFDFFFC, 0xFFFAF9FF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFDFF, 0xFFFFFFF8, 0x00ACB698, 0x005E6C43, 0x00808D67, 0x007C8864, 0x0078865C, 0x007D8D5D, 0x007A8C63, 0x00778960, 0x0073855C, 0x00798B62, 0x0075875E,
        0x0076885F, 0x007F9168, 0x00798B62, 0x00758465, 0x00788767, 0x007B8C67, 0x0075875E, 0x00778960, 0x006B7D54, 0x00687A51, 0x005D6F48, 0x00596E41, 0x00687C51, 0x00607449, 0x006D8157, 0x00798C65, 0x0072845F, 0x00738560, 0x00728361, 0x0074845B,
        0x006F7F56, 0x0077875E, 0x0075855C, 0x00798960, 0x0077875E, 0x007A8A61, 0x006F7F56, 0x00798A5F, 0x0076875C, 0x005C6D42, 0x004F6035, 0x00526338, 0x005C6D42, 0x00728358, 0x007A8B60, 0x00768861, 0x0070825B, 0x004F613A, 0x004F613A, 0x00354720,
        0x00596B44, 0x005B6D46, 0x00798B64, 0x0075885D, 0x0076885F, 0x00778960, 0x00778960, 0x00778962, 0x00768861, 0x00758661, 0x00748560, 0x00738A5E, 0x006E8559, 0x006A8155, 0x0070845A, 0x0061734E, 0x00374529, 0x001D2913, 0x001E2817, 0x00404A3A,
        0x00444F3B, 0x0027341A, 0x00203011, 0x003E4F2D, 0x00687C59, 0x006C7F5E, 0x006B7D5E, 0x00778464, 0x006C7D52, 0x00475531, 0x004D5445, 0x00555B50, 0x004F5942, 0x00566147, 0x00545B4E, 0x00383E33, 0x00404A33, 0x0035431F, 0x0063714D, 0x003F4C32,
        0x00646E5E, 0x00737C6F, 0x003E4838, 0x0026281C, 0x00212A20, 0x0026372E, 0x003D534E, 0x001F332E, 0x00101D15, 0x001B1E15, 0x004A463B, 0x00586343, 0x003B4324, 0x00293112, 0x00283110, 0x00343B1A, 0x00373E1D, 0x00313714, 0x00343A17, 0x002E3013,
        0x002A2C0F, 0x002C2E11, 0x00333518, 0x002D2F12, 0x00313316, 0x003E4023, 0x0036381B, 0x0031341B, 0x002D3017, 0x0030331A, 0x00363920, 0x0033361D, 0x0032351C, 0x00474A31, 0x0062654C, 0x003F4637, 0x001D2116, 0x00192019, 0x00182A23, 0x003F5B55,
        0x003B564D, 0x0017241C, 0x002B2820, 0x00242920, 0x00585F52, 0x004D5641, 0x00465438, 0x006B7B59, 0x00657651, 0x00697B56, 0x006B7D58, 0x00697B56, 0x006B7D58, 0x006D7F5A, 0x006E805B, 0x006E805B, 0x006E805B, 0x006F815C, 0x0070825D, 0x00718261,
        0x006C7E5F, 0x006D7D5B, 0x007D865E, 0x00767D52, 0x003D4C2D, 0x00638077, 0x0083ADB9, 0x006B96B7, 0x00709DB2, 0x0043685E, 0x00586948, 0x0041503B, 0x00597984, 0x0078A7C2, 0x00689AB0, 0x00739CB2, 0x0051726B, 0x00526845, 0x004B603A, 0x00456056,
        0x0078A0B3, 0x006A9ABE, 0x00689CC1, 0x005F7A88, 0x004D6A5A, 0x00506C4F, 0x002E4946, 0x007395AC, 0x0074A2BA, 0x0071A3B7, 0x005F8EA4, 0x004E6146, 0x00647959, 0x00748865, 0x00586D46, 0x004A5D36, 0x00546641, 0x00475735, 0x00364525, 0x004D5C40,
        0x0045552C, 0x0041552A, 0x00304D36, 0x00466F78, 0x004D7F9B, 0x005991AA, 0x00518895, 0x0047747F, 0x00273F35, 0x00424A39, 0x006F7A77, 0x007F8C94, 0x00D2D9DC, 0x00D3D9D8, 0x00919DA3, 0x0075888D, 0x0075888D, 0x007B8E93, 0x00889BA0, 0x0094A7AC,
        0x0092A5AA, 0x0083969B, 0x0075888D, 0x007A888E, 0x0079878D, 0x00819093, 0x00859195, 0x007C898B, 0x00869294, 0x00AEBABC, 0x00D3DFDF, 0x00D9E0DB, 0x007F8A7A, 0x00788768, 0x00798B62, 0x005E7049, 0xFFB4BEA7, 0xFFFDFFFC, 0xFFFDFCFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFBFF, 0xFFFFFFF9, 0x00ADB799, 0x005D6A44, 0x007D8A64, 0x00808D67, 0x00647347, 0x00637441, 0x005E7047, 0x00687A51, 0x00576940, 0x0066794E, 0x0065784D,
        0x00607447, 0x00596D40, 0x0063774A, 0x00718162, 0x0058664E, 0x00485442, 0x00646E62, 0x00505A4D, 0x003A4634, 0x00324126, 0x003A4A2B, 0x00313B2B, 0x00353F2E, 0x00313D27, 0x00495539, 0x00485634, 0x0057653C, 0x00728155, 0x00819162, 0x0076845B,
        0x00708050, 0x00768952, 0x00758555, 0x00828F69, 0x00727D5D, 0x0075825C, 0x0079895A, 0x0077875E, 0x007A8A61, 0x00798960, 0x0058683F, 0x004E5E35, 0x0058683F, 0x005A6A41, 0x0078885F, 0x00798C61, 0x0073855C, 0x004E6037, 0x004B5D34, 0x00384A23,
        0x0053653E, 0x0061724D, 0x007B8C67, 0x00758760, 0x00758760, 0x00758760, 0x00758760, 0x00758760, 0x0074865F, 0x0073855E, 0x0073855E, 0x00738462, 0x0070835C, 0x0071845D, 0x0069785C, 0x002E3929, 0x00242D23, 0x003B4735, 0x003B4A2E, 0x0058614D,
        0x004F5A46, 0x00384231, 0x00303A29, 0x0024311B, 0x0039482C, 0x006D815E, 0x006C815A, 0x0072865C, 0x00677954, 0x004B5C3B, 0x0049583C, 0x00425136, 0x002D3C20, 0x00223312, 0x002D3F1A, 0x003F5231, 0x00243716, 0x002D3E1C, 0x005B6A4A, 0x004A563A,
        0x006D745F, 0x007F8475, 0x00505147, 0x003B4025, 0x002B3420, 0x001F2A22, 0x002D3A3C, 0x000F1B21, 0x0012191C, 0x001D211C, 0x002A291F, 0x002B371B, 0x003D4C26, 0x00425425, 0x0036471C, 0x002B3719, 0x002D381E, 0x003F4D2B, 0x0055663A, 0x004E5D3D,
        0x00414E36, 0x001C2616, 0x00242822, 0x00222620, 0x00222718, 0x002C341D, 0x00364121, 0x00343623, 0x0030321E, 0x002F321C, 0x0030361F, 0x002F341F, 0x002D3020, 0x002C3025, 0x0030332A, 0x001B2319, 0x001D1F19, 0x001C1D1B, 0x0016211F, 0x00374C49,
        0x002B413C, 0x00152018, 0x002C2921, 0x00252C1F, 0x00545C4B, 0x00606A53, 0x004C5B3B, 0x006D7E59, 0x00687A53, 0x00687B54, 0x00687B54, 0x006C8055, 0x0071855A, 0x006E8258, 0x006E8258, 0x0072855E, 0x0070835C, 0x0070835C, 0x00738560, 0x00738263,
        0x006D7D5B, 0x006B7F55, 0x00738A5E, 0x00708761, 0x0051664D, 0x0067786D, 0x00879895, 0x007698A5, 0x0078979A, 0x00617D70, 0x005F7961, 0x003A543C, 0x006C8A7D, 0x007B9EA1, 0x007CA4B0, 0x008499A1, 0x00526A6A, 0x00526F60, 0x0042624A, 0x0042614C,
        0x0078928C, 0x008FA2AF, 0x008F9EB8, 0x00637F68, 0x0057735F, 0x004D6858, 0x00375046, 0x006E8783, 0x00869D9F, 0x0092AAB0, 0x00637A82, 0x005C6A46, 0x006E7F5A, 0x00748560, 0x005E6F4A, 0x00455732, 0x00495B36, 0x004F643E, 0x003C512B, 0x00435635,
        0x00505E3A, 0x00586642, 0x00354C36, 0x004C7272, 0x00578B9C, 0x00558DA6, 0x005187A0, 0x003F737F, 0x00213C33, 0x003D4737, 0x006F7776, 0x00818D93, 0x00D1D9D9, 0x00CFD8D5, 0x008FA0A3, 0x006E868C, 0x00657D83, 0x006C848A, 0x007A9298, 0x008AA2A8,
        0x008DA5AB, 0x007D959B, 0x00768E94, 0x0078889F, 0x00768697, 0x0082939C, 0x00839596, 0x007D8C88, 0x00889593, 0x00AEB8B8, 0x00D8E1E4, 0x00D4DAD9, 0x007E887B, 0x007B8A6B, 0x00788A61, 0x005D6F48, 0xFFB4BEA7, 0xFFFDFFFB, 0xFFFDFCFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBF7FF, 0xFFFFFFF9, 0x00ACB698, 0x005E6B45, 0x00818E68, 0x007F8C66, 0x004F5E32, 0x00394A17, 0x0031431A, 0x002F4118, 0x0032441B, 0x0035481D, 0x002C3F14,
        0x00304417, 0x00314518, 0x00364A1D, 0x006F805F, 0x00526146, 0x004E5A48, 0x00767F75, 0x00A2ABA1, 0x00ADB7AB, 0x00B0BCAA, 0x00AFBCA6, 0x00B3BBB1, 0x00B7C0B3, 0x00A3AD9C, 0x005C6550, 0x00394529, 0x004D5837, 0x007B8862, 0x00707E55, 0x007C8864,
        0x007D8D5E, 0x007E905B, 0x00778757, 0x00798660, 0x00798463, 0x007E8C63, 0x007C8D5A, 0x0078885F, 0x006C7C53, 0x007E8E65, 0x0078885F, 0x005B6B42, 0x0054643B, 0x0054643B, 0x0057673E, 0x00708358, 0x0072845B, 0x0055673E, 0x00506239, 0x00384A23,
        0x00556740, 0x0062734E, 0x007A8B66, 0x00758760, 0x00758760, 0x00758760, 0x00758760, 0x00758760, 0x0074865F, 0x0073855E, 0x0073855E, 0x0070815F, 0x0073865F, 0x006F825B, 0x0048573B, 0x00263121, 0x003E473D, 0x00414D3B, 0x0037462A, 0x004F5843,
        0x0046513D, 0x003B4534, 0x003B4632, 0x00293620, 0x0029381C, 0x00516443, 0x00687D57, 0x00687C52, 0x00778964, 0x00677758, 0x005F6D55, 0x0064725A, 0x0067765B, 0x00637453, 0x003D4F2A, 0x00536645, 0x00435635, 0x00556644, 0x00697858, 0x004D593D,
        0x00707762, 0x00727768, 0x0048493F, 0x00393D24, 0x002C3423, 0x00242F27, 0x00323F41, 0x00111D21, 0x00101818, 0x00171B16, 0x00222018, 0x00141B0C, 0x002F3922, 0x003B4828, 0x002A361A, 0x00141C0B, 0x00141B0E, 0x00323B26, 0x00556143, 0x006B7B59,
        0x004C593F, 0x00162010, 0x00191E15, 0x001E221C, 0x0022261B, 0x00232916, 0x00222A13, 0x00252812, 0x002A2D17, 0x002F331A, 0x002B311A, 0x00232714, 0x001A1E12, 0x001A1C16, 0x001E1F1D, 0x001A2218, 0x001C1E18, 0x001C1D1B, 0x0016211F, 0x00384D4A,
        0x002C423D, 0x00141F17, 0x0029261E, 0x002D3427, 0x005D6554, 0x00616B54, 0x004B5A3A, 0x006E7F5A, 0x00687A53, 0x006B7E57, 0x006B7E57, 0x006B7F54, 0x006C8055, 0x006C8056, 0x006F8359, 0x0070835C, 0x006B7E57, 0x006B7D58, 0x006E805B, 0x00768462,
        0x0076855F, 0x0072845B, 0x0073875D, 0x00718562, 0x004E6146, 0x003A4C3B, 0x002E3E33, 0x003C534E, 0x004C6355, 0x00566950, 0x00748363, 0x00556645, 0x00657A61, 0x00506A5C, 0x0044635C, 0x006A7872, 0x00556658, 0x0062775E, 0x00516848, 0x003C5235,
        0x00576A55, 0x006B7A72, 0x00717D7D, 0x00495B3E, 0x00586B50, 0x0060735A, 0x00465742, 0x00526453, 0x00536457, 0x005F7065, 0x0046574E, 0x0055633F, 0x0071825D, 0x0071825D, 0x005C6D48, 0x00566843, 0x004B5D38, 0x003D522C, 0x004E633D, 0x00485B3A,
        0x005F6D49, 0x00566440, 0x00374E38, 0x00527878, 0x00538798, 0x00548CA5, 0x004E849D, 0x00447884, 0x00254037, 0x00414B3B, 0x00717978, 0x00818D93, 0x00D1D9D9, 0x00D0D9D6, 0x0091A2A5, 0x0083969D, 0x0082959C, 0x008A9DA4, 0x008C9FA6, 0x008EA1A8,
        0x008EA1A8, 0x00899CA3, 0x008B9EA5, 0x008394A7, 0x0080919E, 0x008799A0, 0x00819394, 0x00798785, 0x00869391, 0x00ABB4B7, 0x00D4DADF, 0x00D1D8D3, 0x00778272, 0x00728162, 0x007A8C63, 0x00667851, 0xFFB7C1AA, 0xFFFCFFFA, 0xFFFBFBFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDF9FF, 0xFFFFFFF9, 0x00ABB597, 0x005C6943, 0x00818E68, 0x00818E68, 0x004C5B2F, 0x002F400D, 0x0051633A, 0x0052643B, 0x00475930, 0x00203308, 0x0035481D,
        0x00475B2E, 0x00304417, 0x0035491C, 0x006E7E5C, 0x004A583C, 0x00545E4E, 0x0099A099, 0x00EAEFEE, 0x00ECF1EF, 0x00EBF1EC, 0x00E8F0E6, 0x00E5EAE9, 0x00ECF1EF, 0x00C9D0C9, 0x005D6457, 0x005C6551, 0x00545D43, 0x00687254, 0x006F7A5A, 0x00656D56,
        0x005C6746, 0x00556339, 0x005E6C43, 0x00606B4A, 0x00606B4B, 0x005B6940, 0x005D6E3B, 0x0078885F, 0x00718158, 0x00728259, 0x0077875E, 0x00708057, 0x005B6B42, 0x004F5F36, 0x0054643B, 0x005C6F44, 0x0064764D, 0x0052643B, 0x004F6138, 0x0034461F,
        0x0053653E, 0x0061724D, 0x00778863, 0x00758760, 0x00758760, 0x00758760, 0x00758760, 0x00758760, 0x0074865F, 0x0074865F, 0x0073855E, 0x0070815F, 0x0073865F, 0x00687B54, 0x002A391D, 0x002B3626, 0x00565F55, 0x003C4836, 0x002E3D21, 0x00364029,
        0x002C3822, 0x00303B27, 0x00404B37, 0x0035422C, 0x0028371C, 0x003C4F2E, 0x006D815E, 0x0073875D, 0x006C7D5B, 0x005B6A4F, 0x006C7864, 0x006A7662, 0x0047553D, 0x005B6B4C, 0x00495B36, 0x00526544, 0x00455837, 0x00637452, 0x005E6D4D, 0x00354125,
        0x00676E59, 0x00676C5D, 0x00323329, 0x00212310, 0x001F2617, 0x00232D27, 0x003A4847, 0x001A2729, 0x00141C1C, 0x00151914, 0x001A1810, 0x001D201E, 0x0022271E, 0x001E2516, 0x00171D12, 0x00171B16, 0x001C1F1D, 0x00252923, 0x0030372A, 0x00647550,
        0x0048563A, 0x00151F0E, 0x00171C13, 0x001E221D, 0x00262822, 0x00282C21, 0x00272B1F, 0x00262A11, 0x00353920, 0x003E442B, 0x00383E27, 0x00262C1B, 0x00191D12, 0x00181917, 0x00191B1C, 0x00182016, 0x001A1B17, 0x001A1B19, 0x00172121, 0x003A4F4D,
        0x002D433E, 0x00121C16, 0x00242119, 0x00242B1E, 0x005A6251, 0x0059634C, 0x00465535, 0x006E7F5A, 0x00687A53, 0x006D8059, 0x006D8059, 0x006B7F55, 0x00697D53, 0x006C8056, 0x006E815A, 0x006D8059, 0x006B7D58, 0x006C7E59, 0x0070825D, 0x00717F55,
        0x00728057, 0x0075855C, 0x007A8864, 0x006E7E5C, 0x00465637, 0x00324126, 0x002D3B23, 0x00344425, 0x00475232, 0x0059603B, 0x0082855E, 0x00686D46, 0x005E6943, 0x00384727, 0x002E4323, 0x00555D46, 0x005E674C, 0x00747F5E, 0x0065724C, 0x00414F26,
        0x003B4822, 0x00404B2A, 0x00434D2F, 0x00485130, 0x00687150, 0x00777F60, 0x005C6747, 0x00475133, 0x00354123, 0x003C482A, 0x00333F23, 0x0054623E, 0x0070815C, 0x0070815C, 0x00677853, 0x004C5E39, 0x00455732, 0x00596E48, 0x00445933, 0x00485B3A,
        0x0063714D, 0x004B5935, 0x00304731, 0x004F7575, 0x004F8394, 0x00568EA7, 0x005288A1, 0x00447884, 0x00254037, 0x00424C3C, 0x00727A79, 0x007F8B91, 0x00CFD7D7, 0x00D2DBD8, 0x0093A4A7, 0x0091A3AA, 0x0090A2A9, 0x0094A6AD, 0x0092A4AB, 0x0094A6AD,
        0x009BADB4, 0x0099ABB2, 0x009CAEB5, 0x0096A8B3, 0x0090A3AA, 0x0090A3A6, 0x00819190, 0x00748281, 0x00889494, 0x00B4BDC1, 0x00DDE3E8, 0x00DEE7DD, 0x00818D7B, 0x00707F60, 0x00798B64, 0x00667752, 0xFFB4BEA7, 0xFFFCFFFA, 0xFFFDFDFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFAFF, 0xFFFFFFF9, 0x00ACB698, 0x005C6943, 0x007E8B65, 0x007E8B65, 0x00526135, 0x0040511E, 0x006A7A51, 0x00607047, 0x005D6D44, 0x0034451A, 0x005D6E43,
        0x006B7C50, 0x003C4D21, 0x003C4D21, 0x00677853, 0x004E5C40, 0x00545E4E, 0x00AAAFAD, 0x00E4E7EB, 0x00D0D3D8, 0x00C6C9CD, 0x00BABEBF, 0x00D3D6DB, 0x00DCDFE3, 0x00D6DBDA, 0x00686C66, 0x00474E41, 0x00414736, 0x00515843, 0x00424A33, 0x00575854,
        0x00535849, 0x003B442A, 0x003A4329, 0x00363C29, 0x003C422F, 0x003A4426, 0x004D5B32, 0x0073835A, 0x0076865D, 0x006C7C53, 0x0074845B, 0x007F8F66, 0x006E7E55, 0x005C6C43, 0x0053633A, 0x004E6136, 0x0051633A, 0x00485A31, 0x004E6037, 0x0034461F,
        0x0053653E, 0x0061724D, 0x00798A65, 0x0074865F, 0x0074865F, 0x00758760, 0x00758760, 0x00758760, 0x00758760, 0x0074865F, 0x0074865F, 0x00748563, 0x0073865F, 0x005C6F48, 0x00243317, 0x00424D3D, 0x005A6359, 0x002C3826, 0x00253418, 0x00303B21,
        0x0026331B, 0x002A3521, 0x003B4632, 0x003D4A34, 0x002F3E23, 0x00293B1C, 0x00617453, 0x0070845A, 0x00687958, 0x00414E38, 0x00465141, 0x00485245, 0x0025311D, 0x00516044, 0x00495B36, 0x005E7150, 0x00425534, 0x00637452, 0x00687757, 0x003E4A2E,
        0x006A715C, 0x006F7465, 0x0035362C, 0x0018180A, 0x00161C11, 0x001A241E, 0x002F3D3B, 0x00111F1E, 0x00121A19, 0x001A1E19, 0x0024211C, 0x001F2220, 0x001F231E, 0x001B1F19, 0x001C201A, 0x00242725, 0x00242725, 0x001E221D, 0x001C201A, 0x004C5C3A,
        0x003C4A2E, 0x0018230F, 0x001B2116, 0x001C201B, 0x00212220, 0x001F201E, 0x001F201C, 0x00242A11, 0x00363C23, 0x00444A31, 0x003B422D, 0x00292E1F, 0x001C1E18, 0x0017191A, 0x0018181E, 0x00171E17, 0x00181915, 0x00191919, 0x00182222, 0x003C514F,
        0x002E4340, 0x00101A14, 0x001F1B16, 0x00181F12, 0x00555D4C, 0x00566049, 0x00465535, 0x0070815C, 0x00687A53, 0x006C7F58, 0x006A7D56, 0x006C8056, 0x006A7E54, 0x006F825B, 0x006D8059, 0x006B7D58, 0x0071835E, 0x00738560, 0x00758762, 0x007C8B5F,
        0x00728056, 0x00717E58, 0x0077835F, 0x00717F5D, 0x005B6947, 0x00546240, 0x00586642, 0x00657147, 0x00687248, 0x00656A43, 0x007D8059, 0x006D7049, 0x00656D45, 0x004D5B31, 0x00516439, 0x004B5635, 0x005C6746, 0x006D7857, 0x006B7753, 0x005A6741,
        0x00515F35, 0x00556536, 0x00546434, 0x005B6142, 0x00717758, 0x00737B5C, 0x006C7554, 0x005A6642, 0x0056623E, 0x0056653F, 0x00505F39, 0x005C6A46, 0x00758661, 0x0072835E, 0x00556641, 0x004A5C37, 0x004F613C, 0x004D623C, 0x004A5F39, 0x003D502F,
        0x00515F3B, 0x003F4D29, 0x002A412B, 0x00486E6E, 0x00518596, 0x00578FA8, 0x005389A2, 0x003D717D, 0x001E3930, 0x003E4838, 0x00707877, 0x007C888E, 0x00CED6D6, 0x00D3DCD9, 0x0093A4A7, 0x008D9AA2, 0x008C99A1, 0x00919EA6, 0x00909DA5, 0x0097A4AC,
        0x00A3B0B8, 0x00A0ADB5, 0x009EABB3, 0x0099ADB2, 0x0099ACAF, 0x009AACAD, 0x00879698, 0x007B8988, 0x00969FA2, 0x00C1C8CB, 0x00E3EAED, 0x00D1DCCC, 0x0085927C, 0x00748363, 0x00788964, 0x0061714F, 0xFFABB49F, 0xFFFCFFFA, 0xFFFDFEFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDF9FF, 0xFFFDFFF7, 0x00AAB496, 0x005F6C46, 0x007F8C66, 0x0077845E, 0x004D5C30, 0x00425320, 0x00596940, 0x0034441B, 0x005A6A41, 0x0056673C, 0x0068794E,
        0x006B7C50, 0x00435428, 0x0036471B, 0x0072835E, 0x00657357, 0x005D6757, 0x00B6BBBA, 0x00D9DBE3, 0x00CDCED8, 0x00C9CBD3, 0x00B8BBC0, 0x00C3C5CD, 0x00D2D5DA, 0x00CFD3D4, 0x008B8F8A, 0x00797F74, 0x00666B5C, 0x00585E4B, 0x00636A55, 0x008C8992,
        0x00848583, 0x0054584C, 0x0055594D, 0x0083857F, 0x00A1A39D, 0x00707665, 0x004B5439, 0x00798960, 0x0075855C, 0x0076865D, 0x007A8A61, 0x00708057, 0x0074845B, 0x0078885F, 0x0054643B, 0x00506338, 0x0046582F, 0x0042542B, 0x0052643B, 0x003A4C25,
        0x00576942, 0x0063744F, 0x007E8F6A, 0x0074865F, 0x0074865F, 0x00758760, 0x00758760, 0x00758760, 0x00758760, 0x0074865F, 0x0074865F, 0x00758664, 0x00768962, 0x0052653E, 0x0027361A, 0x00556050, 0x00525B51, 0x0024301E, 0x00223115, 0x00313D21,
        0x002D3A20, 0x002B3721, 0x00333E2A, 0x003C4834, 0x0037452D, 0x00213316, 0x00556748, 0x006E8258, 0x006F805F, 0x00465240, 0x005D665C, 0x007A827B, 0x004F5A4A, 0x0057664A, 0x00455732, 0x00586B4A, 0x00415433, 0x00546543, 0x00627151, 0x00495539,
        0x00606752, 0x00616657, 0x00303127, 0x001A1810, 0x00191D17, 0x001C2522, 0x002E3C3A, 0x000E1C1A, 0x00101916, 0x00191D18, 0x0023201C, 0x00171D12, 0x001C2118, 0x001F231D, 0x00242920, 0x002A3025, 0x00262C21, 0x001E231A, 0x001C201A, 0x00313F23,
        0x002C3921, 0x0016200F, 0x00191F14, 0x00181C17, 0x001B1B1B, 0x00131214, 0x00111012, 0x001F240F, 0x002E331E, 0x00373E29, 0x00333926, 0x00272B1F, 0x001C201A, 0x00181A1B, 0x0016161C, 0x00161D16, 0x00181915, 0x00191919, 0x00182222, 0x003D5250,
        0x002F4441, 0x000F1913, 0x001D1914, 0x001B2215, 0x00596150, 0x005F6952, 0x004C5B3B, 0x0070815C, 0x00687A53, 0x006B7E57, 0x00687B54, 0x006A7D56, 0x006D8059, 0x00748760, 0x006C7E59, 0x006C7E59, 0x00758762, 0x006F805E, 0x006B7C5A, 0x00718257,
        0x0077875E, 0x007C8B65, 0x007A8864, 0x00788460, 0x007D8965, 0x007C8A61, 0x007A885E, 0x00809067, 0x00808D67, 0x00747F5E, 0x007F8768, 0x00778262, 0x007A8866, 0x0072845D, 0x007B9167, 0x00758665, 0x007A8A6B, 0x0078876B, 0x0077866A, 0x00748564,
        0x00738560, 0x00788C61, 0x00768C5C, 0x00748169, 0x007A876D, 0x00718065, 0x00768667, 0x00768766, 0x007C906D, 0x007B906A, 0x00748963, 0x00707E5A, 0x0072835E, 0x00596A45, 0x00556641, 0x004B5D38, 0x003E502B, 0x004E633D, 0x004A5F39, 0x00374A29,
        0x003F4D29, 0x00404E2A, 0x002E452F, 0x00436969, 0x00568A9B, 0x00538BA4, 0x004E849D, 0x003B6F7B, 0x001B362D, 0x003D4737, 0x00707877, 0x007C888E, 0x00CED6D6, 0x00D3DCD9, 0x0092A3A6, 0x00849199, 0x0089969E, 0x0093A0A8, 0x0094A1A9, 0x0098A5AD,
        0x009EABB3, 0x0099A6AE, 0x0096A3AB, 0x0099ADAE, 0x009BAFB0, 0x00A4B5B8, 0x009CA9AB, 0x00929EA0, 0x009DA7A7, 0x00A8B1AE, 0x00B0B7B4, 0x009BA892, 0x00758469, 0x00768565, 0x007B8C67, 0x00606F50, 0xFFA7B09C, 0xFFFBFFF9, 0xFFFDFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFBFF, 0xFBF9FCF3, 0x00A3AD8F, 0x005D6A44, 0x00828F69, 0x007A8761, 0x004D5C30, 0x0041521F, 0x006B7950, 0x00546239, 0x00637148, 0x00536137, 0x00616F45,
        0x00707F53, 0x004B5A2E, 0x003B4A1E, 0x006C7A58, 0x00576347, 0x00555C4F, 0x00AEB1AF, 0x00DEDEE4, 0x00D5D4DD, 0x00D5D5DB, 0x00D5D6DA, 0x00D1D4D9, 0x00E3E7E8, 0x00C0C5C3, 0x008D918B, 0x00A8AFA2, 0x00777D6A, 0x004B533C, 0x00838C72, 0x0099989A,
        0x008C8F86, 0x00616756, 0x00696E5F, 0x00A8AAA4, 0x00BEC0BA, 0x0084897A, 0x00545C45, 0x006A7A51, 0x0077875E, 0x007B8B62, 0x0075855C, 0x006C7C53, 0x0076865D, 0x007F8F66, 0x0065754C, 0x0054673C, 0x00405229, 0x003F5128, 0x0053653C, 0x00394B24,
        0x00556740, 0x005F704B, 0x00798A65, 0x0073855E, 0x0074865F, 0x0074865F, 0x00758760, 0x00758760, 0x00758760, 0x00758760, 0x00758760, 0x00718260, 0x007A8D66, 0x004F623B, 0x00233216, 0x00586353, 0x004A5349, 0x00273321, 0x00243317, 0x00273315,
        0x002D3B1F, 0x002A371F, 0x002E3925, 0x00394531, 0x003D4A34, 0x0026371C, 0x005B6D50, 0x0071855B, 0x00708061, 0x00606B5B, 0x00ACB3B0, 0x00D0D7D4, 0x007C867A, 0x00505F44, 0x0052643F, 0x004A5D3C, 0x00586B4A, 0x00566745, 0x00455434, 0x00475337,
        0x006D745F, 0x00656A5B, 0x00313228, 0x00181413, 0x001B1E1C, 0x00222B28, 0x00364541, 0x00162521, 0x00151E1B, 0x00181B19, 0x001D1A16, 0x001C2413, 0x001A2015, 0x00161A15, 0x001C201A, 0x00262D1E, 0x00232B1A, 0x00192013, 0x00151913, 0x001B2514,
        0x00232D1C, 0x001C2518, 0x001D2219, 0x00161A15, 0x001A1A1A, 0x00181719, 0x00201F23, 0x001E2014, 0x00252A1B, 0x002B3120, 0x002B3120, 0x00242B1E, 0x001E231A, 0x00191E1C, 0x00171B1C, 0x00171D18, 0x00181917, 0x0019181A, 0x00172023, 0x003C5051,
        0x002E4341, 0x000E1714, 0x001D1815, 0x001A2114, 0x00545C4B, 0x00656F58, 0x004C5B3B, 0x00687954, 0x00677952, 0x006B7E57, 0x006C7F58, 0x00677A53, 0x006D8059, 0x00768863, 0x006D7F5A, 0x0070825D, 0x00728361, 0x005D6E4C, 0x00576846, 0x004F603F,
        0x00576847, 0x00687957, 0x0073855E, 0x006F7E58, 0x0073835A, 0x00748259, 0x007A885F, 0x006E7F5D, 0x0070815F, 0x006C7C5D, 0x006F8162, 0x006D7F60, 0x00728465, 0x006D8360, 0x00718764, 0x00708565, 0x00708467, 0x006C8063, 0x006C7F64, 0x006D8164,
        0x006E8363, 0x006F8562, 0x006D845E, 0x0072826A, 0x0074856A, 0x006A7D62, 0x006C8063, 0x006D8464, 0x00708767, 0x00718967, 0x0067805E, 0x00788662, 0x005D6E49, 0x0053643F, 0x0050613C, 0x003D4F2A, 0x0041532E, 0x004F643E, 0x00435832, 0x00445736,
        0x0043512D, 0x0044522E, 0x00314832, 0x003D6363, 0x00568A9B, 0x00538BA4, 0x004F859E, 0x00407480, 0x001D382F, 0x003E4838, 0x00717978, 0x007B878D, 0x00CED6D6, 0x00D4DDDA, 0x0091A2A5, 0x00798B92, 0x00788A91, 0x0081939A, 0x00889AA1, 0x0092A4AB,
        0x0098AAB1, 0x008B9DA4, 0x0083959C, 0x00899C9F, 0x008D9DA3, 0x009FADB3, 0x00A7B3B7, 0x00A8B4B4, 0x00A6B0AA, 0x008C968A, 0x00727D6D, 0x0078876C, 0x006F7F60, 0x007B8B69, 0x007F8F6D, 0x00616F53, 0xFFA6AE9D, 0xFFFDFFFB, 0xFFFDFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFBFF, 0xFFFBFEF5, 0x00A2AC8E, 0x005B6842, 0x0083906A, 0x00808D67, 0x00505F33, 0x003F501D, 0x00647249, 0x006A784F, 0x00536138, 0x00324016, 0x00435127,
        0x0059683C, 0x0038471B, 0x0038471B, 0x00697656, 0x005F6A50, 0x007F8679, 0x00A6A9A7, 0x00ECEDF1, 0x00DDDEE2, 0x00D4D6D6, 0x00DDE0DE, 0x00D3D8D7, 0x00E2E7E5, 0x00CED5CE, 0x006B7265, 0x006A735F, 0x00525B41, 0x00596345, 0x00636E4E, 0x00575D4A,
        0x005E684A, 0x00586440, 0x00505B3B, 0x005F6651, 0x00606655, 0x00687157, 0x00798463, 0x004E5E35, 0x00697950, 0x0074845B, 0x0077875E, 0x007D8D64, 0x007C8C63, 0x0073835A, 0x0068784F, 0x00516439, 0x003D4F26, 0x0041532A, 0x0053653C, 0x00354720,
        0x0054663F, 0x005D6E49, 0x00758661, 0x0073855E, 0x0073855E, 0x0074865F, 0x00758760, 0x00758760, 0x00758760, 0x00758760, 0x00758760, 0x00728361, 0x00788B64, 0x0052653E, 0x00202F13, 0x00556050, 0x00464F45, 0x0025311F, 0x00243317, 0x00263313,
        0x002D3B1F, 0x0027341C, 0x002F3A26, 0x00394531, 0x00394630, 0x0022321A, 0x005A6B50, 0x0075895F, 0x006B7A5E, 0x00465044, 0x0074797A, 0x00888D8E, 0x00596258, 0x0044523A, 0x0071835E, 0x00465938, 0x00516443, 0x00536442, 0x00384727, 0x004A563A,
        0x00818873, 0x006C7162, 0x00303127, 0x001C1719, 0x001C1E1F, 0x001F2726, 0x002F3E3A, 0x0011211A, 0x00141E18, 0x001C1F1D, 0x00221E1D, 0x001A2015, 0x001C1F1D, 0x00191A1E, 0x00191B1C, 0x00191E15, 0x00141B0E, 0x00121610, 0x0018191D, 0x00171E17,
        0x00242C22, 0x00232B21, 0x0020251C, 0x00141812, 0x001A1B19, 0x001B1B1B, 0x00272628, 0x00191A16, 0x001C1E18, 0x0021251A, 0x0022291C, 0x001F2619, 0x00192116, 0x00171E17, 0x00171D18, 0x00181E19, 0x00191A18, 0x001A191B, 0x00172023, 0x003B4F50,
        0x002D4240, 0x000F1815, 0x001F1A17, 0x00171E11, 0x004E5645, 0x006E7861, 0x00516040, 0x00647550, 0x00687A53, 0x006B7E57, 0x006F825B, 0x006B7E57, 0x006D7F5A, 0x0072845F, 0x006C7E59, 0x00748563, 0x006C7D5B, 0x004D5E3D, 0x004E5F3E, 0x00566954,
        0x004A5F46, 0x00576C4B, 0x0073895F, 0x00778B60, 0x00798B62, 0x006F7E58, 0x00748260, 0x00778563, 0x00758563, 0x00758762, 0x00748963, 0x0070855F, 0x00738862, 0x00738764, 0x00748563, 0x0070825D, 0x006F815C, 0x00748661, 0x00758762, 0x00738462,
        0x00738463, 0x00718162, 0x006F7F60, 0x0073845F, 0x00778863, 0x00768762, 0x00738560, 0x00788A65, 0x00738764, 0x00788C69, 0x006E825F, 0x0065734F, 0x0052633E, 0x00596A45, 0x0032431E, 0x00465833, 0x005B6D48, 0x002A3F19, 0x00536842, 0x00495C3B,
        0x004F5D39, 0x0044522E, 0x00344B35, 0x00416767, 0x00548899, 0x00558DA6, 0x005389A2, 0x00427682, 0x001C372E, 0x003B4535, 0x006D7574, 0x0078848A, 0x00CDD5D5, 0x00D6DFDC, 0x0092A3A6, 0x0074878E, 0x006B7E85, 0x0070838A, 0x007D9097, 0x008EA1A8,
        0x0095A8AF, 0x008699A0, 0x007D9097, 0x007E9097, 0x007E8D96, 0x008F9BA5, 0x009EA9B1, 0x00ABB5B5, 0x00A9B4AA, 0x008A9682, 0x006B785E, 0x00778867, 0x00748564, 0x007C8C6A, 0x007D8C6C, 0x00606D53, 0xFFA5AD9C, 0xFFFDFFFB, 0xFFFDFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCF8FF, 0xFFFCFFF6, 0x00A7B193, 0x005D6A44, 0x00828F69, 0x007E8B65, 0x0049582C, 0x0031420F, 0x00344219, 0x0039471E, 0x00344219, 0x00344218, 0x002D3B11,
        0x00354418, 0x0029380C, 0x0039481C, 0x00677454, 0x00838D76, 0x00C2C9BC, 0x00969A95, 0x00E6E8E8, 0x00E1E3E3, 0x00D0D4CF, 0x00C9CEC5, 0x00D0D6D1, 0x00D9E1D7, 0x00CFD8CB, 0x00656D5C, 0x007F8972, 0x00646E50, 0x007B8665, 0x0077835F, 0x0076845B,
        0x00748454, 0x00768952, 0x006D7D4D, 0x007A8662, 0x00717C5C, 0x0066724E, 0x00505F33, 0x0056663D, 0x00516138, 0x00697950, 0x007B8B62, 0x0075855C, 0x0078885F, 0x0078885F, 0x00627249, 0x004F6237, 0x00405229, 0x00485A31, 0x00576940, 0x00374922,
        0x00596B44, 0x0063744F, 0x00798A65, 0x0073855E, 0x0073855E, 0x0074865F, 0x00758760, 0x00758760, 0x00758760, 0x00758760, 0x00758760, 0x00768765, 0x0073865F, 0x00556841, 0x00213014, 0x00545F4F, 0x00434C42, 0x001E2A18, 0x00223115, 0x00273414,
        0x00273617, 0x001E2B13, 0x00313D27, 0x003D4935, 0x00394630, 0x00213119, 0x005B6C51, 0x0073875D, 0x0069785C, 0x004E574D, 0x007D8285, 0x00808489, 0x00525A53, 0x00324028, 0x006A7C57, 0x00596C4B, 0x00324524, 0x004B5C3A, 0x00556444, 0x00667256,
        0x008C937E, 0x00676C5D, 0x00313228, 0x00191219, 0x001A1B1F, 0x001E2625, 0x002F3F38, 0x0011211A, 0x00121C16, 0x00171A18, 0x001A1615, 0x001A1E19, 0x0018181E, 0x00141120, 0x0016151F, 0x001A1D1B, 0x00171B15, 0x00151718, 0x001B1827, 0x00141918,
        0x001B201E, 0x00151B16, 0x00171B15, 0x00161A14, 0x0022231F, 0x001C1D1B, 0x00202020, 0x001C1B1D, 0x001D1D1D, 0x001F231D, 0x0023291E, 0x0021281B, 0x00192215, 0x00182015, 0x001C241A, 0x00191F1A, 0x001A1B19, 0x001A191B, 0x00172023, 0x00394D4E,
        0x002C413F, 0x000F1815, 0x00201B18, 0x001D2417, 0x00525A49, 0x007D8770, 0x005E6D4D, 0x00697A55, 0x006C7E57, 0x006A7D56, 0x006D8059, 0x0071835E, 0x006C7E59, 0x006C7E59, 0x006A7C57, 0x00768765, 0x00697A58, 0x00475837, 0x00526342, 0x003C5043,
        0x00445943, 0x005A7250, 0x006C8559, 0x00687F52, 0x0075895E, 0x0070805E, 0x00748364, 0x007D8461, 0x0078835D, 0x0076875C, 0x0073875A, 0x006F8356, 0x00708358, 0x00788761, 0x00788460, 0x0078865C, 0x00728155, 0x0079885C, 0x0077865A, 0x00738157,
        0x00788460, 0x00788363, 0x007B8469, 0x007A8656, 0x00798658, 0x007A8759, 0x00727F53, 0x007A885E, 0x00728057, 0x0074845B, 0x0065754C, 0x00515F3B, 0x005D6E49, 0x002C3D18, 0x004B5C37, 0x00596B46, 0x00334520, 0x004A5F39, 0x004A5F39, 0x003A4D2C,
        0x0052603C, 0x0042502C, 0x003E553F, 0x00507676, 0x00578B9C, 0x00568EA7, 0x0050869F, 0x00407480, 0x00163128, 0x00343E2E, 0x00676F6E, 0x00737F85, 0x00CCD4D4, 0x00D7E0DD, 0x0094A5A8, 0x0080989E, 0x007A9298, 0x00829AA0, 0x008BA3A9, 0x0095ADB3,
        0x0098B0B6, 0x0090A8AE, 0x0091A9AF, 0x0098A6B2, 0x008D9BA7, 0x00909CA8, 0x00939EA6, 0x0099A3A3, 0x009BA89A, 0x0087967B, 0x00728260, 0x00768765, 0x00728361, 0x00758563, 0x00798868, 0x005F6C52, 0xFFA3AB9A, 0xFFFDFFFB, 0xFFF9FBFB, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFDFF, 0xFFFEFFF7, 0x009EA88A, 0x00606E45, 0x007F8C66, 0x00788460, 0x00657349, 0x004C5C2C, 0x004B5B32, 0x004D5D34, 0x004B5B32, 0x004B5B32, 0x004C5C33,
        0x0047572E, 0x0044542B, 0x004C5C33, 0x006C7D51, 0x00627348, 0x00899773, 0x007F8B6D, 0x008A967A, 0x008B977B, 0x00717D5F, 0x00879474, 0x006A7658, 0x00748062, 0x00869171, 0x006B7655, 0x005C6642, 0x00616C46, 0x007F8A62, 0x007E875F, 0x007B8E63,
        0x0075885D, 0x0074875C, 0x0077875E, 0x0076855F, 0x007B8862, 0x0077835F, 0x00697551, 0x004B5B32, 0x005D6D44, 0x004F5F36, 0x006E7E55, 0x007C8C63, 0x007B8B62, 0x007A8A61, 0x0067774E, 0x0050623B, 0x0042542D, 0x00475932, 0x0050623B, 0x003B4D26,
        0x00566841, 0x0061734C, 0x00768861, 0x0073855C, 0x0073855C, 0x0074865D, 0x0074865D, 0x0074865D, 0x0074865D, 0x0073855C, 0x0073855C, 0x00748661, 0x00778867, 0x00505F43, 0x00222F19, 0x004E5A46, 0x00485442, 0x00283420, 0x0024311B, 0x0029321E,
        0x002A371D, 0x00243314, 0x002F3C24, 0x003D473A, 0x00343E32, 0x00304028, 0x003F5330, 0x004F5D3B, 0x004B563C, 0x00545B4C, 0x00A4A9A0, 0x00BDC2B9, 0x006A7162, 0x00404B31, 0x004C5A38, 0x004C5A42, 0x00435237, 0x003F4D31, 0x00485738, 0x005D6B4F,
        0x006D7760, 0x00555D4C, 0x00282F20, 0x00211710, 0x001A1E18, 0x0022332F, 0x00384847, 0x00181F22, 0x001D1A1C, 0x001C1A19, 0x00191D18, 0x00181D1B, 0x00151B16, 0x00181F18, 0x001C2118, 0x00161B12, 0x00151914, 0x001B1B1B, 0x001C1B1D, 0x001B1B1B,
        0x00171816, 0x001A1C16, 0x001A1D14, 0x00161910, 0x00191C13, 0x001E201A, 0x001C1D19, 0x001B1B21, 0x001B1D1D, 0x00282D24, 0x001F2617, 0x001F2716, 0x00192011, 0x00191E15, 0x00191C1A, 0x00161A1B, 0x001B1D17, 0x001C2015, 0x0017231D, 0x003B4F50,
        0x00304445, 0x00111C14, 0x001E1E0C, 0x001F2213, 0x005C624F, 0x006B745A, 0x00556242, 0x0070815C, 0x00697C55, 0x006B8059, 0x00637852, 0x006D7A5A, 0x0071815F, 0x00748560, 0x0072845D, 0x006A7D56, 0x00516240, 0x00445637, 0x00607156, 0x00526348,
        0x004E6041, 0x00627351, 0x0071845D, 0x0074865D, 0x0073855C, 0x0070825B, 0x00788662, 0x0071835E, 0x0071835E, 0x0071835E, 0x0071835E, 0x0071835E, 0x0071835E, 0x0071835E, 0x0071835E, 0x00748563, 0x00748563, 0x00748563, 0x00748563, 0x00738462,
        0x00728361, 0x00718260, 0x0070815F, 0x006F805B, 0x00758661, 0x00768762, 0x00748560, 0x00798A65, 0x00748560, 0x00667752, 0x00495A35, 0x005E6F4A, 0x002C3D18, 0x0041532E, 0x005A6C47, 0x0030451F, 0x00425731, 0x005D744E, 0x001D340E, 0x00465E40,
        0x003F502E, 0x00303F19, 0x002F452C, 0x004B706C, 0x0055899A, 0x004A859F, 0x00558FAC, 0x003E7185, 0x001E3936, 0x00495346, 0x00697472, 0x0098A6AC, 0x00D5DCDF, 0x00CFD8DB, 0x0097A7B3, 0x008F9CA4, 0x0094A1A9, 0x008F9CA4, 0x0097A4AC, 0x009CA9B1,
        0x009CA9B1, 0x00A4B1B9, 0x00A1AEB6, 0x00A6AEB5, 0x009FAAA8, 0x00929F97, 0x008C9A94, 0x00909C9C, 0x0098A5A3, 0x00798C7B, 0x006C8466, 0x00728263, 0x00778867, 0x0073845F, 0x00788964, 0x00606F4F, 0xFFA4AD98, 0xFFFDFFF8, 0xFFF7FAF8, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFDFF, 0xFFFEFFF7, 0x009DA789, 0x00606E45, 0x007D8A64, 0x007C8864, 0x007A885E, 0x00768656, 0x007E8E65, 0x007B8B62, 0x0077875E, 0x0078885F, 0x007C8C63,
        0x007C8C63, 0x007A8A61, 0x007B8B62, 0x007F925F, 0x006B7D4E, 0x00708156, 0x006B7A54, 0x0075845E, 0x00718158, 0x006D7E53, 0x00839468, 0x00778561, 0x006A7854, 0x006A7854, 0x006C7953, 0x00707E55, 0x00717C54, 0x0079855B, 0x0078845A, 0x00708457,
        0x00728659, 0x00778A5F, 0x0078895E, 0x0074845B, 0x0079875E, 0x007E8C63, 0x007C8963, 0x0066764D, 0x004A5A31, 0x005A6A41, 0x0054643B, 0x00708057, 0x0078885F, 0x007B8B62, 0x00627249, 0x0050623B, 0x0041532C, 0x00455730, 0x004E6039, 0x003A4C25,
        0x00556740, 0x0060724B, 0x00768861, 0x0073855C, 0x0073855C, 0x0074865D, 0x0074865D, 0x0074865D, 0x0074865D, 0x0073855C, 0x0073855C, 0x00738560, 0x00778867, 0x00505F43, 0x00212E18, 0x004C5844, 0x0044503E, 0x0024301C, 0x00212E18, 0x00222B17,
        0x00222F15, 0x00243314, 0x002F3C24, 0x00404A3D, 0x00424C40, 0x0044543C, 0x005A6E4B, 0x00556543, 0x00556445, 0x0045523A, 0x00626D59, 0x0068735F, 0x003D4A32, 0x003F4E2F, 0x005A6A48, 0x00404F34, 0x004B5A3F, 0x00505E42, 0x004D5C3D, 0x00566448,
        0x0058624B, 0x004B5342, 0x00495041, 0x003D342B, 0x0022271E, 0x001A2C25, 0x002F403D, 0x00141C1B, 0x001A1818, 0x00191814, 0x001A1E18, 0x001D231E, 0x00171E17, 0x001B2319, 0x00242A1F, 0x001F241B, 0x001B1C18, 0x001D1D1D, 0x001F1E22, 0x001C1B1D,
        0x001B1B1B, 0x001E1F1D, 0x001D1E1A, 0x00181A14, 0x001B1D17, 0x0020211D, 0x001E1F1B, 0x0017181C, 0x00161917, 0x00252B20, 0x0022291A, 0x00222A19, 0x001A2114, 0x001A1E18, 0x00212323, 0x00131718, 0x00191B15, 0x001B1E15, 0x0014201A, 0x00344849,
        0x002B3F40, 0x0019241C, 0x00333321, 0x00323526, 0x00646A57, 0x00646D53, 0x004D5A3A, 0x006B7C57, 0x00657851, 0x00697E58, 0x00677C56, 0x006B7858, 0x006F7F5D, 0x00687954, 0x006F815A, 0x005F724B, 0x004A5B39, 0x00506243, 0x0044553A, 0x00506146,
        0x005D6F50, 0x00768765, 0x00788B64, 0x0072845B, 0x0074865D, 0x0071835C, 0x00707E5A, 0x00738560, 0x00738560, 0x00738560, 0x00738560, 0x00738560, 0x00738560, 0x00738560, 0x00738560, 0x00738462, 0x00748563, 0x00748563, 0x00748563, 0x00738462,
        0x00738462, 0x00728361, 0x00718260, 0x0073845F, 0x00758661, 0x0072835E, 0x0073845F, 0x0073845F, 0x006C7D58, 0x00445530, 0x005D6E49, 0x002B3C17, 0x004A5B36, 0x005E704B, 0x002E401B, 0x00475C36, 0x005D724C, 0x00223913, 0x0049603A, 0x00496143,
        0x00293A18, 0x0035441E, 0x003D533A, 0x00365B57, 0x00518596, 0x005E99B3, 0x00457F9C, 0x0043768A, 0x002E4945, 0x00626C5F, 0x0085908D, 0x00AAB8BE, 0x00E0E7EA, 0x00D2DBDE, 0x0093A3AF, 0x008A9AA1, 0x0090A0A7, 0x0093A3AA, 0x0099A9B0, 0x009BABB2,
        0x0099A9B0, 0x009CACB3, 0x009AAAB1, 0x0099A3AD, 0x0097A4A6, 0x00919F9B, 0x0092A09C, 0x0097A3A3, 0x009DA8A5, 0x007B8B79, 0x00697E5D, 0x00768569, 0x007B8C6B, 0x00758661, 0x00788964, 0x005F6E4E, 0xFF9FA893, 0xFFFDFFF8, 0xFFFDFFFE, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCFAFF, 0xFBFBFFF4, 0x00A0AA8C, 0x00647249, 0x007C8963, 0x00798561, 0x0078865C, 0x00819161, 0x0074845B, 0x0077875E, 0x007B8B62, 0x00798960, 0x0075855C,
        0x0075855C, 0x0078885F, 0x007A8A61, 0x00778A57, 0x007C8F5E, 0x0077895A, 0x0077885C, 0x00809165, 0x007D8F60, 0x00839663, 0x007D925B, 0x00809166, 0x00809166, 0x007E8F64, 0x007E8C62, 0x007A885E, 0x007A885E, 0x007C885E, 0x007B875D, 0x00728659,
        0x0074885B, 0x00778B5E, 0x0076875B, 0x00718256, 0x00758359, 0x0079875D, 0x0079875D, 0x0073835A, 0x0068784F, 0x0047572E, 0x0057673E, 0x00526239, 0x006F7F56, 0x007A8A61, 0x0064744B, 0x0050623B, 0x0041532C, 0x0044562F, 0x004C5E37, 0x00384A23,
        0x0054663F, 0x0060724B, 0x00768861, 0x0073855C, 0x0073855C, 0x0074865D, 0x0074865D, 0x0074865D, 0x0074865D, 0x0073855C, 0x0073855C, 0x0072845F, 0x00768766, 0x004E5D41, 0x001F2C16, 0x004B5743, 0x00414D3B, 0x00212D19, 0x00202D17, 0x0027301C,
        0x00263319, 0x002C3B1C, 0x00323F27, 0x003D473A, 0x00353F33, 0x002B3B23, 0x00495D3A, 0x00546442, 0x00556543, 0x00394927, 0x00394828, 0x003C4B2B, 0x00324220, 0x00465634, 0x00586846, 0x00314024, 0x00445337, 0x004E5D3E, 0x00475637, 0x00616F53,
        0x007F8972, 0x00646C5B, 0x0040473A, 0x004A4235, 0x00252B20, 0x00172A21, 0x0031423E, 0x0019221F, 0x001E1D19, 0x0021211B, 0x00282D24, 0x002A3228, 0x001B2318, 0x001B2215, 0x0021281B, 0x001E2118, 0x00171814, 0x00181719, 0x001E1A20, 0x00181719,
        0x001A191B, 0x001C1B1D, 0x00191919, 0x00161616, 0x00191A18, 0x001E1F1D, 0x001C1D1B, 0x001A1C1C, 0x00181C17, 0x00242B1E, 0x00232B1A, 0x00202817, 0x00161C11, 0x00161A15, 0x00222425, 0x001A1E1F, 0x001A1B17, 0x00191C13, 0x0018241E, 0x003F5255,
        0x00374A4D, 0x00222D25, 0x00383828, 0x00353829, 0x00616754, 0x005B644A, 0x00485535, 0x006A7B56, 0x00647651, 0x00647953, 0x00677C56, 0x00697656, 0x0071815F, 0x0072835E, 0x004D5F38, 0x004E613A, 0x00455634, 0x00213314, 0x004F6045, 0x0057684D,
        0x00617354, 0x00758664, 0x0072855E, 0x006C7E55, 0x0072845B, 0x0074865F, 0x00778561, 0x00748661, 0x00748661, 0x00748661, 0x00748661, 0x00748661, 0x00748661, 0x00748661, 0x00748661, 0x00738560, 0x00738560, 0x00738560, 0x00748661, 0x00748661,
        0x00738560, 0x00738560, 0x0072845F, 0x00788964, 0x006E7F5A, 0x006E7F5A, 0x00798A65, 0x00667752, 0x003F502B, 0x0061724D, 0x00344520, 0x00485934, 0x00657651, 0x002B3D18, 0x004A5C37, 0x005A6F49, 0x002A3F19, 0x00455C36, 0x0049603A, 0x0021391B,
        0x004B5C3A, 0x00485731, 0x00263C23, 0x00385D59, 0x00588C9D, 0x00538EA8, 0x004E88A5, 0x00487C8D, 0x0035504C, 0x00636E5E, 0x00838E8B, 0x009DABB1, 0x00DAE1E4, 0x00D2DBDE, 0x0094A5AE, 0x007F9299, 0x0080939A, 0x00889BA2, 0x008FA2A9, 0x0095A8AF,
        0x0096A9B0, 0x008DA0A7, 0x00899CA3, 0x008F9EAE, 0x00899BA2, 0x007F9190, 0x00879593, 0x008F9B9B, 0x009BA59F, 0x007D8975, 0x006A7A58, 0x00718064, 0x00768766, 0x00728260, 0x00778863, 0x00627152, 0xFF9FA893, 0xFFFCFFF8, 0xFFFDFFFE, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFDFF, 0xFFFEFFF7, 0x009FA98B, 0x00627047, 0x007B8862, 0x007E8A66, 0x0078865C, 0x00819161, 0x00798960, 0x00798960, 0x007C8C63, 0x007D8D64, 0x007C8C63,
        0x007E8E65, 0x007D8D64, 0x0076865D, 0x0073865B, 0x007C8E65, 0x0073845F, 0x00758661, 0x00758760, 0x006D7F56, 0x00728657, 0x00687D4C, 0x00687B50, 0x006E8156, 0x00738459, 0x0076875C, 0x00738157, 0x007C8A60, 0x007B895F, 0x00778359, 0x0074875C,
        0x00708358, 0x006F8356, 0x00728357, 0x0075865A, 0x007A895D, 0x00788859, 0x00748455, 0x0077875E, 0x007D8D64, 0x005C6C43, 0x004B5B32, 0x0058683F, 0x00506037, 0x0076865D, 0x0068784F, 0x0052643D, 0x0042542D, 0x00455730, 0x004C5E37, 0x00384A23,
        0x0054663F, 0x0061734C, 0x00788A63, 0x0073855C, 0x0073855C, 0x0074865D, 0x0074865D, 0x0074865D, 0x0074865D, 0x0073855C, 0x0073855C, 0x0070825D, 0x00758665, 0x004D5C40, 0x001E2B15, 0x004C5844, 0x00414D3B, 0x00202C18, 0x00222F19, 0x001D2612,
        0x001E2B11, 0x00273617, 0x002F3C24, 0x00424C3F, 0x00323C30, 0x001F2F17, 0x004F6340, 0x00758661, 0x0072845D, 0x0054663D, 0x004F6237, 0x0052653A, 0x004B5D34, 0x0052643D, 0x0051623D, 0x00516142, 0x00425332, 0x004D5C3C, 0x00495838, 0x0048563A,
        0x005E6752, 0x00565E4D, 0x0040473A, 0x00423A2D, 0x00262D20, 0x00213529, 0x00394B44, 0x001A241E, 0x001A1A14, 0x001C1D14, 0x00242A1F, 0x002A3025, 0x001D2417, 0x001A2112, 0x00212617, 0x001E2217, 0x001A1C16, 0x001B1919, 0x001A161B, 0x00171717,
        0x00171618, 0x0017161A, 0x00161519, 0x00161519, 0x001A191B, 0x001B1C1A, 0x00191A16, 0x001A1E18, 0x001C2316, 0x00262E1D, 0x00242D18, 0x00222B17, 0x001C2316, 0x00181B19, 0x00222327, 0x001D2024, 0x001B1C18, 0x001A1D14, 0x001B2623, 0x0044575A,
        0x00394C4F, 0x001E2822, 0x00303020, 0x00393B2F, 0x006B7160, 0x00636B54, 0x004E5B3B, 0x006E7E5C, 0x00697B56, 0x00677C56, 0x006A7E5B, 0x00788565, 0x00687856, 0x00586944, 0x004E6039, 0x0050633C, 0x00445533, 0x0037492A, 0x004C5D42, 0x00506146,
        0x004C5E3F, 0x00627351, 0x0073865F, 0x00778960, 0x0075875E, 0x0070825B, 0x00778561, 0x0072845F, 0x0072845F, 0x0072845F, 0x0072845F, 0x0072845F, 0x0072845F, 0x0072845F, 0x0072845F, 0x0072845F, 0x0072845F, 0x00738560, 0x00738560, 0x00748661,
        0x00738560, 0x00738560, 0x00738560, 0x0073845F, 0x0073845F, 0x00768762, 0x00647550, 0x004E5F3A, 0x005D6E49, 0x002D3E19, 0x00475833, 0x005A6B46, 0x002F401B, 0x004A5C37, 0x00546641, 0x002F441E, 0x00415630, 0x004F6640, 0x00283F19, 0x00486042,
        0x00425331, 0x00374620, 0x002E442B, 0x003F6460, 0x00528697, 0x004F8AA4, 0x00508AA7, 0x00477B8C, 0x002D4844, 0x004D5848, 0x006A7572, 0x00808F92, 0x00CBD3D3, 0x00D0DADA, 0x0095A6AF, 0x00748A90, 0x006D8389, 0x00768C92, 0x007E949A, 0x008DA3A9,
        0x0093A9AF, 0x0081979D, 0x00788E94, 0x00788C9E, 0x007E929D, 0x007E9293, 0x00899998, 0x008E9A9C, 0x00979E9B, 0x007F8A76, 0x006E7C5A, 0x00718064, 0x00768667, 0x00728260, 0x00758563, 0x00637253, 0xFFA2AB97, 0xFFF9FEF5, 0xFFFBFDFD, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFDFF, 0xFFFFFFF8, 0x009EA88A, 0x00606E45, 0x007C8963, 0x00808C68, 0x00627046, 0x005B6B3B, 0x0057673E, 0x005A6A41, 0x005E6E45, 0x005D6D44, 0x005A6A41,
        0x00596940, 0x005C6C43, 0x005E6E45, 0x00738165, 0x00556248, 0x0045513B, 0x0056614D, 0x00505B47, 0x0035422A, 0x002C3A1E, 0x00354425, 0x00263614, 0x00293917, 0x00374823, 0x0045532F, 0x0042512B, 0x0055633A, 0x006E7C52, 0x007B895F, 0x0074865F,
        0x0074865F, 0x0074865D, 0x0077885D, 0x00798A5F, 0x007A895D, 0x00768657, 0x00758556, 0x0076865D, 0x0077875E, 0x007C8C63, 0x0057673E, 0x0058683F, 0x00526239, 0x005C6C43, 0x005E6E45, 0x0053653E, 0x0043552E, 0x00465831, 0x004E6039, 0x003A4C25,
        0x00566841, 0x0063754E, 0x00798B64, 0x0073855C, 0x0073855C, 0x0074865D, 0x0074865D, 0x0074865D, 0x0074865D, 0x0073855C, 0x0073855C, 0x0070825D, 0x00758665, 0x004C5B3F, 0x001F2C16, 0x004F5B47, 0x00434F3D, 0x00212D19, 0x0026331D, 0x0029321E,
        0x0028351B, 0x00283718, 0x00313E26, 0x00495346, 0x00323C30, 0x001F2F17, 0x005E724F, 0x0072845F, 0x00798C65, 0x006D8157, 0x00708459, 0x0075895E, 0x0065794F, 0x00566942, 0x00475934, 0x00435432, 0x004E5F3D, 0x006C7C5A, 0x00637351, 0x004C5B3C,
        0x00565F4A, 0x004E5546, 0x002E3429, 0x00292114, 0x001B2215, 0x001E3128, 0x00354740, 0x00151E1B, 0x00171612, 0x00171711, 0x00191F14, 0x00191E15, 0x00171D12, 0x001F2317, 0x00272C1D, 0x002A2F20, 0x002D2E24, 0x00272721, 0x001B1918, 0x00181917,
        0x00181818, 0x0018171B, 0x001A181E, 0x001C1A20, 0x001B1A1C, 0x00171814, 0x0015180F, 0x0018210D, 0x00212A15, 0x00293519, 0x00273317, 0x0029331C, 0x00272E1F, 0x00161A15, 0x00131516, 0x0015181C, 0x00191A18, 0x001A1C16, 0x0016211E, 0x00374A4F,
        0x002A3D42, 0x00121C16, 0x0029281A, 0x002F3125, 0x00676D5C, 0x005F6750, 0x00424E30, 0x00566644, 0x00556742, 0x00556946, 0x00586C49, 0x005F6C4C, 0x0051613F, 0x00465732, 0x00495B34, 0x005A6D46, 0x00576846, 0x00465839, 0x0054654A, 0x004B5C41,
        0x00415334, 0x00576846, 0x0070835C, 0x00798B62, 0x0074865D, 0x006E8059, 0x00778561, 0x0071835E, 0x0071835E, 0x0071835E, 0x0071835E, 0x0071835E, 0x0071835E, 0x0071835E, 0x0071835E, 0x0071845D, 0x0072855E, 0x0072855E, 0x0073865F, 0x0073865F,
        0x0073865F, 0x0072855E, 0x0072855E, 0x0072835E, 0x00798A65, 0x006A7B56, 0x004A5B36, 0x005E6F4A, 0x003B4C27, 0x003D4E29, 0x005A6B46, 0x0030411C, 0x00475833, 0x005C6E49, 0x0031431E, 0x00445933, 0x00586D47, 0x00253C16, 0x0049603A, 0x00465E40,
        0x002B3C1A, 0x0036451F, 0x00455B42, 0x00476C68, 0x0055899A, 0x005994AE, 0x004C86A3, 0x0045798A, 0x0026423C, 0x00404C3A, 0x0065716B, 0x0078878A, 0x00CCD4D4, 0x00D1DBDB, 0x0092A4AB, 0x00748A90, 0x006C8288, 0x0073898F, 0x007A9096, 0x00899FA5,
        0x0090A6AC, 0x007F959B, 0x00778D93, 0x0074889A, 0x007D919C, 0x007C9192, 0x00859496, 0x00818C90, 0x00899190, 0x007F8979, 0x00758163, 0x00748368, 0x0079896A, 0x00788767, 0x00758563, 0x005F6D51, 0xFFA4AD99, 0xFFFCFFFA, 0xFFFDFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFDFF, 0xFFFFFFF8, 0x009EA88A, 0x00627047, 0x007E8B65, 0x007C8864, 0x0048562C, 0x00334313, 0x0035451C, 0x0034441B, 0x00304017, 0x00304017, 0x0035451C,
        0x00324219, 0x00304017, 0x0036461D, 0x00727E68, 0x004B5544, 0x004A5346, 0x00828982, 0x009FA5A0, 0x0099A099, 0x0090988E, 0x009BA398, 0x009AA595, 0x009BA795, 0x008C9783, 0x0058654B, 0x00414E2E, 0x004D5B37, 0x00718158, 0x007D8B61, 0x00738262,
        0x00788767, 0x007A8A68, 0x007A8864, 0x0075845E, 0x00728057, 0x00738157, 0x007B8A5E, 0x00708057, 0x0076865D, 0x0076865D, 0x0077875E, 0x005C6C43, 0x00596940, 0x0056663D, 0x00415128, 0x0053653E, 0x0044562F, 0x00475932, 0x004F613A, 0x003B4D26,
        0x00576942, 0x0063754E, 0x00798B64, 0x0073855C, 0x0073855C, 0x0074865D, 0x0074865D, 0x0074865D, 0x0074865D, 0x0073855C, 0x0073855C, 0x0071835E, 0x00758665, 0x004A593D, 0x001F2C16, 0x00535F4B, 0x00465240, 0x00222E1A, 0x0028351F, 0x002A331F,
        0x0029361C, 0x00273617, 0x00323F27, 0x00475144, 0x00303A2E, 0x001F2F17, 0x00566A47, 0x0070815F, 0x00687957, 0x00485937, 0x00405130, 0x004B5C3B, 0x00495A38, 0x00475836, 0x00475836, 0x004F613C, 0x006B7E57, 0x006F805B, 0x00536341, 0x00556445,
        0x0077806B, 0x00676E5F, 0x002B3027, 0x001D140B, 0x0012170E, 0x00172922, 0x002E3F3C, 0x00141C1B, 0x001E1C1C, 0x001D1C18, 0x00181C16, 0x00131614, 0x00171814, 0x001D2116, 0x0024291A, 0x002B2E1E, 0x00303323, 0x002E2E20, 0x00202012, 0x00181C11,
        0x00171814, 0x00171618, 0x001B191F, 0x001C1B1F, 0x00161715, 0x00161910, 0x001D2213, 0x00525F3F, 0x005B6947, 0x005C6B45, 0x00596842, 0x005A6747, 0x00515A45, 0x00292E25, 0x00151816, 0x00111418, 0x00161715, 0x00191B15, 0x0015201E, 0x00394C51,
        0x002E4146, 0x00101916, 0x001E1D0F, 0x0023241A, 0x00616657, 0x00606851, 0x00455133, 0x004D5D3B, 0x004C5D3B, 0x004D613E, 0x004C5F3E, 0x004D5A3A, 0x0051613F, 0x0053643F, 0x0040522B, 0x005E714A, 0x006A7B59, 0x00445637, 0x0065765B, 0x00495A3F,
        0x004B5D3E, 0x00617250, 0x006D8059, 0x006F8158, 0x00708259, 0x0070825B, 0x00778561, 0x00738560, 0x00738560, 0x00738560, 0x00738560, 0x00738560, 0x00738560, 0x00738560, 0x00738560, 0x0071845D, 0x0071845D, 0x0072855E, 0x0072855E, 0x0072855E,
        0x0072855E, 0x0071845D, 0x0071845D, 0x00748560, 0x006A7B56, 0x00445530, 0x0062734E, 0x003A4B26, 0x00394A25, 0x005F704B, 0x00394A25, 0x00475833, 0x0060714C, 0x0030421D, 0x00445631, 0x00586D47, 0x00334822, 0x00415832, 0x004C633D, 0x0020381A,
        0x0040512F, 0x004A5933, 0x003E543B, 0x004B706C, 0x005A8E9F, 0x00518CA6, 0x00518BA8, 0x00477B8B, 0x0026423C, 0x003C4836, 0x006B7771, 0x007A898B, 0x00CFD7D6, 0x00D3DEDC, 0x008FA1A8, 0x007F9299, 0x007D9097, 0x0082959C, 0x0085989F, 0x008A9DA4,
        0x008DA0A7, 0x008699A0, 0x0084979E, 0x008598A7, 0x007D9097, 0x00667B79, 0x0069787A, 0x0069747C, 0x00788185, 0x00747F75, 0x0065755E, 0x006D7C61, 0x006D7C60, 0x00768565, 0x00788767, 0x005E6C50, 0xFFA3AB9A, 0xFFFCFFFA, 0xFFFDFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFDFF, 0xFFFFFFF8, 0x009CA688, 0x00627047, 0x007E8B65, 0x007F8B67, 0x004D5B31, 0x00425222, 0x0063734A, 0x0054643B, 0x00415128, 0x004A5A31, 0x00627249,
        0x005B6B42, 0x00425229, 0x003A4A21, 0x0067765A, 0x0048553F, 0x004F5A4A, 0x00A4ACA5, 0x00D9E0DD, 0x00E4EAE9, 0x00E1E7E6, 0x00E2E8E7, 0x00E5E9EE, 0x00EAEFF2, 0x00BCC3BE, 0x00565F52, 0x0049553F, 0x00566244, 0x006A7953, 0x005A6A41, 0x00536046,
        0x00505D43, 0x0049573B, 0x004B5838, 0x00515F3D, 0x0054613B, 0x0055633A, 0x005C6A41, 0x0073835A, 0x0074845B, 0x0077875E, 0x00728259, 0x007D8D64, 0x004E5E35, 0x0064744B, 0x002E3E15, 0x0052643D, 0x0043552E, 0x00475932, 0x0050623B, 0x003B4D26,
        0x00566841, 0x0062744D, 0x00788A63, 0x0073855C, 0x0073855C, 0x0074865D, 0x0074865D, 0x0074865D, 0x0074865D, 0x0073855C, 0x0073855C, 0x00738560, 0x00768766, 0x0049583C, 0x001E2B15, 0x0054604C, 0x00475341, 0x00212D19, 0x0027341E, 0x0028311D,
        0x0027341A, 0x00283718, 0x0035422A, 0x003F493C, 0x00303A2E, 0x00293921, 0x00455936, 0x004C603D, 0x00455738, 0x0033432B, 0x003D4C37, 0x004C5B46, 0x003A4A32, 0x00394B2C, 0x00526643, 0x006E815A, 0x006E8258, 0x0062744D, 0x005D6E49, 0x005C6B4C,
        0x00646D58, 0x00596053, 0x00282D24, 0x00271C18, 0x00181C17, 0x00182926, 0x002D3C3E, 0x00141A1F, 0x001E1A1F, 0x001B1919, 0x00141715, 0x001C1A20, 0x00171618, 0x001A1C16, 0x00212415, 0x00262B16, 0x002E3219, 0x002E3219, 0x00262A11, 0x001E2413,
        0x001B1F14, 0x00181917, 0x0019181C, 0x00181719, 0x00161713, 0x00272C1D, 0x00444B36, 0x0074855A, 0x00738458, 0x006A7C4D, 0x006C7E4F, 0x00707F59, 0x00636F53, 0x002E3526, 0x00131711, 0x0013161B, 0x00191A18, 0x001A1B17, 0x0016211F, 0x003F5257,
        0x00384A51, 0x00141D1A, 0x00181709, 0x001A1B11, 0x0054594A, 0x005A614C, 0x00485438, 0x00475636, 0x00435432, 0x00455837, 0x00445736, 0x004C5939, 0x00475735, 0x00384924, 0x00455730, 0x004B5E37, 0x00495A38, 0x004C5E3F, 0x00334429, 0x003E4F34,
        0x004E6041, 0x006E7F5D, 0x00758861, 0x0071835A, 0x00708259, 0x006D7F58, 0x006F7D59, 0x0072845F, 0x0072845F, 0x0072845F, 0x0072845F, 0x0072845F, 0x0072845F, 0x0072845F, 0x0072845F, 0x0071855B, 0x0071855B, 0x0071855B, 0x0071855B, 0x0071855B,
        0x0070845A, 0x006F8359, 0x006F8359, 0x006E7F5A, 0x003F502B, 0x0061724D, 0x00374823, 0x0041522D, 0x005D6E49, 0x00364722, 0x0041522D, 0x00657651, 0x00263712, 0x004C5E39, 0x00536540, 0x00283D17, 0x00485D37, 0x00516842, 0x00243B15, 0x00496143,
        0x00475836, 0x00495832, 0x0040563D, 0x00426763, 0x004D8192, 0x004E89A3, 0x004F89A6, 0x004A7E8E, 0x00254239, 0x00374331, 0x006D7A72, 0x00758486, 0x00CBD3D2, 0x00D2DDDB, 0x0091A3AA, 0x0088989F, 0x008B9BA2, 0x008B9BA2, 0x008E9EA5, 0x008E9EA5,
        0x008D9DA4, 0x0090A0A7, 0x008F9FA6, 0x008A99A2, 0x00809293, 0x00687B78, 0x006A797B, 0x0069757F, 0x007A8690, 0x00818F8D, 0x0076897A, 0x0085937B, 0x006D7C60, 0x00707F5F, 0x00798868, 0x005F6D51, 0xFFA3AB9A, 0xFFFBFFF9, 0xFFFCFEFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFDFF, 0xFFFCFFF5, 0x009DA789, 0x0067754C, 0x007F8C66, 0x007A8662, 0x0047552B, 0x00455525, 0x005E6E45, 0x00617148, 0x005B6B42, 0x005F6F46, 0x0067774E,
        0x004E5E35, 0x0035451C, 0x003B4B22, 0x006C7E59, 0x004A5A3B, 0x00505D47, 0x00BAC4B7, 0x00E8EFEA, 0x00D4DAD9, 0x00C8CDCE, 0x00C6CBCC, 0x00D0CFE3, 0x00E8E8F8, 0x00C4C7CF, 0x00585E59, 0x004E5848, 0x003F4B2F, 0x0045532F, 0x003C4C23, 0x00636F59,
        0x004E5A44, 0x0037442A, 0x003A462A, 0x004E5B3B, 0x00576241, 0x004E5A36, 0x004A5731, 0x007B8B62, 0x0077875E, 0x0076865D, 0x00718158, 0x00798960, 0x0068784F, 0x00526239, 0x003C4C23, 0x0050623B, 0x0042542D, 0x00465831, 0x004F613A, 0x003B4D26,
        0x00566841, 0x0061734C, 0x00768861, 0x0073855C, 0x0073855C, 0x0074865D, 0x0074865D, 0x0074865D, 0x0074865D, 0x0073855C, 0x0073855C, 0x00758762, 0x00778867, 0x0048573B, 0x001D2A14, 0x0055614D, 0x00475341, 0x001F2B17, 0x0025321C, 0x002C3521,
        0x0028351B, 0x002C3B1C, 0x0039462E, 0x003D473A, 0x003E483C, 0x00485840, 0x00526643, 0x004A5E3B, 0x00506146, 0x005D6A5A, 0x007E897F, 0x007C877D, 0x00435040, 0x003A4B30, 0x006D815E, 0x00667A50, 0x0062764C, 0x0062744B, 0x00697A55, 0x005B6A4B,
        0x00636C57, 0x00676E61, 0x00292E25, 0x00231715, 0x00141616, 0x00152426, 0x002B3A3D, 0x0012181F, 0x001B171D, 0x001B171C, 0x00181A1B, 0x001D1925, 0x0016141A, 0x001D1C18, 0x00292C1D, 0x002E341D, 0x0033381B, 0x0033391A, 0x00303617, 0x002B321D,
        0x00262A1E, 0x001E1F1B, 0x001A191B, 0x00181818, 0x001D1F19, 0x00424837, 0x00727B61, 0x00607342, 0x00586B38, 0x004B5F2A, 0x00576A37, 0x0066774B, 0x005F6C4C, 0x002C3423, 0x00151A11, 0x0014171C, 0x001E1E1E, 0x001D1E1A, 0x00111C1A, 0x0034464D,
        0x002F4148, 0x00141D1A, 0x001F1E10, 0x002F3026, 0x005D6253, 0x005F6651, 0x004E5A3E, 0x00475636, 0x00435432, 0x00495C3B, 0x004B5E3D, 0x004D5A3A, 0x0050603E, 0x0051623D, 0x0053653E, 0x00586B44, 0x00475836, 0x002F4122, 0x00394A2F, 0x003E4F34,
        0x004C5E3F, 0x006A7B59, 0x0072855E, 0x006E8057, 0x006F8158, 0x006F815A, 0x0075835F, 0x0070825D, 0x0070825D, 0x0070825D, 0x0070825D, 0x0070825D, 0x0070825D, 0x0070825D, 0x0070825D, 0x0071855B, 0x0071855B, 0x0071855B, 0x0071855B, 0x0070845A,
        0x006F8359, 0x006E8258, 0x006D8157, 0x004A5B36, 0x00667752, 0x00384924, 0x00455631, 0x005F704B, 0x003F502B, 0x0041522D, 0x0062734E, 0x002F401B, 0x00546540, 0x00556742, 0x002D3F1A, 0x004B603A, 0x00526741, 0x00213812, 0x004D643E, 0x003F5739,
        0x00536442, 0x005B6A44, 0x00445A41, 0x003D625E, 0x00528697, 0x005691AB, 0x004F89A6, 0x00477B8B, 0x00234037, 0x0036422E, 0x00707D75, 0x00748385, 0x00C9D1D0, 0x00D1DCDA, 0x0093A5AC, 0x0089969E, 0x008D9AA2, 0x0087949C, 0x008D9AA2, 0x00909DA5,
        0x008F9CA4, 0x0095A2AA, 0x00919EA6, 0x008B979B, 0x0093A19F, 0x00859692, 0x00808F91, 0x00727E8A, 0x008794A2, 0x00AEBFC2, 0x00C0D5CC, 0x00BCCAB2, 0x00849377, 0x00707F60, 0x00768565, 0x005E6B51, 0xFFA3AB9A, 0xFFFCFFFB, 0xFFFDFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFDFF, 0xFFFFFFF8, 0x009DA789, 0x00637148, 0x00808D67, 0x007E8A66, 0x0047552B, 0x00465626, 0x005E6F44, 0x003E4F24, 0x005A6B40, 0x0054653A, 0x0055663B,
        0x00627348, 0x003D4E23, 0x003C4D22, 0x0072845B, 0x00566546, 0x00707A6A, 0x00BBC0BF, 0x00DDE0E5, 0x00E3E5ED, 0x00CED2D3, 0x00C0C5C4, 0x00D8D8DE, 0x00D5D6DA, 0x00D0D2D2, 0x00767A75, 0x006B7166, 0x006C7463, 0x00535C47, 0x00646E57, 0x008D908E,
        0x00737674, 0x00525553, 0x0050544F, 0x00737772, 0x00B5B9B3, 0x00B1B5AF, 0x00494D47, 0x005E6B45, 0x007B8862, 0x007A8761, 0x0072815B, 0x0075845E, 0x0063754E, 0x0052643D, 0x00354720, 0x0050633C, 0x00465932, 0x0043562F, 0x004E613A, 0x003A4D26,
        0x00546740, 0x00667952, 0x0073865F, 0x0072845B, 0x0073855C, 0x0075875E, 0x0076885F, 0x0075875E, 0x0074865D, 0x0074865D, 0x0076885F, 0x0074825E, 0x007E8F6A, 0x004C5B3B, 0x00232D1C, 0x00565D58, 0x004B524F, 0x00192715, 0x00233615, 0x00212E18,
        0x002D3C20, 0x002C3C1D, 0x003D4935, 0x00424B41, 0x003D463C, 0x0019280D, 0x0044582D, 0x004F6339, 0x004C5B3F, 0x00545D53, 0x00B3B8BB, 0x00CBCFD4, 0x00757D76, 0x0048563E, 0x006C7D5B, 0x006A7D56, 0x00637550, 0x006A7A58, 0x005D6B4F, 0x00404D35,
        0x007F8874, 0x006A7162, 0x002C3326, 0x001D1417, 0x00171A1E, 0x00243133, 0x003B4749, 0x00181C1D, 0x001C1915, 0x001B1E15, 0x001B2518, 0x00181C17, 0x00181C17, 0x001B1F1A, 0x002B2D27, 0x002A2E22, 0x00262B16, 0x00323A1C, 0x00333C1B, 0x0030371C,
        0x003A4029, 0x00282B1C, 0x001B1F14, 0x00171B0F, 0x0017210A, 0x0054623E, 0x006B7C50, 0x00525B41, 0x002C351A, 0x001C2707, 0x00242F0E, 0x00303A1C, 0x00333B24, 0x0023271B, 0x00171A11, 0x00151D12, 0x00171913, 0x001A1B19, 0x00192323, 0x00465A5B,
        0x003A4E4F, 0x000F1717, 0x00201A1B, 0x00262822, 0x0051574C, 0x005C6453, 0x004C5941, 0x00455438, 0x00455738, 0x00495D40, 0x00495D40, 0x0047563A, 0x004A593D, 0x004F5E43, 0x00516045, 0x004E5C44, 0x004C5A42, 0x0054624A, 0x005E6B55, 0x005A6954,
        0x0053634C, 0x005B6A4E, 0x006E7F5D, 0x007A8C65, 0x00778962, 0x00748560, 0x007A8864, 0x0075845E, 0x0076855F, 0x00788761, 0x00798862, 0x00788761, 0x00778660, 0x00778660, 0x00778660, 0x00798862, 0x007B8A64, 0x007A8963, 0x00778660, 0x00788761,
        0x0076855F, 0x00687751, 0x0056653F, 0x0063754E, 0x00384A23, 0x0041532C, 0x0060724B, 0x003E5029, 0x0041532C, 0x0063754E, 0x0031431C, 0x004D6137, 0x00596D43, 0x00293C15, 0x0051643D, 0x00576944, 0x00273914, 0x004C5D3B, 0x00516240, 0x0053643F,
        0x00667859, 0x00627352, 0x00475636, 0x00446459, 0x004C859A, 0x004C8CAB, 0x00548BA0, 0x004B798A, 0x001B4038, 0x00334633, 0x00767C77, 0x007A8184, 0x00C5D6D3, 0x00CFE0DD, 0x0097A0A9, 0x007F9198, 0x007C8E95, 0x0083959C, 0x008D9FA6, 0x0092A4AB,
        0x0093A5AC, 0x008D9FA6, 0x0081939A, 0x007E939B, 0x007D8F98, 0x0083959C, 0x007D9095, 0x00798A8D, 0x00808F91, 0x00B4C1C3, 0x00D0DEDD, 0x00A5B596, 0x007E8F6E, 0x00788866, 0x007C8C6A, 0x005D6B4F, 0xFF9FA796, 0xFFFAFEF8, 0xFFFDFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFCFF, 0xFFFCFFF5, 0x0098A284, 0x00606E45, 0x007E8B65, 0x007B8763, 0x0046542A, 0x00435323, 0x00606E44, 0x00505E34, 0x005D6B41, 0x004F5D33, 0x0057653B,
        0x00657349, 0x00414F25, 0x00414F25, 0x006D7F58, 0x004C5B3C, 0x00707A6A, 0x00C7CCCA, 0x00D8DBE0, 0x00D4D7DC, 0x00D6DADB, 0x00D6DBD9, 0x00D3D3D9, 0x00E7E8EC, 0x00C8CACA, 0x00727670, 0x00858C7D, 0x005F6853, 0x004E593F, 0x00727E62, 0x00A8AEA3,
        0x008E9489, 0x006E7469, 0x0072796C, 0x00899083, 0x00ACB3A4, 0x00B7BEAF, 0x008A9182, 0x004B5832, 0x0068754F, 0x00727F59, 0x00778660, 0x007D8C66, 0x005D6F48, 0x00556740, 0x00374922, 0x00546740, 0x003F522B, 0x004A5D36, 0x004B5E37, 0x00364922,
        0x005A6D46, 0x0061744D, 0x00788B64, 0x0074865D, 0x0075875E, 0x0076885F, 0x00778960, 0x0076885F, 0x0075875E, 0x0074865D, 0x0074865D, 0x0073815D, 0x00758760, 0x004C5B3B, 0x00293420, 0x00545B56, 0x004F5653, 0x0022301E, 0x001E3011, 0x00202D17,
        0x001D2C11, 0x002B3A1F, 0x003C4834, 0x004A5349, 0x00343E32, 0x00334226, 0x0055693E, 0x00768A60, 0x005B6A4E, 0x00545E52, 0x00999E9F, 0x00979C9F, 0x00565F55, 0x004A5840, 0x006B7C5A, 0x00667952, 0x00687A55, 0x00657553, 0x00576549, 0x00505D45,
        0x0077806C, 0x00555C4D, 0x001F2619, 0x001C1414, 0x00131817, 0x001C2A29, 0x00333F41, 0x0015191A, 0x001B1716, 0x001A1C16, 0x001A2319, 0x00212520, 0x001D211C, 0x001A1E19, 0x0023251F, 0x001F2317, 0x001F2310, 0x002C3219, 0x002F3718, 0x00262D12,
        0x002D321D, 0x00232519, 0x001B1E15, 0x001E2118, 0x001E2615, 0x004C583C, 0x005B6947, 0x002D3320, 0x001F2611, 0x00232C12, 0x00283117, 0x00252D16, 0x00212716, 0x00191C13, 0x001A1B17, 0x00171E17, 0x00191A16, 0x00191919, 0x00111B1B, 0x003C514F,
        0x00344946, 0x000D1613, 0x001D1914, 0x001B1E15, 0x005E6558, 0x0068715C, 0x00465438, 0x00425233, 0x00485B3A, 0x00445938, 0x003C5131, 0x00485839, 0x004A5A3B, 0x004E5E3F, 0x00505F43, 0x004E5D41, 0x004D5C41, 0x00536247, 0x005B6A4F, 0x0051614A,
        0x0047583D, 0x00455635, 0x004C5E39, 0x00506239, 0x004C5E35, 0x004B5D36, 0x00515F3B, 0x00576640, 0x00586741, 0x00596842, 0x00596842, 0x00576640, 0x00576640, 0x00586741, 0x005A6943, 0x00576640, 0x00576640, 0x0052613B, 0x004F5E38, 0x0054633D,
        0x005B6A44, 0x00596842, 0x0051603A, 0x003B4D26, 0x00455730, 0x0062744D, 0x00354720, 0x0040522B, 0x0064764F, 0x00384A23, 0x0042542D, 0x00596D43, 0x0030441A, 0x00546740, 0x004C5F38, 0x0031431E, 0x00546641, 0x00526341, 0x0030411F, 0x0053643F,
        0x00566849, 0x004B5C3B, 0x00394828, 0x003D5D52, 0x00478095, 0x004A8AA9, 0x005A91A6, 0x004A7889, 0x001A3F37, 0x00334633, 0x00757B76, 0x007A8184, 0x00C5D6D3, 0x00CEDFDC, 0x0097A0A9, 0x0074868D, 0x006F8188, 0x0076888F, 0x0084969D, 0x008EA0A7,
        0x0090A2A9, 0x0085979E, 0x0074868D, 0x00798B94, 0x007B8D96, 0x007F9198, 0x0079898F, 0x00778689, 0x00829193, 0x00B4C1C3, 0x00CCD8D8, 0x00829273, 0x006A7B5A, 0x006D7D5B, 0x00778765, 0x005F6D51, 0xFFA3AB9A, 0xFFFDFFFB, 0xFFFDFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFDFF, 0xFFFEFFF7, 0x0098A284, 0x0065734A, 0x0083906A, 0x007D8965, 0x0049572D, 0x00415121, 0x007A845A, 0x00687248, 0x00596339, 0x004D572D, 0x00646E44,
        0x00697349, 0x00424C22, 0x003E481E, 0x006E7E5C, 0x00455238, 0x00596353, 0x00C0C6C1, 0x00E4E8E9, 0x00DADEDF, 0x00D4D9D7, 0x00D4DAD5, 0x00D7D8DC, 0x00E3E5E6, 0x00C0C4BF, 0x00697063, 0x00747D69, 0x00495539, 0x005D6B49, 0x0053613D, 0x005D6750,
        0x00545E47, 0x00465039, 0x00535E44, 0x005C674D, 0x00566246, 0x005B674B, 0x00566246, 0x00596640, 0x004A5731, 0x0075825C, 0x0073825C, 0x0074835D, 0x0061734C, 0x004E6039, 0x00354720, 0x004F613A, 0x0042542D, 0x00495B34, 0x0052643D, 0x003D4F28,
        0x00566841, 0x00687A53, 0x00758760, 0x0073855C, 0x0074865D, 0x0075875E, 0x0075875E, 0x0075875E, 0x0075875E, 0x0074865D, 0x0072845B, 0x0073815D, 0x007F916A, 0x00455533, 0x001E2A14, 0x005B635C, 0x0059605D, 0x00253222, 0x001A2C0F, 0x0027341E,
        0x00223018, 0x0028351F, 0x00424D3D, 0x00495347, 0x00253020, 0x00233216, 0x006A7E54, 0x0071855B, 0x00687859, 0x00566151, 0x00888F8C, 0x00909794, 0x004C564A, 0x003E4D32, 0x006E805B, 0x006C7F58, 0x00657752, 0x005C6C4A, 0x00576549, 0x006C7961,
        0x00838C78, 0x00676E5F, 0x00333A2D, 0x00211C13, 0x00121912, 0x00152420, 0x002C3838, 0x00131718, 0x001C1719, 0x001A1B19, 0x001B221D, 0x001A1E18, 0x00191D17, 0x00181C17, 0x001D1F19, 0x001A1E13, 0x001D2011, 0x00292E19, 0x002A3017, 0x002B3118,
        0x002C301D, 0x0027281E, 0x001D1E1A, 0x001F201C, 0x00181D14, 0x002B3223, 0x002E3723, 0x001F2318, 0x001C2015, 0x00262A1E, 0x0024281C, 0x001A1E13, 0x00151711, 0x00151614, 0x001C1B1D, 0x00181D1C, 0x001C1C1C, 0x001B1A1C, 0x000E171A, 0x00344947,
        0x002F463E, 0x000C170D, 0x001D1B10, 0x0025291D, 0x007B8372, 0x0088927B, 0x005B6A4B, 0x004D5E3C, 0x004F643E, 0x004F6542, 0x00536946, 0x00526341, 0x00526341, 0x00546543, 0x00556645, 0x00556645, 0x00556546, 0x0059694A, 0x005E6E4F, 0x00637459,
        0x005C6E4F, 0x00576944, 0x0055693F, 0x0056693E, 0x0055683D, 0x0056683F, 0x005C6B45, 0x005B6945, 0x005C6A46, 0x005B6945, 0x005A6844, 0x00596743, 0x00596743, 0x005B6945, 0x005D6B47, 0x00586642, 0x005D6B47, 0x005F6D49, 0x005E6C48, 0x005F6D49,
        0x005E6C48, 0x00566440, 0x004B5935, 0x0042542D, 0x0063754E, 0x00394B24, 0x00485A33, 0x00596B44, 0x003D4F28, 0x0053653E, 0x005D6F48, 0x003B4F25, 0x0045592F, 0x00566942, 0x003B4E27, 0x004A5C37, 0x00536540, 0x002B3C1A, 0x00495A38, 0x00596A45,
        0x00506243, 0x00465736, 0x00425131, 0x004C6C61, 0x004D869B, 0x004A8AA9, 0x005A91A6, 0x00497788, 0x001A3F37, 0x00314431, 0x00747A75, 0x007A8184, 0x00C6D7D4, 0x00CEDFDC, 0x0097A0A9, 0x00778990, 0x006F8188, 0x0073858C, 0x0081939A, 0x008D9FA6,
        0x0091A3AA, 0x008799A0, 0x0076888F, 0x00778992, 0x007C8F96, 0x0084969D, 0x007F8F95, 0x007C8B8E, 0x00919EA0, 0x00BECCCB, 0x00C8D4D4, 0x0079896A, 0x00718261, 0x00748462, 0x007A8A68, 0x00637155, 0xFFA4AC9B, 0xFFF9FDF7, 0xFFFBFDFE, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFDFF, 0xFFFFFFF8, 0x0097A183, 0x0066744B, 0x00808D67, 0x0074805C, 0x00435127, 0x00374717, 0x00434C24, 0x003C451D, 0x00343D15, 0x00363F17, 0x00454E26,
        0x003C451D, 0x002F3810, 0x00434C24, 0x00758465, 0x005D6A50, 0x00596352, 0x00B2BAAF, 0x00EBF2EB, 0x00E2E9E2, 0x00D6DED4, 0x00DDE5DA, 0x00E1E4E2, 0x00F4F8F3, 0x00C4CABF, 0x006A735F, 0x00939E84, 0x00667452, 0x007C8C63, 0x006D7E53, 0x006F7D5B,
        0x0073815F, 0x006C7A56, 0x0072805C, 0x0074835D, 0x00697852, 0x006A7953, 0x006C7C53, 0x0055623C, 0x00606D47, 0x0053603A, 0x005F6E48, 0x0085946E, 0x005A6C45, 0x00586A43, 0x00374922, 0x0050623B, 0x003F512A, 0x004C5E37, 0x004F613A, 0x003C4E27,
        0x00576942, 0x00667851, 0x00768861, 0x0072845B, 0x0073855C, 0x0073855C, 0x0072845B, 0x0073855C, 0x0075875E, 0x0075875E, 0x0073855C, 0x00778561, 0x0073855E, 0x0062734E, 0x0025321A, 0x00636C62, 0x00838A87, 0x002B372B, 0x001D2D16, 0x00202D17,
        0x00323E2A, 0x00121D0D, 0x00606A5D, 0x00535D50, 0x00323E2A, 0x002D3D1E, 0x005A6D46, 0x006A7E53, 0x006C7D5C, 0x0065715D, 0x00A3ACA2, 0x00B6BFB5, 0x00606C5A, 0x00445337, 0x00788A65, 0x00586B44, 0x00475934, 0x00465634, 0x00465438, 0x005E6B53,
        0x006F7864, 0x006C7364, 0x003E4538, 0x00373426, 0x00232B20, 0x001E2F26, 0x00323F3D, 0x001A1E1F, 0x00211C1E, 0x001D1C1E, 0x001E2423, 0x001A2015, 0x001C2118, 0x0021251F, 0x00262723, 0x0023251F, 0x0025261C, 0x00282B1B, 0x00232714, 0x00262B16,
        0x00232617, 0x0026271E, 0x001B1C1A, 0x001D1D1D, 0x00141616, 0x00171A18, 0x00161A15, 0x001C1D1B, 0x00161715, 0x00191A18, 0x00181917, 0x00191919, 0x001D1C1E, 0x0019181C, 0x001B191F, 0x00121617, 0x00161519, 0x001E1D21, 0x00182124, 0x003E5350,
        0x00395147, 0x00202D1F, 0x003B3B2B, 0x002F3425, 0x00616A56, 0x00616D51, 0x00475735, 0x00475934, 0x00455A33, 0x00415931, 0x00455C36, 0x004D6039, 0x004C5F38, 0x004D5F3A, 0x004E603B, 0x004F613C, 0x004F603E, 0x00516240, 0x00536442, 0x004D5F40,
        0x004D613E, 0x004F623B, 0x004E6237, 0x004F6336, 0x00506338, 0x0051633A, 0x0053623C, 0x0052633E, 0x0052633E, 0x0053643F, 0x0051623D, 0x0050613C, 0x0050613C, 0x0051623D, 0x0053643F, 0x0052633E, 0x00556641, 0x00566742, 0x0053643F, 0x0052633E,
        0x0052633E, 0x004F603B, 0x004A5B36, 0x00596B44, 0x003F512A, 0x004A5C35, 0x005D6F48, 0x003C4E27, 0x0040522B, 0x005F714A, 0x00394B24, 0x004C6036, 0x005A6E44, 0x0031441D, 0x004B5E37, 0x00566843, 0x00354722, 0x004F603E, 0x00576846, 0x004F603B,
        0x00455738, 0x00415231, 0x00455434, 0x00507065, 0x004E879C, 0x004989A8, 0x00568DA2, 0x00487687, 0x001B4038, 0x00304330, 0x00737974, 0x007B8285, 0x00C6D7D4, 0x00CDDEDB, 0x0098A1AA, 0x0085979E, 0x007D8F96, 0x007D8F96, 0x0083959C, 0x00899BA2,
        0x008FA1A8, 0x008FA1A8, 0x008799A0, 0x0084979E, 0x0085979E, 0x0090A0A6, 0x0088999C, 0x00758486, 0x008D9B9A, 0x00B5C1C1, 0x00AAB7B5, 0x006F7F60, 0x00738463, 0x00748462, 0x00758563, 0x005F6D51, 0xFFA1A998, 0xFFF9FDF7, 0xFFFDFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFCFF, 0xFFFDFFF6, 0x00909A7C, 0x00647249, 0x00818E68, 0x007A8662, 0x005B693F, 0x00546434, 0x00515A32, 0x004E572F, 0x004B542C, 0x00505931, 0x00515A32,
        0x00454E26, 0x00464F27, 0x00576038, 0x007B8A6B, 0x007D8B6F, 0x006F7C64, 0x00929D89, 0x00A0AA99, 0x00939D8C, 0x0095A08C, 0x00A9B4A0, 0x00959C8D, 0x00939B8A, 0x00818A75, 0x00505B41, 0x007C8969, 0x005D6C46, 0x0078895E, 0x0075865A, 0x0076875C,
        0x00798A5F, 0x0077885D, 0x0077885C, 0x0075865A, 0x0075865A, 0x007A8C5D, 0x00788A5B, 0x006D7A54, 0x0053603A, 0x005B6842, 0x00586741, 0x006A7953, 0x005F714A, 0x00586A43, 0x0033451E, 0x00566841, 0x003C4E27, 0x0053653E, 0x00475932, 0x00394B24,
        0x005A6C45, 0x005B6D46, 0x00778962, 0x0075875E, 0x00778960, 0x0076885F, 0x0073855C, 0x0073855C, 0x0076885F, 0x0076885F, 0x0073855C, 0x007B8967, 0x00708259, 0x004F6138, 0x00324024, 0x00778175, 0x00A5ACA9, 0x00667167, 0x00162412, 0x0023301A,
        0x00162111, 0x003C453B, 0x008F988E, 0x006D7868, 0x004D5B43, 0x002D3E1D, 0x006A7C57, 0x0075895E, 0x006D7F5A, 0x004C5B40, 0x00475341, 0x00455040, 0x003D4A34, 0x00586948, 0x00647750, 0x00475A33, 0x00435530, 0x004B5B39, 0x0048563A, 0x005C6951,
        0x00646D59, 0x00666D5E, 0x00444B3E, 0x003F3C2D, 0x002A3326, 0x00213229, 0x00313F3B, 0x00181C1D, 0x001C1719, 0x00161616, 0x00191F1E, 0x001B2215, 0x00191F14, 0x001E221C, 0x0022231F, 0x0020211D, 0x00262620, 0x0026271D, 0x00222418, 0x001E2014,
        0x001C1D13, 0x0025251F, 0x001A1B19, 0x001D1C1E, 0x00151718, 0x00161819, 0x00161819, 0x001C1C1C, 0x00151416, 0x00151416, 0x00151418, 0x001B1A1E, 0x001D1C20, 0x00151418, 0x00151416, 0x00191D1E, 0x00161517, 0x001D1C20, 0x001B2525, 0x003B514C,
        0x002F473B, 0x001C2919, 0x0040402E, 0x00383D2E, 0x00515A46, 0x004F5B3F, 0x00465634, 0x00495B36, 0x00465B34, 0x00445C34, 0x00475E38, 0x00495C35, 0x00495C35, 0x00485B34, 0x00495B36, 0x004A5C37, 0x004C5E39, 0x004D5E3C, 0x004C5D3B, 0x00495C3B,
        0x004D613E, 0x0051643D, 0x0051653A, 0x00516439, 0x0051633A, 0x0050613C, 0x00505E3C, 0x00556543, 0x00566644, 0x00576745, 0x00576745, 0x00566644, 0x00546442, 0x00546442, 0x00556543, 0x00576745, 0x00586846, 0x00566644, 0x00526240, 0x0051613F,
        0x00546442, 0x00576745, 0x00596947, 0x0050623B, 0x00394B24, 0x005D6F48, 0x003E5029, 0x0043552E, 0x0062744D, 0x0034461F, 0x0043552E, 0x0054683E, 0x00384C22, 0x0052653E, 0x004E613A, 0x00364823, 0x004A5C37, 0x00566745, 0x00546543, 0x00697A55,
        0x005F7152, 0x00556645, 0x004C5B3B, 0x004C6C61, 0x004C859A, 0x004A8AA9, 0x00548BA0, 0x00497788, 0x001C4139, 0x00304330, 0x00727873, 0x007D8487, 0x00C7D8D5, 0x00CCDDDA, 0x0097A0A9, 0x008A9CA3, 0x0086989F, 0x008799A0, 0x008799A0, 0x0084969D,
        0x00889AA1, 0x008FA1A8, 0x0090A2A9, 0x0091A3AA, 0x00879A9F, 0x0093A3A9, 0x008F9EA1, 0x006F7C7E, 0x008B9797, 0x00B4C1BF, 0x00A0ABA9, 0x006A7A5B, 0x00748564, 0x00738361, 0x00738361, 0x005F6D51, 0xFFA2AA99, 0xFFFCFFFA, 0xFFFDFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFCFF, 0xFFFDFFF6, 0x008C9678, 0x0065734A, 0x0083906A, 0x0085916D, 0x007A885E, 0x007C8C5C, 0x00829067, 0x007D8B62, 0x0079875E, 0x007A885F, 0x007D8B62,
        0x007E8C63, 0x007D8B62, 0x0077855C, 0x00707F5F, 0x00758464, 0x006E7D5D, 0x00788768, 0x006C7B5C, 0x006B7A5B, 0x00758465, 0x007A896A, 0x00788466, 0x00687456, 0x007B8868, 0x00687654, 0x006C7B55, 0x00697950, 0x0085966B, 0x0074855A, 0x0076875C,
        0x0075865B, 0x00798A5E, 0x007C8D61, 0x00768859, 0x00738556, 0x00768859, 0x00768958, 0x007B8862, 0x00707D57, 0x0057643E, 0x005B6A44, 0x0051603A, 0x0041532C, 0x0062744D, 0x00354720, 0x004C5B35, 0x004E5D37, 0x00495832, 0x0052613B, 0x004C5B35,
        0x004D5C36, 0x00606F49, 0x0064734D, 0x0074865D, 0x007A8C63, 0x007B8D64, 0x00778960, 0x0075875E, 0x00778960, 0x00778960, 0x0073855C, 0x0072805E, 0x008A9C73, 0x005D7045, 0x00314020, 0x006B7568, 0x00A4ABA8, 0x00AAB4AE, 0x008A968A, 0x0066735D,
        0x00717B6E, 0x00A6ADAA, 0x00A1A8A3, 0x00919C8C, 0x00657458, 0x00415230, 0x0070815F, 0x006C8154, 0x0070835C, 0x00485839, 0x002B3921, 0x002A3721, 0x002F3E22, 0x00495A38, 0x00475A33, 0x00475A33, 0x004C5E39, 0x004D5D3B, 0x00475539, 0x006B7860,
        0x00737C68, 0x00545B4C, 0x002A3124, 0x002F2B20, 0x001F271C, 0x001A2A23, 0x002E3C38, 0x00171C1B, 0x001B1716, 0x00181915, 0x00222A23, 0x002E3526, 0x0020271A, 0x001B1F19, 0x00181917, 0x00161616, 0x001F1D1C, 0x0021201C, 0x0022221C, 0x0021201C,
        0x00201F1B, 0x00272622, 0x001C1D1B, 0x001E1E1E, 0x00151717, 0x00181A1A, 0x00191B1C, 0x001C1D1B, 0x001B1B1B, 0x001D1C1E, 0x0019181C, 0x0018171B, 0x0019181A, 0x001C1D1B, 0x002C2D29, 0x00202621, 0x00131412, 0x00161616, 0x0016211F, 0x00354B46,
        0x00284036, 0x00172416, 0x003D3C2E, 0x002F3327, 0x00555D4C, 0x005E6851, 0x004F5E3F, 0x00485937, 0x00475C36, 0x004C623F, 0x004E6441, 0x0051643D, 0x0052643F, 0x0051633E, 0x0051633E, 0x00536442, 0x00566745, 0x00556645, 0x00536443, 0x00546647,
        0x00566948, 0x00586A45, 0x00586B44, 0x00596B44, 0x00596A45, 0x00586747, 0x005A664A, 0x00576745, 0x00596947, 0x005A6A48, 0x005A6A48, 0x00586846, 0x00576745, 0x00566644, 0x00566644, 0x00576745, 0x005A6A48, 0x005C6C4A, 0x005B6B49, 0x00596947,
        0x00576745, 0x00556543, 0x00536341, 0x0053653E, 0x0064764F, 0x003B4D26, 0x0044562F, 0x005F714A, 0x0043552E, 0x00455730, 0x005D6F48, 0x00364A20, 0x00495D33, 0x005D7049, 0x00394C25, 0x00445631, 0x005C6E49, 0x00465735, 0x006C7D5B, 0x006C7D58,
        0x00667859, 0x005C6D4C, 0x00495838, 0x00446459, 0x004B8499, 0x004E8EAD, 0x00558CA1, 0x004B798A, 0x001F443C, 0x00314431, 0x00727873, 0x007E8588, 0x00C8D9D6, 0x00CBDCD9, 0x0097A0A9, 0x0086989F, 0x0086989F, 0x008B9DA4, 0x008D9FA6, 0x00899BA2,
        0x00899BA2, 0x008D9FA6, 0x008B9DA4, 0x008EA1A6, 0x0084949A, 0x008B9C9F, 0x008C9B9D, 0x006F7D7C, 0x008D9999, 0x00B7C2C0, 0x00A7B2B0, 0x006D7D5E, 0x00788968, 0x00768664, 0x00788866, 0x00616F53, 0xFFA1A998, 0xFFFBFFF9, 0xFFFAFCFD, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFDFF, 0xFFFFFFF8, 0x008E987A, 0x0065734A, 0x007C8963, 0x007B8763, 0x0078865C, 0x007D8D5D, 0x0073855E, 0x007A8C65, 0x007F916A, 0x00788A63, 0x0073855E,
        0x0074865F, 0x00778962, 0x00798B64, 0x007D8D6B, 0x00798A65, 0x00768861, 0x00809269, 0x007C8F64, 0x0084976C, 0x0081936A, 0x00798B62, 0x007A8B5F, 0x008A9B6F, 0x0088996E, 0x00798A5F, 0x007B8B62, 0x007C8C63, 0x0073825C, 0x0075845E, 0x007D8D64,
        0x00798960, 0x0077885D, 0x0076875C, 0x00748559, 0x00708155, 0x00718256, 0x00788A5B, 0x0074815B, 0x00818E68, 0x006B7852, 0x004C5B35, 0x00576640, 0x0054663F, 0x003A4C25, 0x005B6D46, 0x0045542E, 0x0055643E, 0x0046552F, 0x0056653F, 0x00576640,
        0x00485731, 0x00596842, 0x0055643E, 0x0066784F, 0x0071835A, 0x00788A61, 0x0076885F, 0x0075875E, 0x00788A61, 0x00778960, 0x0074865D, 0x00758361, 0x006F8158, 0x0074885B, 0x00344422, 0x005F6A5A, 0x00A7AEAB, 0x00868F8C, 0x00828D85, 0x0097A48E,
        0x0098A197, 0x0084898A, 0x00A2A9A6, 0x009CA896, 0x00354625, 0x00556644, 0x007A8B6A, 0x00718659, 0x00697D53, 0x00566745, 0x00667559, 0x006C7B5F, 0x00364627, 0x00374924, 0x0050633C, 0x0042552E, 0x0042542F, 0x00425230, 0x00455337, 0x0078856D,
        0x0099A28E, 0x00686F60, 0x002C3326, 0x00231D18, 0x00191F1A, 0x001B2A26, 0x00323F3D, 0x001D2220, 0x00221F1A, 0x0022261B, 0x00313B2E, 0x00454D3C, 0x002D3427, 0x0022271E, 0x001C1D1B, 0x00181719, 0x001D1A1C, 0x001B1919, 0x001D1B1A, 0x001D1A1C,
        0x001D1A1C, 0x00201E1D, 0x001A1B17, 0x001F201C, 0x00171B16, 0x001E221D, 0x001C201B, 0x00171A11, 0x00181915, 0x001D1D1D, 0x0019181A, 0x00181719, 0x001C1D19, 0x002B2E25, 0x004B4F43, 0x00323A2F, 0x001E2118, 0x001B1C18, 0x001A2522, 0x003B514C,
        0x002E453D, 0x00121D15, 0x002C2A20, 0x002F3229, 0x005E6558, 0x00616A55, 0x0049573B, 0x004B5B3C, 0x00506342, 0x004D6241, 0x00465B3B, 0x0050613F, 0x00526341, 0x00526341, 0x00516241, 0x00526342, 0x00566647, 0x00556546, 0x00526243, 0x00536548,
        0x00516344, 0x00536443, 0x00556644, 0x00576745, 0x00576647, 0x0058654B, 0x005C6550, 0x00556644, 0x00566745, 0x00576846, 0x00566745, 0x00546543, 0x00536442, 0x00536442, 0x00546543, 0x00546543, 0x00556644, 0x00566745, 0x00566745, 0x00566745,
        0x00566745, 0x00576846, 0x00586947, 0x005F714A, 0x005B6D46, 0x004B5D36, 0x00596B44, 0x0040522B, 0x003B4D26, 0x0061734C, 0x00384A23, 0x004C6036, 0x0061754B, 0x0033461F, 0x00465932, 0x00566843, 0x004B5D38, 0x00748563, 0x006B7C5A, 0x006D7E59,
        0x00697B5C, 0x005F704F, 0x004B5A3A, 0x0045655A, 0x004E879C, 0x005191B0, 0x00548BA0, 0x004D7B8C, 0x0021463E, 0x00324532, 0x00727873, 0x007F8689, 0x00C8D9D6, 0x00CADBD8, 0x00969FA8, 0x007F9198, 0x007C8E95, 0x0083959C, 0x008D9FA6, 0x0090A2A9,
        0x0090A2A9, 0x008B9DA4, 0x00809299, 0x00839399, 0x00809096, 0x00829194, 0x00859294, 0x006F7B7B, 0x00828D8B, 0x009DA8A6, 0x009BA4A1, 0x0069795A, 0x00708160, 0x006E7E5C, 0x00748462, 0x005E6C50, 0xFF9EA695, 0xFFFCFFFA, 0xFFF8FAFB, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBF9FF, 0xFFFFFFF8, 0x00909A7C, 0x006A784F, 0x00808D67, 0x007B8763, 0x007B895F, 0x007F8F5F, 0x00788B64, 0x00788B64, 0x00798C65, 0x00798C65, 0x007C8F68,
        0x00798C65, 0x00758861, 0x007F926B, 0x00768762, 0x007A8C63, 0x00728659, 0x00728657, 0x006F8453, 0x006E8352, 0x00617546, 0x006A7E4F, 0x00677B46, 0x00617540, 0x00627544, 0x007D8F60, 0x006F8055, 0x00798862, 0x00778561, 0x007A8866, 0x00778660,
        0x00798862, 0x0074835D, 0x00718158, 0x00798960, 0x00798A5F, 0x00728358, 0x0077885D, 0x007D8A64, 0x0074815B, 0x007E8B65, 0x0074835D, 0x0054633D, 0x00576942, 0x0044562F, 0x004B5D36, 0x0056653F, 0x0042512B, 0x005C6B45, 0x0043522C, 0x00495832,
        0x005D6C46, 0x003D4C26, 0x00606F49, 0x0054663D, 0x0063754C, 0x00708259, 0x0073855C, 0x0074865D, 0x00778960, 0x00788A61, 0x0074865D, 0x00768462, 0x00798B62, 0x007D9164, 0x005A6A48, 0x00313D2B, 0x005B625F, 0x00A7AFAE, 0x0086908A, 0x00818E78,
        0x008D968C, 0x00ABB0B3, 0x008B9190, 0x003C4836, 0x00425332, 0x0071835E, 0x00758665, 0x006D8255, 0x0071855B, 0x00738560, 0x00708160, 0x005E6E4F, 0x00495A39, 0x00586A45, 0x0041552B, 0x004F623B, 0x00455732, 0x004A5A38, 0x0049573B, 0x0066735B,
        0x00969F8B, 0x00697061, 0x0021281B, 0x001C1414, 0x00151A18, 0x00182624, 0x002F3C3A, 0x00171D18, 0x0017150D, 0x00171C0D, 0x00293521, 0x002F3824, 0x00181F10, 0x00141910, 0x00171816, 0x0019181A, 0x001F1B20, 0x00191618, 0x001B1919, 0x001E1A20,
        0x001D191E, 0x001C1A1A, 0x00171814, 0x001E2118, 0x0013180F, 0x001A1F16, 0x0013180F, 0x001C2014, 0x001A1D14, 0x001D1E1A, 0x001B1B1B, 0x001A1B19, 0x00191C13, 0x00212617, 0x003E4431, 0x00273121, 0x0014180C, 0x0012140E, 0x00141F1C, 0x003C514E,
        0x00324843, 0x000E1812, 0x00191510, 0x002A2C26, 0x00696F64, 0x006A7261, 0x0048553D, 0x00465539, 0x00485A3B, 0x00465A3D, 0x004B5F42, 0x004C5D3C, 0x004E5F3E, 0x004F603F, 0x004E5E3F, 0x004F5F40, 0x00536246, 0x00526145, 0x004F5E42, 0x00506146,
        0x004D5F42, 0x004F5F40, 0x00536443, 0x00566546, 0x00546147, 0x00535F49, 0x0057604C, 0x00546544, 0x00546544, 0x00536443, 0x00526342, 0x00506140, 0x004F603F, 0x00506140, 0x00526342, 0x00546544, 0x00546544, 0x00546544, 0x00556645, 0x00546544,
        0x00536443, 0x00536443, 0x00546544, 0x0053653E, 0x0054663F, 0x00596B44, 0x003C4E27, 0x00485A33, 0x005A6C45, 0x003C4E27, 0x00475932, 0x0063774D, 0x002A3E14, 0x0052653E, 0x00586B44, 0x00394B26, 0x00546641, 0x00617250, 0x00596A48, 0x00596A45,
        0x00526445, 0x00495A39, 0x00394828, 0x0039594E, 0x00488196, 0x004F8FAE, 0x00548BA0, 0x004E7C8D, 0x00234840, 0x00324532, 0x00727873, 0x0080878A, 0x00C9DAD7, 0x00CADBD8, 0x00969FA8, 0x00778990, 0x00708289, 0x0074868D, 0x0083959C, 0x0090A2A9,
        0x0093A5AC, 0x008799A0, 0x0074868D, 0x0076868C, 0x007F9093, 0x007E8D90, 0x00869395, 0x007A8686, 0x00838E8C, 0x008F9A97, 0x0097A09D, 0x00748465, 0x00758665, 0x0070805E, 0x00778765, 0x005F6D51, 0xFFA1A998, 0xFFFDFFFB, 0xFFFDFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFCFF, 0xFFFFFFF7, 0x008E9979, 0x00637147, 0x007D8B62, 0x00818E68, 0x005C6B3F, 0x005B6C39, 0x005E6A40, 0x00626E44, 0x00636F45, 0x00616D43, 0x005D693F,
        0x005D693F, 0x00606C42, 0x00626E44, 0x006F7F5D, 0x004A593A, 0x0048553D, 0x005C6753, 0x0049553F, 0x00354327, 0x0032431E, 0x0036491E, 0x002B3820, 0x00313E24, 0x0039472B, 0x003A4727, 0x00475531, 0x0053603A, 0x0078865D, 0x007E8C62, 0x00768C5C,
        0x0074895C, 0x00708558, 0x007A8E61, 0x00778A5F, 0x006E7F54, 0x0076865D, 0x0077875E, 0x0075855C, 0x0078885F, 0x00708057, 0x007A8A61, 0x006B7B52, 0x0056663D, 0x005A6A41, 0x0047572E, 0x0051603A, 0x0055643E, 0x00404F29, 0x005E6D47, 0x00475630,
        0x004C5B35, 0x005D6C46, 0x003C4B25, 0x0066754F, 0x004A5933, 0x0064734D, 0x007F8E68, 0x0073825C, 0x007A8963, 0x0072815B, 0x00788761, 0x007A8B60, 0x0074845B, 0x007B8B62, 0x007C8C63, 0x005A6943, 0x0034431D, 0x0042502C, 0x006D7B57, 0x00778464,
        0x00748161, 0x0053613F, 0x00354321, 0x00465430, 0x006E7C58, 0x007C8A66, 0x0075835F, 0x00708057, 0x0073835A, 0x00798960, 0x00607047, 0x00495930, 0x005E6E45, 0x004A5A31, 0x0054643B, 0x0045542E, 0x00495733, 0x00495735, 0x004C583A, 0x005D684E,
        0x00727B66, 0x006D7564, 0x00343C2B, 0x00111614, 0x001A1F1E, 0x0025292A, 0x002E3135, 0x00141819, 0x001A1F1D, 0x00111811, 0x00171F14, 0x00181917, 0x00191A18, 0x001A1B19, 0x001A1B19, 0x00191A18, 0x00191A18, 0x00191A18, 0x00191A18, 0x00181818,
        0x00191919, 0x00191919, 0x001A1A1A, 0x001A1A1A, 0x00191919, 0x00181818, 0x00181818, 0x001A1B17, 0x001B1C18, 0x001C1D1B, 0x001B1C1A, 0x001A1A1A, 0x0019181A, 0x0019181A, 0x0019181A, 0x001A1817, 0x00141414, 0x0015161A, 0x0014171C, 0x0032393C,
        0x002F3939, 0x0015231F, 0x00091912, 0x001F251A, 0x00686F60, 0x007C8570, 0x005A684C, 0x00526141, 0x00576745, 0x00516240, 0x00516241, 0x00576745, 0x00556543, 0x00546442, 0x005B6B49, 0x005F6F4D, 0x005E6E4C, 0x005F6F4D, 0x005E6E4C, 0x005B6C47,
        0x005B6C47, 0x005A6B46, 0x00596A45, 0x00596A45, 0x00586944, 0x00576843, 0x00576843, 0x00576944, 0x00576944, 0x00576944, 0x00576944, 0x00576944, 0x00576944, 0x00576944, 0x00576944, 0x00596A45, 0x00596A45, 0x00596A45, 0x00586944, 0x00586944,
        0x00586944, 0x00586944, 0x00576843, 0x005B6D48, 0x00556742, 0x005A6C47, 0x005F714C, 0x0051633E, 0x003E502B, 0x00475934, 0x0060724D, 0x0031431E, 0x00536540, 0x00566843, 0x003B4D28, 0x00485A35, 0x005C6E49, 0x00546641, 0x00556742, 0x00566343,
        0x004B5D40, 0x00455435, 0x00485436, 0x0057746B, 0x004C8299, 0x00508DAF, 0x00558BA2, 0x00497789, 0x001D423A, 0x002F4130, 0x00717772, 0x0080868B, 0x00CBDBDA, 0x00CCDCDB, 0x00949DA7, 0x0074868D, 0x006F8188, 0x006D7F86, 0x007A8C93, 0x008A9CA3,
        0x008EA0A7, 0x0086989F, 0x007A8C93, 0x00798C93, 0x0075888F, 0x00809398, 0x00809096, 0x0079888B, 0x00879397, 0x00A6B3B5, 0x00C9D5D7, 0x007E8A78, 0x006C7A62, 0x00798868, 0x00778863, 0x005F6E4E, 0xFF9EA792, 0xFFFCFFFA, 0xFFFDFEFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFF9F7FD, 0xFFFFFFF7, 0x008E9979, 0x0067754B, 0x00818F66, 0x0078855F, 0x00435226, 0x003C4D1A, 0x0039451B, 0x003C481E, 0x002B370D, 0x00313D13, 0x00414D23,
        0x00354117, 0x00323E14, 0x00414D23, 0x006E7C60, 0x0054604A, 0x00596255, 0x00929992, 0x00A7AEA7, 0x00A7AFA4, 0x00A4AF9B, 0x00AAB79F, 0x00A7B1A0, 0x00B0BBA7, 0x008C9882, 0x00465137, 0x004C583A, 0x00505B3B, 0x007B8763, 0x0078855F, 0x0075895E,
        0x007A8E63, 0x00778B60, 0x00788B60, 0x00798D60, 0x007A8B5F, 0x007B8C60, 0x0078895D, 0x0075855C, 0x0077875E, 0x0073835A, 0x007B8B62, 0x00798960, 0x005F6F46, 0x0056663D, 0x00607047, 0x0041502A, 0x004F5E38, 0x0061704A, 0x003A4923, 0x0063724C,
        0x0045542E, 0x004F5E38, 0x0062714B, 0x00374620, 0x00687751, 0x0054633D, 0x0064734D, 0x0086956F, 0x006D7C56, 0x007E8D67, 0x00778660, 0x0078895E, 0x00728259, 0x00728259, 0x007A8A61, 0x00778660, 0x0061704A, 0x00465430, 0x00364420, 0x00293616,
        0x00384525, 0x00485634, 0x005C6A48, 0x00768460, 0x0083916D, 0x007E8C68, 0x00778660, 0x0078885F, 0x006E7E55, 0x006A7A51, 0x004D5D34, 0x005E6E45, 0x0045552C, 0x00596940, 0x0046562D, 0x0053623C, 0x0053623C, 0x00495735, 0x005F6C4C, 0x00515D41,
        0x006B755E, 0x006F7864, 0x00212A16, 0x00151A18, 0x000E1312, 0x00292D2E, 0x003C3F43, 0x000E1115, 0x00121716, 0x00171D18, 0x00161E14, 0x00171A18, 0x00181B19, 0x00181B19, 0x00181B19, 0x00171A18, 0x00171A18, 0x00181B19, 0x00181B19, 0x00181A1A,
        0x00181A1A, 0x00181A1A, 0x00181A1A, 0x00171919, 0x00171919, 0x00171919, 0x00171919, 0x00161917, 0x00171A18, 0x00181A1A, 0x00181A1A, 0x0017191A, 0x0017191A, 0x0018191D, 0x00191A1E, 0x00171919, 0x00181C1D, 0x0015181C, 0x00212429, 0x0051555A,
        0x00384040, 0x000B1411, 0x00131E16, 0x00252C1F, 0x00697160, 0x0078826B, 0x00526142, 0x00485836, 0x004F5F3D, 0x004C5D3B, 0x004C5D3C, 0x004E5E3C, 0x00465634, 0x004E5E3C, 0x00566644, 0x004D5D3B, 0x004D5D3B, 0x00546442, 0x004D5D3B, 0x00546540,
        0x00546540, 0x0053643F, 0x0053643F, 0x0052633E, 0x0051623D, 0x0051623D, 0x0051623D, 0x0051633E, 0x0051633E, 0x0051633E, 0x0051633E, 0x0051633E, 0x0051633E, 0x0051633E, 0x0051633E, 0x00556641, 0x00556641, 0x00556641, 0x00546540, 0x00546540,
        0x00546540, 0x00546540, 0x00546540, 0x0050623D, 0x00566843, 0x00566843, 0x0052643F, 0x00536540, 0x00556742, 0x004B5D38, 0x003A4C27, 0x004C5E39, 0x00586A45, 0x003C4E29, 0x00485A35, 0x005E704B, 0x004D5F3A, 0x004E603B, 0x00546641, 0x0053613F,
        0x004A5C3F, 0x00475637, 0x00465234, 0x00516E65, 0x004B8198, 0x00528FB1, 0x00558BA2, 0x004D7B8D, 0x001F443C, 0x002F4130, 0x00707671, 0x0080868B, 0x00CADAD9, 0x00CBDBDA, 0x00959EA8, 0x0085979E, 0x0083959C, 0x0082949B, 0x008799A0, 0x008C9EA5,
        0x008EA0A7, 0x008B9DA4, 0x008799A0, 0x0080939A, 0x007A8D94, 0x0082959A, 0x007F8F95, 0x00768588, 0x00849094, 0x00A7B4B6, 0x00CEDADC, 0x0099A593, 0x006F7D65, 0x00707F5F, 0x00748560, 0x00606F4F, 0xFF9FA893, 0xFFF9FDF7, 0xFFFBFCFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFCFF, 0xFFFFFFF7, 0x008C9777, 0x0066744A, 0x0085936A, 0x0077845E, 0x003E4D21, 0x003D4E1B, 0x006B774D, 0x005F6B41, 0x00434F25, 0x004B572D, 0x005A663C,
        0x00424E24, 0x003A461C, 0x004C582E, 0x006B7761, 0x005D6757, 0x00686E69, 0x00BFC2C6, 0x00E9EBF3, 0x00EFF2F7, 0x00E5E9EA, 0x00EAEFED, 0x00E9F0E9, 0x00F1F8F1, 0x00AEB6AB, 0x00454C3D, 0x00545D49, 0x00515942, 0x006E775C, 0x00656F51, 0x00566647,
        0x004C5C3D, 0x00485737, 0x004C5D38, 0x0056653F, 0x00516237, 0x004E5F33, 0x00607041, 0x007B8B62, 0x0077875E, 0x0074845B, 0x00718158, 0x007D8D64, 0x007A8A61, 0x005D6D44, 0x0054643B, 0x005F6E48, 0x00404F29, 0x004A5933, 0x005C6B45, 0x0035441E,
        0x00687751, 0x0042512B, 0x004B5A34, 0x00606F49, 0x00374620, 0x0062714B, 0x0055643E, 0x0061704A, 0x007F8E68, 0x0076855F, 0x006E7D57, 0x00738459, 0x00798960, 0x007B8B62, 0x007A8A61, 0x007D8C66, 0x0082916B, 0x007C8A66, 0x0072805C, 0x00758361,
        0x00788664, 0x007C8A68, 0x0083916D, 0x0084926E, 0x007A8864, 0x0071805A, 0x0073825C, 0x007D8D64, 0x006B7B52, 0x0057673E, 0x00627249, 0x0048582F, 0x00697950, 0x0043532A, 0x0057673E, 0x0048582F, 0x004C5B35, 0x00586642, 0x00435030, 0x005E6A4C,
        0x00636E54, 0x004E5841, 0x00242E17, 0x00151B16, 0x00161B19, 0x001A1E1F, 0x001C1F23, 0x000C0F13, 0x001E2223, 0x00161B1A, 0x000F1510, 0x0014191A, 0x0014191A, 0x0014191A, 0x0014191A, 0x0014191A, 0x0014191A, 0x0014191A, 0x0014191A, 0x00121718,
        0x00111617, 0x00111617, 0x00101516, 0x00101516, 0x00101516, 0x00101516, 0x000F1415, 0x00111617, 0x00121718, 0x00131819, 0x00121718, 0x00111617, 0x00111617, 0x0012171A, 0x0013181B, 0x000A1212, 0x0012191C, 0x0014181D, 0x000C1015, 0x001C1F24,
        0x001C2021, 0x00151914, 0x00191D17, 0x00242C1B, 0x005F6854, 0x006F7A60, 0x00516040, 0x00485934, 0x004D5E39, 0x00485937, 0x00475836, 0x00495A35, 0x00546540, 0x0052633E, 0x004A5B36, 0x00546540, 0x0050613C, 0x00475833, 0x005E6F4A, 0x00576843,
        0x00566742, 0x00566742, 0x00566742, 0x00556641, 0x00546540, 0x00546540, 0x00546540, 0x00546641, 0x00546641, 0x00546641, 0x00546641, 0x00546641, 0x00546641, 0x00546641, 0x00546641, 0x00546540, 0x00546540, 0x00546540, 0x0053643F, 0x0053643F,
        0x0053643F, 0x0053643F, 0x0053643F, 0x0052643F, 0x0052643F, 0x0051633E, 0x0051633E, 0x00546641, 0x00536540, 0x004A5C37, 0x003F512C, 0x00556742, 0x00374924, 0x004C5E39, 0x00536540, 0x0051633E, 0x00697B56, 0x006F815C, 0x00738560, 0x00707E5C,
        0x00627457, 0x00596848, 0x00475434, 0x0047645B, 0x00457B92, 0x00518EAE, 0x005389A0, 0x00507E90, 0x0021463E, 0x002E402F, 0x006F7570, 0x0080868B, 0x00C9D9D8, 0x00CADAD9, 0x00969FA9, 0x008B9DA4, 0x008B9DA4, 0x008A9CA3, 0x0086989F, 0x0085979E,
        0x00889AA1, 0x008C9EA5, 0x0090A2A9, 0x00889BA2, 0x007F9299, 0x0085989D, 0x007F8F95, 0x00738285, 0x00808C90, 0x00A6B3B5, 0x00D1DDDF, 0x00DBE7D5, 0x008C9A82, 0x00778666, 0x00768762, 0x00606F4F, 0xFFA0A994, 0xFFFCFFFA, 0xFFFDFEFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFDFF, 0xFFFFFFF7, 0x008A9575, 0x00647248, 0x0087956C, 0x00798660, 0x00455428, 0x004E5F2C, 0x006E7A50, 0x005C683E, 0x005C683E, 0x00647046, 0x005E6A40,
        0x00445026, 0x00364218, 0x0049552B, 0x006D7B5F, 0x0066715D, 0x00777E77, 0x00CED1D5, 0x00E8E9F3, 0x00E3E3EF, 0x00D3D5DD, 0x00D2D5DA, 0x00E5E8EC, 0x00EBEFF0, 0x00B1B6B4, 0x005B5F59, 0x005E6558, 0x00484E3D, 0x00414833, 0x00434B34, 0x00555D52,
        0x00454E41, 0x003B4535, 0x003A432E, 0x00455036, 0x00424C2E, 0x00374221, 0x004A5632, 0x00738459, 0x00728358, 0x007A8B60, 0x0074855A, 0x00718257, 0x007C8D62, 0x0076875C, 0x0065764B, 0x0053623C, 0x005C6B45, 0x003A4923, 0x0051603A, 0x005C6B45,
        0x0036451F, 0x0066754F, 0x003F4E28, 0x004F5E38, 0x00596842, 0x003B4A24, 0x0062714B, 0x004C5B35, 0x006D7C56, 0x0076855F, 0x007D8C66, 0x0077885D, 0x0078885F, 0x0076865D, 0x00728259, 0x0072815B, 0x00778660, 0x007C8A66, 0x007E8C68, 0x00849270,
        0x00859371, 0x00808E6A, 0x00798763, 0x00768460, 0x00788761, 0x007B8A64, 0x007E8D67, 0x006B7950, 0x005C6A41, 0x005B6940, 0x004E5C33, 0x00647249, 0x0048562D, 0x005E6C43, 0x0055633A, 0x004E5E35, 0x00596842, 0x0041502A, 0x005C6A48, 0x004C5939,
        0x00626E50, 0x00707C60, 0x004C583C, 0x0011190E, 0x00161D16, 0x00111614, 0x00111516, 0x0013161A, 0x00292C30, 0x00262A2B, 0x002D3231, 0x00272F2F, 0x00272F2F, 0x00272F2F, 0x00283030, 0x00293131, 0x00283030, 0x00272F2F, 0x00262E2E, 0x002A3232,
        0x002B3333, 0x002B3333, 0x002B3333, 0x002B3333, 0x00293131, 0x00283030, 0x00283030, 0x002B3235, 0x002B3235, 0x002B3333, 0x002A3232, 0x00283030, 0x00283030, 0x00293131, 0x002A3231, 0x00232F2F, 0x00283134, 0x00252C2F, 0x0015191E, 0x00151718,
        0x00212220, 0x0022231A, 0x0018170D, 0x003A432E, 0x00626D53, 0x00707C5E, 0x0063744F, 0x0064764F, 0x006A7C55, 0x00677954, 0x00687957, 0x00677551, 0x0072805C, 0x00616F4B, 0x00717F5B, 0x005B6945, 0x0043512D, 0x0063714D, 0x004F5D39, 0x005A6B46,
        0x005A6B46, 0x005A6B46, 0x00596A45, 0x00596A45, 0x00596A45, 0x00586944, 0x00586944, 0x00586A45, 0x00586A45, 0x00586A45, 0x00586A45, 0x00586A45, 0x00586A45, 0x00586A45, 0x00586A45, 0x005B6C47, 0x005B6C47, 0x005A6B46, 0x005A6B46, 0x005A6B46,
        0x005A6B46, 0x00596A45, 0x00596A45, 0x005C6E49, 0x00566843, 0x00566843, 0x005C6E49, 0x005A6C47, 0x00536540, 0x00546641, 0x005D6F4A, 0x002C3E19, 0x004B5D38, 0x004E603B, 0x00576944, 0x006D7F5A, 0x0070825D, 0x006E805B, 0x006B7D58, 0x00707E5C,
        0x00687A5B, 0x00667555, 0x00515E3E, 0x004C6A5F, 0x004C8398, 0x005491B1, 0x0052899E, 0x004E7C8E, 0x001F443C, 0x002B3D2C, 0x006D736E, 0x0080868B, 0x00C9D9D8, 0x00C9D9D8, 0x0097A0AA, 0x00889AA1, 0x00889AA1, 0x008B9DA4, 0x00889AA1, 0x00899BA2,
        0x008C9EA5, 0x00889AA1, 0x008799A0, 0x00889BA2, 0x007F9299, 0x0085989D, 0x00809096, 0x00728184, 0x007C888C, 0x00A2AFB1, 0x00D1DDDF, 0x00DCE8D6, 0x0084927A, 0x00748363, 0x00788964, 0x00627151, 0xFFA4AD98, 0xFFFDFFFB, 0xFFFDFEFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFBFF, 0xFFFFFFF7, 0x008C9777, 0x0067754B, 0x0087956C, 0x0075825C, 0x00415024, 0x004D5E2B, 0x00525E34, 0x004A562C, 0x00647046, 0x006B774D, 0x0069754B,
        0x0058643A, 0x0038441A, 0x004D592F, 0x00778863, 0x00707E62, 0x008C9686, 0x00D1D6D4, 0x00DBDEE2, 0x00D1D4D9, 0x00CACDD1, 0x00C4C8C9, 0x00CDCED8, 0x00DDDFE7, 0x00BFC2C6, 0x00909391, 0x0083887F, 0x00696E5F, 0x00585F4A, 0x00767E67, 0x008F9296,
        0x00767A7B, 0x00585B59, 0x004F534D, 0x00787C70, 0x00909685, 0x006C735E, 0x0050563F, 0x007D8E63, 0x0078895E, 0x0076875C, 0x007A8B60, 0x00738459, 0x00738459, 0x007F9065, 0x007D8E63, 0x0066754F, 0x0052613B, 0x0064734D, 0x003E4D27, 0x00586741,
        0x005A6943, 0x003D4C26, 0x005F6E48, 0x0041502A, 0x0056653F, 0x00576640, 0x003A4923, 0x00697852, 0x0053623C, 0x0072815B, 0x006F7E58, 0x0077885D, 0x0077875E, 0x0077875E, 0x0078885F, 0x00798862, 0x00778660, 0x00778561, 0x00778561, 0x00768460,
        0x007A8864, 0x007B8965, 0x00788662, 0x0076855F, 0x00788761, 0x0075855C, 0x006E7E55, 0x0058663D, 0x005E6C43, 0x00505E35, 0x005F6D44, 0x0056643B, 0x0057653C, 0x0058663D, 0x0058663D, 0x005D6D44, 0x0043532A, 0x005E6D47, 0x0054633D, 0x00677551,
        0x0072805E, 0x007C8A68, 0x00727F5F, 0x004A5541, 0x00182212, 0x000D150B, 0x001D2220, 0x00141819, 0x001C2021, 0x001D2122, 0x001A1F1E, 0x00151D1C, 0x00161E1D, 0x00171F1E, 0x00192120, 0x001A2221, 0x00192120, 0x00161E1D, 0x00131B1A, 0x00192120,
        0x001A2221, 0x001C2423, 0x001D2524, 0x001D2524, 0x001B2322, 0x00192120, 0x00171F1E, 0x00161E1E, 0x00161E1E, 0x00161E1E, 0x00171F1E, 0x0017201D, 0x0018211E, 0x0018221C, 0x0018221C, 0x00121D1B, 0x001C2725, 0x00131B1B, 0x00161B1A, 0x001E211F,
        0x0015160D, 0x001B1B0D, 0x003E402D, 0x00707B61, 0x007A8668, 0x007A8866, 0x0073855E, 0x0075875E, 0x0074865F, 0x0072845F, 0x00788967, 0x00778660, 0x0075845E, 0x00798862, 0x0071805A, 0x005D6C46, 0x004F5E38, 0x004A5933, 0x004B5A34, 0x0053643F,
        0x0053643F, 0x0053643F, 0x0053643F, 0x0053643F, 0x0052633E, 0x0052633E, 0x0052633E, 0x0052643F, 0x0052643F, 0x0052643F, 0x0052643F, 0x0052643F, 0x0052643F, 0x0052643F, 0x0052643F, 0x00546540, 0x00546540, 0x00546540, 0x00546540, 0x0053643F,
        0x0053643F, 0x0053643F, 0x0053643F, 0x004A5C37, 0x004E603B, 0x004E603B, 0x004B5D38, 0x004E603B, 0x00536540, 0x0050623D, 0x00465833, 0x004D5F3A, 0x005B6D48, 0x00586A45, 0x00657752, 0x00778964, 0x0072845F, 0x006E805B, 0x006F815C, 0x00687652,
        0x00617354, 0x0060704E, 0x00475533, 0x00466459, 0x004C8398, 0x005391AF, 0x00538A9F, 0x00497789, 0x001C4139, 0x00283A29, 0x006C726D, 0x0082888D, 0x00CADAD9, 0x00C7D7D6, 0x0097A0AA, 0x0082949B, 0x0081939A, 0x008B9DA4, 0x008FA1A8, 0x0097A9B0,
        0x009BADB4, 0x0086989F, 0x00798B92, 0x007F9299, 0x00778A91, 0x0082959A, 0x00839399, 0x00768588, 0x007D898D, 0x00A2AFB1, 0x00D2DEE0, 0x00C0CCBA, 0x00717F67, 0x006F7E5E, 0x00758661, 0x005C6B4B, 0xFFA3AC97, 0xFFFDFFFB, 0xFFFDFEFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBF9FF, 0xFFFFFFF7, 0x008C9777, 0x0069774D, 0x0086946B, 0x0076835D, 0x00435226, 0x004A5B28, 0x006A764C, 0x005D693F, 0x005F6B41, 0x005C683E, 0x007A865C,
        0x00748056, 0x003F4B21, 0x004D592F, 0x006A7C55, 0x00677657, 0x0098A291, 0x00CCD3CC, 0x00DDE2E1, 0x00DEE2E3, 0x00E8EDEB, 0x00E4EAE5, 0x00D9DAE4, 0x00E3E5ED, 0x00BABEBF, 0x00919590, 0x00838A7D, 0x005D6350, 0x00515A40, 0x00697257, 0x00A8ABA9,
        0x00898D88, 0x00626660, 0x0060635A, 0x008A8E82, 0x00A3A899, 0x00868979, 0x00626653, 0x00718256, 0x007C8D61, 0x00738458, 0x0075865A, 0x007B8C60, 0x0075865A, 0x00738458, 0x00708155, 0x007E8D67, 0x006E7D57, 0x004C5B35, 0x00606F49, 0x003E4D27,
        0x005D6C46, 0x004A5933, 0x004B5A34, 0x005A6943, 0x0041502A, 0x00586741, 0x0052613B, 0x0044532D, 0x0066754F, 0x004B5A34, 0x005A6943, 0x0057683D, 0x005D6D44, 0x005D6D44, 0x0057673E, 0x0053623C, 0x0056653F, 0x005A6844, 0x005C6A46, 0x00596743,
        0x0054623E, 0x0055633F, 0x005A6943, 0x005A6943, 0x00596940, 0x00596940, 0x0056663D, 0x005E6941, 0x00556038, 0x00636E46, 0x005A653D, 0x005A653D, 0x00667149, 0x00545F37, 0x005A653D, 0x00495930, 0x005F6F46, 0x004A5A31, 0x006D7D54, 0x00798960,
        0x007A8963, 0x00707F59, 0x006F7E58, 0x00738263, 0x003C492F, 0x00172110, 0x00131B10, 0x001A201B, 0x00282D2B, 0x001F2423, 0x00151A18, 0x001D241F, 0x001C231E, 0x001D241F, 0x001F2621, 0x00212823, 0x00202722, 0x001D241F, 0x0019201B, 0x0019211A,
        0x001B231C, 0x001D251E, 0x001E261F, 0x001E261F, 0x001D251E, 0x001B231C, 0x001A221B, 0x00171D1C, 0x00171E1B, 0x00171E1B, 0x001B221D, 0x001F2720, 0x00222C20, 0x00212B1F, 0x001F291C, 0x00182019, 0x001D231E, 0x00181E19, 0x0020241E, 0x00171D12,
        0x001C2211, 0x00464E37, 0x007D866B, 0x00788565, 0x00758361, 0x0072815B, 0x0073865B, 0x0076895E, 0x0072845B, 0x0070835C, 0x00758664, 0x0077845E, 0x007E8B65, 0x0073805A, 0x00525F39, 0x005E6B45, 0x0056633D, 0x0035421C, 0x005F6C46, 0x0053643F,
        0x0053643F, 0x0053643F, 0x0053643F, 0x0053643F, 0x0053643F, 0x0053643F, 0x0053643F, 0x0052643F, 0x0052643F, 0x0052643F, 0x0052643F, 0x0052643F, 0x0052643F, 0x0052643F, 0x0052643F, 0x0052633E, 0x0052633E, 0x0051623D, 0x0051623D, 0x0051623D,
        0x0051623D, 0x0050613C, 0x0050613C, 0x0050623D, 0x00576944, 0x00576944, 0x0050623D, 0x0052643F, 0x00596B46, 0x00556742, 0x00495B36, 0x00556742, 0x00445631, 0x006D7F5A, 0x00778964, 0x00677954, 0x0072845F, 0x006E805B, 0x00657752, 0x0072805C,
        0x00677A59, 0x005B6B49, 0x003A4826, 0x003D5B4E, 0x00477F92, 0x004D8BA9, 0x00558DA0, 0x00487688, 0x001A3F37, 0x00263827, 0x006B716C, 0x00848A8F, 0x00CADAD9, 0x00C6D6D5, 0x0098A1AB, 0x007A8C93, 0x0074868D, 0x007C8E95, 0x00809299, 0x0090A2A9,
        0x009DAFB6, 0x00899BA2, 0x007C8E95, 0x007A8D94, 0x0072858C, 0x00809398, 0x0086969C, 0x007B8A8D, 0x00808C90, 0x00A4B1B3, 0x00D5E1E3, 0x00BDC9B7, 0x00738169, 0x00758464, 0x00768762, 0x005A6949, 0xFFA0A994, 0xFFFCFFFA, 0xFFFDFEFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFDFF, 0xFFFDFFF5, 0x008A9575, 0x0067754B, 0x0085936A, 0x007A8761, 0x0047562A, 0x00455623, 0x006D794F, 0x00616D43, 0x004A562C, 0x00445026, 0x00647046,
        0x00606C42, 0x003C481E, 0x0048542A, 0x006F7D61, 0x0079856F, 0x00BAC2B7, 0x00CED3D2, 0x00E0E3E7, 0x00D8DBDF, 0x00DFE4E3, 0x00DBE0DE, 0x00DFE2E7, 0x00E5E8EC, 0x00A9AEAC, 0x0082887D, 0x009BA392, 0x00576046, 0x00626D4D, 0x00606B4A, 0x005C674D,
        0x00586349, 0x00505B41, 0x00565F44, 0x005F684D, 0x00646B50, 0x00676F51, 0x00666E50, 0x004B5C30, 0x0067784C, 0x00798A5E, 0x00748559, 0x00748559, 0x0076875B, 0x006F8054, 0x00728357, 0x0072815B, 0x007C8B65, 0x0064734D, 0x004F5E38, 0x0065744E,
        0x0031401A, 0x0061704A, 0x00475630, 0x00475630, 0x005D6C46, 0x003E4D27, 0x00596842, 0x0053623C, 0x003F4E28, 0x00596842, 0x005C6B45, 0x0056673C, 0x0056663D, 0x0055653C, 0x0054643B, 0x00596842, 0x005F6E48, 0x005F6D49, 0x005A6844, 0x00616F4B,
        0x00586642, 0x00596842, 0x005F6E48, 0x005D6D44, 0x005B6B42, 0x005D6E43, 0x005D6E43, 0x0059643C, 0x005A653D, 0x00566139, 0x0057623A, 0x005D6840, 0x00535E36, 0x005B663E, 0x00525D35, 0x005F7045, 0x00516237, 0x00728358, 0x00718257, 0x00738459,
        0x0076875C, 0x007A8B60, 0x00708156, 0x0075875E, 0x0072835E, 0x004D5A40, 0x00182211, 0x000C1409, 0x00171E17, 0x00111712, 0x00111712, 0x00171D12, 0x00151B10, 0x00141A0F, 0x00151B10, 0x00171D12, 0x00181E13, 0x00161C11, 0x0013190E, 0x00141B0E,
        0x00151C0F, 0x00151C0F, 0x00161D10, 0x00171E11, 0x00171E11, 0x00171E11, 0x00171E11, 0x00151914, 0x00131711, 0x0013180F, 0x00181E13, 0x001E2518, 0x00212918, 0x001D2612, 0x0018210D, 0x00202216, 0x001B1C12, 0x0013170C, 0x001C2014, 0x001B2410,
        0x00424F35, 0x006E7E5C, 0x0074865F, 0x00768460, 0x0074835D, 0x0076875C, 0x00778B5E, 0x0075895C, 0x00718459, 0x006E815A, 0x006F815C, 0x007E8C63, 0x0078865D, 0x0056643B, 0x0058663D, 0x0049572E, 0x003E4C23, 0x005F6D44, 0x00546239, 0x00647550,
        0x00647550, 0x00647550, 0x00647550, 0x00647550, 0x00647550, 0x00647550, 0x00647550, 0x00647651, 0x00647651, 0x00647651, 0x00647651, 0x00647651, 0x00647651, 0x00647651, 0x00647651, 0x00677853, 0x00677853, 0x00667752, 0x00667752, 0x00667752,
        0x00667752, 0x00657651, 0x00657651, 0x00637550, 0x0062744F, 0x0062744F, 0x0061734E, 0x005E704B, 0x005C6E49, 0x005E704B, 0x00637550, 0x005D6F4A, 0x00798B66, 0x006C7E59, 0x006C7E59, 0x006E805B, 0x00667853, 0x00748661, 0x00748661, 0x006D7C56,
        0x00667958, 0x005D6D4B, 0x003F4D2B, 0x004B695C, 0x0050889B, 0x004B89A7, 0x00548C9F, 0x004C7A8C, 0x001D423A, 0x00263827, 0x006A706B, 0x00858B90, 0x00CADAD9, 0x00C6D6D5, 0x009AA3AD, 0x00809299, 0x00778990, 0x007B8D94, 0x00788A91, 0x0086989F,
        0x009AACB3, 0x0090A2A9, 0x008B9DA4, 0x0082959C, 0x00788B92, 0x0084979C, 0x008B9BA1, 0x007F8E91, 0x00818D91, 0x00A3B0B2, 0x00D4E0E2, 0x00B4C0AE, 0x006C7A62, 0x00738262, 0x00798A65, 0x00617050, 0xFFA3AC97, 0xFFF7FBF5, 0xFFFCFDFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFDFF, 0xFBFBFFF3, 0x00899474, 0x0068764C, 0x0085936A, 0x007A8761, 0x00404F23, 0x00344512, 0x00323E14, 0x003B471D, 0x00333F15, 0x00364218, 0x0039451B,
        0x002F3B11, 0x0038441A, 0x004C582E, 0x006B7564, 0x00878F84, 0x00D5DAD9, 0x00D5D7DF, 0x00E7E7F3, 0x00D3D4DE, 0x00D2D5D9, 0x00D1D5D6, 0x00D5D8DC, 0x00E5EAE9, 0x00A9B0A9, 0x008B9285, 0x00C6D0B9, 0x005F694B, 0x00838F6B, 0x00748259, 0x0076875B,
        0x007B8C60, 0x0077865A, 0x0079875D, 0x007B875D, 0x00758157, 0x006A754D, 0x00515A32, 0x00596A3E, 0x004F6034, 0x006D7E52, 0x0075865A, 0x00738458, 0x007A8B5F, 0x006F8054, 0x0075865A, 0x00778660, 0x0071805A, 0x0082916B, 0x0065744E, 0x004E5D37,
        0x0064734D, 0x00384721, 0x00586741, 0x004B5A34, 0x004A5933, 0x0053623C, 0x0042512B, 0x0054633D, 0x00606F49, 0x0056653F, 0x00586741, 0x00596A3F, 0x0058683F, 0x005A6A41, 0x005C6C43, 0x00596842, 0x0054633D, 0x00576541, 0x005D6B47, 0x005B6945,
        0x00586741, 0x005A6943, 0x005B6A44, 0x0056663D, 0x00596940, 0x005C6D42, 0x00596A3F, 0x00606B43, 0x00545F37, 0x00616C44, 0x005A653D, 0x00556038, 0x005F6A42, 0x00505B33, 0x00626D45, 0x00516237, 0x006F8055, 0x0078895E, 0x00798A5F, 0x0075865B,
        0x00738458, 0x00718256, 0x007A8B5F, 0x00708455, 0x0075875E, 0x00758464, 0x004E5A44, 0x002F382B, 0x003E463C, 0x004A514A, 0x00404740, 0x004A4E42, 0x00474B3F, 0x0043473B, 0x0044483C, 0x00464A3E, 0x00484C40, 0x00484C40, 0x00464A3E, 0x00444A39,
        0x00434938, 0x00434938, 0x00434938, 0x00444A39, 0x00454B3A, 0x00474D3C, 0x00494F3E, 0x0043453F, 0x003F4239, 0x003E4237, 0x00424738, 0x00494F3E, 0x004A513C, 0x00434B34, 0x003C452B, 0x00444335, 0x00525143, 0x003E3E30, 0x003A402F, 0x0049533C,
        0x00687958, 0x00738861, 0x006F865A, 0x0073825C, 0x0075855C, 0x0078895D, 0x00748859, 0x00708457, 0x0072855A, 0x00768962, 0x00778964, 0x0076845B, 0x004D5B32, 0x005F6D44, 0x004B5930, 0x00414F26, 0x005C6A41, 0x00536138, 0x00637148, 0x00748560,
        0x00748560, 0x00748560, 0x00758661, 0x00758661, 0x00758661, 0x00758661, 0x00758661, 0x00748661, 0x00748661, 0x00748661, 0x00748661, 0x00748661, 0x00748661, 0x00748661, 0x00748661, 0x00758661, 0x00758661, 0x00748560, 0x00748560, 0x00748560,
        0x00748560, 0x0073845F, 0x0073845F, 0x00738560, 0x0072845F, 0x0072845F, 0x00738560, 0x00758762, 0x00758762, 0x00748661, 0x00748661, 0x0072845F, 0x0070825D, 0x0070825D, 0x006A7C57, 0x0070825D, 0x0071835E, 0x00677954, 0x006E805B, 0x00707F59,
        0x00697C5B, 0x005C6D48, 0x003D4B27, 0x004D6B5E, 0x0051899C, 0x004887A3, 0x00538B9E, 0x00517F91, 0x0020453D, 0x00273928, 0x006A706B, 0x00858B90, 0x00CADAD9, 0x00C7D7D6, 0x009CA5AF, 0x0093A5AC, 0x008EA0A7, 0x0095A7AE, 0x008B9DA4, 0x0091A3AA,
        0x00A0B2B9, 0x0096A8AF, 0x0095A7AE, 0x0090A3AA, 0x0081949B, 0x008A9DA2, 0x008E9EA4, 0x00808F92, 0x00808C90, 0x00A0ADAF, 0x00D2DEE0, 0x00C1CDBB, 0x00707E66, 0x006E7D5D, 0x0073845F, 0x00606F4F, 0xFFA4AD98, 0xFFF8FCF6, 0xFFFDFEFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCFAFF, 0xFBFBFFF3, 0x00899474, 0x006C7A50, 0x00829067, 0x007E8B65, 0x00647347, 0x005E6F3C, 0x0058693E, 0x00596A3F, 0x005B6C41, 0x0054653A, 0x0055663B,
        0x00596A3F, 0x0056673C, 0x005F7045, 0x00728358, 0x00596842, 0x00869373, 0x00ADB99D, 0x0087917A, 0x006E795F, 0x00818C72, 0x008B977B, 0x00737E5D, 0x0075815D, 0x00737D59, 0x006A754F, 0x006C774F, 0x00697349, 0x007A8459, 0x007E895B, 0x00798862,
        0x00798960, 0x0075855C, 0x007A8A61, 0x00798A5F, 0x0078895E, 0x00798A5E, 0x0066774B, 0x0048592D, 0x005A6B3F, 0x004F6034, 0x006C7D51, 0x00798A5E, 0x0075865A, 0x0078895D, 0x0075865A, 0x00728455, 0x00748657, 0x00798B5C, 0x0077885C, 0x00617246,
        0x0057683D, 0x0055663B, 0x003E4F24, 0x0056663D, 0x004E5E35, 0x004F5F36, 0x0053633A, 0x004F5F36, 0x00516138, 0x0055653C, 0x0053633A, 0x0052613B, 0x0053623C, 0x0053623C, 0x0053623C, 0x0053623C, 0x0054633D, 0x0054633D, 0x0054633D, 0x0054633D,
        0x0055643E, 0x0055643E, 0x0056653F, 0x0056653F, 0x0055643E, 0x0055643E, 0x0054633D, 0x00526239, 0x0057673E, 0x005A6A41, 0x00526239, 0x0053633A, 0x0055653C, 0x005A6A41, 0x0057673E, 0x00748559, 0x00738458, 0x00738458, 0x00738458, 0x00738458,
        0x00748559, 0x00748559, 0x0075865A, 0x00728357, 0x00728357, 0x0074855A, 0x00788761, 0x00606C4E, 0x00838C77, 0x00848A7F, 0x00828680, 0x00A3A199, 0x009E9C94, 0x00A3A199, 0x009F9D95, 0x00A5A39B, 0x009D9B93, 0x009C9A92, 0x009A9890, 0x0099948B,
        0x00A5A097, 0x009C978E, 0x00928D84, 0x00B0ABA2, 0x00A09B92, 0x009B968D, 0x00A9A49B, 0x009E9C94, 0x00939189, 0x00A19F97, 0x0095938B, 0x009A9890, 0x00AFADA5, 0x0097958D, 0x008A8880, 0x00A2989E, 0x00A9A39E, 0x007C7D69, 0x0078825E, 0x00768559,
        0x00798D60, 0x006E8258, 0x0070855F, 0x0075885D, 0x00708358, 0x0076895E, 0x0076875C, 0x0078895E, 0x007D8B61, 0x0076845A, 0x007A885E, 0x004E5D37, 0x0055643E, 0x004B5A34, 0x00364821, 0x0052643D, 0x0054663F, 0x00586B44, 0x007F926B, 0x00748560,
        0x0073845F, 0x0072845D, 0x0072845D, 0x0072845B, 0x0072845B, 0x0072845B, 0x0072855A, 0x00758760, 0x0074865F, 0x0073855E, 0x0072845D, 0x0072845D, 0x0072845D, 0x0073855E, 0x0074865F, 0x0074865F, 0x0074865F, 0x0074865F, 0x0073855E, 0x0072845D,
        0x0071835C, 0x0070825B, 0x006F815A, 0x0073865F, 0x0073865F, 0x0072855E, 0x0072855E, 0x0071845D, 0x0070835C, 0x0070835C, 0x006F825B, 0x006F815C, 0x006F815C, 0x006F815C, 0x006F815C, 0x006E805B, 0x006E805B, 0x006E805B, 0x006E805B, 0x00697E5E,
        0x006B7A54, 0x00636D43, 0x00415334, 0x00416359, 0x005C8D95, 0x005C94A5, 0x0051899C, 0x004B7D89, 0x002C4C4B, 0x002E382B, 0x00767668, 0x00898D88, 0x00D4E0E4, 0x00BBCED5, 0x0090A4A9, 0x0091A0A9, 0x0093A2AB, 0x008F9EA7, 0x008C9BA4, 0x008D9CA5,
        0x008C9BA4, 0x008B9AA3, 0x00909FA8, 0x00869CA1, 0x0080999D, 0x007E979B, 0x00768F93, 0x0074888D, 0x007C8C92, 0x009DA7AE, 0x00CFD5DC, 0x00C9D3CD, 0x00849181, 0x006A795D, 0x00758760, 0x0063714D, 0xFFA3AC92, 0xFFFBFFF4, 0xFFFFFEFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFDFF, 0xFFFFFFF7, 0x00879272, 0x006A784E, 0x007F8D64, 0x00828F69, 0x0079885C, 0x007C8D5A, 0x007F9065, 0x007C8D62, 0x007B8C61, 0x007C8D62, 0x007C8D62,
        0x007A8B60, 0x00798A5F, 0x00809166, 0x007A8C5D, 0x006F8054, 0x0072815B, 0x007B8965, 0x00778563, 0x0075835F, 0x00788761, 0x007C8C63, 0x007A8761, 0x00798660, 0x0076835D, 0x00717C54, 0x0077825A, 0x00778157, 0x00828C62, 0x00798358, 0x0075855C,
        0x0077875E, 0x0075865B, 0x0077885D, 0x0075865A, 0x0075865A, 0x007B8C60, 0x00708253, 0x0065764A, 0x0048592D, 0x005B6C40, 0x0056673B, 0x00738458, 0x007B8C60, 0x007C8D61, 0x00718256, 0x00768859, 0x00758758, 0x006F8152, 0x0078895D, 0x0076875B,
        0x00627348, 0x00596A3F, 0x0056673C, 0x0043532A, 0x004D5D34, 0x0048582F, 0x004B5B32, 0x005C6C43, 0x00596940, 0x00526239, 0x005F6F46, 0x00596842, 0x00596842, 0x00596842, 0x005A6943, 0x005A6943, 0x005A6943, 0x005A6943, 0x005A6943, 0x00596842,
        0x00596842, 0x005A6943, 0x005A6943, 0x005A6943, 0x005A6943, 0x00596842, 0x00596842, 0x0055653C, 0x0055653C, 0x004F5F36, 0x00596940, 0x00516138, 0x005B6B42, 0x005E6E45, 0x006D7D54, 0x0076875B, 0x0076875B, 0x0076875B, 0x0076875B, 0x0076875B,
        0x0076875B, 0x0076875B, 0x0076875B, 0x0077885C, 0x00798A5E, 0x00738459, 0x007F8E68, 0x00546141, 0x00727C65, 0x006E7568, 0x007B8077, 0x008A8A7E, 0x0089897D, 0x00838377, 0x007F7F73, 0x008B8B7F, 0x008E8E82, 0x009B9B8F, 0x00959589, 0x0089887A,
        0x00868577, 0x007D7C6E, 0x00888779, 0x007C7B6D, 0x008C8B7D, 0x007A796B, 0x008E8D7F, 0x008B8D81, 0x007F8175, 0x008E9084, 0x0085877B, 0x0086887C, 0x0094968A, 0x0085877B, 0x00828478, 0x00938B8B, 0x00908E84, 0x005F634A, 0x00707B55, 0x00758758,
        0x00708455, 0x00708459, 0x00738861, 0x0074865D, 0x0074865D, 0x00708259, 0x007D8D64, 0x00728259, 0x00748259, 0x007B8960, 0x004A582F, 0x00596842, 0x004C5B35, 0x0036451F, 0x005B6D46, 0x004F613A, 0x005F714A, 0x00748760, 0x0072855E, 0x00748560,
        0x0073845F, 0x0073855E, 0x0072845D, 0x0072845B, 0x0072845B, 0x0072845B, 0x0072855A, 0x0074865F, 0x0073855E, 0x0073855E, 0x0072845D, 0x0072845D, 0x0073855E, 0x0074865F, 0x0074865F, 0x00758760, 0x00758760, 0x0074865F, 0x0073855E, 0x0072845D,
        0x0071835C, 0x0070825B, 0x0070825B, 0x0073865F, 0x0073865F, 0x0072855E, 0x0072855E, 0x0071845D, 0x0070835C, 0x0070835C, 0x0070835C, 0x0070825D, 0x006F815C, 0x006F815C, 0x006F815C, 0x006F815C, 0x006F815C, 0x006E805B, 0x006E805B, 0x00697C5B,
        0x006D7A54, 0x00687248, 0x004A5C3D, 0x0044665F, 0x00548692, 0x00568FA5, 0x00518AA3, 0x004B7F8F, 0x002D5053, 0x002B392E, 0x0066675D, 0x00838886, 0x00D2DEE4, 0x00BCCFD4, 0x007B8E91, 0x006C838B, 0x006F868E, 0x006C838B, 0x006A8189, 0x006C838B,
        0x006A8189, 0x00687F87, 0x006C838B, 0x006F8388, 0x00677D82, 0x00647D81, 0x005D767A, 0x0061757A, 0x0074848A, 0x009CA6AD, 0x00CBD1D8, 0x00E4EEE8, 0x009DAA9C, 0x00728165, 0x00778962, 0x00616F4B, 0xFF9FA88E, 0xFFFEFFF8, 0xFFFFFEFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFDFF, 0xFFFFFFF7, 0x00869171, 0x006F7D53, 0x007E8C63, 0x007E8B65, 0x007A895D, 0x007C8D5A, 0x0078895E, 0x00798A5F, 0x0076875C, 0x00798A5F, 0x0077885D,
        0x00798A5F, 0x007A8B60, 0x007C8D62, 0x007F9261, 0x00829465, 0x0077885D, 0x0076865D, 0x007D8D64, 0x00849569, 0x00809362, 0x007E915E, 0x0083936A, 0x00839168, 0x0086946B, 0x00849269, 0x00828D65, 0x0077825A, 0x00848D65, 0x007E875F, 0x0077885D,
        0x0077885D, 0x00748559, 0x0075865A, 0x00748657, 0x00748657, 0x007A8D5C, 0x00768958, 0x00748559, 0x0065764A, 0x0046572B, 0x0058693D, 0x0055663A, 0x00728357, 0x0077885C, 0x006E7F53, 0x00738556, 0x00788A5B, 0x00728455, 0x00748559, 0x00798A5E,
        0x006F8055, 0x00607146, 0x00536439, 0x0054643B, 0x00495930, 0x0055653C, 0x00617148, 0x00596940, 0x005C6C43, 0x0063734A, 0x00596940, 0x005E6E45, 0x005E6E45, 0x005E6E45, 0x005E6E45, 0x005F6F46, 0x005F6F46, 0x005F6F46, 0x005F6F46, 0x005F6E48,
        0x005E6D47, 0x005E6D47, 0x005E6D47, 0x005E6D47, 0x005E6D47, 0x005E6D47, 0x005F6E48, 0x0064744B, 0x0058683F, 0x005D6D44, 0x00516138, 0x005F6F46, 0x0057673E, 0x006C7C53, 0x0075855C, 0x00748559, 0x00748559, 0x0075865A, 0x0075865A, 0x0075865A,
        0x00738458, 0x00728357, 0x00718256, 0x0074855A, 0x00708156, 0x007B8C61, 0x0073835A, 0x00697755, 0x00818C72, 0x00A5AE9A, 0x00B7BEB1, 0x008F947F, 0x00969B86, 0x008F947F, 0x00808570, 0x00828772, 0x00828772, 0x00959A85, 0x008F947F, 0x008C8F79,
        0x00757862, 0x00747761, 0x00777A64, 0x006D705A, 0x006D705A, 0x00757862, 0x006E715B, 0x00676E59, 0x00646B56, 0x007F8671, 0x00838A75, 0x00868D78, 0x00888F7A, 0x00787F6A, 0x00757C67, 0x0089877C, 0x00898B78, 0x005B6344, 0x00748258, 0x00798B5C,
        0x006C8051, 0x006F8457, 0x0071855A, 0x006E8057, 0x006E8057, 0x0076885F, 0x006F7F56, 0x0078885F, 0x0078865D, 0x0055633A, 0x005B6940, 0x0044532D, 0x00394822, 0x00596842, 0x004B5D36, 0x00657750, 0x0072845D, 0x0073865F, 0x0071845D, 0x00748560,
        0x0073845F, 0x0073855E, 0x0072845D, 0x0072845B, 0x0072845B, 0x0072845B, 0x0073865B, 0x0073855E, 0x0073855E, 0x0072845D, 0x0072845D, 0x0073855E, 0x0074865F, 0x00758760, 0x00758760, 0x00768861, 0x00758760, 0x0073855E, 0x0072845D, 0x0071835C,
        0x0071835C, 0x0071835C, 0x0072845D, 0x0073865F, 0x0073865F, 0x0072855E, 0x0072855E, 0x0071845D, 0x0071845D, 0x0070835C, 0x0070835C, 0x0070825D, 0x0070825D, 0x0070825D, 0x0070825D, 0x0070825D, 0x006F815C, 0x006F815C, 0x006F815C, 0x006C805D,
        0x0075835A, 0x00717B51, 0x004C6043, 0x00466A64, 0x00558999, 0x005B95B2, 0x00518DAB, 0x00477F92, 0x00274C54, 0x00273834, 0x005D645D, 0x008F9495, 0x00D2DEE4, 0x00BECFD2, 0x006F7F7E, 0x00506D72, 0x00547176, 0x00526F74, 0x00516E73, 0x00547176,
        0x00537075, 0x004F6C71, 0x00506D72, 0x00596C6F, 0x0053686A, 0x00556C6E, 0x00506769, 0x00526769, 0x006C7D80, 0x0097A2A6, 0x00C2C8CD, 0x00EAF3F0, 0x00A9B6A8, 0x006F7E62, 0x0073845F, 0x005F6D49, 0xFF99A18A, 0xFFFFFFF9, 0xFFFFFEFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFDFF, 0xFFFFFFF7, 0x007F8A6A, 0x006E7C52, 0x007E8C63, 0x007F8C66, 0x007B8A5E, 0x007F905D, 0x00808E64, 0x0089976D, 0x00829066, 0x00818F65, 0x007A885E,
        0x00808E64, 0x00829066, 0x00808E64, 0x007A8C65, 0x00768762, 0x00778765, 0x007F8E6E, 0x006B7B59, 0x0063754E, 0x0064774C, 0x005F7346, 0x0061704A, 0x005A6943, 0x0066734D, 0x00727F59, 0x007A8761, 0x0075805A, 0x00818C66, 0x007B8660, 0x007A8B5F,
        0x0077885C, 0x00738458, 0x00758758, 0x00758758, 0x00748756, 0x00758857, 0x00748756, 0x00798A5F, 0x007C8D62, 0x005D6E43, 0x004E5F34, 0x00596A3F, 0x0057683D, 0x0075865B, 0x0078895E, 0x00738556, 0x00728455, 0x00728455, 0x0075865A, 0x00738458,
        0x0077885D, 0x0077885D, 0x00607146, 0x0054643B, 0x0056663D, 0x0053633A, 0x0055653C, 0x005A6A41, 0x0055653C, 0x004E5E35, 0x00526239, 0x00516138, 0x00516138, 0x00526239, 0x00526239, 0x00526239, 0x00526239, 0x0053633A, 0x0053633A, 0x0055643E,
        0x0054633D, 0x0053623C, 0x0053623C, 0x0053623C, 0x0053623C, 0x0054633D, 0x0055643E, 0x00506037, 0x0057673E, 0x004A5A31, 0x0056663D, 0x004F5F36, 0x006D7D54, 0x006E7E55, 0x0077875E, 0x0076875C, 0x0076875C, 0x0077885D, 0x0078895E, 0x0077885D,
        0x0075865B, 0x00738459, 0x00728358, 0x006F7F56, 0x007C8C63, 0x006E7F54, 0x00708057, 0x00495733, 0x006E7A5C, 0x00717B64, 0x0077806C, 0x005F694B, 0x00677153, 0x006D7759, 0x005B6547, 0x00576143, 0x00535D3F, 0x00586244, 0x00545E40, 0x00545C3E,
        0x00646C4E, 0x00444C2E, 0x00424A2C, 0x006C7456, 0x005B6345, 0x0061694B, 0x00687052, 0x00656F51, 0x00566042, 0x005A6446, 0x00525C3E, 0x00576143, 0x005B6547, 0x00586244, 0x00545E40, 0x00696F58, 0x00737A5F, 0x005F6B47, 0x00748258, 0x0077895A,
        0x00728657, 0x0074885B, 0x0075885D, 0x00778960, 0x0073855C, 0x0073855C, 0x007C8C63, 0x006D7D54, 0x005B6940, 0x0059673E, 0x004F5D34, 0x0033421C, 0x00586741, 0x0053623C, 0x005C6E47, 0x006E8059, 0x00778962, 0x006E815A, 0x0072855E, 0x00748560,
        0x00748560, 0x0073855E, 0x0072845D, 0x0072845B, 0x0072845B, 0x0073855C, 0x0073865B, 0x0072845D, 0x0072845D, 0x0072845D, 0x0073855E, 0x0074865F, 0x00758760, 0x00758760, 0x00768861, 0x00768861, 0x00758760, 0x0073855E, 0x0071835C, 0x0071835C,
        0x0071835C, 0x0072845D, 0x0073855E, 0x0073865F, 0x0073865F, 0x0072855E, 0x0072855E, 0x0072855E, 0x0071845D, 0x0071845D, 0x0071845D, 0x0071835E, 0x0071835E, 0x0071835E, 0x0071835E, 0x0071835E, 0x0070825D, 0x0070825D, 0x0070825D, 0x00687C59,
        0x0076845A, 0x006C764C, 0x003D5134, 0x003D605C, 0x005A8C9E, 0x0067A0BF, 0x00528DAD, 0x004B8396, 0x00274E56, 0x00394B4A, 0x007A8380, 0x00B2BBBE, 0x00DAE6EC, 0x00C1CED0, 0x00697773, 0x004C6267, 0x0052686D, 0x0051676C, 0x0051676C, 0x00556B70,
        0x00546A6F, 0x004F656A, 0x004E6469, 0x0056676A, 0x004E6164, 0x004F6466, 0x00465B5D, 0x0043585A, 0x00627376, 0x0094A0A4, 0x00C2CBCF, 0x00E2EBE8, 0x00ACB9AB, 0x006A795E, 0x0072835E, 0x0062704E, 0xFF979F88, 0xFFFFFFF9, 0xFFFDF9FE, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFDFF, 0xFFFEFFF6, 0x007C8767, 0x006F7D53, 0x00808E65, 0x007A8761, 0x00617044, 0x0060713E, 0x0057653B, 0x005E6C42, 0x0056643A, 0x005C6A40, 0x0058663C,
        0x005D6B41, 0x005C6A40, 0x0067754B, 0x0077846C, 0x005C6852, 0x00545E4D, 0x00697363, 0x004B5545, 0x003A4531, 0x0037442C, 0x002D3A20, 0x002B371B, 0x00364224, 0x00414D2F, 0x00404B2B, 0x00475231, 0x0054603C, 0x0077825C, 0x0079845E, 0x00798A5F,
        0x0076875C, 0x0077885D, 0x0078895D, 0x0077885C, 0x00738556, 0x00728455, 0x00788A5B, 0x0077885D, 0x0075865B, 0x007C8D62, 0x0057683D, 0x00526338, 0x0056673C, 0x00596A3F, 0x0074855A, 0x007A8C5D, 0x00708253, 0x006D7F50, 0x0076875B, 0x00728357,
        0x006E7F54, 0x0078895E, 0x0077885D, 0x0053633A, 0x0055653C, 0x00516138, 0x0053633A, 0x005B6B42, 0x00596940, 0x0057673E, 0x005D6D44, 0x00596940, 0x00596940, 0x00596940, 0x005A6A41, 0x005A6A41, 0x005A6A41, 0x005A6A41, 0x005B6B42, 0x005D6C46,
        0x005C6B45, 0x005B6A44, 0x005B6A44, 0x005B6A44, 0x005B6A44, 0x005C6B45, 0x005D6C46, 0x0058683F, 0x0053633A, 0x005C6C43, 0x00516138, 0x006C7C53, 0x006C7C53, 0x00798960, 0x006F7F56, 0x0075865B, 0x0076875C, 0x0077885D, 0x0077885D, 0x0077885D,
        0x0075865B, 0x00738459, 0x00728358, 0x00798763, 0x0072815B, 0x00728259, 0x0057683D, 0x0054643B, 0x004C5A36, 0x00546042, 0x003F4A30, 0x0057633F, 0x005A6642, 0x0076825E, 0x006F7B57, 0x0077835F, 0x007B8763, 0x00737F5B, 0x0075815D, 0x0073815F,
        0x00768462, 0x00505E3C, 0x00566442, 0x00465432, 0x005A6846, 0x004D5B39, 0x00505E3C, 0x0052603C, 0x004A5834, 0x0054623E, 0x00586642, 0x006C7A56, 0x006F7D59, 0x0065734F, 0x004C5A36, 0x004F5A3A, 0x004D5B39, 0x0052613B, 0x005F7045, 0x00647549,
        0x006A7B4F, 0x00617548, 0x00697C51, 0x00687A53, 0x006E8059, 0x006B7D56, 0x006A7953, 0x005D6C46, 0x0056633D, 0x00515E38, 0x003B4822, 0x00596842, 0x00586741, 0x005B6A44, 0x00768861, 0x0073855E, 0x0071835C, 0x0073865F, 0x0071845D, 0x00748560,
        0x00748560, 0x0073855E, 0x0073855E, 0x0072845B, 0x0072845B, 0x0073855C, 0x0073865B, 0x0072845D, 0x0072845D, 0x0073855E, 0x0074865F, 0x0074865F, 0x00758760, 0x00758760, 0x00758760, 0x00768861, 0x00758760, 0x0073855E, 0x0072845D, 0x0071835C,
        0x0072845D, 0x0073855E, 0x0074865F, 0x0073865F, 0x0073865F, 0x0072855E, 0x0072855E, 0x0072855E, 0x0072855E, 0x0072855E, 0x0072855E, 0x0072845F, 0x0072845F, 0x0072845F, 0x0072845F, 0x0072845F, 0x0071835E, 0x0071835E, 0x0071835E, 0x006B7F5C,
        0x0078865C, 0x006C764B, 0x003F5132, 0x0044645F, 0x006290A1, 0x007CB1CC, 0x006FA3C1, 0x00588A96, 0x00375C60, 0x00596A67, 0x00949D9A, 0x00C6D1D5, 0x00DEECF2, 0x00C0CECD, 0x0067746C, 0x004E595D, 0x00576266, 0x00596468, 0x00586367, 0x005C676B,
        0x005C676B, 0x00566165, 0x00545F63, 0x00566365, 0x00505F61, 0x00506465, 0x00485D5E, 0x00425758, 0x005A6C6D, 0x008D9A9C, 0x00C0CCCE, 0x00E4ECEB, 0x00B8C4B8, 0x00707F64, 0x00788866, 0x00687654, 0xFF989F8A, 0xFFFFFFFB, 0xFFFBF7FC, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFDFF, 0xFFFEFFF6, 0x007E8969, 0x00707E54, 0x00839168, 0x0073805A, 0x003E4D21, 0x003C4D1A, 0x0039451B, 0x00344016, 0x002A360C, 0x0038441A, 0x003B471D,
        0x003A461C, 0x002B370D, 0x00475329, 0x006A7463, 0x004D5649, 0x004B5349, 0x00929893, 0x00AEB3B1, 0x00B8BDBB, 0x00B7BDB8, 0x00B1B8B1, 0x00A5AEA1, 0x00B1BBAB, 0x00959E8A, 0x00535D46, 0x00434D2F, 0x005B6645, 0x00808D67, 0x007F8A62, 0x007A8963,
        0x00788761, 0x007B8A64, 0x007B8B62, 0x007A8A61, 0x0075855C, 0x0074855A, 0x00839469, 0x0078885F, 0x007B8B62, 0x007C8C63, 0x00798960, 0x0053633A, 0x005B6B42, 0x00506037, 0x0058683F, 0x00708253, 0x007D8F60, 0x00768859, 0x0077885C, 0x007B8C60,
        0x00718257, 0x00708156, 0x00798A5F, 0x00708057, 0x005F6F46, 0x0064744B, 0x0068784F, 0x005B6B42, 0x005D6D44, 0x0065754C, 0x005C6C43, 0x005D6E43, 0x005E6F44, 0x005E6F44, 0x005E6F44, 0x005E6F44, 0x005E6F44, 0x005F7045, 0x005F7045, 0x005E6D47,
        0x005E6D47, 0x005E6D47, 0x005D6C46, 0x005D6C46, 0x005E6D47, 0x005E6D47, 0x005E6D47, 0x00627249, 0x00617148, 0x00596940, 0x00718158, 0x006E7E55, 0x007B8B62, 0x00718158, 0x0075855C, 0x0078885F, 0x0078885F, 0x00798960, 0x00798960, 0x0078885F,
        0x0077875E, 0x0076865D, 0x0075855C, 0x007B8967, 0x006A7854, 0x004F5F36, 0x0056673C, 0x0048592E, 0x0053633A, 0x0053613D, 0x00546240, 0x0053623C, 0x005B6A44, 0x007D8C66, 0x0075845E, 0x0076855F, 0x0075845E, 0x00707F59, 0x00788761, 0x0073845F,
        0x00566742, 0x005A6B46, 0x0050613C, 0x0031421D, 0x00556641, 0x004D5E39, 0x0052633E, 0x0051633C, 0x004A5C35, 0x0053653E, 0x005D6F48, 0x007A8C65, 0x007A8C65, 0x006F815A, 0x004B5D36, 0x0052643D, 0x003D4F28, 0x00465831, 0x004F613A, 0x0053623C,
        0x0056653F, 0x00485731, 0x0055643E, 0x004E6039, 0x00556740, 0x005A6C45, 0x004B5A34, 0x0053623C, 0x0053603A, 0x003B4822, 0x0053603A, 0x005F6E48, 0x0052613B, 0x007C8B65, 0x0072845D, 0x007A8C65, 0x0071835C, 0x0070835C, 0x0072855E, 0x00758661,
        0x00748560, 0x0074865F, 0x0073855E, 0x0073855C, 0x0073855C, 0x0073855C, 0x0073865B, 0x0072845D, 0x0073855E, 0x0074865F, 0x00758760, 0x00758760, 0x00758760, 0x00758760, 0x00758760, 0x00758760, 0x0074865F, 0x0073855E, 0x0072845D, 0x0072845D,
        0x0073855E, 0x0073855E, 0x0074865F, 0x0072855E, 0x0072855E, 0x0072855E, 0x0072855E, 0x0072855E, 0x0072855E, 0x0072855E, 0x0072855E, 0x00748661, 0x00738560, 0x00738560, 0x00738560, 0x00738560, 0x0072845F, 0x0072845F, 0x0072845F, 0x006E8664,
        0x0078885F, 0x00768055, 0x00596848, 0x005D786E, 0x00688F98, 0x0088B3C6, 0x008BB6CB, 0x005A8385, 0x0044605A, 0x00627065, 0x00818883, 0x00ACB5B9, 0x00D9E6EE, 0x00C2D0CF, 0x006D7870, 0x00676C6F, 0x0073787B, 0x00767B7E, 0x00757A7D, 0x00787D80,
        0x00787D80, 0x0074797C, 0x0072777A, 0x00697577, 0x00606D6F, 0x00596B6C, 0x004E6263, 0x00475B5C, 0x00516364, 0x007E8D8F, 0x00BECACC, 0x00E5EDEC, 0x00BECABE, 0x0074826A, 0x00778765, 0x00687555, 0xFF99A08B, 0xFFFFFFFB, 0xFFFFFBFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFDFF, 0xFFFFFFF7, 0x007D8868, 0x006A784E, 0x00839168, 0x007A8761, 0x003F4E22, 0x004D5E2B, 0x006A764C, 0x00616D43, 0x00505C32, 0x00556137, 0x005F6B41,
        0x00616D43, 0x003A461C, 0x00546036, 0x005F6D55, 0x00434F3B, 0x004F594D, 0x00B9C0BB, 0x00E7ECED, 0x00EBF0F3, 0x00E4E9EC, 0x00E2E7EA, 0x00EEF1F5, 0x00EEF2F3, 0x00AEB4AF, 0x00515849, 0x003C462F, 0x00545F3F, 0x006B7852, 0x005C6A40, 0x005F6C4C,
        0x00525F3F, 0x004E5C3A, 0x004E5C3A, 0x0054623E, 0x0053613D, 0x004E5C38, 0x005D6C46, 0x007B8B62, 0x0075855C, 0x00798960, 0x0074845B, 0x0076865D, 0x00596940, 0x0065754C, 0x004D5D34, 0x005A6C3D, 0x00758758, 0x00758758, 0x00728357, 0x007A8B5F,
        0x0077885D, 0x0074855A, 0x0074855A, 0x00718158, 0x00798960, 0x00718158, 0x00718158, 0x007F8F66, 0x007A8A61, 0x00728259, 0x007F8F66, 0x00798A5F, 0x007A8B60, 0x007A8B60, 0x007A8B60, 0x007A8B60, 0x007A8B60, 0x007B8C61, 0x007B8C61, 0x00798862,
        0x007A8963, 0x007A8963, 0x007A8963, 0x007A8963, 0x007A8963, 0x007A8963, 0x00798862, 0x007C8C63, 0x0075855C, 0x007B8B62, 0x0078885F, 0x00819168, 0x0074845B, 0x0078885F, 0x0077875E, 0x00798960, 0x00798960, 0x00798960, 0x00798960, 0x00798960,
        0x00798960, 0x0078885F, 0x0078885F, 0x00707D5D, 0x005A6844, 0x0054643B, 0x004F6034, 0x005B6C40, 0x004A5B30, 0x005B6B42, 0x00576640, 0x00566841, 0x00687A53, 0x007B8D66, 0x0074865F, 0x00758760, 0x0070825B, 0x00778962, 0x0074865F, 0x0052643F,
        0x00546641, 0x00455732, 0x002F411C, 0x0050623D, 0x004D5F3A, 0x00364823, 0x00576944, 0x004E613A, 0x00475A33, 0x004F623B, 0x005C6F48, 0x00778A63, 0x0070835C, 0x006F825B, 0x0051643D, 0x0052663C, 0x0040532C, 0x00495B36, 0x0051613F, 0x0051613F,
        0x00556341, 0x004F5D3B, 0x00566442, 0x0053643F, 0x004E5F3A, 0x00485934, 0x005C6A46, 0x004D5B37, 0x003F4B27, 0x00586440, 0x0057633F, 0x004E5D37, 0x007D8C66, 0x006E7D57, 0x007B8D66, 0x0071835C, 0x0074865F, 0x0071845D, 0x0073865F, 0x00758661,
        0x00748560, 0x0074865F, 0x0073855E, 0x0073855C, 0x0073855C, 0x0073855C, 0x0074875C, 0x0073855E, 0x0074865F, 0x00758760, 0x00758760, 0x00758760, 0x00758760, 0x0074865F, 0x0074865F, 0x0074865F, 0x0074865F, 0x0074865F, 0x0073855E, 0x0073855E,
        0x0073855E, 0x0073855E, 0x0073855E, 0x0072855E, 0x0072855E, 0x0072855E, 0x0073865F, 0x0073865F, 0x0073865F, 0x0073865F, 0x0073865F, 0x00748661, 0x00748661, 0x00748661, 0x00748661, 0x00738560, 0x00738560, 0x00738560, 0x00738560, 0x00688362,
        0x0074865F, 0x007C865B, 0x006C7854, 0x006D8273, 0x00628081, 0x007899A2, 0x007997A2, 0x004F6F64, 0x00435645, 0x005F6756, 0x006D7067, 0x008E979A, 0x00D3E0E8, 0x00BDCACC, 0x0069766E, 0x00778181, 0x00858F8F, 0x008B9595, 0x00889292, 0x008A9494,
        0x008B9595, 0x00889292, 0x00879191, 0x00868D90, 0x006D797B, 0x00576668, 0x00495D5E, 0x0045595A, 0x00465859, 0x00707F81, 0x00BCC9CB, 0x00E1E9E8, 0x00BEC9BF, 0x0075836B, 0x00738361, 0x00667353, 0xFF99A08B, 0xFFFFFFFC, 0xFFFFFDFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFDFF, 0xFFFDFFF5, 0x007E8969, 0x0069774D, 0x00849269, 0x007B8862, 0x0039481C, 0x0051622F, 0x00647046, 0x00636F45, 0x00515D33, 0x004B572D, 0x005F6B41,
        0x00717D53, 0x003D491F, 0x004A562C, 0x006B7C5B, 0x0047563A, 0x005F6B59, 0x00D2DBD1, 0x00E0E6E5, 0x00C6CBCE, 0x00BDC2C5, 0x00C2C6CB, 0x00D0CFDF, 0x00E6E7F1, 0x00BBBFC0, 0x0060655C, 0x00363F2A, 0x00344121, 0x004D5B32, 0x00526135, 0x00616D51,
        0x00465234, 0x00364224, 0x00364224, 0x00465333, 0x004A5737, 0x003F4D2B, 0x00485634, 0x0065754C, 0x005B6B42, 0x005E6E45, 0x00617148, 0x00697950, 0x0073835A, 0x0053633A, 0x005C6C43, 0x00556738, 0x00586A3B, 0x005A6C3D, 0x00627347, 0x005E6F43,
        0x0058693E, 0x00607146, 0x00637449, 0x00617148, 0x005B6B42, 0x00617148, 0x0068784F, 0x0065754C, 0x0065754C, 0x0065754C, 0x00617148, 0x0064754A, 0x0064754A, 0x0064754A, 0x0064754A, 0x0065764B, 0x0065764B, 0x0065764B, 0x0065764B, 0x0065744E,
        0x0066754F, 0x00677650, 0x00677650, 0x00677650, 0x00677650, 0x0066754F, 0x0065744E, 0x005E6E45, 0x0066764D, 0x0067774E, 0x0064744B, 0x005E6E45, 0x0065754C, 0x0067774E, 0x00697950, 0x00697950, 0x00697950, 0x00697950, 0x00697950, 0x00697950,
        0x006A7A51, 0x006A7A51, 0x006A7A51, 0x00576444, 0x00546240, 0x00516138, 0x0055663A, 0x00566839, 0x004F6034, 0x0058693E, 0x0053633A, 0x006F815A, 0x007D8F68, 0x0071835C, 0x006F815A, 0x007A8C65, 0x0073855E, 0x00788A63, 0x00566841, 0x004F643E,
        0x00536842, 0x00293E18, 0x00536842, 0x00536842, 0x00556A44, 0x004B603A, 0x004A5F39, 0x0053663F, 0x00495C35, 0x004F623B, 0x005C6F48, 0x00758861, 0x006D8059, 0x007B8E67, 0x006B7E57, 0x004A6036, 0x004D623B, 0x00576846, 0x005A6949, 0x00546344,
        0x005A6648, 0x005F6C4C, 0x005B6646, 0x00566742, 0x00596A45, 0x00576843, 0x0053613D, 0x00616F4B, 0x0065714D, 0x0055613D, 0x005B6743, 0x00778660, 0x007A8963, 0x007C8B65, 0x00697B54, 0x00758760, 0x0074865F, 0x006F825B, 0x00788B64, 0x00758661,
        0x00758661, 0x0074865F, 0x0073855E, 0x0073855C, 0x0073855C, 0x0073855C, 0x0074875C, 0x0074865F, 0x0074865F, 0x00758760, 0x00768861, 0x00758760, 0x00758760, 0x0074865F, 0x0073855E, 0x0073855E, 0x0074865F, 0x0074865F, 0x0074865F, 0x0074865F,
        0x0074865F, 0x0073855E, 0x0073855E, 0x0072855E, 0x0072855E, 0x0072855E, 0x0073865F, 0x0073865F, 0x0073865F, 0x0073865F, 0x0073865F, 0x00758762, 0x00758762, 0x00748661, 0x00748661, 0x00748661, 0x00748661, 0x00738560, 0x00738560, 0x00678365,
        0x00788B64, 0x00848E63, 0x0075805A, 0x00748774, 0x00637C78, 0x006A8387, 0x00586F71, 0x0048614D, 0x00414F37, 0x00686B55, 0x0075776B, 0x00929A9A, 0x00D7E4EC, 0x00B0BFC1, 0x005C6862, 0x005E706F, 0x006E807F, 0x00748685, 0x00718382, 0x00728483,
        0x00738584, 0x00718382, 0x00718382, 0x00777F7F, 0x00626C6C, 0x0052605F, 0x00516362, 0x00516664, 0x00465857, 0x005E6E6D, 0x00A6B4B3, 0x00E4ECEC, 0x00C3CEC4, 0x007C8A72, 0x00768565, 0x00687555, 0xFF9AA08D, 0xFFFFFFFC, 0xFFFFFDFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFF, 0xF7FBFFF1, 0x007D8965, 0x0069784C, 0x00818F65, 0x0077855C, 0x003A4A1B, 0x00576934, 0x00505C32, 0x004D592F, 0x00647145, 0x00344115, 0x00697648,
        0x00546133, 0x00364315, 0x004E5C2C, 0x006C7B5F, 0x00505E46, 0x006F7A6A, 0x00CAD2CB, 0x00DBE2DF, 0x00D3D9D8, 0x00BBC1C0, 0x00C0C6C5, 0x00CCD1D4, 0x00DDE2E5, 0x00C6CBCC, 0x00747B78, 0x007D847F, 0x00616A60, 0x00586256, 0x007C8679, 0x00A2A4A4,
        0x006E716F, 0x005E625D, 0x0060645E, 0x005E6459, 0x009BA293, 0x00727A69, 0x00535B4A, 0x0056663D, 0x005E6E45, 0x0053633A, 0x005B6B42, 0x0054643B, 0x00607047, 0x006E7E55, 0x004A5A31, 0x0057653C, 0x005C6A41, 0x00616F46, 0x00606E45, 0x005C6A41,
        0x0059673E, 0x005A683F, 0x005D6B42, 0x005A6844, 0x00596743, 0x00586642, 0x005A6844, 0x005C6A46, 0x005D6B47, 0x005B6945, 0x00596743, 0x005C673F, 0x005D6840, 0x005F6A42, 0x00606B43, 0x00616C44, 0x00606B43, 0x005F6A42, 0x005E6941, 0x005C6B45,
        0x005C6B45, 0x005C6B45, 0x005C6B45, 0x005C6B45, 0x005C6B45, 0x005C6B45, 0x005C6B45, 0x00546239, 0x0057653C, 0x005B6940, 0x005C6943, 0x005D6A44, 0x005D6945, 0x005E6A46, 0x00606C48, 0x005F6B41, 0x00646F47, 0x00616C44, 0x005F6A42, 0x00636E48,
        0x00616C46, 0x005F6945, 0x00646E4A, 0x00707A56, 0x00525E3A, 0x005D6945, 0x00596541, 0x004E5C38, 0x005D6B47, 0x004F603B, 0x00758661, 0x00768962, 0x00768962, 0x006D8059, 0x0073865F, 0x006F825B, 0x00748760, 0x005B6E47, 0x004D6039, 0x005F714A,
        0x002D3E19, 0x00576646, 0x005C6B4C, 0x00536243, 0x00758464, 0x0051623D, 0x0052643D, 0x00596A3E, 0x004A5B30, 0x005A6943, 0x005A6846, 0x007E8C6A, 0x0072805C, 0x006E7D57, 0x007E8E65, 0x00717F5B, 0x0055633F, 0x0055633F, 0x0053613D, 0x0052603C,
        0x00576541, 0x00505E3A, 0x00566440, 0x0051623D, 0x00586944, 0x004F603B, 0x0051623D, 0x005D6E49, 0x00546540, 0x00576843, 0x00798A65, 0x00758760, 0x0074865F, 0x0074865F, 0x0074865F, 0x0074865F, 0x0073855E, 0x0073855E, 0x0073855E, 0x00748760,
        0x00748760, 0x00748760, 0x00748760, 0x0073865F, 0x0073865F, 0x0073865F, 0x0073865F, 0x0071845D, 0x0071845D, 0x0071845D, 0x0071845D, 0x0071845D, 0x0071845D, 0x0071845D, 0x0071845D, 0x0073865F, 0x0073865F, 0x0073865F, 0x0073865F, 0x0073865F,
        0x0073865F, 0x0073865F, 0x0073865F, 0x0072855A, 0x0076885F, 0x0071835A, 0x0075875E, 0x0074865F, 0x0071835C, 0x00788964, 0x00758661, 0x00768762, 0x00768762, 0x0073845F, 0x0073845F, 0x00778863, 0x0073845F, 0x006F805B, 0x00788964, 0x00758760,
        0x0074865F, 0x00687954, 0x006B7C57, 0x006E7E5C, 0x006E7E5C, 0x00677755, 0x004A5939, 0x00565B3E, 0x00494F38, 0x0060665B, 0x00686E6D, 0x008E999D, 0x00D3E1E7, 0x00ACBFC2, 0x0094A8A9, 0x0097A1AB, 0x009AA4AE, 0x009BA6AE, 0x009CA7AF, 0x00A4AFB7,
        0x00A7B2BA, 0x00A3AEB6, 0x00A6B1B9, 0x00A0AAB4, 0x00B4BFC7, 0x00A6B2B6, 0x00A5B2B4, 0x00ABB8BA, 0x00A4B1B3, 0x00AFBBC1, 0x00B8C4CA, 0x00E4E7EF, 0x00C9D0CB, 0x007B8771, 0x00778863, 0x00667752, 0xFF97A288, 0xFFFDFFF9, 0xFFFAFCFD, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFF, 0xFBFDFFF3, 0x007E8968, 0x0069784C, 0x00808E64, 0x0076845B, 0x003A4A1B, 0x004E602B, 0x00636F45, 0x005E6A40, 0x005C683E, 0x003B481C, 0x00637044,
        0x00475426, 0x00384517, 0x00515E30, 0x006B7862, 0x00515C4C, 0x007A8379, 0x00D8DFDC, 0x00D9DEE1, 0x00CDD1D6, 0x00CACED3, 0x00D5D9DE, 0x00D7DADE, 0x00D4D8D9, 0x00BEC3C1, 0x009AA19A, 0x00969E93, 0x004D5747, 0x0057624E, 0x0095A18B, 0x00ACB1A8,
        0x007E8479, 0x00585F52, 0x00636A5B, 0x00848D79, 0x00ABB49F, 0x00646E57, 0x00454F38, 0x0056663D, 0x00495930, 0x00607047, 0x00516138, 0x00506037, 0x0056663D, 0x0056663D, 0x00495930, 0x004F5D34, 0x00536138, 0x0057653C, 0x0058663D, 0x0056643B,
        0x00546239, 0x0056643B, 0x0058663D, 0x00566440, 0x0055633F, 0x0055633F, 0x00566440, 0x00586642, 0x00586642, 0x00576541, 0x00566440, 0x00566139, 0x0057623A, 0x0059643C, 0x005A653D, 0x005A653D, 0x0059643C, 0x0058633B, 0x0057623A, 0x0053623C,
        0x0053623C, 0x0053623C, 0x0052613B, 0x0052613B, 0x0051603A, 0x0051603A, 0x0051603A, 0x00526037, 0x00546239, 0x0058663D, 0x00596640, 0x00596640, 0x00596640, 0x005A6642, 0x005B6743, 0x005E6A40, 0x005F6A42, 0x005E6941, 0x005E6941, 0x005D6842,
        0x005D6842, 0x005D6743, 0x005E6844, 0x004A5731, 0x0066734D, 0x005D6A44, 0x0048552F, 0x005F6E48, 0x0052613B, 0x006E8059, 0x00798B64, 0x006E8057, 0x0072845B, 0x007D8F66, 0x006F8158, 0x007A8C63, 0x005B6D44, 0x005A6C43, 0x00586A41, 0x0036481F,
        0x00566841, 0x00556543, 0x00556444, 0x007D8C6C, 0x0081916F, 0x00495B34, 0x0056683F, 0x004F6336, 0x0056693E, 0x004B5D34, 0x006A7C53, 0x00677952, 0x00778962, 0x0084966F, 0x00697B54, 0x00758760, 0x00788A63, 0x007B8D66, 0x007A8C65, 0x0074865F,
        0x00758760, 0x00788A63, 0x0073855E, 0x0073845F, 0x00798A65, 0x007B8C67, 0x00748560, 0x0071825D, 0x00778863, 0x007A8B66, 0x00778863, 0x0072845D, 0x0072845D, 0x0073855E, 0x0073855E, 0x0074865F, 0x00758760, 0x00768861, 0x00768861, 0x00748760,
        0x00748760, 0x00748760, 0x0073865F, 0x0073865F, 0x0073865F, 0x0073865F, 0x0072855E, 0x0072855E, 0x0072855E, 0x0072855E, 0x0072855E, 0x0072855E, 0x0072855E, 0x0072855E, 0x0072855E, 0x0073865F, 0x0073865F, 0x0073865F, 0x0073865F, 0x0073865F,
        0x0073865F, 0x0073865F, 0x0073865F, 0x0072855A, 0x0075875E, 0x0071835A, 0x0075875E, 0x00768861, 0x0073855E, 0x00788964, 0x00768762, 0x0073845F, 0x00758661, 0x0073845F, 0x00778863, 0x00768762, 0x00748560, 0x00798A65, 0x00768762, 0x0064764F,
        0x00556740, 0x0053643F, 0x00647550, 0x00556543, 0x005B6B49, 0x005A6A48, 0x00617050, 0x00545D3C, 0x004D563B, 0x00676F5E, 0x00737C72, 0x00959F99, 0x00D8E6E2, 0x00DAEAE3, 0x00D9EAE1, 0x00DDE8E6, 0x00E0EBE9, 0x00E0EBE9, 0x00E0EBE9, 0x00E1ECEA,
        0x00DFEAE8, 0x00E1ECEA, 0x00EBF6F4, 0x00E6EFF2, 0x00DDE7E7, 0x00E2EDEB, 0x00E6F1EE, 0x00E2EEE8, 0x00E2EEE8, 0x00E1ECE9, 0x00D9E4E1, 0x00E2E8E7, 0x00CAD4C8, 0x00859377, 0x007C8E67, 0x0064764F, 0xFF949F85, 0xFFFDFFF9, 0xFFF9FAFE, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFCFF, 0xFFFDFFF5, 0x00808B6A, 0x006D7B51, 0x0086946B, 0x007B8960, 0x00415024, 0x00495B26, 0x00778359, 0x0069754B, 0x0048542A, 0x00404D21, 0x00616E42,
        0x00455226, 0x003A4719, 0x00485527, 0x00687261, 0x004F584B, 0x006C736C, 0x00D1D6D5, 0x00E6E9ED, 0x00D7DADF, 0x00D0D3D8, 0x00D6D9DD, 0x00DCDCDC, 0x00F1F2EE, 0x00B8BBB2, 0x006C7162, 0x006B725D, 0x00586146, 0x00677252, 0x00545F3E, 0x005D6750,
        0x00646E57, 0x00566147, 0x00576347, 0x00566244, 0x00596646, 0x003B4927, 0x0053613F, 0x0075855C, 0x0077875E, 0x006E7E55, 0x007A8A61, 0x0058683F, 0x0058683F, 0x005A6A41, 0x0056663D, 0x0058663D, 0x005B6940, 0x005D6B42, 0x005E6C43, 0x005E6C43,
        0x005D6B42, 0x005E6C43, 0x005F6D44, 0x005D6C46, 0x005D6C46, 0x005D6C46, 0x005E6D47, 0x005F6E48, 0x005F6E48, 0x005E6D47, 0x005D6C46, 0x00636E46, 0x00636E46, 0x00646F47, 0x00657048, 0x00657048, 0x00646F47, 0x00626D45, 0x00626D45, 0x005E6E45,
        0x005E6E45, 0x005D6D44, 0x005C6C43, 0x005B6B42, 0x005B6B42, 0x005A6A41, 0x005A6A41, 0x005B693F, 0x005D6B41, 0x005F6D44, 0x00616F46, 0x00616E48, 0x00606D47, 0x00616E48, 0x00616D49, 0x00657147, 0x00636E46, 0x00657048, 0x0067724A, 0x0066714B,
        0x0068734D, 0x006A7450, 0x0068724E, 0x006B7950, 0x005B6940, 0x004F5D34, 0x00697950, 0x005E6E45, 0x00708259, 0x0075875E, 0x0075875E, 0x007B895F, 0x0077855B, 0x0079875D, 0x00839167, 0x00647248, 0x005A683E, 0x005D6B41, 0x0039471D, 0x005B6E43,
        0x0052643B, 0x005F704B, 0x007D8D6B, 0x007C8C6A, 0x0070815C, 0x00596B42, 0x0055683D, 0x005D6F46, 0x00516439, 0x00506437, 0x0055693C, 0x007A8E61, 0x0072845B, 0x006D7F58, 0x007A8B66, 0x006F8158, 0x00788A61, 0x006F8158, 0x0072845B, 0x00708259,
        0x00708259, 0x007D8F66, 0x0071835A, 0x0072835E, 0x006F805B, 0x0073845F, 0x00778863, 0x00758661, 0x00798A65, 0x007B8C67, 0x00748560, 0x0072845D, 0x0072845D, 0x0073855E, 0x0074865F, 0x00758760, 0x00758760, 0x00768861, 0x00768861, 0x00748760,
        0x0073865F, 0x0073865F, 0x0073865F, 0x0073865F, 0x0072855E, 0x0072855E, 0x0072855E, 0x0072855E, 0x0072855E, 0x0072855E, 0x0072855E, 0x0072855E, 0x0072855E, 0x0072855E, 0x0072855E, 0x0073865F, 0x0073865F, 0x0073865F, 0x0073865F, 0x0073865F,
        0x0073865F, 0x0073865F, 0x0073865F, 0x0072855A, 0x0075875E, 0x0072845B, 0x0075875E, 0x00758760, 0x0073855E, 0x00768762, 0x0073845F, 0x0072835E, 0x00768762, 0x00748560, 0x00798A65, 0x00748560, 0x0073845F, 0x00788964, 0x00687954, 0x005B6D46,
        0x004E6039, 0x005B6C47, 0x00576843, 0x0051613F, 0x005A6A48, 0x00536341, 0x004F5E3E, 0x005E6D47, 0x005A6846, 0x006D795D, 0x0078846E, 0x008D9884, 0x00AFB9A8, 0x00AEBAA6, 0x00A1AD99, 0x00A6B29E, 0x00A5B19D, 0x00A0AC98, 0x00A1AD99, 0x00A3AF9D,
        0x009CA896, 0x0097A391, 0x0099A593, 0x0099A397, 0x008B9589, 0x00929C90, 0x00899386, 0x008A9585, 0x00A3AF9D, 0x00A1AD9B, 0x009AA692, 0x009EA999, 0x0096A48C, 0x00768762, 0x00788B60, 0x00657750, 0xFF97A288, 0xFFFCFFFA, 0xFFFCFDFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFCFF, 0xFFFEFFF6, 0x00808B6A, 0x006B794F, 0x00818F66, 0x00727F59, 0x003B4A1E, 0x00384916, 0x0037451C, 0x003C4A21, 0x002B390F, 0x00334117, 0x003F4E22,
        0x00303F13, 0x00344317, 0x004D5D2E, 0x0068765A, 0x005A674F, 0x005C6655, 0x00B5BDB2, 0x00E9F0E9, 0x00E0E7E0, 0x00D3DBD1, 0x00DAE2D8, 0x00ECEDE4, 0x00EAEBE1, 0x00B3B6A6, 0x00797F68, 0x0071795B, 0x005D6842, 0x007C885E, 0x00788557, 0x00717F5B,
        0x00768460, 0x0071805A, 0x00788761, 0x006C7C53, 0x006D7E53, 0x006E7F54, 0x00809166, 0x0077875E, 0x0077875E, 0x007C8C63, 0x00728259, 0x0068784F, 0x0045552C, 0x00627249, 0x0055653C, 0x005E6C42, 0x005E6C42, 0x005E6C42, 0x005E6C42, 0x005E6C42,
        0x005D6B41, 0x005C6A40, 0x005B693F, 0x005B6B42, 0x005B6B42, 0x005B6B42, 0x005C6C43, 0x005C6C43, 0x005C6C43, 0x005B6B42, 0x005B6B42, 0x0059673D, 0x005A683E, 0x005A683E, 0x005A683E, 0x005A683E, 0x0059673D, 0x0058663C, 0x0057653B, 0x0057673E,
        0x0057673E, 0x0057673E, 0x0056663D, 0x0056663D, 0x0055653C, 0x0055653C, 0x0055653C, 0x0056673C, 0x0057683D, 0x0058693E, 0x005A6A41, 0x005A6A41, 0x00596842, 0x00596842, 0x00586741, 0x005B693F, 0x005D6B42, 0x005B6940, 0x005A683F, 0x005C6943,
        0x005B6842, 0x00596541, 0x00596541, 0x00637148, 0x005C6A41, 0x005A6A41, 0x004F5F36, 0x006D7F56, 0x0082946B, 0x007A8E64, 0x0074885E, 0x007C875F, 0x007D8860, 0x007D8860, 0x006C774F, 0x005E6941, 0x0069744C, 0x003B461E, 0x00515C34, 0x005D7144,
        0x005F7247, 0x00758760, 0x00788964, 0x0072835E, 0x007C8E67, 0x005E7146, 0x00576B3E, 0x00556740, 0x00405328, 0x005D7144, 0x004A5E2F, 0x00677B4E, 0x00778A5F, 0x0081936C, 0x00738361, 0x0074865D, 0x00798B62, 0x0075875E, 0x007C8E65, 0x00798B62,
        0x00708259, 0x007B8D64, 0x007A8C63, 0x007C8D68, 0x00788964, 0x0072835E, 0x00768762, 0x007B8C67, 0x00748560, 0x006F805B, 0x00778863, 0x00758760, 0x00758760, 0x00758760, 0x0074865F, 0x0074865F, 0x0074865F, 0x0074865F, 0x0074865F, 0x0073865F,
        0x0073865F, 0x0073865F, 0x0073865F, 0x0073865F, 0x0072855E, 0x0072855E, 0x0072855E, 0x0072855E, 0x0072855E, 0x0072855E, 0x0072855E, 0x0072855E, 0x0072855E, 0x0072855E, 0x0072855E, 0x0073865F, 0x0073865F, 0x0073865F, 0x0073865F, 0x0073865F,
        0x0073865F, 0x0073865F, 0x0073865F, 0x0074875C, 0x0075875E, 0x0074865D, 0x0075875E, 0x0074865F, 0x0072845D, 0x0073845F, 0x0072835E, 0x00768762, 0x00778863, 0x00788964, 0x00748560, 0x0073845F, 0x0073845F, 0x00667752, 0x00556641, 0x00556740,
        0x00556740, 0x005E6F4A, 0x0040512C, 0x00546442, 0x005F6F4D, 0x00697957, 0x005B6A4A, 0x00506239, 0x00667851, 0x007C8D68, 0x007F8C6C, 0x00818D6F, 0x00818A6F, 0x0080896E, 0x007A8368, 0x0073845F, 0x00788866, 0x0071815F, 0x006C7B5B, 0x00667556,
        0x00556445, 0x00475539, 0x003E4C30, 0x0037422E, 0x00545F4B, 0x005D6854, 0x00495440, 0x005D6953, 0x007B886E, 0x00718061, 0x006D7D5B, 0x00718064, 0x00768765, 0x0074875C, 0x007C9063, 0x006A7C55, 0xFF9BA58E, 0xFFFCFFFA, 0xFFFDFDFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFDFF, 0xFFFFFFF8, 0x007F8A6A, 0x006A784F, 0x00818E68, 0x0076835D, 0x00505E34, 0x004C5D2A, 0x0048562D, 0x004F5D34, 0x004C5A31, 0x004E5C32, 0x0049572D,
        0x0048572B, 0x00455428, 0x005C6B3F, 0x006B7E53, 0x00677952, 0x00566644, 0x007F8D71, 0x0099A68C, 0x008D9A80, 0x008A987C, 0x0096A586, 0x00878A7A, 0x00989C89, 0x008B9178, 0x005B6345, 0x0056613B, 0x005F6C40, 0x007F8D5D, 0x007A8956, 0x007F9064,
        0x0078895D, 0x00708155, 0x007C8D61, 0x007A8C5D, 0x007D8F60, 0x007D8F60, 0x00728455, 0x00798960, 0x0074845B, 0x007A8A61, 0x0074845B, 0x00506037, 0x00617148, 0x00516138, 0x00617148, 0x005B693F, 0x005A683E, 0x005A683E, 0x005A683E, 0x005A683E,
        0x0059673D, 0x0058663C, 0x0057653B, 0x0054653A, 0x0055663B, 0x0056673C, 0x0056673C, 0x0055663B, 0x0055663B, 0x0054653A, 0x0054653A, 0x0059673D, 0x0059673D, 0x0059673D, 0x0059673D, 0x0059673D, 0x0058663C, 0x0057653B, 0x0057653B, 0x0056663D,
        0x0056663D, 0x0056663D, 0x0057673E, 0x0057673E, 0x0057673E, 0x0058683F, 0x0058683F, 0x0056673B, 0x0057683C, 0x0058693E, 0x00596A3F, 0x005A6A41, 0x00596940, 0x00586741, 0x00576640, 0x00556339, 0x005D6B42, 0x0059673E, 0x0058663D, 0x00616E48,
        0x005F6C46, 0x005A6642, 0x00616D49, 0x0053623C, 0x00586741, 0x005E6D47, 0x006D7F58, 0x0074865F, 0x0053663F, 0x00596C45, 0x0063764F, 0x005E6B45, 0x0064714B, 0x0065724C, 0x00525F39, 0x005A6741, 0x003E4B25, 0x00505D37, 0x006D7A54, 0x00566A3D,
        0x0073855C, 0x007A8C65, 0x00748462, 0x007A8A68, 0x00778962, 0x004C5E35, 0x00516538, 0x0051643D, 0x00485C32, 0x00384C22, 0x00586C42, 0x0054683E, 0x0050633C, 0x005B6D48, 0x00596A48, 0x005B6E47, 0x00576A43, 0x005B6E47, 0x006B7E57, 0x00798C65,
        0x00798C65, 0x0070835C, 0x006B7E57, 0x00748560, 0x00788964, 0x00748560, 0x0070815C, 0x00748560, 0x0073845F, 0x0070815C, 0x0072835E, 0x00758760, 0x00758760, 0x00758760, 0x00758760, 0x00758760, 0x0074865F, 0x0074865F, 0x0074865F, 0x00748760,
        0x00748760, 0x0073865F, 0x0073865F, 0x0073865F, 0x0073865F, 0x0072855E, 0x0072855E, 0x0073865F, 0x0073865F, 0x0073865F, 0x0073865F, 0x0073865F, 0x0073865F, 0x0073865F, 0x0073865F, 0x0073865F, 0x0073865F, 0x0073865F, 0x0073865F, 0x0073865F,
        0x0073865F, 0x0073865F, 0x0073865F, 0x0074875C, 0x0075875E, 0x00778960, 0x0076885F, 0x0074865F, 0x0074865F, 0x00748560, 0x00768762, 0x00758661, 0x00758661, 0x007A8B66, 0x006F805B, 0x00788964, 0x00768762, 0x0053643F, 0x004F603B, 0x0053653E,
        0x006C7E57, 0x005E6F4A, 0x0053643F, 0x00536341, 0x00576745, 0x00546442, 0x00526141, 0x0064784E, 0x007A8D66, 0x0081936C, 0x006A7B56, 0x006F7C5C, 0x00626E52, 0x00636D56, 0x0069705B, 0x005A6A41, 0x0068784F, 0x005E6D47, 0x004F5D39, 0x00445230,
        0x00424F2F, 0x004E5A3C, 0x00535F43, 0x003A442D, 0x00636C57, 0x005D6652, 0x0048503F, 0x00606954, 0x00798569, 0x00788662, 0x007C8C63, 0x00758664, 0x00788B64, 0x007C8F64, 0x007C8F64, 0x00667752, 0xFF97A08B, 0xFFFCFFFA, 0xFFFDFEFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFDFF, 0xFFFFFFF8, 0x007E8969, 0x006C7A51, 0x0087946E, 0x0084906C, 0x0077855B, 0x00788858, 0x007F8E68, 0x00788761, 0x0077875E, 0x0075855C, 0x0074855A,
        0x007F9065, 0x0075865B, 0x007B8C60, 0x00748754, 0x00738655, 0x006E7F54, 0x007B8A64, 0x0074835D, 0x006E7D57, 0x00798960, 0x007E8F64, 0x00767F64, 0x00717B5D, 0x00788363, 0x006B7753, 0x00728057, 0x00748357, 0x007E8E5F, 0x007C8C5C, 0x00738556,
        0x007D8F60, 0x007A8C5D, 0x00788A5B, 0x00758758, 0x006F8054, 0x0075865A, 0x0075865A, 0x00819168, 0x006E7E55, 0x00708057, 0x00506037, 0x00526239, 0x0055653C, 0x0067774E, 0x00697950, 0x00748357, 0x00748357, 0x00748357, 0x00748357, 0x00758458,
        0x00768559, 0x00758458, 0x00758458, 0x00718256, 0x00728357, 0x00738458, 0x00738458, 0x00728357, 0x00718256, 0x00718256, 0x00718256, 0x006F8054, 0x006F8054, 0x006F8054, 0x006E7F53, 0x006E7F53, 0x006E7F53, 0x006E7F53, 0x006E7F53, 0x006B7C51,
        0x006C7D52, 0x006C7D52, 0x006D7E53, 0x006E7F54, 0x006F8055, 0x006F8055, 0x00708156, 0x006A7E51, 0x006A7E51, 0x006B7F52, 0x006D8055, 0x006E8156, 0x006E8057, 0x006C7E55, 0x006B7D54, 0x0067784D, 0x006F7F56, 0x006D7D54, 0x006B7B52, 0x00707F59,
        0x006D7C56, 0x00697753, 0x006F7D59, 0x006C7A58, 0x00717F5D, 0x0070805E, 0x006C7C5A, 0x00435432, 0x005E6F4D, 0x005E6F4D, 0x004F6340, 0x00627151, 0x00586747, 0x005A6949, 0x005A6949, 0x00435232, 0x00404F2F, 0x005C6B4B, 0x00475636, 0x007A8C63,
        0x007E9069, 0x0071815F, 0x00819070, 0x00718060, 0x00596947, 0x00556740, 0x0056683F, 0x0043572D, 0x005A6D46, 0x00485938, 0x0037462A, 0x00536246, 0x00607051, 0x005E6F4D, 0x005B6D48, 0x00667755, 0x005B6C4A, 0x0050613F, 0x00516240, 0x00657654,
        0x00778866, 0x00798A68, 0x00798A68, 0x00798A65, 0x0070815C, 0x00748560, 0x007C8D68, 0x00778863, 0x0072835E, 0x0071825D, 0x006F805B, 0x0073855E, 0x0073855E, 0x0074865F, 0x0074865F, 0x00758760, 0x00768861, 0x00778962, 0x00778962, 0x00748760,
        0x00748760, 0x00748760, 0x00748760, 0x0073865F, 0x0073865F, 0x0073865F, 0x0073865F, 0x00748760, 0x00748760, 0x00748760, 0x00748760, 0x00748760, 0x00748760, 0x00748760, 0x00748760, 0x0073865F, 0x0073865F, 0x0073865F, 0x0073865F, 0x0073865F,
        0x0073865F, 0x0073865F, 0x0073865F, 0x0074875C, 0x0074865D, 0x00798B62, 0x0075875E, 0x0071835C, 0x0072845D, 0x0072835E, 0x00788964, 0x0072835E, 0x0073845F, 0x00788964, 0x0070815C, 0x00798A65, 0x006F805B, 0x004B5C37, 0x00546540, 0x0061734C,
        0x0083956E, 0x0053643F, 0x0062734E, 0x004D5D3B, 0x00798967, 0x00748462, 0x00849373, 0x007B8C67, 0x007B8D68, 0x007D8E6C, 0x005D6E4D, 0x006F7E63, 0x00677563, 0x00606B61, 0x00626C66, 0x0052633E, 0x0060704E, 0x00526141, 0x00475539, 0x00435036,
        0x0045513B, 0x0055604C, 0x0058634F, 0x00596352, 0x00636D5D, 0x005D655A, 0x00586056, 0x00646D60, 0x00707D65, 0x00758464, 0x0075875E, 0x00758664, 0x00778964, 0x007A8C65, 0x00788A63, 0x00627151, 0xFF949D89, 0xFFFDFFF9, 0xFFFDFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFCFF, 0xFFFFFFF8, 0x007C8668, 0x006A784F, 0x00828F69, 0x007C8864, 0x007C8A61, 0x00819161, 0x007C8B65, 0x00788761, 0x007F8E68, 0x007C8C63, 0x0073835A,
        0x0078895E, 0x007C8D62, 0x00809166, 0x007C8F5E, 0x007C8D61, 0x00819168, 0x00879670, 0x0082906C, 0x00808F69, 0x0084946B, 0x00829368, 0x007F916A, 0x007D8F68, 0x00859770, 0x007E9069, 0x007F9168, 0x00788A61, 0x007D8F66, 0x00798B62, 0x007E8F63,
        0x00798A5E, 0x00718256, 0x006E7F54, 0x007B8C61, 0x0078885F, 0x007B8B62, 0x0076865D, 0x0077875E, 0x00708057, 0x00506037, 0x0057673E, 0x0055653C, 0x006B7B52, 0x007F8F66, 0x007E8E65, 0x00768559, 0x00768559, 0x00768559, 0x00768559, 0x00768559,
        0x00768559, 0x0077865A, 0x0077865A, 0x00738458, 0x00748559, 0x0076875B, 0x0075865A, 0x00738458, 0x00728357, 0x00728357, 0x00738458, 0x00748559, 0x00748559, 0x00748559, 0x00748559, 0x00748559, 0x0075865A, 0x0075865A, 0x0075865A, 0x00728358,
        0x00738459, 0x00738459, 0x0074855A, 0x0074855A, 0x0075865B, 0x0075865B, 0x0075865B, 0x0075895C, 0x0074885B, 0x0075895C, 0x00778B5E, 0x00798C61, 0x00798C61, 0x00778960, 0x0076885F, 0x00798A5F, 0x0076865D, 0x0078885F, 0x0073835A, 0x0066754F,
        0x005F6E48, 0x005E6C48, 0x005A6844, 0x00596849, 0x004E5D3E, 0x005E6D4E, 0x00485839, 0x00586849, 0x00415132, 0x002F4122, 0x00394B2C, 0x00415336, 0x0035472A, 0x004B5D40, 0x003D4F32, 0x0037492C, 0x005F7154, 0x00293B1E, 0x0046583B, 0x005B6C47,
        0x00667654, 0x004E5D3E, 0x004F5D41, 0x004C5A3E, 0x00485738, 0x004E5E3C, 0x005D6E49, 0x00748B5E, 0x00475B38, 0x0057674F, 0x00414E40, 0x00556254, 0x0041503B, 0x003A4C2D, 0x003A4F28, 0x00304223, 0x00405233, 0x00445637, 0x00536546, 0x00596B4C,
        0x00516344, 0x00566849, 0x00586A4B, 0x005F704B, 0x00546540, 0x00596A45, 0x006D7E59, 0x00778863, 0x0073845F, 0x0071825D, 0x00768762, 0x0073855E, 0x0073855E, 0x0074865F, 0x00758760, 0x00768861, 0x00768861, 0x00778962, 0x00778962, 0x00758861,
        0x00758861, 0x00758861, 0x00748760, 0x00748760, 0x00748760, 0x00748760, 0x00748760, 0x00748760, 0x00748760, 0x00748760, 0x00748760, 0x00748760, 0x00748760, 0x00748760, 0x00748760, 0x0073865F, 0x0073865F, 0x0073865F, 0x0073865F, 0x0073865F,
        0x0073865F, 0x0073865F, 0x0073865F, 0x0074875C, 0x0073855C, 0x00788A61, 0x006F8158, 0x00667851, 0x00667851, 0x00657651, 0x006E7F5A, 0x0071825D, 0x00768762, 0x0073845F, 0x00768762, 0x0070815C, 0x00546540, 0x00455631, 0x0051623D, 0x0054663F,
        0x0061734C, 0x00465732, 0x00556641, 0x00425230, 0x00647452, 0x005F6F4D, 0x006D7C5C, 0x006C785A, 0x005C6B4C, 0x00758566, 0x0055684F, 0x00647665, 0x005E6F6B, 0x0054646B, 0x005D6A78, 0x004D5B43, 0x00606E56, 0x00687460, 0x00838F7D, 0x0097A194,
        0x00959E94, 0x00979E99, 0x008E9590, 0x00818A80, 0x00808782, 0x00979C9D, 0x00A3A8AB, 0x00A3AAA7, 0x009CA699, 0x00839277, 0x00758664, 0x0077866A, 0x007A8A6B, 0x007B8A6A, 0x007B8A6A, 0x0068765A, 0xFF969F8B, 0xFFFDFFF9, 0xFFFAFEF9, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFCFF, 0xFFFDFFF7, 0x007D8769, 0x006D7A54, 0x00838F6B, 0x00798561, 0x007C8A61, 0x00829262, 0x0082916B, 0x00798862, 0x007B8A64, 0x007F8F66, 0x007C8C63,
        0x0078895E, 0x007F9065, 0x0077885D, 0x007A8B60, 0x007D8C66, 0x007B8967, 0x00778464, 0x007A8668, 0x00748161, 0x00697753, 0x006E7D57, 0x006B7F54, 0x00697D52, 0x006C8055, 0x0075895F, 0x007C8F68, 0x0071845D, 0x00798B66, 0x0072845F, 0x007B8C61,
        0x00728358, 0x00798A5F, 0x0078885F, 0x00788761, 0x0071805A, 0x007E8C68, 0x007C8A66, 0x006E7E55, 0x0053633A, 0x00596940, 0x0054643B, 0x0067774E, 0x007C8C63, 0x0073835A, 0x0075855C, 0x007B8A5E, 0x007B8A5E, 0x007B8A5E, 0x0079885C, 0x0077865A,
        0x00768559, 0x00768559, 0x0077865A, 0x00738556, 0x00758758, 0x00768859, 0x00768859, 0x00748657, 0x00728455, 0x00738556, 0x00738556, 0x00738458, 0x00738458, 0x00738458, 0x00738458, 0x00738458, 0x00748559, 0x0075865A, 0x0075865A, 0x0074855A,
        0x0074855A, 0x0074855A, 0x0074855A, 0x0074855A, 0x0074855A, 0x0074855A, 0x0074855A, 0x00718556, 0x00708457, 0x00718558, 0x0073875A, 0x0075885D, 0x0076895E, 0x0074865D, 0x0072845B, 0x00798A5F, 0x006E7E55, 0x0078885F, 0x0077875E, 0x005E6D47,
        0x005B6A44, 0x0062704C, 0x0055633F, 0x0038452B, 0x00455238, 0x003C492F, 0x0057664B, 0x00415035, 0x0037482D, 0x00627358, 0x0067785D, 0x003A4D34, 0x00374A31, 0x00485B42, 0x0055684F, 0x0050634A, 0x002B3E25, 0x0043563D, 0x00667960, 0x005B6A4A,
        0x003B4A2B, 0x0049563C, 0x00606D55, 0x0056634B, 0x00546147, 0x00546344, 0x007A8969, 0x00738A5D, 0x006B7F5C, 0x004D5B49, 0x00656F69, 0x0078817E, 0x00536052, 0x00344627, 0x003D5329, 0x00627358, 0x0055664B, 0x00304126, 0x00425338, 0x004C5D42,
        0x00324328, 0x0035462B, 0x002D3E23, 0x004B5C37, 0x00596A45, 0x0051623D, 0x0052633E, 0x0071825D, 0x007B8C67, 0x0070815C, 0x0072835E, 0x00768861, 0x00768861, 0x00768861, 0x00758760, 0x00758760, 0x00758760, 0x00758760, 0x0074865F, 0x00768962,
        0x00758861, 0x00758861, 0x00758861, 0x00758861, 0x00748760, 0x00748760, 0x00748760, 0x00748760, 0x00748760, 0x00748760, 0x00748760, 0x00748760, 0x00748760, 0x00748760, 0x00748760, 0x0073865F, 0x0073865F, 0x0073865F, 0x0073865F, 0x0073865F,
        0x0073865F, 0x0073865F, 0x0073865F, 0x0074875C, 0x0072845B, 0x0076885F, 0x00687A51, 0x005A6C45, 0x00576942, 0x00556641, 0x005E6F4A, 0x00748560, 0x007B8C67, 0x0070815C, 0x007B8C67, 0x00647550, 0x00384924, 0x003E4F2A, 0x00475833, 0x0042542D,
        0x0024360F, 0x00394A25, 0x003C4D28, 0x003D4D2B, 0x002E3E1C, 0x00495937, 0x006F7E5E, 0x00869276, 0x00556347, 0x00718065, 0x00556853, 0x006B7E75, 0x006E8186, 0x005F7083, 0x005F708B, 0x00515E4E, 0x00616E5E, 0x006B776B, 0x008E9991, 0x00A2ABA8,
        0x0098A0A0, 0x009BA2A5, 0x00999FA4, 0x00959E9B, 0x008F9699, 0x00A9AEB7, 0x00A2A6B1, 0x009FA5AA, 0x009DA8A0, 0x00778671, 0x00728465, 0x0076846C, 0x0078876C, 0x00768468, 0x00778569, 0x0067745A, 0xFF949C8B, 0xFFFDFFF8, 0xFFF7FBF5, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFF, 0xFFFFFEFE, 0x00788664, 0x006E8450, 0x00788768, 0x0082906C, 0x0060703A, 0x00667045, 0x00626E44, 0x00677349, 0x00647046, 0x006B774D, 0x00677349,
        0x00667248, 0x00616D43, 0x00748056, 0x00778863, 0x00495838, 0x0049563C, 0x005B6751, 0x003F4C34, 0x00334223, 0x0030421B, 0x00384B20, 0x002B3820, 0x00303D23, 0x00374529, 0x00414E2E, 0x004C5A38, 0x005F6C46, 0x00818F66, 0x0076845A, 0x007F9261,
        0x00718453, 0x007B8D5E, 0x007A8B60, 0x0074845B, 0x007B8A64, 0x007A8864, 0x00768462, 0x00617148, 0x00516138, 0x00526239, 0x006B7C51, 0x007D8E63, 0x00798A5F, 0x00748559, 0x0076875B, 0x00768859, 0x00768859, 0x00768859, 0x00758758, 0x00758758,
        0x00748657, 0x00748657, 0x00748657, 0x0078875B, 0x0078875B, 0x0077865A, 0x0077865A, 0x0077865A, 0x0077865A, 0x00768559, 0x00768559, 0x00738458, 0x00728357, 0x00728357, 0x00728357, 0x00738458, 0x00748559, 0x00738458, 0x00728357, 0x0074855A,
        0x0075865B, 0x0075865B, 0x0076875C, 0x0076875C, 0x0075865B, 0x0075865B, 0x0074855A, 0x00728455, 0x00728455, 0x00748559, 0x0075865A, 0x0076875C, 0x0077885D, 0x0077885D, 0x0077875E, 0x00738955, 0x00768B5A, 0x006F8257, 0x0070825D, 0x00526243,
        0x0058694E, 0x0034432E, 0x00677563, 0x00536A3D, 0x005E6E57, 0x00737B7A, 0x00737F79, 0x002A3D22, 0x00415936, 0x0041553E, 0x004E5C58, 0x006D7A62, 0x006F7969, 0x00727972, 0x006D776B, 0x004D5A44, 0x0027391C, 0x0051614A, 0x00374434, 0x00677B58,
        0x005F7055, 0x005B685A, 0x007A847E, 0x0077827A, 0x003E4D38, 0x00667A57, 0x00748B5E, 0x00798C61, 0x0076885F, 0x00495838, 0x00515A4D, 0x00717576, 0x006B706F, 0x00596450, 0x0072835E, 0x00424F3F, 0x004A5A43, 0x00435439, 0x00293521, 0x00616B5F,
        0x00636B60, 0x0057644C, 0x0051613F, 0x0067706D, 0x0037423A, 0x00596454, 0x00455439, 0x00718060, 0x006B7B59, 0x0073845F, 0x0075835F, 0x0072845F, 0x0072845F, 0x0072845F, 0x00738560, 0x00738560, 0x00738560, 0x00738560, 0x00748661, 0x00778962,
        0x00768861, 0x00758760, 0x00758760, 0x0074865F, 0x00758760, 0x00758760, 0x00758760, 0x00768861, 0x00758760, 0x0074865F, 0x0073855E, 0x0073855E, 0x0074865F, 0x00758760, 0x00768861, 0x00778962, 0x00778962, 0x00768861, 0x00758760, 0x0073855E,
        0x0073855E, 0x0074865F, 0x00768861, 0x00768C62, 0x006D8359, 0x00768B65, 0x00586C49, 0x0057694A, 0x00435538, 0x005D6E53, 0x004C5C44, 0x007F8A69, 0x007C8668, 0x00758163, 0x00798765, 0x0063754C, 0x00485938, 0x00656F63, 0x005C5F67, 0x004F603B,
        0x001F2919, 0x00424647, 0x00626964, 0x0059684D, 0x00364928, 0x003C4939, 0x004D5358, 0x00726E7A, 0x00787965, 0x00788254, 0x00465539, 0x005B7282, 0x006C89BC, 0x006587BC, 0x006B92B9, 0x005E6C66, 0x00536449, 0x006D7C5D, 0x008A8E88, 0x00B0ADB6,
        0x00959798, 0x00A1A6A5, 0x009FA5AA, 0x00ABB7BD, 0x00A8B6B5, 0x009CAAA6, 0x00A1ABAB, 0x00A2A8AD, 0x009BA29F, 0x007B8872, 0x0073855E, 0x00798B62, 0x00778765, 0x00798869, 0x00798765, 0x00687652, 0xFF96A082, 0xFFFFFFF8, 0xFFFDFBFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFF, 0xFFFFFEFE, 0x00798765, 0x00738955, 0x007B8A6B, 0x0073815D, 0x003F4F19, 0x00414B20, 0x0039451B, 0x00364218, 0x0039451B, 0x0039451B, 0x002D390F,
        0x0038441A, 0x003C481E, 0x004C582E, 0x00687758, 0x004F5C44, 0x00535D4D, 0x00889086, 0x009CA49A, 0x00A3AC9F, 0x00A1AC98, 0x00A0AD93, 0x0099A392, 0x00A5AF9E, 0x00727E68, 0x00444F35, 0x004A5638, 0x00576242, 0x007C8864, 0x0084906C, 0x007C8D61,
        0x00798A5E, 0x007C8D61, 0x00809166, 0x0078885F, 0x0075855C, 0x006F7E58, 0x005A6943, 0x0054643B, 0x0058683F, 0x0066764D, 0x0076875C, 0x007B8C61, 0x0075865A, 0x00748559, 0x00798A5E, 0x00768859, 0x00768859, 0x00768859, 0x00758758, 0x00758758,
        0x00748657, 0x00748657, 0x00748657, 0x0078875B, 0x0077865A, 0x0077865A, 0x0077865A, 0x0077865A, 0x00768559, 0x00768559, 0x00768559, 0x00748559, 0x00738458, 0x00738458, 0x00738458, 0x00748559, 0x0075865A, 0x00748559, 0x00738458, 0x0074855A,
        0x0074855A, 0x0075865B, 0x0075865B, 0x0075865B, 0x0075865B, 0x0074855A, 0x0074855A, 0x00718354, 0x00728455, 0x00738556, 0x0075865A, 0x0076875B, 0x0076875C, 0x0076875C, 0x0076875C, 0x006D834F, 0x00728756, 0x0082956A, 0x0071845D, 0x004A5B3A,
        0x00637257, 0x0062725B, 0x004E5D48, 0x003E5027, 0x0065715D, 0x006B726F, 0x00717972, 0x00304126, 0x00465B35, 0x005D7055, 0x005B695D, 0x003F4E2F, 0x004F5948, 0x00535A53, 0x00535C52, 0x004E5A46, 0x00344327, 0x0058694E, 0x00596853, 0x00546543,
        0x00425136, 0x00545F4F, 0x00676F68, 0x00687167, 0x0044503C, 0x005D6E4C, 0x007B9063, 0x00718459, 0x007B8D64, 0x00576646, 0x005B6555, 0x00767B7A, 0x006A6F6D, 0x00444F3B, 0x00445530, 0x00677760, 0x0056684B, 0x00415132, 0x0036432D, 0x00656F63,
        0x005E665C, 0x005A6551, 0x003C4B2B, 0x005A6A52, 0x005E6F54, 0x00647554, 0x004B5D38, 0x0074865F, 0x007B8D66, 0x00748560, 0x00717F5D, 0x00738560, 0x00738560, 0x00738560, 0x00738560, 0x00738560, 0x00748661, 0x00748661, 0x00748661, 0x00768861,
        0x00768861, 0x00758760, 0x00758760, 0x0074865F, 0x0074865F, 0x00758760, 0x00758760, 0x00768861, 0x00758760, 0x0074865F, 0x0073855E, 0x0073855E, 0x0074865F, 0x00758760, 0x00768861, 0x00758760, 0x00768861, 0x00768861, 0x00758760, 0x0074865F,
        0x0074865F, 0x00758760, 0x00768861, 0x00758B61, 0x0073895F, 0x00748962, 0x00566A47, 0x00536645, 0x004E6043, 0x0066775C, 0x00536449, 0x005F6F46, 0x00788662, 0x007A8866, 0x00778960, 0x006A7E51, 0x004C5E37, 0x005D6957, 0x00606665, 0x004B5B39,
        0x00404A3A, 0x00888C8D, 0x00A9B0AB, 0x007C8A72, 0x00314122, 0x00596658, 0x00A3A9AE, 0x008D969F, 0x004A5640, 0x00415324, 0x00516947, 0x00708D92, 0x007698BC, 0x0082A8CB, 0x007298B0, 0x0064756C, 0x00405639, 0x00475738, 0x00636B61, 0x009C9CA2,
        0x00909495, 0x00A0A9A6, 0x00A4ADB0, 0x00B3BFC5, 0x00A6B4B3, 0x0099A7A3, 0x00939D9D, 0x008E9499, 0x00939A97, 0x007E8A74, 0x00788A63, 0x00788A61, 0x00778765, 0x00798869, 0x007A8866, 0x00677551, 0xFF949E80, 0xFFFFFFF8, 0xFFFEFCFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFBFC, 0xFFFBF9F9, 0x00707E5C, 0x00708652, 0x00819071, 0x0073815D, 0x003B4B15, 0x00485227, 0x00677349, 0x00576339, 0x00424E24, 0x00475329, 0x005D693F,
        0x00546036, 0x00303C12, 0x00546036, 0x006A775F, 0x00545E4D, 0x00636A63, 0x00C4C8C9, 0x00EAEDF2, 0x00DEE1E5, 0x00D5DAD9, 0x00DDE3DE, 0x00ECF3EC, 0x00EFF7ED, 0x008F978C, 0x00464D3E, 0x0057604C, 0x005D664C, 0x00687156, 0x00656F51, 0x005A6747,
        0x005C6949, 0x00546240, 0x005B6947, 0x0054623E, 0x0056653F, 0x0066754F, 0x0063724C, 0x0055653C, 0x0067774E, 0x0078895E, 0x007C8D62, 0x0076875B, 0x00738458, 0x0075865A, 0x00798B5C, 0x00768859, 0x00768859, 0x00758758, 0x00758758, 0x00758758,
        0x00758758, 0x00748657, 0x00748657, 0x0077865A, 0x0077865A, 0x0077865A, 0x0077865A, 0x0077865A, 0x00768559, 0x00768559, 0x00768559, 0x0075865A, 0x00748559, 0x00738458, 0x00748559, 0x0075865A, 0x0075865A, 0x00748559, 0x00738458, 0x0074855A,
        0x0074855A, 0x0075865B, 0x0075865B, 0x0075865B, 0x0075865B, 0x0074855A, 0x0074855A, 0x00718354, 0x00728455, 0x00738556, 0x00748559, 0x0075865A, 0x0075865A, 0x0075865B, 0x0075865B, 0x00778A59, 0x00758857, 0x006A7E51, 0x0074865F, 0x007B8C6A,
        0x00404F33, 0x002D3B23, 0x0054644C, 0x00535F3B, 0x00434B3A, 0x00494D48, 0x004E5449, 0x003D4C2D, 0x006F8158, 0x00586947, 0x0058654F, 0x00707F59, 0x00424C35, 0x00444B44, 0x00505651, 0x00465141, 0x004A593D, 0x00718261, 0x00506243, 0x00606E4C,
        0x00626E52, 0x00454D3C, 0x004E5449, 0x004E5548, 0x00363F2A, 0x0072805E, 0x0074855A, 0x00788A61, 0x00809269, 0x00586846, 0x0046513D, 0x004E544F, 0x00474E47, 0x0047533D, 0x00667851, 0x00506243, 0x004C5D3B, 0x0070825D, 0x00435237, 0x004B5447,
        0x004C544A, 0x00404837, 0x00535F43, 0x004F653B, 0x00344B1F, 0x00455A2D, 0x006D8353, 0x0073875A, 0x006B7D54, 0x00748560, 0x00778563, 0x0073865F, 0x0073865F, 0x0073865F, 0x00748760, 0x00748760, 0x00748760, 0x00748760, 0x00748760, 0x00768861,
        0x00768861, 0x00758760, 0x0074865F, 0x0074865F, 0x0074865F, 0x00758760, 0x00758760, 0x00768861, 0x00758760, 0x0074865F, 0x0073855E, 0x0073855E, 0x0074865F, 0x00758760, 0x00768861, 0x0073855E, 0x00758760, 0x00768861, 0x00768861, 0x00758760,
        0x0074865F, 0x00758760, 0x00768861, 0x0072865C, 0x0073875D, 0x00798C65, 0x0070825D, 0x005E6F4D, 0x00506140, 0x00627253, 0x00657458, 0x00516236, 0x006A7953, 0x0073845F, 0x007B8D64, 0x00708455, 0x004B5D34, 0x004B5840, 0x00495049, 0x003C482A,
        0x002F3629, 0x005F6463, 0x006E746F, 0x00505C48, 0x001B2911, 0x00636D61, 0x00A6ACB1, 0x00859A9B, 0x003B5138, 0x00607A4A, 0x004D6C47, 0x005E807F, 0x0083ACC3, 0x007FA9C0, 0x0090BAC6, 0x0071847B, 0x00425A3C, 0x00364B2A, 0x005D665C, 0x00A5A9AE,
        0x00A1A6A7, 0x00AAB5B2, 0x00AFBBBD, 0x00B5C1C7, 0x00AEBABA, 0x00B8C6C2, 0x00B4BEBE, 0x00A0A6AB, 0x00A1A8A5, 0x00808C76, 0x006C7E57, 0x00778960, 0x00778765, 0x00798869, 0x007B8967, 0x00677551, 0xFF919B7D, 0xFFFFFFF8, 0xFFFEFCFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFF, 0xFFFEFCFC, 0x006C7A58, 0x006C824E, 0x00829172, 0x0072805C, 0x0040501A, 0x005C663B, 0x006C784E, 0x00616D43, 0x00505C32, 0x005D693F, 0x007E8A60,
        0x00677349, 0x002B370D, 0x00546036, 0x00728162, 0x0054604A, 0x00727A70, 0x00D9DDDE, 0x00E3E5ED, 0x00C6C7D1, 0x00BBBEC3, 0x00CCCFD3, 0x00D2D5D9, 0x00E6EAEB, 0x00A5AAA8, 0x005F645B, 0x00565D50, 0x00414734, 0x00464E37, 0x00565F45, 0x00697063,
        0x004F5647, 0x00353D2C, 0x003E4733, 0x0047513A, 0x00535E44, 0x00576347, 0x00586448, 0x006D7E53, 0x0075865B, 0x007A8B60, 0x0078895D, 0x00748559, 0x0075865A, 0x00768859, 0x00768859, 0x00758758, 0x00758758, 0x00758758, 0x00758758, 0x00758758,
        0x00758758, 0x00758758, 0x00758758, 0x00778758, 0x00778758, 0x00778758, 0x00778758, 0x00768657, 0x00768657, 0x00768657, 0x00768657, 0x00748657, 0x00738556, 0x00728455, 0x00738556, 0x00748657, 0x00758758, 0x00748657, 0x00738556, 0x00738458,
        0x00748559, 0x00748559, 0x00748559, 0x00748559, 0x00748559, 0x00748559, 0x00738458, 0x00718453, 0x00728554, 0x00738556, 0x00748657, 0x0075865A, 0x0075865A, 0x0075865A, 0x0075865B, 0x00778A59, 0x006B7D4E, 0x00809165, 0x007D8F66, 0x00586944,
        0x00536443, 0x005E6D51, 0x0048573C, 0x0041492A, 0x00454936, 0x00393A31, 0x00494E3F, 0x004D5838, 0x00738459, 0x0078885F, 0x0073815F, 0x006A7C4D, 0x00465234, 0x00454A41, 0x00464C47, 0x00495343, 0x00516142, 0x006F815C, 0x0070835C, 0x0076825E,
        0x00616B4D, 0x004D543F, 0x00454B3A, 0x00454B3A, 0x00414932, 0x00667151, 0x0075825C, 0x0072835E, 0x006D7F58, 0x004A5A38, 0x00435038, 0x004A5247, 0x00394136, 0x00445139, 0x0072845D, 0x0071835E, 0x00798D63, 0x00667A50, 0x003C4B2C, 0x00505A4A,
        0x004C5148, 0x00474E3F, 0x003F4A30, 0x00506342, 0x00495D3A, 0x004F623B, 0x005F7348, 0x007A8D62, 0x0073855C, 0x0071835C, 0x007A8864, 0x0073865F, 0x00748760, 0x00748760, 0x00748760, 0x00748760, 0x00758861, 0x00758861, 0x00758861, 0x00768861,
        0x00758760, 0x00758760, 0x0074865F, 0x0074865F, 0x0074865F, 0x0074865F, 0x00758760, 0x00758760, 0x00758760, 0x0074865F, 0x0074865F, 0x0074865F, 0x0074865F, 0x00758760, 0x00758760, 0x0072845D, 0x0073855E, 0x00758760, 0x00768861, 0x00758760,
        0x00758760, 0x00758760, 0x00768861, 0x00788C62, 0x0071855B, 0x006E815A, 0x007C8E69, 0x00768863, 0x006A7B59, 0x00627351, 0x00576847, 0x006E8059, 0x00596848, 0x00515F43, 0x005E6D4D, 0x00576942, 0x00485634, 0x004D5642, 0x00484C46, 0x00414D31,
        0x002D3425, 0x0050544F, 0x00596059, 0x004A5443, 0x001E2B15, 0x005F695D, 0x00777C7D, 0x00738A82, 0x00647B5F, 0x00627A50, 0x00284728, 0x00507678, 0x0081ACC7, 0x007BAAC6, 0x0084B4C6, 0x00596E65, 0x00375133, 0x00344C2A, 0x005F6A60, 0x00A3A7AC,
        0x009BA3A2, 0x00A8B6B2, 0x00BCC9CB, 0x00B3BDC4, 0x00ACB8B8, 0x00C4CFCC, 0x00B9C1C1, 0x00999DA2, 0x009FA4A2, 0x00828E78, 0x0072815B, 0x0076885F, 0x00788866, 0x00798869, 0x007C8A68, 0x00667450, 0xFF8D9779, 0xFFFFFFF8, 0xFFFFFDFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFF, 0xFFFEFCFC, 0x006E7C5A, 0x006D834F, 0x00819071, 0x006F7D59, 0x003D4D17, 0x005D673C, 0x004C582E, 0x004D592F, 0x00606C42, 0x0068744A, 0x00657147,
        0x00626E44, 0x00414D23, 0x00525E34, 0x007C8E67, 0x00617051, 0x00889281, 0x00DCE2DD, 0x00D2D6D7, 0x00CBCED2, 0x00C6CACB, 0x00CBD0CF, 0x00D1D3DB, 0x00DDE0E5, 0x00ADB2B1, 0x00848883, 0x00888F82, 0x00646A59, 0x00606851, 0x00848D73, 0x008E9090,
        0x006F7270, 0x005D615C, 0x00636761, 0x0072776E, 0x00838A7D, 0x005F6657, 0x00545B4C, 0x007E8F64, 0x00798A5F, 0x0075865A, 0x00748559, 0x0076875B, 0x0077895A, 0x00768859, 0x00768859, 0x00758758, 0x00758758, 0x00758758, 0x00758758, 0x00758758,
        0x00758758, 0x00758758, 0x00758758, 0x00778758, 0x00778758, 0x00778758, 0x00768657, 0x00768657, 0x00768657, 0x00768657, 0x00758556, 0x00738556, 0x00728455, 0x00718354, 0x00718354, 0x00738556, 0x00738556, 0x00728455, 0x00718354, 0x00738458,
        0x00738458, 0x00738458, 0x00748559, 0x00748559, 0x00738458, 0x00738458, 0x00738458, 0x00728554, 0x00728554, 0x00738655, 0x00748657, 0x00748657, 0x0075865A, 0x00748559, 0x00748559, 0x00758555, 0x00788859, 0x00728357, 0x006E7F54, 0x0052643D,
        0x00566644, 0x00475837, 0x005F704F, 0x004C5233, 0x008A8D77, 0x009B9E8E, 0x007D826D, 0x00475231, 0x004D5B31, 0x00556438, 0x0057673E, 0x004F602D, 0x00657050, 0x009EA598, 0x00A4A9A0, 0x0076816D, 0x004D5D3B, 0x004B5F35, 0x00506439, 0x005B6842,
        0x004F5A39, 0x00677056, 0x00939A85, 0x008E9580, 0x00586147, 0x004E5939, 0x00596541, 0x00566545, 0x0051623D, 0x004B5C37, 0x006D7B5F, 0x008C9686, 0x00697363, 0x00475539, 0x004A5C33, 0x00485B34, 0x00506538, 0x00465A2D, 0x005B6A4A, 0x009EA695,
        0x00979D92, 0x00777D6A, 0x003A4328, 0x00596559, 0x00505D4D, 0x005D6B53, 0x00465637, 0x006E7F5A, 0x00768861, 0x007A8C65, 0x0075845E, 0x0073875D, 0x0074885E, 0x0074885E, 0x0074885E, 0x0074885E, 0x0075895F, 0x0075895F, 0x0075895F, 0x00768861,
        0x00758760, 0x0074865F, 0x0074865F, 0x0074865F, 0x0074865F, 0x0074865F, 0x0074865F, 0x00758760, 0x00758760, 0x0074865F, 0x0074865F, 0x0074865F, 0x0074865F, 0x00758760, 0x00758760, 0x0071835C, 0x0073855E, 0x00758760, 0x00768861, 0x00758760,
        0x0074865F, 0x00758760, 0x00758760, 0x0073855C, 0x007A8C63, 0x0073855E, 0x00778962, 0x00788A63, 0x007F916A, 0x0071825D, 0x00546540, 0x005A6C4D, 0x0064715B, 0x00626D5D, 0x00545E4D, 0x004B563C, 0x00626D53, 0x0082867A, 0x00888987, 0x0060694F,
        0x00444A37, 0x006C7366, 0x00868D80, 0x0068735F, 0x0035402C, 0x007D877A, 0x009DA49F, 0x00728376, 0x00606D53, 0x0052603E, 0x00203421, 0x00557580, 0x0083AECF, 0x0079A6CB, 0x007EADCD, 0x00596F63, 0x00395131, 0x00314625, 0x005B6559, 0x009CA1A4,
        0x009BA3A2, 0x00ABB7B1, 0x00BECACA, 0x00B0BAC1, 0x00AFB9B9, 0x00C6D1CE, 0x00B6BEBE, 0x00909499, 0x00969B99, 0x00818A75, 0x0074835D, 0x0076885F, 0x00798967, 0x00788768, 0x007E8C6A, 0x00677551, 0xFF8B9577, 0xFFFFFFF8, 0xFFFFFDFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFBFC, 0xFFFEFCFC, 0x006F7D5B, 0x006D834F, 0x00808F70, 0x00717F5B, 0x003F4F19, 0x005B653A, 0x00647046, 0x005C683E, 0x005B673D, 0x00606C42, 0x00657147,
        0x00616D43, 0x00414D23, 0x00525E34, 0x006D7F56, 0x005B6A4A, 0x007B8672, 0x00D3DBD1, 0x00D2D7D5, 0x00D2D7D6, 0x00CBD0CE, 0x00C8CFC8, 0x00D2D5DA, 0x00E5E8EC, 0x00AEB3B1, 0x00969B92, 0x00949B8C, 0x00505841, 0x00525B40, 0x008A9575, 0x00999D97,
        0x00737771, 0x005B5F59, 0x00656A61, 0x0093998E, 0x00BCC2B7, 0x007A8174, 0x0052594C, 0x007D8E63, 0x0076875B, 0x00738458, 0x0076875B, 0x00798B5C, 0x0077895A, 0x00768958, 0x00788B5A, 0x00748657, 0x00748657, 0x00758758, 0x00758758, 0x00758758,
        0x00758758, 0x00768859, 0x00768859, 0x00778757, 0x00768656, 0x00768656, 0x00768656, 0x00768656, 0x00758555, 0x00758555, 0x00758555, 0x00728554, 0x00718453, 0x00708352, 0x00718453, 0x00728554, 0x00728554, 0x00728554, 0x00708352, 0x00728455,
        0x00728455, 0x00738556, 0x00738556, 0x00738556, 0x00738556, 0x00728455, 0x00728455, 0x00738653, 0x00738653, 0x00748756, 0x00748756, 0x00758758, 0x00758758, 0x00748657, 0x00748559, 0x00758555, 0x007A8A5B, 0x007A8A5B, 0x0074855A, 0x0054643B,
        0x0060724B, 0x004D5E39, 0x005E6F4A, 0x00626C48, 0x007E8667, 0x009FA68B, 0x007C856A, 0x005C6746, 0x0067774E, 0x0056673C, 0x00617247, 0x00637441, 0x005F6A49, 0x00929885, 0x009AA291, 0x006D795D, 0x005A6C45, 0x0065784D, 0x005D6F46, 0x005D6C46,
        0x00677551, 0x00738060, 0x00ABB79B, 0x00A2AD93, 0x00647054, 0x006C785A, 0x006A7757, 0x00617051, 0x00647550, 0x0060724B, 0x00728161, 0x008E9A84, 0x0078836F, 0x00627152, 0x005D6F46, 0x00657750, 0x00586B40, 0x005E7245, 0x005B6947, 0x00616A55,
        0x00616756, 0x00697258, 0x0065714D, 0x006A7370, 0x00404B41, 0x005E6A58, 0x0059684C, 0x00738361, 0x006E8059, 0x007A8C63, 0x00728259, 0x0073875D, 0x0073875D, 0x0073875D, 0x0074885E, 0x0074885E, 0x0074885E, 0x0074885E, 0x0074885E, 0x00758760,
        0x00758760, 0x0074865F, 0x0074865F, 0x0073855E, 0x0073855E, 0x0074865F, 0x0074865F, 0x00758760, 0x00758760, 0x0074865F, 0x0074865F, 0x0074865F, 0x0074865F, 0x00758760, 0x00758760, 0x0072845D, 0x0074865F, 0x00758760, 0x00758760, 0x0074865F,
        0x0074865F, 0x0074865F, 0x00758760, 0x0070825B, 0x007A8C63, 0x0076885F, 0x0074865D, 0x0072845B, 0x0076885F, 0x00798B62, 0x006F8158, 0x004D6242, 0x004E5D48, 0x00576155, 0x006D7669, 0x006D7661, 0x005E664F, 0x006A6D5E, 0x009D9C98, 0x0097A085,
        0x00737C62, 0x00939A85, 0x00BAC3AE, 0x00A3AC97, 0x0066725C, 0x00747E6D, 0x00656E61, 0x0063715F, 0x00434C32, 0x006E755A, 0x00536052, 0x00637D84, 0x0088ABC5, 0x0084AAC8, 0x008CB1CB, 0x0055665B, 0x00536A4A, 0x00617250, 0x0070786D, 0x00828387,
        0x00717674, 0x008D9791, 0x00B0BABA, 0x00A3ABB2, 0x00A2ACAC, 0x00AEB7B4, 0x009DA2A3, 0x007F8287, 0x00888B89, 0x007A836E, 0x0078855F, 0x00778960, 0x007A8A68, 0x00778667, 0x007F8D6B, 0x00687652, 0xFF8A9476, 0xFFFFFFF8, 0xFFFFFDFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFF, 0xFFFFFFFF, 0x00717F5D, 0x006C824E, 0x007E8D6E, 0x0073815D, 0x003D4D17, 0x004C562B, 0x00748056, 0x00657147, 0x00445026, 0x004E5A30, 0x0069754B,
        0x0059653B, 0x00344016, 0x00556137, 0x006A795A, 0x007C8971, 0x0080887D, 0x00D8DDDB, 0x00E6E9ED, 0x00D7DBDC, 0x00CED3D1, 0x00CFD5D0, 0x00DFE3E4, 0x00E3E8E7, 0x00939A93, 0x009EA596, 0x00A8B19C, 0x00555F41, 0x005B6743, 0x0068754F, 0x00576347,
        0x005C684C, 0x00596549, 0x00586349, 0x005A654B, 0x00707A63, 0x0057614A, 0x00616A55, 0x0076875B, 0x00748559, 0x0075865A, 0x0077895A, 0x00788A5B, 0x00768958, 0x00768958, 0x00778A59, 0x00748657, 0x00748657, 0x00748657, 0x00758758, 0x00758758,
        0x00768859, 0x00768859, 0x00768859, 0x00768656, 0x00768656, 0x00768656, 0x00768656, 0x00768656, 0x00758555, 0x00758555, 0x00758555, 0x00738655, 0x00728554, 0x00718453, 0x00718453, 0x00738655, 0x00738655, 0x00728554, 0x00718453, 0x00728455,
        0x00728455, 0x00738556, 0x00738556, 0x00738556, 0x00738556, 0x00728455, 0x00728455, 0x00738653, 0x00748754, 0x00758855, 0x00758857, 0x00758857, 0x00758758, 0x00758758, 0x00748657, 0x00798959, 0x00738354, 0x00758556, 0x007A895D, 0x0065764B,
        0x0056663D, 0x004C5E37, 0x0051633C, 0x004E5C32, 0x003B4B22, 0x00202F09, 0x00303E1C, 0x00445432, 0x0052633E, 0x005D7147, 0x0051653A, 0x0059693A, 0x0045512D, 0x00313922, 0x002E371D, 0x00414F2B, 0x004F6034, 0x00506338, 0x005A6C45, 0x005B6F45,
        0x00475A33, 0x0040512F, 0x00314122, 0x002E3E1F, 0x00415034, 0x005A6A4B, 0x00748465, 0x00576549, 0x005B6B49, 0x0044562D, 0x002A3A18, 0x002D3A20, 0x002B3820, 0x00415030, 0x0056693E, 0x004E5E3C, 0x005B6D44, 0x0056673C, 0x0052603C, 0x00394228,
        0x001C240D, 0x00505B3B, 0x005A693D, 0x004B5A45, 0x004E5E46, 0x00536344, 0x00546641, 0x00798B62, 0x0073855C, 0x006D7F56, 0x0073825C, 0x0073875D, 0x0073875D, 0x0073875D, 0x0073875D, 0x0073875D, 0x0074885E, 0x0074885E, 0x0074885E, 0x00758760,
        0x00758760, 0x0074865F, 0x0073855E, 0x0073855E, 0x0073855E, 0x0074865F, 0x0074865F, 0x0074865F, 0x0074865F, 0x00758760, 0x00758760, 0x00758760, 0x00758760, 0x0074865F, 0x0074865F, 0x0074865F, 0x00758760, 0x00758760, 0x0074865F, 0x0073855E,
        0x0072845D, 0x0073855E, 0x00758760, 0x007C8E67, 0x0071835A, 0x006A7C53, 0x0071835A, 0x007C8F64, 0x0074875C, 0x00798D60, 0x00778B5E, 0x0051693F, 0x005A6F4F, 0x0051604B, 0x004A5640, 0x00586446, 0x00677251, 0x004D5439, 0x00464835, 0x007D8868,
        0x004C5737, 0x00364022, 0x00434C31, 0x00455036, 0x00434D36, 0x0045523A, 0x0026321C, 0x004D6350, 0x004D5B43, 0x006E755A, 0x0077806C, 0x0070817D, 0x006D8388, 0x008EA4A9, 0x0077898A, 0x00768478, 0x006D805F, 0x0073815F, 0x00868A7E, 0x009B989A,
        0x008A8B89, 0x00898D87, 0x00858B8A, 0x00899198, 0x0096A0A0, 0x00A4ADAA, 0x00A7ACAD, 0x009DA0A5, 0x009EA19F, 0x00858C77, 0x007B8862, 0x00798B62, 0x007B8B69, 0x00768566, 0x00808E6C, 0x006A7854, 0xFF8A9476, 0xFFFFFFF8, 0xFFFEFCFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFAFB, 0xFFFBF9F9, 0x006E7C5A, 0x006B814D, 0x007F8E6F, 0x00778561, 0x003B4B15, 0x003E481D, 0x0039451B, 0x003A461C, 0x002F3B11, 0x00374319, 0x003E4A20,
        0x003A461C, 0x00344016, 0x00525E34, 0x006C7763, 0x00B0B8AD, 0x00969B99, 0x00D3D6DB, 0x00E8E9F3, 0x00DADCE4, 0x00DBDEE2, 0x00DDE2E1, 0x00E3E8E7, 0x00F2F8F3, 0x00A9B1A6, 0x00C8D1BD, 0x00B7C3A7, 0x00596443, 0x00818F66, 0x00728155, 0x00778A59,
        0x007D8F60, 0x00748559, 0x007F9065, 0x0077875E, 0x0075835F, 0x00657351, 0x007C8A68, 0x0076875B, 0x0076875B, 0x00768859, 0x00748657, 0x00748657, 0x00758857, 0x00758857, 0x00748756, 0x00748657, 0x00748657, 0x00748657, 0x00758758, 0x00758758,
        0x00768859, 0x00768859, 0x00768859, 0x00768656, 0x00768656, 0x00768656, 0x00768656, 0x00758555, 0x00758555, 0x00758555, 0x00758555, 0x00748756, 0x00738655, 0x00728554, 0x00728554, 0x00748756, 0x00748756, 0x00738655, 0x00728554, 0x00718354,
        0x00728455, 0x00728455, 0x00738556, 0x00738556, 0x00728455, 0x00728455, 0x00718354, 0x00748754, 0x00748754, 0x00758855, 0x00768958, 0x00768958, 0x00758758, 0x00758758, 0x00748657, 0x00758353, 0x00768657, 0x00718152, 0x00707F53, 0x00819267,
        0x0066774C, 0x006F8158, 0x006F8158, 0x006C7F4E, 0x0055693A, 0x00576A3F, 0x00556740, 0x00617250, 0x00778866, 0x00738861, 0x00758B61, 0x007B885C, 0x00626D4C, 0x005C654A, 0x005F6A4A, 0x005E6F44, 0x006F8251, 0x007A8D62, 0x00768664, 0x00758B61,
        0x006E835C, 0x00516640, 0x004F6340, 0x004F6142, 0x00586A4B, 0x00748669, 0x006E8063, 0x0079866C, 0x007A8A68, 0x0065774E, 0x004C5D38, 0x00526044, 0x00505D45, 0x00647353, 0x0073865B, 0x00798869, 0x0073845F, 0x0075855C, 0x005E6C48, 0x005F684D,
        0x005C654B, 0x005E6B45, 0x006F7E4B, 0x006F855B, 0x00687F53, 0x005F7545, 0x00788E5D, 0x00748859, 0x00718558, 0x00778960, 0x0075845E, 0x0072865B, 0x0072865B, 0x0072865B, 0x0073875C, 0x0073875C, 0x0073875C, 0x0073875C, 0x0074885D, 0x00758760,
        0x00758760, 0x0074865F, 0x0073855E, 0x0073855E, 0x0073855E, 0x0073855E, 0x0074865F, 0x0074865F, 0x0074865F, 0x00758760, 0x00758760, 0x00758760, 0x00758760, 0x0074865F, 0x0074865F, 0x00758760, 0x00758760, 0x00758760, 0x0074865F, 0x0072845D,
        0x0072845D, 0x0073855E, 0x00758760, 0x0074835D, 0x0075855C, 0x00798960, 0x0074855A, 0x007E8F64, 0x00728357, 0x007B8C60, 0x00768859, 0x006B8A53, 0x0060784E, 0x0067795A, 0x00728362, 0x0068784F, 0x00647143, 0x00535D33, 0x005C6342, 0x005C6544,
        0x00535F3B, 0x004C5834, 0x00515C3B, 0x00465234, 0x004A553B, 0x004F5C42, 0x0049573B, 0x004A6A57, 0x00495F46, 0x00677355, 0x00616A4F, 0x005C6854, 0x004A5A48, 0x0059654F, 0x0063684D, 0x005C685C, 0x00657454, 0x007B8665, 0x00919185, 0x009A9597,
        0x00878584, 0x00888A84, 0x00818383, 0x00959DA4, 0x00A1A9A9, 0x009BA4A1, 0x009CA1A2, 0x009C9FA4, 0x009B9E9C, 0x00818873, 0x0078855F, 0x007A8C63, 0x007C8C6A, 0x00758465, 0x00808E6C, 0x006B7955, 0xFF8A9476, 0xFFFFFFF8, 0xFFFEFCFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBF8FF, 0xFBFCFFF4, 0x00727E5A, 0x00738354, 0x00808F63, 0x00717E58, 0x00536138, 0x004D5C30, 0x00495B34, 0x0044562F, 0x0043552E, 0x00465831, 0x00495B34,
        0x00485A33, 0x00495B34, 0x0053653E, 0x006F7A52, 0x007B865E, 0x0089946C, 0x00A5B088, 0x009FAA82, 0x0087926A, 0x0095A078, 0x00A0AB83, 0x00808B63, 0x0099A47C, 0x00B8C39B, 0x00B9C49C, 0x00A3AE86, 0x00667149, 0x0077825A, 0x007D8860, 0x007C8B5F,
        0x007C8B5F, 0x007C8B5F, 0x007B8A5E, 0x007B8A5E, 0x007B8A5E, 0x007B8A5E, 0x007A895D, 0x00788859, 0x00788859, 0x00788859, 0x00788858, 0x00788858, 0x00788858, 0x00788956, 0x00788956, 0x00758555, 0x00768656, 0x00778757, 0x00778757, 0x00778757,
        0x00778757, 0x00768656, 0x00758555, 0x00758458, 0x00788859, 0x00748455, 0x00728252, 0x00758555, 0x00758653, 0x00758752, 0x00758752, 0x00718151, 0x00798959, 0x00768656, 0x00708050, 0x00758555, 0x00778757, 0x00728252, 0x00738353, 0x00718152,
        0x00778758, 0x00778758, 0x00748455, 0x00788859, 0x00778758, 0x00708051, 0x00728253, 0x00728252, 0x00738353, 0x00748454, 0x00758556, 0x00768657, 0x00768559, 0x00768559, 0x00768559, 0x00768656, 0x00758555, 0x00758555, 0x00748454, 0x00748454,
        0x00758555, 0x00758555, 0x00768656, 0x00798A5E, 0x00798A5E, 0x0078895D, 0x0077885C, 0x0076875B, 0x0076875B, 0x0075865A, 0x0075865A, 0x00718459, 0x0072855A, 0x00788B60, 0x007C8C63, 0x0078885F, 0x0078865D, 0x0078855F, 0x0075825C, 0x006F8158,
        0x006A7C53, 0x0073855C, 0x007D8F66, 0x00798B62, 0x0075875E, 0x0075875E, 0x00708259, 0x0073835A, 0x00728259, 0x0075855C, 0x00778960, 0x0074865D, 0x0075895F, 0x00778B61, 0x006E8258, 0x006E8156, 0x00708358, 0x0072855A, 0x0074875C, 0x0075885D,
        0x0074875C, 0x0073865B, 0x0072855A, 0x0075885D, 0x0075885D, 0x0074875C, 0x0073865B, 0x0073865B, 0x0072855A, 0x00718459, 0x00718459, 0x0074875C, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x0076895E,
        0x0076895E, 0x0074875C, 0x00718459, 0x0073865B, 0x0073865B, 0x006F8257, 0x0072855A, 0x00728358, 0x0075865B, 0x0078895E, 0x00738459, 0x006E7F54, 0x0078895E, 0x0076875C, 0x007A8B60, 0x0074895C, 0x0074895C, 0x0074885B, 0x0073865B, 0x0073855C,
        0x0074845B, 0x00778660, 0x007D8C66, 0x0073855C, 0x0074865D, 0x0075875E, 0x0076885F, 0x0075875E, 0x0074865D, 0x0072845B, 0x0071835A, 0x0076885F, 0x00778960, 0x00788A61, 0x00798B62, 0x00788A61, 0x0075875E, 0x0073855C, 0x0071835A, 0x00738462,
        0x00748563, 0x00768765, 0x00778A69, 0x00788B6A, 0x00738868, 0x006D8262, 0x00687D5D, 0x005E735D, 0x0060745D, 0x0072846D, 0x00506146, 0x0048563A, 0x003A4628, 0x004C5435, 0x004B5334, 0x00576345, 0x00707C60, 0x00848F75, 0x007D8672, 0x007D8475,
        0x00898E85, 0x008F938E, 0x007F8280, 0x00888D84, 0x0080867B, 0x008A9184, 0x00858D7C, 0x0079826D, 0x008D987E, 0x00818D6F, 0x007D896B, 0x00798D60, 0x00778962, 0x00798967, 0x007B8965, 0x006A7953, 0xFF889274, 0xFFFFFFF8, 0xFFFFFDFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFCFF, 0xFFFDFFF5, 0x006F7B57, 0x00708051, 0x00849367, 0x0083906A, 0x0078865D, 0x007D8C60, 0x00788A63, 0x00788A63, 0x007A8C65, 0x007B8D66, 0x00798B64,
        0x0074865F, 0x0073855E, 0x00778962, 0x00768159, 0x00747F57, 0x00707B53, 0x007D8860, 0x0079845C, 0x006F7A52, 0x007D8860, 0x007D8860, 0x00768159, 0x00737E56, 0x00727D55, 0x00737E56, 0x0079845C, 0x0068734B, 0x00818C64, 0x00818C64, 0x007A895D,
        0x007A895D, 0x007A895D, 0x0079885C, 0x0079885C, 0x0079885C, 0x0079885C, 0x0078875B, 0x0079895A, 0x0079895A, 0x00788859, 0x00778757, 0x00778757, 0x00768656, 0x00768754, 0x00758653, 0x00768656, 0x00768656, 0x00768656, 0x00778757, 0x00778757,
        0x00768656, 0x00768656, 0x00768656, 0x00718152, 0x00768657, 0x00778758, 0x00778757, 0x00768656, 0x00738451, 0x0070814E, 0x006D7E4B, 0x00778757, 0x00748454, 0x00758555, 0x00738353, 0x00738353, 0x00768656, 0x00738353, 0x00748454, 0x0079895A,
        0x00788859, 0x00738354, 0x006F7F50, 0x00738354, 0x00738354, 0x00738354, 0x007A8A5B, 0x00738353, 0x00738353, 0x00748454, 0x00768657, 0x00768657, 0x0077865A, 0x0077865A, 0x0077865A, 0x00768656, 0x00758555, 0x00758555, 0x00748454, 0x00748454,
        0x00758555, 0x00758555, 0x00768656, 0x0075865A, 0x00748559, 0x00748559, 0x00738458, 0x00738458, 0x00728357, 0x00728357, 0x00728357, 0x0076895E, 0x0073865B, 0x0073865B, 0x0076865D, 0x0074845B, 0x0075835A, 0x0073805A, 0x00717E58, 0x00788A61,
        0x0075875E, 0x0072845B, 0x0071835A, 0x0072845B, 0x0073855C, 0x0073855C, 0x0071835A, 0x0075855C, 0x00718158, 0x00728259, 0x0073855C, 0x0071835A, 0x0071855B, 0x0074885E, 0x006F8359, 0x00718459, 0x00718459, 0x0072855A, 0x0072855A, 0x0072855A,
        0x0073865B, 0x0073865B, 0x0073865B, 0x0074875C, 0x0074875C, 0x0073865B, 0x0073865B, 0x0072855A, 0x0072855A, 0x0072855A, 0x0072855A, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x00778960,
        0x0074865D, 0x0072845B, 0x0072845B, 0x0074865D, 0x0072845B, 0x0072845B, 0x00778960, 0x0076865D, 0x0074845B, 0x0076865D, 0x0076865D, 0x00798960, 0x00798960, 0x0074845B, 0x00718158, 0x00708558, 0x0074885D, 0x0075885D, 0x0075885D, 0x0076885F,
        0x0076865D, 0x0073825C, 0x0074835D, 0x0074865D, 0x0075875E, 0x0075875E, 0x0076885F, 0x0075875E, 0x0074865D, 0x0073855C, 0x0072845B, 0x0073855C, 0x0074865D, 0x0075875E, 0x0076885F, 0x0076885F, 0x0075875E, 0x0074865D, 0x0074865D, 0x0074865F,
        0x00738560, 0x00748661, 0x00778964, 0x00768A67, 0x00758966, 0x00708564, 0x006D8261, 0x00677C63, 0x00697F63, 0x0076896E, 0x00607255, 0x00627152, 0x00606D4D, 0x00677251, 0x00636C4B, 0x00606E4C, 0x00798666, 0x007D896D, 0x0069735C, 0x005D6652,
        0x005F6659, 0x0080867B, 0x00747970, 0x00737A6D, 0x00575E4F, 0x0058604F, 0x005A634E, 0x00556046, 0x00758163, 0x007A8767, 0x007C8A68, 0x00798D60, 0x00778962, 0x00798967, 0x007B8965, 0x006A7953, 0xFF889274, 0xFFFFFFF8, 0xFFFFFDFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFCFF, 0xFBFCFFF4, 0x006F7B57, 0x006E7E4F, 0x007F8E62, 0x00808D67, 0x0079875E, 0x00808F63, 0x00798B62, 0x00798B62, 0x007A8C63, 0x00798B62, 0x0076885F,
        0x0076885F, 0x00798B62, 0x00788A61, 0x00838E66, 0x00869169, 0x007A855D, 0x007E8961, 0x00848F67, 0x00828D65, 0x0088936B, 0x00848F67, 0x00848F67, 0x00818C64, 0x007C875F, 0x007E8961, 0x00838E66, 0x007E8961, 0x0087926A, 0x007B865E, 0x007A895D,
        0x007A895D, 0x007A895D, 0x007A895D, 0x0079885C, 0x0079885C, 0x0079885C, 0x0079885C, 0x0079895A, 0x0079895A, 0x00788859, 0x00778757, 0x00768656, 0x00758555, 0x00748552, 0x00748552, 0x00778757, 0x00768656, 0x00768656, 0x00768656, 0x00768656,
        0x00768656, 0x00768656, 0x00778757, 0x00768657, 0x00788859, 0x00788859, 0x00768657, 0x00778757, 0x00788858, 0x00778757, 0x00788858, 0x007A8A5B, 0x00708051, 0x00738354, 0x00728253, 0x00718152, 0x00758556, 0x00738354, 0x00758556, 0x00768657,
        0x00748455, 0x00738354, 0x00758556, 0x007A8A5B, 0x00758556, 0x00738354, 0x00728253, 0x00738353, 0x00748454, 0x00758555, 0x00768657, 0x00778758, 0x0078875B, 0x0078875B, 0x0078875B, 0x00768656, 0x00768656, 0x00758555, 0x00758555, 0x00758555,
        0x00758555, 0x00768656, 0x00768656, 0x00728357, 0x00728357, 0x00728357, 0x00728357, 0x00718256, 0x00718256, 0x00718256, 0x00718256, 0x0074875C, 0x006F8257, 0x006B7E53, 0x00728259, 0x00718158, 0x0075835A, 0x0073805A, 0x0074815B, 0x006E8057,
        0x0075875E, 0x0075875E, 0x00708259, 0x00708259, 0x00708259, 0x0071835A, 0x0076885F, 0x0076845B, 0x00728259, 0x0074845B, 0x0075855C, 0x0071835A, 0x0071835A, 0x0072865C, 0x0074885E, 0x0074875C, 0x0072855A, 0x00718459, 0x00708358, 0x00708358,
        0x00718459, 0x0073865B, 0x0074875C, 0x0073865B, 0x0073865B, 0x0072855A, 0x0072855A, 0x0072855A, 0x0072855A, 0x0072855A, 0x0072855A, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x0075875E,
        0x0074865D, 0x0073855C, 0x0076885F, 0x00778960, 0x0073855C, 0x0072845B, 0x0075875E, 0x0078885F, 0x0073835A, 0x00728259, 0x00728259, 0x00798960, 0x0073835A, 0x0078885F, 0x0075855C, 0x0073875D, 0x00768A60, 0x0072845B, 0x00708259, 0x00708259,
        0x0075855C, 0x0074845B, 0x0077875E, 0x0075875E, 0x0075875E, 0x0075875E, 0x0075875E, 0x0075875E, 0x0074865D, 0x0074865D, 0x0074865D, 0x0072845B, 0x0073855C, 0x0073855C, 0x0073855C, 0x0074865D, 0x0074865D, 0x0074865D, 0x0074865D, 0x0074875C,
        0x0074875C, 0x0073875D, 0x0074885E, 0x00748962, 0x00758A63, 0x00758A63, 0x00738A64, 0x00748969, 0x00758A69, 0x007C8F6E, 0x00738462, 0x00778765, 0x00818F6B, 0x00818E68, 0x007E8B65, 0x0076855F, 0x0085936F, 0x007F8D6B, 0x00717D5F, 0x006B765C,
        0x00636C57, 0x00868F7B, 0x006B7362, 0x0079826D, 0x00565F4A, 0x004E5841, 0x00556145, 0x00515E3E, 0x006F7D5B, 0x007B8965, 0x007E8D67, 0x00798D60, 0x00778962, 0x00798967, 0x007B8965, 0x006A7953, 0xFF889274, 0xFFFFFFF8, 0xFFFFFDFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFAFF, 0xFBFCFFF4, 0x00737F5B, 0x00738354, 0x00819064, 0x00808D67, 0x0078865D, 0x007D8C60, 0x007A8A61, 0x007A8A61, 0x00798960, 0x007A8A61, 0x0078885F,
        0x007D8D64, 0x007F8F66, 0x00708057, 0x00748056, 0x00828E64, 0x007B875D, 0x007B875D, 0x00849066, 0x00818D63, 0x00808C62, 0x00808C62, 0x00808C62, 0x00818D63, 0x00808C62, 0x007E8A60, 0x007A865C, 0x00758157, 0x007B875D, 0x007C885E, 0x007D8C60,
        0x007D8C60, 0x007C8B5F, 0x007C8B5F, 0x007C8B5F, 0x007C8B5F, 0x007B8A5E, 0x007B8A5E, 0x0079895A, 0x0079895A, 0x00788859, 0x00788858, 0x00778757, 0x00768656, 0x00758653, 0x00758653, 0x00778757, 0x00778757, 0x00768656, 0x00758555, 0x00758555,
        0x00768656, 0x00778757, 0x00778757, 0x00758555, 0x00738353, 0x00738354, 0x00748455, 0x0079895A, 0x0079895A, 0x00728253, 0x00758458, 0x00768559, 0x00728155, 0x0077865A, 0x00768559, 0x0078875B, 0x007B8A5E, 0x00758458, 0x00758458, 0x007A895D,
        0x0078875B, 0x0078875B, 0x0077865A, 0x007B8A5E, 0x0077865A, 0x007E8D61, 0x0079885C, 0x00748454, 0x00758555, 0x00768656, 0x00778758, 0x00788859, 0x0078875B, 0x0078875B, 0x0078875B, 0x00778757, 0x00768656, 0x00768656, 0x00758555, 0x00758555,
        0x00768656, 0x00768656, 0x00778757, 0x00738458, 0x00738458, 0x00738458, 0x00748559, 0x00748559, 0x00748559, 0x0075865A, 0x0075865A, 0x0076895E, 0x0075885D, 0x0075885D, 0x007D8D64, 0x0075855C, 0x007A885F, 0x007B8862, 0x007F8C66, 0x00798960,
        0x007D8D64, 0x007F8F66, 0x007E8E65, 0x007C8C63, 0x007A8A61, 0x007A8A61, 0x007A8A61, 0x007C8A61, 0x007B8960, 0x007C8A61, 0x0076865D, 0x0076865D, 0x0074865D, 0x00708259, 0x0075875E, 0x0074875C, 0x0073865B, 0x0072855A, 0x00708358, 0x00708358,
        0x00718459, 0x0072855A, 0x0073865B, 0x0072855A, 0x0072855A, 0x0072855A, 0x0072855A, 0x0072855A, 0x0072855A, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x0074875C, 0x0074875C, 0x0074875C, 0x0074875C, 0x0074875C, 0x0074865D,
        0x00798B62, 0x0074865D, 0x0075875E, 0x007A8C63, 0x00788A61, 0x00778960, 0x0076885F, 0x00798B62, 0x00798B62, 0x00788A61, 0x0072845B, 0x0075875E, 0x006E8057, 0x00798B62, 0x00798B62, 0x0072855E, 0x00768962, 0x0074865F, 0x00768861, 0x00708259,
        0x0076865D, 0x0075855C, 0x00798960, 0x0076885F, 0x0076885F, 0x0075875E, 0x0075875E, 0x0075875E, 0x0075875E, 0x0075875E, 0x0075875E, 0x0076885F, 0x0075875E, 0x0074865D, 0x0073855C, 0x0072845B, 0x0072845B, 0x0072845B, 0x0072845B, 0x0074885B,
        0x0074885B, 0x0074885B, 0x0074885D, 0x00768A5F, 0x00758C60, 0x00768C62, 0x00778D63, 0x007B9069, 0x007A8F68, 0x007E916A, 0x007F916A, 0x007B8D66, 0x0083936A, 0x007E8C63, 0x00818F66, 0x0086976C, 0x00829368, 0x007C8B65, 0x0075835F, 0x00778464,
        0x006E7A5C, 0x008A957B, 0x00707B61, 0x00768468, 0x006B7A5B, 0x00687757, 0x006E7E5C, 0x00667752, 0x0074865F, 0x0076885F, 0x0076885F, 0x00798D60, 0x00778962, 0x00798967, 0x007B8965, 0x006A7953, 0xFF889274, 0xFFFFFFF8, 0xFFFFFDFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFCFF, 0xFBFCFFF4, 0x00727E5A, 0x00728253, 0x007E8D61, 0x007F8C66, 0x007C8A61, 0x00829165, 0x0077875E, 0x0077875E, 0x0077875E, 0x007C8C63, 0x007A8A61,
        0x007C8C63, 0x0073835A, 0x004D5D34, 0x003B471D, 0x00404C22, 0x00404C22, 0x00414D23, 0x003F4B21, 0x003F4B21, 0x00445026, 0x00404C22, 0x003F4B21, 0x003D491F, 0x00434F25, 0x00445026, 0x004B572D, 0x00404C22, 0x00404C22, 0x004D592F, 0x007C8B5F,
        0x007C8B5F, 0x007C8B5F, 0x007C8B5F, 0x007C8B5F, 0x007B8A5E, 0x007B8A5E, 0x007B8A5E, 0x0079895A, 0x0079895A, 0x00788859, 0x00788858, 0x00788858, 0x00788858, 0x00788956, 0x00788956, 0x00778757, 0x00778757, 0x00768656, 0x00758555, 0x00758555,
        0x00768656, 0x00778757, 0x00778757, 0x007C8C5C, 0x00798959, 0x00788858, 0x00788859, 0x007A895D, 0x00637246, 0x00404E24, 0x003D4B21, 0x003F4E22, 0x00425125, 0x003D4C20, 0x003A491D, 0x003F4E22, 0x00435226, 0x00425125, 0x00445327, 0x00455428,
        0x00445327, 0x00455428, 0x003E4D21, 0x003E4D21, 0x00445327, 0x006D7C50, 0x007A895D, 0x00748454, 0x00758555, 0x00768656, 0x00778758, 0x00788859, 0x0078875B, 0x0079885C, 0x0078875B, 0x00778757, 0x00778757, 0x00768656, 0x00768656, 0x00768656,
        0x00768656, 0x00778757, 0x00778757, 0x00748559, 0x0075865A, 0x0075865A, 0x0075865A, 0x0076875B, 0x0076875B, 0x0077885C, 0x0077885C, 0x0073865B, 0x0073865B, 0x0072855A, 0x006F7F56, 0x004C5C33, 0x004A582F, 0x00495630, 0x00495630, 0x004E5E35,
        0x0045552C, 0x0044542B, 0x00495930, 0x004B5B32, 0x004C5C33, 0x004B5B32, 0x0047572E, 0x004D5830, 0x004A582F, 0x0049572E, 0x0048562D, 0x005E6E45, 0x0076865D, 0x0072845B, 0x0075875E, 0x0073865B, 0x0073865B, 0x0073865B, 0x0072855A, 0x0072855A,
        0x0072855A, 0x0072855A, 0x0072855A, 0x0072855A, 0x0072855A, 0x0072855A, 0x0072855A, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x0074875C, 0x0074875C, 0x0074875C, 0x0075885D, 0x0075885D, 0x0073855E,
        0x00768861, 0x005A6C45, 0x00495B34, 0x004D5F38, 0x004D5F38, 0x004D5F38, 0x004B5D36, 0x004A5C35, 0x004F613A, 0x0050623B, 0x004D5F38, 0x004A5C35, 0x00495B34, 0x004B5D36, 0x00495B34, 0x00425331, 0x00485A35, 0x005B6C47, 0x00778962, 0x0073855E,
        0x0078885F, 0x0074855A, 0x0077885D, 0x0075875E, 0x0075875E, 0x0075875E, 0x0075875E, 0x0075875E, 0x0075875E, 0x0076885F, 0x0076885F, 0x00778960, 0x0076885F, 0x0075875E, 0x0073855C, 0x0073855C, 0x0073855C, 0x0074865D, 0x0075875E, 0x0077895A,
        0x0077895A, 0x00768A5D, 0x00778B5E, 0x00768A5F, 0x00778B60, 0x00788C61, 0x00768D61, 0x0063764B, 0x0055683D, 0x0056693E, 0x005E7047, 0x005B6B42, 0x005C6C43, 0x0057673E, 0x005D6D44, 0x00627347, 0x005D6E42, 0x00637449, 0x00607047, 0x005D6B47,
        0x00586644, 0x006A7757, 0x00657252, 0x005D6D4B, 0x007D8D6B, 0x0083946F, 0x00859671, 0x007E9069, 0x0081936A, 0x007B8D64, 0x007E9166, 0x00798D60, 0x00778962, 0x00798967, 0x007B8965, 0x006A7953, 0xFF889274, 0xFFFFFFF8, 0xFFFFFDFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFCFF, 0xF7F9FDF1, 0x00707C58, 0x00708051, 0x007A895D, 0x007A8761, 0x0077855C, 0x007B8A5E, 0x007D8B61, 0x007C8A60, 0x0078865C, 0x007D8B61, 0x007B895F,
        0x00808E64, 0x00748258, 0x003F4D23, 0x0039461A, 0x00364317, 0x003E4B1F, 0x00435024, 0x00414E22, 0x004B582C, 0x00515E32, 0x00424F23, 0x00455226, 0x003B481C, 0x003E4B1F, 0x00323F13, 0x00455226, 0x00323F13, 0x00334014, 0x00505D31, 0x0079885C,
        0x0079885C, 0x0079885C, 0x0079885C, 0x0079885C, 0x0078875B, 0x0078875B, 0x0078875B, 0x00788859, 0x00788859, 0x00788859, 0x00788858, 0x00788858, 0x00788858, 0x00788956, 0x00788956, 0x00778757, 0x00768656, 0x00768656, 0x00768656, 0x00768656,
        0x00768656, 0x00768656, 0x00778757, 0x00748552, 0x00738451, 0x00748454, 0x00778758, 0x007E8D61, 0x005B693F, 0x002B3910, 0x0033401A, 0x002D3B11, 0x0036441A, 0x00334117, 0x003B491F, 0x003B491F, 0x00334117, 0x0037451B, 0x002F3D13, 0x00303E14,
        0x00313F15, 0x003D4B21, 0x003A481E, 0x00303E14, 0x002B390F, 0x00637147, 0x007B895F, 0x00748454, 0x00758555, 0x00768656, 0x00778758, 0x00788859, 0x0078875B, 0x0078875B, 0x0078875B, 0x00788858, 0x00778757, 0x00778757, 0x00768656, 0x00768656,
        0x00778757, 0x00778757, 0x00788858, 0x00748559, 0x00748559, 0x0075865A, 0x0075865A, 0x0075865A, 0x0076875B, 0x0076875B, 0x0076875B, 0x007A8D62, 0x00798C61, 0x00798C61, 0x006C7C53, 0x0033431A, 0x00313F16, 0x0035421C, 0x002E3B15, 0x0035431A,
        0x0039471E, 0x003D4B22, 0x003C4A21, 0x0037451C, 0x00334118, 0x00334118, 0x0035431A, 0x0037421A, 0x0037421A, 0x002B3910, 0x00233108, 0x004C5A31, 0x0078885F, 0x0077875E, 0x0074845B, 0x0072855A, 0x0073865B, 0x0074875C, 0x0074875C, 0x0074875C,
        0x0074875C, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x0074875C, 0x0074875C, 0x0075885D, 0x0075885D, 0x0076895E, 0x00778962,
        0x0073855E, 0x003D4F28, 0x001F310A, 0x00293B14, 0x00293B14, 0x00293B14, 0x002D3F18, 0x002C3E17, 0x00293B14, 0x00253710, 0x002A3C15, 0x0024360F, 0x0031431C, 0x00263811, 0x002B3D16, 0x00253615, 0x001F300F, 0x003C4C2A, 0x0071825D, 0x0070825B,
        0x0076865D, 0x0075865B, 0x0077885C, 0x0074865D, 0x0074865D, 0x0074865D, 0x0075875E, 0x0075875E, 0x0075875E, 0x0075875E, 0x0075875E, 0x0074865D, 0x0074865D, 0x0074865D, 0x0074865D, 0x0075875E, 0x0076885F, 0x00778960, 0x00788A61, 0x0077885C,
        0x00798A5E, 0x007A8B5F, 0x00788B60, 0x00788B60, 0x00768A60, 0x00778B61, 0x00788C62, 0x004B5C30, 0x002B3C11, 0x002A3B10, 0x002C3C13, 0x00293910, 0x002C3B15, 0x0032401C, 0x0034421E, 0x00304115, 0x002F4015, 0x00304116, 0x00314118, 0x00293812,
        0x002C3A16, 0x002A3814, 0x00293715, 0x00374823, 0x0072835E, 0x007B8C67, 0x00788A63, 0x0074865F, 0x00758760, 0x0073855E, 0x00798B62, 0x00798D60, 0x00778962, 0x00798967, 0x007B8965, 0x006A7953, 0xFF889274, 0xFFFFFFF8, 0xFFFFFDFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFAFF, 0xF4F7FBEF, 0x00727E5A, 0x00758556, 0x00808F63, 0x00818E68, 0x007C8A61, 0x007D8C60, 0x007C8A60, 0x007C8A60, 0x0077855B, 0x007A885E, 0x0077855B,
        0x00808E64, 0x0079875D, 0x003E4C22, 0x0049562A, 0x005F6C40, 0x005A673B, 0x00525F33, 0x00667347, 0x006F7C50, 0x005F6C40, 0x0059663A, 0x00505D31, 0x004C592D, 0x005B683C, 0x00475428, 0x0069764A, 0x00445125, 0x00354216, 0x004D5A2E, 0x0079885C,
        0x0079885C, 0x0078875B, 0x0078875B, 0x0078875B, 0x0078875B, 0x0077865A, 0x0077865A, 0x00778758, 0x00778758, 0x00778758, 0x00778757, 0x00768656, 0x00768656, 0x00758653, 0x00758653, 0x00768656, 0x00768656, 0x00768656, 0x00778757, 0x00778757,
        0x00768656, 0x00768656, 0x00768656, 0x00778954, 0x00778855, 0x00738353, 0x00748455, 0x007F8D63, 0x0059673E, 0x002D3A14, 0x004C5834, 0x004C5A31, 0x004F5D34, 0x00536138, 0x00707E55, 0x00637148, 0x004B5930, 0x0057653C, 0x00435128, 0x00556339,
        0x0049572D, 0x0058663C, 0x00606E44, 0x00505E34, 0x00334117, 0x00606E44, 0x0076845A, 0x00748454, 0x00758555, 0x00768656, 0x00778758, 0x00788859, 0x0078875B, 0x0078875B, 0x0078875B, 0x00788858, 0x00788858, 0x00778757, 0x00778757, 0x00778757,
        0x00778757, 0x00788858, 0x00788858, 0x0075865A, 0x0075865A, 0x0075865A, 0x0076875B, 0x0076875B, 0x0076875B, 0x0076875B, 0x0076875B, 0x0073865B, 0x0072855A, 0x00788B60, 0x006F7F56, 0x0033431A, 0x00435128, 0x0056633D, 0x004D5A34, 0x0049572E,
        0x00637148, 0x00627047, 0x00515F36, 0x004F5D34, 0x004A582F, 0x00435128, 0x004B5930, 0x005D6840, 0x00667149, 0x00566139, 0x00344219, 0x00515F36, 0x007D8D64, 0x0077875E, 0x00708057, 0x0073865B, 0x0073865B, 0x0074875C, 0x0075885D, 0x0075885D,
        0x0075885D, 0x0075885D, 0x0075885D, 0x0075885D, 0x0075885D, 0x0075885D, 0x0074875C, 0x0074875C, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x0074875C, 0x0075885D, 0x0075885D, 0x0076895E, 0x0076895E, 0x007B8C67,
        0x00788964, 0x003E4F2A, 0x002D3E19, 0x00495A35, 0x00455631, 0x0041522D, 0x004C5D38, 0x0060724D, 0x0050623D, 0x0042542F, 0x004A5C37, 0x0031431E, 0x0040522D, 0x00243611, 0x00384A25, 0x004A5A3B, 0x00273718, 0x00394828, 0x00778863, 0x0070825B,
        0x0075855C, 0x0076875C, 0x0076875B, 0x0072845B, 0x0073855C, 0x0074865D, 0x0075875E, 0x0076885F, 0x0075875E, 0x0075875E, 0x0074865D, 0x0073855C, 0x0073855C, 0x0073855C, 0x0074865D, 0x0075875E, 0x0076885F, 0x00778960, 0x00788A61, 0x007A885E,
        0x00798A5F, 0x007A8A61, 0x007A8A61, 0x00778962, 0x00778962, 0x00788A65, 0x007A8C67, 0x00546036, 0x00344218, 0x0045532A, 0x0047542E, 0x00475531, 0x004D5B39, 0x005F6F4D, 0x00576646, 0x00425229, 0x004D5D34, 0x0037471E, 0x00485731, 0x004C5B35,
        0x0062704C, 0x0055633F, 0x0044522E, 0x00334520, 0x0071835E, 0x00798B66, 0x00788A65, 0x00738560, 0x00748661, 0x00778964, 0x00788A65, 0x00798D60, 0x00778962, 0x00798967, 0x007B8965, 0x006A7953, 0xFF889274, 0xFFFFFFF8, 0xFFFFFDFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFCFF, 0xF7FAFEF2, 0x00727E5A, 0x00738354, 0x007D8C60, 0x007F8C66, 0x007B8960, 0x007C8B5F, 0x0078865C, 0x007D8B61, 0x007C8A60, 0x00808E64, 0x007A885E,
        0x00818F65, 0x0079875D, 0x003A481E, 0x00475428, 0x007D8A5E, 0x005D6A3E, 0x003A471B, 0x00657246, 0x00616E42, 0x00384519, 0x004A572B, 0x006E7B4F, 0x005D6A3E, 0x005E6B3F, 0x003D4A1E, 0x00707D51, 0x004C592D, 0x00374418, 0x0049562A, 0x007A895D,
        0x007A895D, 0x007A895D, 0x007A895D, 0x007A895D, 0x0079885C, 0x0079885C, 0x0079885C, 0x00778758, 0x00778758, 0x00768657, 0x00758555, 0x00748454, 0x00738353, 0x00738451, 0x00728350, 0x00758555, 0x00768656, 0x00778757, 0x00778757, 0x00778757,
        0x00778757, 0x00768656, 0x00758555, 0x00778954, 0x007A8B58, 0x00748454, 0x00738256, 0x00808E64, 0x0058653F, 0x00313D19, 0x00606C48, 0x0067754C, 0x00505E35, 0x00425027, 0x005E6C43, 0x00445229, 0x00324017, 0x005F6D44, 0x00536138, 0x00657349,
        0x00435127, 0x0049572D, 0x005E6C42, 0x0058663C, 0x0036441A, 0x00647248, 0x007B895F, 0x00748454, 0x00748454, 0x00758555, 0x00778758, 0x00778758, 0x0078875B, 0x0078875B, 0x0078875B, 0x00788858, 0x00788858, 0x00778757, 0x00778757, 0x00778757,
        0x00778757, 0x00788858, 0x00788858, 0x0078895D, 0x0078895D, 0x0078895D, 0x0078895D, 0x0078895D, 0x0078895D, 0x0078895D, 0x0078895D, 0x00778A5F, 0x0072855A, 0x00798C61, 0x00708057, 0x0034441B, 0x00505E35, 0x006C7953, 0x00606D47, 0x00414F26,
        0x00606E45, 0x004D5B32, 0x0037451C, 0x00505E35, 0x005C6A41, 0x00515F36, 0x0058663D, 0x00485129, 0x00626D45, 0x005F6A42, 0x0037421A, 0x004B5930, 0x007B8960, 0x00798960, 0x0077875E, 0x0073865B, 0x0074875C, 0x0074875C, 0x0075885D, 0x0075885D,
        0x0076895E, 0x00778A5F, 0x00778A5F, 0x0076895E, 0x0076895E, 0x0075885D, 0x0075885D, 0x0074875C, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x0074875C, 0x0075885D, 0x0076895E, 0x0076895E, 0x0076895E, 0x0073845F,
        0x00748560, 0x0040512C, 0x0040512C, 0x00677853, 0x00576843, 0x00465732, 0x0053643F, 0x004D5F3A, 0x003F512C, 0x003F512C, 0x005A6C47, 0x0040522D, 0x00556742, 0x00374924, 0x005D6F4A, 0x005F6E52, 0x0029391A, 0x00334222, 0x00778765, 0x0070825B,
        0x0075855C, 0x0075865A, 0x00748559, 0x0071835A, 0x0072845B, 0x0074865D, 0x0075875E, 0x0076885F, 0x0075875E, 0x0074865D, 0x0073855C, 0x0075875E, 0x0074865D, 0x0074865D, 0x0074865D, 0x0074865D, 0x0074865D, 0x0074865D, 0x0074865D, 0x007A885F,
        0x007B8862, 0x00798862, 0x00798862, 0x00768762, 0x00788964, 0x007B8B69, 0x007D8E6C, 0x004F5B31, 0x00404B23, 0x0066744B, 0x0063704A, 0x005B6947, 0x00525F3F, 0x005E6D4E, 0x00455435, 0x0042512B, 0x0064734D, 0x0045542E, 0x00606F49, 0x0062704C,
        0x0073815D, 0x0055633F, 0x002C3A16, 0x00354722, 0x006D7F5A, 0x00768863, 0x007C8D6B, 0x00768765, 0x00778866, 0x007A8B69, 0x00738462, 0x00798D60, 0x00778962, 0x00798967, 0x007B8965, 0x006A7953, 0xFF889274, 0xFFFFFFF8, 0xFFFFFDFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFDFF, 0xF0F7F9ED, 0x006D7753, 0x00738354, 0x007C8B5F, 0x007A8A61, 0x007E8E65, 0x007D8E62, 0x00788D67, 0x00768A60, 0x00798A5E, 0x007F8F60, 0x007E8E5E,
        0x007A8C5D, 0x00768B5E, 0x00364D21, 0x004D582A, 0x007A8557, 0x005D683A, 0x00384315, 0x00697446, 0x00626D3F, 0x003A4517, 0x00384315, 0x005C6638, 0x00737D4F, 0x003C4618, 0x00353F11, 0x00646E40, 0x004D5729, 0x00323C0E, 0x004D5729, 0x00798B62,
        0x00758760, 0x00778660, 0x007A8963, 0x007A885E, 0x00798658, 0x007B8A57, 0x0080905B, 0x00768657, 0x00768657, 0x00768657, 0x00768657, 0x00768657, 0x00758556, 0x00748455, 0x00748455, 0x00738556, 0x00738556, 0x00748657, 0x00758758, 0x00758758,
        0x00768859, 0x00768859, 0x00768859, 0x006F8356, 0x00708358, 0x0075885D, 0x0071855B, 0x007B8F65, 0x00596C45, 0x002A3F19, 0x00566B45, 0x00677E51, 0x003A5124, 0x003A5124, 0x00647B4E, 0x003A5124, 0x00233A0D, 0x00374E21, 0x00667D50, 0x00445A30,
        0x00293E17, 0x004A5F39, 0x00516542, 0x00394E28, 0x002A3F18, 0x005E7548, 0x00758D5D, 0x00738A56, 0x00708656, 0x006F8158, 0x0071835C, 0x0075845E, 0x0076845A, 0x00758555, 0x00788B54, 0x00738655, 0x00738655, 0x00738655, 0x00738556, 0x00748657,
        0x00758758, 0x0075865A, 0x0076875B, 0x0077885C, 0x00798A5E, 0x007A8B5F, 0x00798A5E, 0x0078895D, 0x0076875B, 0x0077885C, 0x007A8B5F, 0x006E8160, 0x00778C66, 0x00798E67, 0x0070875B, 0x002E4518, 0x00485F32, 0x006B8255, 0x00465D31, 0x00364A1D,
        0x00627649, 0x004C6033, 0x00293D10, 0x00304417, 0x00627649, 0x00617548, 0x00384C1F, 0x0033451C, 0x0051633A, 0x00687B50, 0x002F4217, 0x004C5E35, 0x007F906B, 0x006F7E5E, 0x00778667, 0x0078895E, 0x007A8B60, 0x0077885D, 0x0077885D, 0x007B8C61,
        0x00798A5F, 0x0076875C, 0x0078895E, 0x00778960, 0x0076885F, 0x0075875E, 0x0074865D, 0x0074865D, 0x0074865D, 0x0075875E, 0x0075875E, 0x0079895A, 0x00738458, 0x00738459, 0x0074865D, 0x0074865F, 0x00738462, 0x00728564, 0x00738665, 0x0070855E,
        0x007C916B, 0x003A4E2B, 0x00354827, 0x00728663, 0x004C613B, 0x0022380E, 0x00536A3D, 0x00566E46, 0x002A421A, 0x00243C14, 0x00566E46, 0x00627A52, 0x002F471F, 0x00526A42, 0x005D754D, 0x00627250, 0x0023340F, 0x00364821, 0x0076885F, 0x00798B62,
        0x006D7E59, 0x00758464, 0x00748266, 0x00758760, 0x0074865F, 0x0073855E, 0x0072845D, 0x0073855E, 0x0073855E, 0x0073855E, 0x0073855E, 0x00758760, 0x00758760, 0x00768861, 0x00768861, 0x00778962, 0x00768861, 0x00768861, 0x00768861, 0x0078885F,
        0x00778660, 0x00788662, 0x00788866, 0x00788968, 0x00768765, 0x00768B65, 0x007B9069, 0x004F6334, 0x00344819, 0x00738758, 0x00627647, 0x00334718, 0x004D6132, 0x00708455, 0x00384C1D, 0x00354117, 0x00535F35, 0x007D895F, 0x004A562C, 0x004D592F,
        0x00626E44, 0x0068744A, 0x003F4B21, 0x002D4417, 0x006E845A, 0x00788C69, 0x00768869, 0x007D8F70, 0x00758966, 0x00768C62, 0x0072895C, 0x007A8D62, 0x007A8B66, 0x00788767, 0x007B8967, 0x006A7953, 0xFF869171, 0xFFFFFFF7, 0xFFFCFBFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFDFF, 0xECF6F8EC, 0x006C7652, 0x00728253, 0x007B8A5E, 0x00788761, 0x007B8B62, 0x00798A5E, 0x00748661, 0x0073855C, 0x00768657, 0x0073824F, 0x006C7A4A,
        0x00637246, 0x005E7049, 0x002B3C1B, 0x00324322, 0x004C5D3C, 0x004A5B3A, 0x00394A29, 0x00506140, 0x004F603F, 0x003C4D2C, 0x002D3E1D, 0x00344226, 0x0049573B, 0x002C3A1E, 0x00344226, 0x00566448, 0x00404E32, 0x0029371B, 0x00334125, 0x00647549,
        0x0064754A, 0x0067784D, 0x006D7B51, 0x00728155, 0x00768355, 0x00758353, 0x0073824F, 0x00758556, 0x00758556, 0x00768657, 0x00768657, 0x00768657, 0x00768657, 0x00758556, 0x00758556, 0x00738556, 0x00738556, 0x00738556, 0x00738556, 0x00738556,
        0x00738556, 0x00728455, 0x00728455, 0x00768956, 0x006D804F, 0x00697D50, 0x005F7148, 0x0063744F, 0x00475837, 0x00213014, 0x00435236, 0x0049583C, 0x003F4E32, 0x00354428, 0x004D5C40, 0x003E4D31, 0x002A391D, 0x00243317, 0x004A593D, 0x002A3A1B,
        0x00334226, 0x00556448, 0x00455438, 0x002B3B1C, 0x00213210, 0x004E6238, 0x0063784B, 0x00647B44, 0x00667C48, 0x006B7F52, 0x00708057, 0x00718158, 0x00717F55, 0x00718151, 0x00728350, 0x00728554, 0x00728554, 0x00728554, 0x00738556, 0x00738556,
        0x00748559, 0x0075865A, 0x0075865A, 0x00748559, 0x0075865A, 0x0076875B, 0x0076875B, 0x0076875B, 0x0075865A, 0x00748559, 0x00738458, 0x0073875C, 0x0070845A, 0x006B7E57, 0x00637550, 0x002D3E1C, 0x00415230, 0x005D6E4C, 0x00495A38, 0x00374529,
        0x00566448, 0x004B593D, 0x00313F23, 0x00253317, 0x00404E32, 0x00435135, 0x00273519, 0x004F5E3E, 0x00546343, 0x00556444, 0x00253414, 0x00425230, 0x0072835E, 0x006C7E57, 0x00778960, 0x0075855C, 0x0078885F, 0x0076865D, 0x0076865D, 0x007A8A61,
        0x0078885F, 0x0074845B, 0x0077875E, 0x0076885F, 0x0076885F, 0x0075875E, 0x0074865D, 0x0074865D, 0x0074865D, 0x0074865D, 0x0074865D, 0x0077885C, 0x0075865A, 0x0075865B, 0x0075885D, 0x0076885F, 0x0073875D, 0x0070835C, 0x006E815A, 0x0070835C,
        0x006E7F5D, 0x00354526, 0x00324125, 0x00657459, 0x00556448, 0x00384928, 0x0050613F, 0x00495B3E, 0x002E4023, 0x001C2E11, 0x003A4C2F, 0x004C5E41, 0x00283A1D, 0x004A5C3F, 0x0057694C, 0x005F6C54, 0x002B391D, 0x00354424, 0x00697B54, 0x0076885F,
        0x0072845B, 0x00768861, 0x0071825D, 0x0072845D, 0x0072845D, 0x0072845D, 0x0072845D, 0x0073855E, 0x0073855E, 0x0073855E, 0x0073855E, 0x0074865F, 0x00758760, 0x00758760, 0x00768861, 0x00768861, 0x00768861, 0x00758760, 0x00758760, 0x00788761,
        0x00778660, 0x00768460, 0x00768762, 0x00758760, 0x0072865C, 0x0074885D, 0x00788C61, 0x00445333, 0x00303F1F, 0x00627151, 0x005A6949, 0x00425131, 0x004C5B3B, 0x005C6B4B, 0x00364525, 0x002F3B1D, 0x003C482A, 0x005C684A, 0x00354123, 0x003F4B2D,
        0x00546042, 0x005F6B4D, 0x00434F31, 0x0034481E, 0x006D8157, 0x00788A65, 0x00758664, 0x00798A68, 0x00748661, 0x00798D63, 0x00798D63, 0x00788B60, 0x00788964, 0x00778666, 0x007B8967, 0x006B7A54, 0xFF879272, 0xFFFFFFF7, 0xFFFEFDFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFBFF, 0xECF6F8EC, 0x006C7652, 0x00728253, 0x0079875D, 0x0075845E, 0x0076855F, 0x0074855A, 0x006C7D58, 0x006D7D54, 0x006B7949, 0x005C6935, 0x004F5B2B,
        0x00414C24, 0x003B472B, 0x0018230F, 0x00122514, 0x00172A19, 0x001F3221, 0x001A2D1C, 0x001B2E1D, 0x001D301F, 0x001D301F, 0x00102312, 0x0016261B, 0x001D2D22, 0x000F1F14, 0x0018281D, 0x0026362B, 0x001A2A1F, 0x0015251A, 0x0016261B, 0x00415121,
        0x00465626, 0x004C5C2C, 0x00546434, 0x00617142, 0x006C7C4D, 0x00738052, 0x00748153, 0x00748455, 0x00748455, 0x00758556, 0x00768657, 0x00768657, 0x00768657, 0x00768657, 0x00768657, 0x00738556, 0x00738556, 0x00728455, 0x00728455, 0x00718354,
        0x006F8152, 0x006E8051, 0x006D7F50, 0x00677A41, 0x00546730, 0x004E5E2E, 0x00425229, 0x00404D2D, 0x002D3A22, 0x00121C0B, 0x00212A1D, 0x00192019, 0x00282F28, 0x001C231C, 0x00252C25, 0x00282F28, 0x00232A23, 0x000F160F, 0x00222922, 0x00131D0D,
        0x001C2616, 0x002E3828, 0x00242E1D, 0x001F2B15, 0x00132105, 0x002E3E1C, 0x00455730, 0x00455B20, 0x004F652B, 0x005F723F, 0x006A7C4D, 0x006E7F53, 0x00728155, 0x00748357, 0x00758556, 0x00718453, 0x00718453, 0x00718354, 0x00728455, 0x00728357,
        0x00738458, 0x00738458, 0x0074855A, 0x00748559, 0x00738458, 0x00728357, 0x00738458, 0x00728357, 0x00708155, 0x006B7C50, 0x00647549, 0x00536A33, 0x00495D2E, 0x0042532E, 0x00414E34, 0x001C2713, 0x00222C1B, 0x00293420, 0x0024301A, 0x002A322B,
        0x00353D36, 0x00363E37, 0x002F3730, 0x001B231C, 0x00212922, 0x00272F28, 0x001B231C, 0x002E3A26, 0x002A3624, 0x00273222, 0x00111D0B, 0x002A3820, 0x004A5B39, 0x004C6232, 0x00566E38, 0x00697950, 0x006F7F56, 0x00708057, 0x00718158, 0x0076865D,
        0x0076865D, 0x0073835A, 0x0076865D, 0x0075875E, 0x0075875E, 0x0075875E, 0x0075875E, 0x0074865D, 0x0073855C, 0x0072845B, 0x0072845B, 0x0075855C, 0x0074855A, 0x00728358, 0x00708155, 0x006C8053, 0x00637748, 0x00576B3C, 0x00506435, 0x004B5B39,
        0x00435233, 0x00212E16, 0x0018230F, 0x002C3626, 0x002B3525, 0x00242E1E, 0x002A3423, 0x003A4535, 0x00364131, 0x001E2919, 0x001F2A1A, 0x002C3727, 0x000C1707, 0x00192414, 0x001C2717, 0x002D362C, 0x00182313, 0x0025331B, 0x00495A38, 0x00586C42,
        0x005A6F42, 0x00627848, 0x00697F4F, 0x006E8059, 0x006F815A, 0x0071835C, 0x0072845D, 0x0072845D, 0x0072845D, 0x0072845D, 0x0072845D, 0x0074865F, 0x0074865F, 0x00758760, 0x00758760, 0x00758760, 0x00758760, 0x0074865F, 0x0074865F, 0x0075835F,
        0x00717F5B, 0x006C7B55, 0x0066774C, 0x005C6D41, 0x00526637, 0x004F6433, 0x004E6332, 0x00313D2B, 0x001E2A18, 0x00323E2C, 0x002D3927, 0x00333F2D, 0x00394533, 0x00465240, 0x0044503E, 0x0025341F, 0x0022311C, 0x00374631, 0x0022311C, 0x002E3D28,
        0x00394833, 0x003E4D38, 0x002C3B26, 0x00253611, 0x004E6039, 0x005C6E45, 0x00607348, 0x00697C51, 0x006E8057, 0x00768861, 0x00758661, 0x0074875C, 0x00758661, 0x00768565, 0x007C8A68, 0x006C7B55, 0xFF879272, 0xFFFFFFF7, 0xFFFFFEFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFBFF, 0xF0F6F7ED, 0x006D7655, 0x00728155, 0x0079875D, 0x0074835D, 0x0074835D, 0x00708156, 0x00748260, 0x00717F56, 0x006A7646, 0x00515C2A, 0x00444E20,
        0x00363D1C, 0x002F3522, 0x001B2017, 0x00142216, 0x00152317, 0x00142216, 0x00111F13, 0x00132115, 0x00101E12, 0x00101E12, 0x00132115, 0x00111A17, 0x00121B18, 0x000D1613, 0x00151E1B, 0x0017201D, 0x00121B18, 0x00161F1C, 0x00161F1C, 0x00313F0F,
        0x00394815, 0x0041501D, 0x004D5C29, 0x005E6D3A, 0x00687849, 0x006F7E52, 0x00758359, 0x00738256, 0x00738256, 0x00748357, 0x00768559, 0x0077865A, 0x0077865A, 0x0077865A, 0x0077865A, 0x00748559, 0x00748559, 0x00738458, 0x00728357, 0x00708155,
        0x006D7E52, 0x006A7B4F, 0x00697A4E, 0x0066783B, 0x004D5E25, 0x00414F1F, 0x0033401A, 0x002B341A, 0x0022291A, 0x00141812, 0x00151816, 0x00111210, 0x00191A18, 0x00141513, 0x00191A18, 0x00171816, 0x0020211F, 0x00171816, 0x00171816, 0x001B1F1A,
        0x00131712, 0x00151914, 0x0013180F, 0x001E2518, 0x00141D08, 0x001F2B0F, 0x002E3C1A, 0x00374C0E, 0x0043561D, 0x00586B34, 0x00687946, 0x006B7B4C, 0x006B7C50, 0x006E7F54, 0x006D7E53, 0x00708253, 0x00708253, 0x00718354, 0x00728357, 0x00728357,
        0x00728357, 0x00728358, 0x00728358, 0x0077885D, 0x00728358, 0x00718257, 0x00708156, 0x006E7F54, 0x006B7C51, 0x00617247, 0x00536439, 0x00435A1C, 0x00374A17, 0x002B3917, 0x00293120, 0x00161A14, 0x00171B16, 0x0011150F, 0x00151B10, 0x00141B18,
        0x00111815, 0x00131A17, 0x001A211E, 0x00141B18, 0x00111815, 0x00131A17, 0x00121916, 0x000F180E, 0x00101811, 0x00141B16, 0x00101811, 0x001D2917, 0x002F401F, 0x00374D1C, 0x00425D1E, 0x00596940, 0x0063734A, 0x0068784F, 0x006B7B52, 0x00718158,
        0x0074845B, 0x0074845B, 0x0077875E, 0x0074865D, 0x0075875E, 0x0075875E, 0x0075875E, 0x0074865D, 0x0073855C, 0x0071835A, 0x00708259, 0x006E8059, 0x006F8158, 0x006D7E53, 0x00697A4E, 0x00637546, 0x00536633, 0x003F531E, 0x00364813, 0x00323E20,
        0x002B361C, 0x001E2713, 0x0013190E, 0x000F130D, 0x00121611, 0x00161A15, 0x00161A15, 0x00121610, 0x001E221C, 0x00141812, 0x00141812, 0x00232721, 0x00121610, 0x00181C16, 0x00141812, 0x0012171A, 0x00121914, 0x001C2717, 0x002E3D21, 0x003A4E24,
        0x00405626, 0x00526935, 0x0069814B, 0x006A7C55, 0x006C7E57, 0x006F815A, 0x0072845D, 0x0072845D, 0x0072845D, 0x0072845D, 0x0072845D, 0x0073855E, 0x0073855E, 0x0074865F, 0x0074865F, 0x0074865F, 0x0073855E, 0x0073855E, 0x0072845D, 0x00717F5D,
        0x006B7955, 0x0065764B, 0x005A6C3D, 0x004C5D2A, 0x0040511E, 0x003C4D1A, 0x00384916, 0x001F291C, 0x00121C0F, 0x00151F12, 0x000F190C, 0x001C2619, 0x00162013, 0x00151F12, 0x001F291C, 0x00192917, 0x0010200E, 0x001D2D1B, 0x00132311, 0x001B2B19,
        0x001D2D1B, 0x001C2C1A, 0x00122210, 0x00222F0F, 0x00364420, 0x00425328, 0x004D5F30, 0x00607243, 0x006E7F54, 0x0073815D, 0x006E7B5B, 0x0074875C, 0x00748560, 0x00768565, 0x007D8B69, 0x006D7C56, 0xFF869171, 0xFFFFFFF7, 0xFFFFFEFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFBFF, 0xF0F7F8EE, 0x006E7756, 0x00748357, 0x007B8960, 0x0074825E, 0x0074825E, 0x00708057, 0x0075805F, 0x006A724D, 0x005F673E, 0x00484C22, 0x003E411A,
        0x002F3218, 0x00282919, 0x001B1E15, 0x00232616, 0x00232616, 0x00202313, 0x00242717, 0x00272A1A, 0x00222515, 0x001D2010, 0x00242717, 0x0026251B, 0x0027261C, 0x00242319, 0x0025241A, 0x00232218, 0x001E1D13, 0x00222117, 0x00242319, 0x00323A11,
        0x00353E13, 0x00384414, 0x00475722, 0x005F6E3B, 0x00687848, 0x006A784E, 0x006F7E58, 0x00728155, 0x00738256, 0x00748357, 0x00768559, 0x0077865A, 0x0077865A, 0x0078875B, 0x0078875B, 0x0076875B, 0x0076875B, 0x0075865A, 0x00738458, 0x00708155,
        0x006D7E52, 0x006A7B4F, 0x0068794D, 0x00606D37, 0x00495422, 0x00374117, 0x002B3211, 0x00202510, 0x00202216, 0x001E1D19, 0x00191919, 0x00222018, 0x001D1B13, 0x001C1A12, 0x00222018, 0x0018160E, 0x001D1B13, 0x001E1C14, 0x001E1C14, 0x001D1C18,
        0x001D1C18, 0x001F1E1A, 0x00161511, 0x001A1B12, 0x001C1F0F, 0x00252B14, 0x00242B10, 0x00394612, 0x00404D19, 0x0053632E, 0x00677643, 0x00697949, 0x006A7B4F, 0x006D7E53, 0x006A7C53, 0x006F8152, 0x00708253, 0x00718256, 0x00728357, 0x00738458,
        0x00738459, 0x00728358, 0x00728358, 0x0077885D, 0x00718257, 0x006F8055, 0x006F8055, 0x006C7D52, 0x00697A4F, 0x005D6E43, 0x004A5B30, 0x003C4D14, 0x00334012, 0x00242C0E, 0x001D1F13, 0x00181615, 0x001D1B1B, 0x00191716, 0x0021211B, 0x00191E15,
        0x00141910, 0x0013180F, 0x00161B12, 0x001D2219, 0x00181D14, 0x0013180F, 0x00191E15, 0x00171B15, 0x001C201B, 0x00191B1B, 0x00161917, 0x00161D10, 0x00212D0F, 0x002D3F10, 0x00384E14, 0x0052613B, 0x00606F49, 0x00687751, 0x006B7A54, 0x0071805A,
        0x0075845E, 0x0075845E, 0x00778660, 0x0073855C, 0x0074865D, 0x0074865D, 0x0074865D, 0x0074865D, 0x0073855C, 0x0071835A, 0x00708259, 0x006B7D56, 0x006E8059, 0x006B7D54, 0x006A7B50, 0x00657546, 0x00506030, 0x003C4B18, 0x00364611, 0x00293015,
        0x00222811, 0x001E2112, 0x001A1B12, 0x00191716, 0x001C1A1A, 0x001C1A1A, 0x001A1817, 0x00161511, 0x001B1A16, 0x00181713, 0x00161511, 0x001D1C18, 0x00171612, 0x001F1E1A, 0x00191814, 0x0016161C, 0x00141616, 0x00131A0D, 0x001C270D, 0x002B3915,
        0x0037481C, 0x004C5F2E, 0x00697C49, 0x00677952, 0x006B7D56, 0x006F815A, 0x0072845D, 0x0072845D, 0x0071835C, 0x0072845D, 0x0072845D, 0x0073855E, 0x0073855E, 0x0074865F, 0x0074865F, 0x0073855E, 0x0073855E, 0x0072845D, 0x0071835C, 0x00738060,
        0x006D7C56, 0x0067784C, 0x005A6B38, 0x00465621, 0x003B4A17, 0x003B4717, 0x00374214, 0x00222B16, 0x001F2813, 0x00222B16, 0x001E2712, 0x0027301B, 0x001E2712, 0x0018210C, 0x001E2712, 0x001C2D12, 0x0017280D, 0x001D2E13, 0x0017280D, 0x00192A0F,
        0x001C2D12, 0x001F3015, 0x001C2D12, 0x002B3315, 0x002F3817, 0x0038431B, 0x00445125, 0x0059663A, 0x006E7951, 0x00747D5C, 0x00788062, 0x0075885D, 0x00758661, 0x00778666, 0x007E8C6A, 0x006C7B55, 0xFF848F6F, 0xFFFFFFF7, 0xFFFFFEFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFBFF, 0xF4F7F8EF, 0x006E7657, 0x00748258, 0x007C8A61, 0x00768460, 0x00768460, 0x00728259, 0x00797F60, 0x00686D4D, 0x006C6D4D, 0x005F5D3F, 0x00605D41,
        0x005E5B46, 0x00575745, 0x00555547, 0x0064614C, 0x005D5A45, 0x005C5944, 0x00625F4A, 0x005B5843, 0x005C5944, 0x005C5944, 0x005C5944, 0x005B5542, 0x00605A47, 0x005E5845, 0x005D5744, 0x005C5643, 0x0058523F, 0x0058523F, 0x005D5744, 0x0053543A,
        0x004C4F2F, 0x003D451C, 0x00424E1E, 0x005A6936, 0x00687848, 0x0068794E, 0x006C7B55, 0x00728056, 0x00738157, 0x00748258, 0x0076845A, 0x0077855B, 0x0077855B, 0x0077855B, 0x0077855B, 0x0076875C, 0x0076875C, 0x0076875C, 0x0074855A, 0x00718257,
        0x006E7F54, 0x006A7B50, 0x0068794E, 0x00626740, 0x005D613D, 0x0057593B, 0x0055583E, 0x00535440, 0x00525244, 0x0057564C, 0x0054524A, 0x00595745, 0x00565442, 0x0053513F, 0x00585644, 0x00565442, 0x0052503E, 0x00504E3C, 0x005A5846, 0x00515143,
        0x004E4E42, 0x00525147, 0x00504E46, 0x004C4B41, 0x0049493B, 0x004D4F3B, 0x004B4E38, 0x004A4E2A, 0x00424A21, 0x00515B30, 0x00667444, 0x006B7B4B, 0x006C7D51, 0x006F8257, 0x006F8158, 0x00708253, 0x00708155, 0x00728357, 0x00738458, 0x0074855A,
        0x0074855A, 0x0073835A, 0x00728259, 0x0075855C, 0x006E7E55, 0x006E7E55, 0x006E7E55, 0x006C7C53, 0x006B7B52, 0x00607047, 0x00495930, 0x003E481E, 0x00424926, 0x003F432A, 0x00404032, 0x00413E39, 0x0044413C, 0x00403D38, 0x003B3931, 0x00414532,
        0x00404431, 0x003F4330, 0x00383C29, 0x00414532, 0x003D412E, 0x00393D2A, 0x00424633, 0x003A3B31, 0x00414239, 0x003E3E38, 0x003D3E35, 0x003C3F30, 0x0041472E, 0x00404A26, 0x00424F23, 0x0054633D, 0x0064734D, 0x006E7D57, 0x006F7E58, 0x0073825C,
        0x0076855F, 0x0075845E, 0x00778660, 0x0073855C, 0x0073855C, 0x0074865D, 0x0074865D, 0x0073855C, 0x0073855C, 0x0072845B, 0x0072845B, 0x006E815A, 0x006F825B, 0x006D7F56, 0x006C7C53, 0x00657349, 0x004E5A30, 0x003E481D, 0x00444D22, 0x00383C23,
        0x00383A26, 0x003C3C2E, 0x003A3830, 0x003B3833, 0x003B3833, 0x0036332E, 0x0039372F, 0x00424036, 0x003D3B31, 0x003D3B31, 0x003C3A30, 0x003A382E, 0x0038362C, 0x003E3C32, 0x0037352B, 0x00323030, 0x0032312D, 0x00343728, 0x00383E27, 0x003D4526,
        0x00414B27, 0x004F5A34, 0x00626D47, 0x00677952, 0x006B7D56, 0x0070825B, 0x0072845D, 0x0072845D, 0x0071835C, 0x0072845D, 0x0073855E, 0x0073855E, 0x0074865F, 0x0074865F, 0x0074865F, 0x0073855E, 0x0072845D, 0x0071835C, 0x0071835C, 0x0073815F,
        0x006D7D54, 0x0069794A, 0x00596835, 0x00434F1D, 0x003E481A, 0x00474B27, 0x00464929, 0x003F462B, 0x003E452A, 0x003E452A, 0x00394025, 0x003D4429, 0x003C4328, 0x003D4429, 0x003D4429, 0x003A4426, 0x003C4628, 0x003F492B, 0x003F492B, 0x003C4628,
        0x003F492B, 0x00404A2C, 0x00414B2D, 0x00454A2F, 0x00414629, 0x00474D2E, 0x0049502F, 0x00565D3C, 0x00666C4D, 0x006D7255, 0x007E8368, 0x00778A5F, 0x00768762, 0x00778666, 0x007E8C6A, 0x006B7A54, 0xFF828D6D, 0xFFFDFFF5, 0xFFFFFEFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFAFF, 0xF0F6F7EE, 0x006D7556, 0x00748258, 0x007B8960, 0x00778563, 0x00778561, 0x0074845B, 0x006F7455, 0x005F6046, 0x00726D58, 0x006E6655, 0x00736B5A,
        0x0077715E, 0x0072725A, 0x0072755B, 0x006E6A57, 0x006C6855, 0x006A6653, 0x006C6855, 0x005E5A47, 0x00635F4C, 0x00635F4C, 0x00625E4B, 0x0066614C, 0x006C6752, 0x00746F5A, 0x0077725D, 0x0078735E, 0x0075705B, 0x00716C57, 0x00716C57, 0x00797066,
        0x0074705D, 0x005C5F3F, 0x004C552A, 0x005A6936, 0x006B7B4B, 0x006D7E53, 0x006C7E57, 0x00738157, 0x00748258, 0x00758359, 0x0076845A, 0x0077855B, 0x0077855B, 0x0077855B, 0x0077855B, 0x0075865B, 0x0075865B, 0x0075865B, 0x0074855A, 0x00728358,
        0x006E7F54, 0x006B7C51, 0x0068794E, 0x00625F4A, 0x006D6956, 0x006C6855, 0x006F6E5A, 0x0071705C, 0x00686955, 0x006E6E5C, 0x00727260, 0x00615D4A, 0x00615D4A, 0x005E5A47, 0x00605C49, 0x00625E4B, 0x005E5A47, 0x005C5845, 0x00615D4A, 0x0061644A,
        0x0061634D, 0x00656553, 0x006A695B, 0x006D6C5E, 0x006B6A5C, 0x006E6E5C, 0x00747561, 0x006A6752, 0x0054553B, 0x00565C39, 0x006B754B, 0x006D7D4E, 0x006B7D4E, 0x006B7E53, 0x006A7E54, 0x00708155, 0x00718256, 0x00738458, 0x0075865B, 0x0075865B,
        0x0075855C, 0x0074845B, 0x0073835A, 0x0075855C, 0x006E7E55, 0x006F7F56, 0x00708057, 0x006C7C53, 0x006E7E55, 0x0063734A, 0x004B5B32, 0x0060624C, 0x00686A54, 0x00686955, 0x0070705E, 0x006E6E5E, 0x006E6E5E, 0x00747464, 0x00686858, 0x00666551,
        0x0061604C, 0x00666551, 0x005A5945, 0x005E5D49, 0x005F5E4A, 0x00605F4B, 0x00656450, 0x00656351, 0x006E6C5A, 0x006B6957, 0x006F6D5B, 0x00706F5B, 0x0074735E, 0x006A6A52, 0x006F7056, 0x0053613D, 0x00667450, 0x00707E5A, 0x00717F5B, 0x0074825E,
        0x00768460, 0x0075835F, 0x00768460, 0x0073855C, 0x0073855C, 0x0073855C, 0x0073855C, 0x0073855C, 0x0074865D, 0x0074865D, 0x0075875E, 0x006F855B, 0x0071855B, 0x006C7E57, 0x006C7B55, 0x0066704C, 0x004E5534, 0x00464B2B, 0x00595C3C, 0x0062644E,
        0x00656652, 0x006A6A5A, 0x00666459, 0x0069675C, 0x006B6A5C, 0x00616151, 0x00626250, 0x00666452, 0x00605E4C, 0x00646250, 0x00646250, 0x0063614F, 0x00666452, 0x00676553, 0x00646250, 0x0068635A, 0x00686557, 0x006C6A58, 0x006B6B53, 0x0064654B,
        0x0063644A, 0x0063634B, 0x005F5E49, 0x00687A53, 0x006C7E57, 0x0071835C, 0x0072845D, 0x0072845D, 0x0071835C, 0x0073855E, 0x00758760, 0x0074865F, 0x0074865F, 0x0074865F, 0x0074865F, 0x0073855E, 0x0072845D, 0x0071835C, 0x0070825B, 0x006D7E59,
        0x006A7B50, 0x00687848, 0x005A6936, 0x00485223, 0x004F532F, 0x0065644A, 0x006D6655, 0x006D6E54, 0x006D6E54, 0x00696A50, 0x0067684E, 0x0066674D, 0x00616248, 0x00595A40, 0x00525339, 0x0059573F, 0x005C5A42, 0x005B5941, 0x00626048, 0x005E5C44,
        0x005F5D45, 0x005E5C44, 0x00626048, 0x00676A50, 0x0060634A, 0x0063654F, 0x005D5E4A, 0x0061624E, 0x00656751, 0x0060634A, 0x0076795F, 0x00778A5F, 0x00758661, 0x00768565, 0x007E8C6A, 0x006A7953, 0xFF808B6B, 0xFFFDFFF5, 0xFFFFFEFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFF8FF, 0xF0F5F6ED, 0x006C7455, 0x00738157, 0x007B8862, 0x00778563, 0x00788662, 0x0076855F, 0x00757A5B, 0x00636149, 0x00746D5E, 0x00695D53, 0x005E5248,
        0x00534C3B, 0x00454428, 0x003F4522, 0x004F5040, 0x005F6050, 0x005F6050, 0x00606151, 0x00575848, 0x00575848, 0x004D4E3E, 0x00505141, 0x0061624E, 0x005C5D49, 0x005A5B47, 0x00535440, 0x004B4C38, 0x004C4D39, 0x004D4E3A, 0x004D4E3A, 0x00625656,
        0x00736A60, 0x0065664C, 0x00515930, 0x005A6838, 0x006E7E4E, 0x00728357, 0x00708259, 0x00738157, 0x00748258, 0x00758359, 0x0076845A, 0x0076845A, 0x0077855B, 0x0076845A, 0x0076845A, 0x00738459, 0x0074855A, 0x0074855A, 0x0074855A, 0x00728358,
        0x006E7F54, 0x006B7C51, 0x0068794E, 0x00655C53, 0x0072695F, 0x00635D50, 0x005D5849, 0x00565541, 0x00484732, 0x004D5036, 0x00595C42, 0x00686150, 0x00625B4A, 0x00635C4B, 0x00615A49, 0x005B5443, 0x005E5746, 0x005F5847, 0x00554E3D, 0x005B5F3C,
        0x00717355, 0x006D6E54, 0x00555440, 0x004E4B3C, 0x00545142, 0x00555341, 0x00545240, 0x00797368, 0x005B5745, 0x0057593C, 0x006B744C, 0x00707F53, 0x006E8051, 0x006F8257, 0x006F8359, 0x00718256, 0x00728357, 0x0074855A, 0x0076875C, 0x0076875C,
        0x0076865D, 0x0074845B, 0x0074845B, 0x0078885F, 0x00718158, 0x00728259, 0x00718158, 0x006C7C53, 0x006E7E55, 0x0063734A, 0x004A5A31, 0x006F6B60, 0x006A6759, 0x005A5846, 0x00595843, 0x0053523D, 0x005A5944, 0x00797863, 0x00757460, 0x00706958,
        0x00625B4A, 0x006A6352, 0x005E5746, 0x005E5746, 0x00625B4A, 0x00665F4E, 0x00615A49, 0x0069654D, 0x006A664E, 0x005E5A41, 0x005B573E, 0x005D5941, 0x0068624F, 0x00676051, 0x007C7467, 0x004E5C38, 0x0062704C, 0x006E7C58, 0x006F7D59, 0x0072805C,
        0x0074825E, 0x0074825E, 0x0075835F, 0x0073855C, 0x0073855C, 0x0072845B, 0x0072845B, 0x0073855C, 0x0074865D, 0x0076885F, 0x0076885F, 0x006F865A, 0x006F8359, 0x006B7D56, 0x006E7A56, 0x00697152, 0x0054583B, 0x0056573D, 0x0072725A, 0x00686752,
        0x0062614D, 0x00605E4C, 0x005D5A4B, 0x006C695A, 0x00797864, 0x00686850, 0x00595B3E, 0x005C5B41, 0x0059583E, 0x0058573D, 0x00545339, 0x0058573D, 0x00605F45, 0x005E5D43, 0x00605F45, 0x0077705F, 0x006B6552, 0x0068634E, 0x0069654D, 0x006D6853,
        0x00797360, 0x00746D5E, 0x005B5248, 0x00697B54, 0x006D7F58, 0x0071835C, 0x0073855E, 0x0071835C, 0x0071835C, 0x0073855E, 0x00758760, 0x0074865F, 0x0074865F, 0x0074865F, 0x0074865F, 0x0073855E, 0x0072845D, 0x0071835C, 0x0070825B, 0x0072845D,
        0x006E7F54, 0x006A7A4A, 0x005B6735, 0x00465022, 0x00535434, 0x00706958, 0x007B7068, 0x005D5843, 0x005D5843, 0x005B5641, 0x00625D48, 0x006C6752, 0x006B6651, 0x0065604B, 0x005F5A45, 0x0063584A, 0x00615648, 0x00584D3F, 0x00625749, 0x00605547,
        0x00665B4D, 0x006A5F51, 0x00766B5D, 0x00636548, 0x005C5B46, 0x00636051, 0x00625E53, 0x006D695E, 0x006E6B5C, 0x005E5D48, 0x00737558, 0x00778A5F, 0x00758661, 0x00758464, 0x007D8B69, 0x006A7953, 0xFF808B6B, 0xFFFEFFF6, 0xFFFFFEFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFDFF, 0xE8F1F5E9, 0x006A7652, 0x00768657, 0x007B895F, 0x007C8864, 0x00818D69, 0x0075835A, 0x00706F5A, 0x00645F4A, 0x00706551, 0x00675A44, 0x005E533D,
        0x00645E47, 0x00474A30, 0x002C3318, 0x003B391B, 0x00444023, 0x00514A2F, 0x00554B33, 0x00504831, 0x00524B37, 0x004E4A37, 0x003E3F2B, 0x00454723, 0x00353915, 0x002E3411, 0x00353A1A, 0x00303313, 0x004F4D2F, 0x005D563B, 0x0054492E, 0x00524F3A,
        0x006A694D, 0x005C603D, 0x005A6037, 0x0060693E, 0x006E764D, 0x00737A55, 0x007D8463, 0x007A885F, 0x00717F56, 0x0076845B, 0x0079875D, 0x00748258, 0x0077865A, 0x007B8A5E, 0x007A895D, 0x0071835C, 0x0073855C, 0x00708358, 0x0076875B, 0x006B7C50,
        0x007D8E63, 0x006D7A54, 0x00677251, 0x0061634F, 0x00686753, 0x0057523D, 0x00564E37, 0x005D523C, 0x00564C34, 0x0041381D, 0x0050472C, 0x00625B4A, 0x00595340, 0x00504A33, 0x004F482D, 0x00514D30, 0x00515034, 0x00474B32, 0x003F452E, 0x004E543D,
        0x0053573E, 0x004B4C32, 0x003E3C1E, 0x004B472A, 0x005B5439, 0x00514D31, 0x00565138, 0x0063625E, 0x00575844, 0x005B5C35, 0x00717246, 0x007C7D55, 0x007A805D, 0x007A8864, 0x0071855B, 0x00728357, 0x00728357, 0x00738458, 0x00738458, 0x00748559,
        0x00748559, 0x0075865A, 0x0075865A, 0x00748563, 0x00768762, 0x0072845B, 0x006D7E52, 0x007A895D, 0x006F7C50, 0x00646E44, 0x00576137, 0x00656456, 0x00565442, 0x004F4B33, 0x00555135, 0x00453E25, 0x0039321E, 0x00635C4D, 0x008F867C, 0x00898681,
        0x007E7C72, 0x00716C5D, 0x0066614C, 0x00615D45, 0x005F5E44, 0x00585B42, 0x00545741, 0x0054532D, 0x0043411E, 0x003F3A19, 0x00524C2F, 0x00524B30, 0x004B472F, 0x004B4833, 0x00686753, 0x00615942, 0x006D7255, 0x006B7F5C, 0x00687D56, 0x0076845B,
        0x007F895F, 0x00738158, 0x00697F55, 0x0072845B, 0x0072845B, 0x0072845B, 0x0072845B, 0x0072845B, 0x0071835A, 0x0071835A, 0x0071835A, 0x00747F59, 0x00707B5A, 0x00707E5C, 0x006F8257, 0x00627542, 0x00525F31, 0x0057593C, 0x00696358, 0x00525038,
        0x004F4C30, 0x00524F30, 0x004D4B29, 0x0041401E, 0x00454428, 0x0050513D, 0x00545545, 0x004A5339, 0x0050543B, 0x0053543A, 0x00545037, 0x00534F33, 0x00555134, 0x005A5839, 0x005C5D3D, 0x0052512B, 0x004A4825, 0x004C4726, 0x00524B30, 0x00565039,
        0x00595340, 0x00696657, 0x00525143, 0x0065744E, 0x0073835A, 0x00728357, 0x00778B5C, 0x00768A5D, 0x006F8358, 0x00768962, 0x0072845F, 0x00778A5F, 0x0076885F, 0x00708259, 0x0075875E, 0x0074865F, 0x006B7D56, 0x006E7F5A, 0x0071825D, 0x00778458,
        0x00757F54, 0x00707A4F, 0x00596139, 0x004D5030, 0x005D5A45, 0x00635B4E, 0x0061584F, 0x005A4B38, 0x005B5139, 0x00595739, 0x00454B28, 0x0049502D, 0x004E5336, 0x00575A44, 0x0051513F, 0x004E4D39, 0x004E4B36, 0x004E4930, 0x00524A2D, 0x00585033,
        0x005B5439, 0x00575239, 0x004F4B33, 0x0047502F, 0x004D5233, 0x0059553C, 0x00564D39, 0x005A513D, 0x006F6A55, 0x0062654B, 0x006C7456, 0x007F8C6C, 0x0074845B, 0x00778A59, 0x007B8E5B, 0x006F8055, 0xFF7D886E, 0xFFFAFEF9, 0xFFFDFCFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBF8FF, 0xE8F1F5EA, 0x006C7756, 0x00758359, 0x007B8960, 0x007D8867, 0x00778261, 0x005D6A44, 0x00585742, 0x00605B46, 0x00716854, 0x006B604A, 0x0060553F,
        0x0069644B, 0x005E5F45, 0x00353A1F, 0x00454D2F, 0x004A4E31, 0x00525135, 0x00535034, 0x004D492D, 0x004C492D, 0x004A4C2F, 0x0044482B, 0x003F3F1B, 0x003A3B19, 0x00363A17, 0x003C4121, 0x003D4223, 0x00565539, 0x005F5A41, 0x005D533B, 0x00636051,
        0x0073715F, 0x005D6047, 0x0044492A, 0x00383F1C, 0x00404823, 0x00424D27, 0x0058633D, 0x006D7B52, 0x007F8D64, 0x0077855C, 0x00738157, 0x0077855B, 0x00768559, 0x0079885C, 0x00758458, 0x00708259, 0x007B8E63, 0x006C7F54, 0x00728358, 0x007F8F66,
        0x00636F4B, 0x004C5638, 0x00475036, 0x006A6955, 0x0072715D, 0x00615C47, 0x005C563F, 0x00605B42, 0x005D583F, 0x004A462A, 0x00565235, 0x00515641, 0x004E5138, 0x00494B2E, 0x00444525, 0x003D3E1E, 0x003A3C1E, 0x0042472A, 0x004D5439, 0x00495238,
        0x0051573E, 0x0051543A, 0x00464529, 0x00524F33, 0x00625D44, 0x005E5841, 0x005F5942, 0x0067655A, 0x005E6147, 0x004E532C, 0x0042491E, 0x00474E29, 0x00515B37, 0x00617148, 0x00778C5B, 0x00728357, 0x00738458, 0x00738458, 0x00748559, 0x00748559,
        0x0075865A, 0x0075865A, 0x0075865A, 0x00748760, 0x0064764F, 0x0075875E, 0x00718158, 0x0059673E, 0x00444F29, 0x00484F2C, 0x00484F2E, 0x006B685A, 0x005B5947, 0x00585540, 0x00666249, 0x005C583F, 0x004F4C37, 0x006F6B59, 0x008F8C7E, 0x008F908C,
        0x007E7C74, 0x00656456, 0x00585441, 0x00504D38, 0x00494B35, 0x004B4D39, 0x004C533E, 0x00525333, 0x00494728, 0x00464426, 0x00595539, 0x005D583F, 0x005C5840, 0x0056533E, 0x006C6954, 0x006B624E, 0x004C5037, 0x003B4D2E, 0x004A5E3B, 0x0066724E,
        0x007A825D, 0x007B8862, 0x0071865F, 0x0073855C, 0x0073855C, 0x0073855C, 0x0072845B, 0x0072845B, 0x0072845B, 0x0072845B, 0x0071835A, 0x00768159, 0x007F8A69, 0x00606C4E, 0x00495937, 0x00435429, 0x00455028, 0x00606147, 0x006E685B, 0x0066614C,
        0x00534F37, 0x005D5B3D, 0x005D5B3C, 0x00404022, 0x0044452B, 0x00545642, 0x00454838, 0x004A543D, 0x00464E37, 0x00484B35, 0x004F4E39, 0x0051503B, 0x00484A34, 0x003C422B, 0x00363E27, 0x004C502D, 0x00474828, 0x004D4B2D, 0x00575438, 0x005D5941,
        0x005C5944, 0x006D6C58, 0x005A5846, 0x00475335, 0x00515E3E, 0x005F6D49, 0x00718459, 0x00718459, 0x0072865B, 0x007C9066, 0x00667952, 0x0072855A, 0x0074865D, 0x00708259, 0x0074865D, 0x0073855E, 0x006E8059, 0x0073845F, 0x0072835E, 0x006C7A51,
        0x0058643A, 0x00535F35, 0x004E572F, 0x00484E2B, 0x0057593C, 0x006D6A55, 0x0074705E, 0x006C604E, 0x005F5844, 0x0057563A, 0x004B5030, 0x004D5433, 0x0044492C, 0x00464832, 0x00494834, 0x00474B32, 0x004C4F35, 0x00525135, 0x00504E30, 0x004A4A2C,
        0x0048492F, 0x00464933, 0x00414833, 0x00505839, 0x00595C42, 0x00645F4A, 0x00605946, 0x00665E4D, 0x00797360, 0x005D5F49, 0x0061674E, 0x006A755B, 0x00727F5F, 0x007E8F64, 0x007B8D5E, 0x0068784F, 0xFF7A856B, 0xFFFCFFFB, 0xFFFDFCFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFBFF, 0xF0F4F7EE, 0x00687254, 0x00717F56, 0x00808C68, 0x007A8466, 0x005E674C, 0x003B4626, 0x00464531, 0x0068634E, 0x0068614D, 0x00686049, 0x007E775E,
        0x00777357, 0x005C5B3F, 0x00414326, 0x003F4B2F, 0x00434B2D, 0x004F5133, 0x005C5A3B, 0x00615C3B, 0x0064603D, 0x00696542, 0x00686741, 0x00554F2C, 0x004F4D2B, 0x003F4020, 0x0037391B, 0x00393D20, 0x0056573D, 0x00706E56, 0x00827D68, 0x00707064,
        0x00727266, 0x00545446, 0x00373A2A, 0x00282D18, 0x00293218, 0x00263111, 0x0037431F, 0x00515F36, 0x007F8D64, 0x0075835A, 0x00707E54, 0x007A885E, 0x00758458, 0x0079885C, 0x00768559, 0x0074885B, 0x0073875A, 0x00738459, 0x00798960, 0x006B7655,
        0x00485137, 0x00868C79, 0x009EA094, 0x0065614F, 0x00676350, 0x0063604B, 0x007D7B63, 0x00818268, 0x00616346, 0x003C3E20, 0x00464929, 0x003E472C, 0x003C4426, 0x00474B28, 0x005A5A36, 0x0062613B, 0x005D5B38, 0x00555432, 0x00525234, 0x004F5739,
        0x0052573C, 0x004E5338, 0x0047472F, 0x0054523A, 0x00716C57, 0x007E7763, 0x00827866, 0x00777662, 0x0053573A, 0x002F3915, 0x00192705, 0x00233115, 0x002F3D21, 0x003F4F26, 0x006C804B, 0x00738458, 0x00738458, 0x00738458, 0x00748559, 0x00748559,
        0x0075865A, 0x0075865A, 0x0076875B, 0x006F8257, 0x00788A61, 0x007A8963, 0x00505B3A, 0x003E4628, 0x003C4126, 0x00444731, 0x00565842, 0x006A6556, 0x00625E4C, 0x0065644F, 0x006E6F55, 0x0058593F, 0x003E4128, 0x004F513B, 0x00686955, 0x007E7F75,
        0x00727163, 0x00666452, 0x0066624A, 0x00615D44, 0x0054543C, 0x004F5239, 0x004F553E, 0x0053543A, 0x0047482E, 0x0044452B, 0x00595A40, 0x006D6C52, 0x0078765E, 0x006D6951, 0x0077735B, 0x00594E40, 0x00686A57, 0x00788871, 0x006A7B60, 0x00515A3F,
        0x00616748, 0x007A8564, 0x0070855F, 0x0074865D, 0x0073855C, 0x0073855C, 0x0073855C, 0x0073855C, 0x0072845B, 0x0072845B, 0x0072845B, 0x007C885E, 0x00616B4D, 0x0039422E, 0x00313C28, 0x00283418, 0x00283011, 0x0056563E, 0x00716C5D, 0x00736C59,
        0x00766F5B, 0x00747057, 0x00636246, 0x004A4C2F, 0x00404329, 0x00494C36, 0x00545642, 0x00585F44, 0x0054593E, 0x0055583F, 0x005C5B46, 0x00575945, 0x00494F3C, 0x00404A39, 0x00404E3C, 0x00414629, 0x0043482B, 0x00595D40, 0x0072755B, 0x0078795F,
        0x006B6A50, 0x006F6D55, 0x0059553D, 0x00777C6D, 0x006E7763, 0x004E5A3E, 0x005C6A48, 0x007B8D64, 0x0072855A, 0x006C8055, 0x00778B61, 0x00708358, 0x0074865D, 0x0071835A, 0x0073855C, 0x0073855E, 0x0072845D, 0x0073845F, 0x00697A55, 0x00445236,
        0x00384426, 0x0032401E, 0x00293511, 0x002A3410, 0x00515738, 0x007B7E64, 0x0072755C, 0x00807769, 0x00716D5A, 0x005E5E46, 0x004A4F32, 0x00474C2F, 0x00414326, 0x004B4931, 0x005E5743, 0x0066684A, 0x00696A4A, 0x00686745, 0x00616242, 0x005B5D3F,
        0x0052583F, 0x0046513D, 0x003C4A38, 0x0044492E, 0x00585742, 0x00736F5D, 0x00746D5E, 0x006C6457, 0x007E796A, 0x005E5C4A, 0x0051533F, 0x004B5245, 0x00626B56, 0x00788664, 0x007C8D62, 0x00697852, 0xFF7E896F, 0xFFFDFFF9, 0xFFFDFEFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFAFF, 0xF4F5F8EF, 0x00697355, 0x0076835D, 0x00859070, 0x00697258, 0x0049513A, 0x00495237, 0x00534F3C, 0x00625E4B, 0x00635E49, 0x0058523B, 0x00615C43,
        0x004B472A, 0x003A381A, 0x004A4829, 0x00434528, 0x004C4A2C, 0x005E5534, 0x006F603F, 0x007A6742, 0x007B673E, 0x00736237, 0x006C5C2E, 0x00766844, 0x006E6442, 0x005E5736, 0x00474526, 0x0037391C, 0x0042422A, 0x0055543F, 0x0064604D, 0x00414730,
        0x005E6151, 0x0056574D, 0x0053534D, 0x003B3D37, 0x002C3025, 0x00373F2E, 0x00505944, 0x004B5930, 0x006E7C53, 0x00748259, 0x00748258, 0x0077855B, 0x00748357, 0x0078875B, 0x0079885C, 0x00798B5C, 0x00728455, 0x00748559, 0x007C8963, 0x00576143,
        0x005A604D, 0x009FA097, 0x008D8B8A, 0x006B6352, 0x005C5544, 0x0044432F, 0x005D6047, 0x0063684B, 0x00464C2D, 0x00303613, 0x00424825, 0x004E4F2D, 0x00575532, 0x00676039, 0x0071653B, 0x00716137, 0x006B5930, 0x006D5B36, 0x0073603D, 0x00616240,
        0x00545737, 0x004D4F32, 0x00474933, 0x004C4B37, 0x00585442, 0x0057503F, 0x004B4431, 0x00676351, 0x00585A44, 0x00525C45, 0x00334030, 0x002F3C34, 0x00495346, 0x004B5739, 0x005A6739, 0x00738458, 0x00738458, 0x00748559, 0x00748559, 0x0075865A,
        0x0075865A, 0x0075865A, 0x0076875B, 0x00728756, 0x00738458, 0x005D6B47, 0x004A5338, 0x00565B46, 0x00444535, 0x00414032, 0x00504F41, 0x00655E4D, 0x005A5643, 0x005B5A45, 0x005F634A, 0x004D5237, 0x00393E23, 0x0046492F, 0x005E5F45, 0x0072694E,
        0x006B6044, 0x00665939, 0x00675935, 0x00685B35, 0x00675B37, 0x00685F3D, 0x006B6443, 0x0057553D, 0x00484830, 0x003F4229, 0x00494C33, 0x0054573E, 0x005E5F45, 0x00534F36, 0x00645F46, 0x0065594F, 0x006E6E62, 0x00AFBCAE, 0x00B4C1B1, 0x005B624D,
        0x004E5338, 0x007F8A6A, 0x00728761, 0x0074865D, 0x0074865D, 0x0074865D, 0x0074865D, 0x0073855C, 0x0073855C, 0x0073855C, 0x0073855C, 0x006E7B4F, 0x00555E43, 0x00646A5F, 0x00545B54, 0x00313829, 0x003F452E, 0x005A5944, 0x00605C4A, 0x005F5544,
        0x006E6754, 0x0066634E, 0x0052523A, 0x0046492F, 0x003B3F22, 0x00414326, 0x00595B3E, 0x00756F46, 0x0069623B, 0x00645B36, 0x006B6241, 0x00726C4F, 0x006D6C52, 0x005E6249, 0x00515942, 0x00484E35, 0x0041472E, 0x004C5239, 0x005E654A, 0x0062674C,
        0x00595B3E, 0x006B684C, 0x005B573B, 0x00A1A29E, 0x00BEC2B7, 0x007A806D, 0x00475335, 0x006B7955, 0x007C8E65, 0x0072855A, 0x00708358, 0x0073865B, 0x00778960, 0x0074865D, 0x0074865D, 0x00758760, 0x00758760, 0x006C7D58, 0x00546540, 0x00545C55,
        0x00586055, 0x00505A4A, 0x0039422D, 0x002F381E, 0x004B5138, 0x00747761, 0x00565844, 0x00535041, 0x0052503E, 0x00454632, 0x003D4027, 0x004A4B31, 0x00585539, 0x006A6245, 0x007C7054, 0x00756945, 0x00786B45, 0x00796C46, 0x00766A46, 0x0071694B,
        0x0069654C, 0x00595B48, 0x004B5041, 0x004C4B36, 0x00504F3B, 0x006D6859, 0x006A6459, 0x00575047, 0x007B756A, 0x00676455, 0x00595745, 0x004E514F, 0x005F6659, 0x006F7A60, 0x007E8C68, 0x006C7A56, 0xFF7D886E, 0xFFFDFFF8, 0xFFFDFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCF9FF, 0xF4F7FBF0, 0x006D7858, 0x0077845E, 0x00828D6D, 0x00616952, 0x00666D58, 0x00ADB69C, 0x00979381, 0x00605C49, 0x0063604B, 0x004E4D33, 0x003B381C,
        0x00393617, 0x00423D1C, 0x004E4825, 0x00695635, 0x00826C49, 0x009F8360, 0x00B7936D, 0x00C59F75, 0x00CDA67A, 0x00C9A373, 0x00C29D6B, 0x0090764E, 0x00826D47, 0x00766844, 0x00615A39, 0x004C4A2C, 0x0048472D, 0x004C4B36, 0x00484732, 0x00424928,
        0x0063684D, 0x005E6151, 0x00898A81, 0x00969493, 0x00868686, 0x008D8E8C, 0x00868783, 0x0068764D, 0x00606E45, 0x00738158, 0x007A885E, 0x00738157, 0x0078875B, 0x0078875B, 0x007A895D, 0x00788B5A, 0x00758758, 0x00707F53, 0x007C8963, 0x004A5338,
        0x005F6252, 0x00787872, 0x00686666, 0x00675C4E, 0x00625B4A, 0x003D3E2A, 0x003B3F26, 0x003A4224, 0x003A3F1F, 0x003E401C, 0x004F5029, 0x007A6742, 0x00856F46, 0x00977C50, 0x00AD8C5E, 0x00C09C6E, 0x00C59E72, 0x00B58F65, 0x00A37C55, 0x00796D43,
        0x00615832, 0x00524D2E, 0x00525038, 0x00535341, 0x00565442, 0x004F4B38, 0x003F3926, 0x005D544B, 0x005C5A4F, 0x008E9188, 0x008E9493, 0x007A8087, 0x0082878A, 0x006A7162, 0x00525B3A, 0x00738458, 0x00738458, 0x00738458, 0x00748559, 0x00748559,
        0x0075865A, 0x0075865A, 0x0075865A, 0x00768956, 0x00718256, 0x005D6847, 0x005A6049, 0x006D6E5E, 0x00717165, 0x007A786D, 0x005D594E, 0x0068624F, 0x004C4835, 0x003F412B, 0x00434932, 0x00474C31, 0x004C4E31, 0x005E5B3C, 0x00716C4D, 0x00785F33,
        0x00886E3F, 0x009B7E4B, 0x00A78853, 0x00A98A55, 0x00A28552, 0x00907745, 0x00816A3A, 0x00665D42, 0x00575035, 0x0048472B, 0x003E4127, 0x00373C21, 0x003B3C22, 0x0038341B, 0x005D583F, 0x0062554D, 0x00828078, 0x007B867C, 0x00707B71, 0x006A6F60,
        0x005A5D47, 0x00606B4B, 0x00768B64, 0x0074865D, 0x0074865D, 0x0074865D, 0x0074865D, 0x0074865D, 0x0073855C, 0x0073855C, 0x0073855C, 0x006A774B, 0x005E674D, 0x00B3B7B1, 0x00ADB2B1, 0x00797E75, 0x00737764, 0x005A5945, 0x0065614F, 0x00493F2E,
        0x00423C29, 0x00474330, 0x00494931, 0x00444629, 0x00524F30, 0x00645E3B, 0x00685F3A, 0x00765E28, 0x008C743E, 0x00A18654, 0x009D8355, 0x008C744A, 0x007D6B42, 0x00796C46, 0x00786F49, 0x0057573F, 0x0042452C, 0x00353B22, 0x00363F24, 0x003A4126,
        0x003F4326, 0x00636044, 0x005F583D, 0x005E5C5C, 0x00878983, 0x006F7465, 0x00535C42, 0x00616F4D, 0x006F7F56, 0x0072855A, 0x00718459, 0x0074875C, 0x00778960, 0x0074865D, 0x0076885F, 0x00788A63, 0x00778962, 0x00687954, 0x00445530, 0x0071737E,
        0x0084868E, 0x00878C8B, 0x00848882, 0x0072766B, 0x0056584C, 0x00656559, 0x0049493D, 0x003F3F2F, 0x00424230, 0x0041422E, 0x004C4C34, 0x00625E42, 0x00726747, 0x00766642, 0x007B6541, 0x0094744B, 0x009E7E55, 0x00A5855C, 0x00A1825B, 0x00967A57,
        0x00887256, 0x007D6B54, 0x00746552, 0x00605D48, 0x00534F3D, 0x00585547, 0x005A554C, 0x00534E45, 0x00757166, 0x00676154, 0x00777263, 0x0077797A, 0x006C7168, 0x00667059, 0x007F8D69, 0x00717F5B, 0xFF7A856B, 0xFFF8FEF3, 0xFFFDFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFF, 0xECF6FBEC, 0x006B7655, 0x0076845B, 0x00828D6C, 0x00666F55, 0x00717962, 0x00C2CBB1, 0x00A5A18F, 0x00635F4D, 0x0061604B, 0x0047482E, 0x004A4A2C,
        0x00575533, 0x00544E2B, 0x00584F2A, 0x009A774F, 0x00B79167, 0x00CFA37A, 0x00D5A57B, 0x00D7A479, 0x00D7A577, 0x00D4A474, 0x00D2A370, 0x00CAA377, 0x00AE8C61, 0x00957C54, 0x00756540, 0x005A5332, 0x004F4B2E, 0x00504F35, 0x0046442C, 0x00454926,
        0x005F6445, 0x00545640, 0x008A897B, 0x00B7B5AD, 0x00D5D2CE, 0x00FAF8F7, 0x00F7F5F4, 0x00919F76, 0x006C7A51, 0x0079875E, 0x007C8A60, 0x00717F55, 0x0078875B, 0x00728155, 0x006E7D51, 0x00738556, 0x007A8A5B, 0x0077865A, 0x00798660, 0x0051593B,
        0x00A9AD9A, 0x00C7C5BD, 0x00999692, 0x00605448, 0x00666152, 0x004C4D39, 0x00474E33, 0x00414728, 0x00454422, 0x0058502B, 0x0071643E, 0x00A47E54, 0x00BB9468, 0x00D0A574, 0x00D3A471, 0x00CE9E6A, 0x00D09F6D, 0x00D4A474, 0x00D4A579, 0x00BA9B68,
        0x00988052, 0x0073633F, 0x00625B42, 0x00595844, 0x00575945, 0x005C5E48, 0x0056563E, 0x00665F56, 0x005A564B, 0x00929187, 0x00BFBDBD, 0x00DFDCE5, 0x00F6F4FA, 0x00B0B4A8, 0x00565D42, 0x00728357, 0x00728357, 0x00738458, 0x00738458, 0x00748559,
        0x00748559, 0x0075865A, 0x0075865A, 0x00798D58, 0x007B8A5E, 0x00545F3F, 0x00606550, 0x00BEBEB0, 0x00E9E7DC, 0x00BDBAAB, 0x00555341, 0x0067654D, 0x004A4934, 0x003E402C, 0x00414730, 0x004A4A32, 0x005A5437, 0x00706140, 0x0086734E, 0x00B18B55,
        0x00BF995F, 0x00CFA56A, 0x00D3A76A, 0x00D4A86B, 0x00D3A96E, 0x00C7A069, 0x00BB9460, 0x00907A57, 0x00756541, 0x0058522F, 0x00414424, 0x003B4122, 0x0044472D, 0x00413F27, 0x006B674F, 0x005E5149, 0x008E8C84, 0x00AEB8B2, 0x009DA8A0, 0x00686C60,
        0x005A5D47, 0x0075815D, 0x0072895D, 0x0074865D, 0x0074865D, 0x0074865D, 0x0074865D, 0x0074865D, 0x0073855C, 0x0073855C, 0x0073855C, 0x006B774D, 0x005A6349, 0x00B7BBB5, 0x00D1D6D4, 0x00BAC0B5, 0x00949885, 0x0051503C, 0x006C6758, 0x0058513D,
        0x00524D38, 0x004B4A35, 0x00494A30, 0x00524E31, 0x00685C38, 0x00816E43, 0x0092784A, 0x00C7A367, 0x00CCA66C, 0x00CFA66F, 0x00CDA36E, 0x00CBA36F, 0x00C29F6D, 0x00AC8C5B, 0x00937846, 0x0075684E, 0x00615A3F, 0x004F5134, 0x00474E33, 0x004B5237,
        0x0053563C, 0x00726E56, 0x00635B44, 0x008F8D8C, 0x00CCCDC4, 0x009AA08F, 0x004F583D, 0x00586440, 0x0076865D, 0x007D8E63, 0x00718257, 0x0072855A, 0x0074865D, 0x0073855C, 0x0076885F, 0x00778962, 0x00788A63, 0x006A7B56, 0x00455631, 0x009696A4,
        0x00BEBDC7, 0x00ACADB1, 0x00989995, 0x008A8B82, 0x005D5C52, 0x0068665C, 0x0057554B, 0x004D4C38, 0x004F4E3A, 0x0057543F, 0x006B654E, 0x00766B4D, 0x0086734E, 0x00967D51, 0x00AA8C5D, 0x00C79C71, 0x00CEA175, 0x00D1A478, 0x00CDA074, 0x00C59A6F,
        0x00B8916B, 0x00A98665, 0x009C7C5F, 0x0067624D, 0x005A5643, 0x00545142, 0x005A5A4E, 0x005D5D51, 0x006F6B60, 0x005C5748, 0x00A09988, 0x00D2D5D3, 0x009BA295, 0x00657155, 0x00778660, 0x00707E5A, 0xFF7F8A70, 0xFFF8FEF3, 0xFFFAFCFC, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFEFC, 0xD9EEF4E1, 0x006A784F, 0x00768559, 0x0085926C, 0x0070795E, 0x00596248, 0x006C755A, 0x00696253, 0x005D5B49, 0x0062644E, 0x0041462B, 0x004F5133,
        0x004D4B28, 0x00544B26, 0x007D704A, 0x00C09867, 0x00D0A776, 0x00D9AB7B, 0x00D8A777, 0x00D5A474, 0x00D1A171, 0x00CEA070, 0x00CEA574, 0x00DDAC7A, 0x00CDA271, 0x00B59466, 0x008D774D, 0x006E613B, 0x00524B2A, 0x004C482B, 0x0049462A, 0x00504B36,
        0x0077725D, 0x0065634B, 0x00525038, 0x0041402B, 0x0061604C, 0x009F9C8D, 0x00BDBCAE, 0x007A885F, 0x006C7A51, 0x0075835A, 0x0077855B, 0x0076845A, 0x007F8E62, 0x007C8B5F, 0x007B8A5E, 0x00748455, 0x007D8D5E, 0x007B8A5E, 0x00737E56, 0x00717A59,
        0x00EAEED5, 0x00FBFCEC, 0x0089887E, 0x00696053, 0x00676253, 0x00444632, 0x00454A2F, 0x00424525, 0x004E4825, 0x00796641, 0x00A38863, 0x00CCA071, 0x00D0A272, 0x00D3A36F, 0x00D2A169, 0x00D3A26A, 0x00D4A76E, 0x00D0A46F, 0x00C8A06C, 0x00D8A96C,
        0x00C69E6A, 0x009A8058, 0x00726749, 0x00515139, 0x00464933, 0x004A5136, 0x00474C2F, 0x00716D5B, 0x005A5840, 0x00555139, 0x005E5748, 0x00A69D99, 0x00F2EFE7, 0x00C4C9B4, 0x00697453, 0x00718256, 0x00718256, 0x00728357, 0x00728357, 0x00738458,
        0x00738458, 0x00748559, 0x00748559, 0x00738752, 0x007B8A5E, 0x00626A4B, 0x00575C47, 0x00919183, 0x00919181, 0x00666550, 0x00505137, 0x0064654B, 0x004E503A, 0x004B503B, 0x0050523E, 0x005A563E, 0x00716144, 0x008E724F, 0x00AD8963, 0x00C49C68,
        0x00CBA26B, 0x00D1A46B, 0x00CFA167, 0x00CFA068, 0x00D1A36D, 0x00CFA473, 0x00CCA273, 0x00BC996D, 0x009D8256, 0x0071653B, 0x004C4B25, 0x00424727, 0x004C5134, 0x0043422D, 0x0066624F, 0x00665A50, 0x006C6A62, 0x007A847E, 0x0089938D, 0x00717569,
        0x0063674E, 0x0077855C, 0x00708957, 0x0074865D, 0x0074865D, 0x0074865D, 0x0073855C, 0x0073855C, 0x0073855C, 0x0073855C, 0x0073855C, 0x00717C54, 0x00555E44, 0x006A7065, 0x00788076, 0x007A8172, 0x006D725D, 0x00545240, 0x00686255, 0x004F4B32,
        0x0054553B, 0x004D4E34, 0x004C4B2F, 0x00675E3D, 0x00867047, 0x00AA8656, 0x00CFA36E, 0x00C39C68, 0x00C79F6B, 0x00CC9F6C, 0x00CE9F6C, 0x00D1A26F, 0x00D1A471, 0x00C8A06C, 0x00BF9864, 0x008E7456, 0x00786649, 0x005B5538, 0x0044482B, 0x00444A31,
        0x0052553F, 0x006D6956, 0x00544C3B, 0x00898A80, 0x00ADB0A1, 0x007A8069, 0x00555F41, 0x0076825E, 0x0077875E, 0x006B7B52, 0x0078885F, 0x00718459, 0x0073855C, 0x0074865D, 0x0076885F, 0x0073855E, 0x00758760, 0x0070815C, 0x0053643F, 0x00C0C0C0,
        0x00FFFFFB, 0x00C1C2B8, 0x00767767, 0x0070705E, 0x00575642, 0x006E6A58, 0x005F5B49, 0x0055533B, 0x0059573F, 0x0067614A, 0x007B7055, 0x007E6B4A, 0x009A7E55, 0x00BA9765, 0x00D1AB71, 0x00CBA174, 0x00CCA071, 0x00CC9F6C, 0x00CFA06C, 0x00D3A471,
        0x00CFA473, 0x00C2996C, 0x00B58D63, 0x00767158, 0x0068634E, 0x00585846, 0x00565949, 0x00545748, 0x00696959, 0x005B5443, 0x00A29B88, 0x00EBF1E6, 0x00B2BBA7, 0x006E7B5B, 0x0075855C, 0x00687751, 0xFF7E896F, 0xFFFDFFF8, 0xFFFDFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFB, 0xD1EDF5DE, 0x0069774D, 0x006D7D4D, 0x00818F66, 0x00889274, 0x006E775C, 0x005B6547, 0x00665F50, 0x0063614F, 0x00696C56, 0x004A4F34, 0x00484D2D,
        0x0043411E, 0x006C633D, 0x00A79871, 0x00D3AE74, 0x00D4AE74, 0x00D0A770, 0x00D1A570, 0x00D3A875, 0x00CFA675, 0x00C9A373, 0x00CAA978, 0x00D69D69, 0x00DBAB77, 0x00D1AC7A, 0x00A98F61, 0x0086764C, 0x005C532E, 0x00524D2C, 0x00595637, 0x00594D47,
        0x00766D60, 0x006B6450, 0x00494729, 0x003D3C1A, 0x005D5E3C, 0x00676749, 0x00605F43, 0x00627047, 0x0079875E, 0x007D8B62, 0x0077855B, 0x0078865C, 0x00768559, 0x00758458, 0x00768559, 0x0079885C, 0x00738256, 0x00727F53, 0x007C885E, 0x00737D59,
        0x00787D60, 0x008E907C, 0x00808171, 0x00645C4F, 0x00696657, 0x00494B37, 0x00454A2F, 0x004C4D2D, 0x006A5E3A, 0x00957B56, 0x00B18D67, 0x00CFA473, 0x00CFA36E, 0x00CFA269, 0x00CFA368, 0x00CEA567, 0x00C9A468, 0x00C6A469, 0x00C2A46B, 0x00DC9F5F,
        0x00DBAA72, 0x00B8966B, 0x00847555, 0x0057563C, 0x00444A31, 0x004A5436, 0x004A5332, 0x00707254, 0x00595935, 0x004E4B25, 0x00595133, 0x007C735F, 0x0085816E, 0x006C7253, 0x00697A4E, 0x00718256, 0x00718256, 0x00718256, 0x00728357, 0x00728357,
        0x00738458, 0x00738458, 0x00748559, 0x00728350, 0x00758359, 0x007F8768, 0x005D5F4B, 0x00595949, 0x0051523E, 0x00414228, 0x00515232, 0x00696C52, 0x004E5239, 0x00474C37, 0x004C4E3A, 0x00605841, 0x00836D51, 0x00A7835F, 0x00C79B72, 0x00C8A174,
        0x00CAA272, 0x00CDA271, 0x00CEA16E, 0x00CB9D6D, 0x00C89C6D, 0x00C69C72, 0x00C79E77, 0x00CDA36E, 0x00B89765, 0x00917F50, 0x0059572E, 0x003F4522, 0x00474C2F, 0x003F412B, 0x00666452, 0x00675B4F, 0x0085847A, 0x009FA9A3, 0x009DA7A1, 0x00707468,
        0x0062674C, 0x007C8A60, 0x006D8751, 0x0074865D, 0x0074865D, 0x0073855C, 0x0073855C, 0x0073855C, 0x0073855C, 0x0072845B, 0x0072845B, 0x007D8862, 0x005C654B, 0x00636A5D, 0x0099A295, 0x00939C87, 0x0060664D, 0x005D5C48, 0x00686257, 0x00515133,
        0x0046482B, 0x00505437, 0x00646244, 0x00756945, 0x009F8458, 0x00CCA06B, 0x00DAA468, 0x00C19E73, 0x00C29C72, 0x00C69B70, 0x00CB9C70, 0x00CE9D6F, 0x00CD9F6F, 0x00CBA06F, 0x00CCA16E, 0x00B29170, 0x00987F5F, 0x006C6141, 0x0045472A, 0x0042482F,
        0x00585A46, 0x00747162, 0x005B5245, 0x00737365, 0x00808471, 0x00686E55, 0x00636C4B, 0x0077845E, 0x00798660, 0x0075845E, 0x0071805A, 0x0072855A, 0x0075875E, 0x00778960, 0x00778960, 0x006E8059, 0x0070825B, 0x00748560, 0x0060714C, 0x009C9F90,
        0x00F9FBE8, 0x00B9BDA4, 0x00686C4F, 0x00747658, 0x005F5F41, 0x006D6B4D, 0x00575438, 0x00524F33, 0x005B573E, 0x006D664D, 0x0085775B, 0x00927957, 0x00BA996C, 0x00CDA66F, 0x00CB9F60, 0x00C29E6E, 0x00C7A270, 0x00CBA36E, 0x00CEA36A, 0x00CEA36A,
        0x00CDA46D, 0x00CAA26D, 0x00C59E6A, 0x00888166, 0x006C6850, 0x005F604C, 0x005A5E4B, 0x00505343, 0x00737361, 0x0057513E, 0x006F6652, 0x00787F70, 0x00788369, 0x006A7854, 0x00829367, 0x00697950, 0xFF778268, 0xFFF9FEF5, 0xFFFDFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFBFD, 0xD1EBEEDE, 0x0068734B, 0x00738353, 0x007D8B61, 0x007A8864, 0x00778561, 0x0076855F, 0x00716C53, 0x006A5F57, 0x00695F58, 0x004B5138, 0x00424F2F,
        0x0042452B, 0x008C7958, 0x00C6A573, 0x00D2A572, 0x00D4A774, 0x00D5A875, 0x00D4A774, 0x00D3A673, 0x00D2A572, 0x00D3A673, 0x00D4A774, 0x00C6A46F, 0x00CDA771, 0x00D1A974, 0x00C7A06C, 0x00997B4C, 0x00826F49, 0x00524E31, 0x0051553C, 0x00544E3B,
        0x00756C62, 0x00625E4B, 0x00545D32, 0x00566133, 0x005C6445, 0x00606A4C, 0x006A7A51, 0x00728056, 0x0078865C, 0x00758359, 0x00728155, 0x00768559, 0x00788859, 0x00768657, 0x00768657, 0x0073825C, 0x00788761, 0x0072815B, 0x00748259, 0x00748258,
        0x006F7B51, 0x00657246, 0x00576438, 0x005F534D, 0x00767260, 0x00575C41, 0x00464E30, 0x004E4D33, 0x00807255, 0x00A2895D, 0x00C3A56A, 0x00CFA26F, 0x00CEA16E, 0x00CEA16E, 0x00CEA16E, 0x00CDA06D, 0x00CEA16E, 0x00CEA16E, 0x00CFA26F, 0x00C3A56E,
        0x00C9A26E, 0x00D3A576, 0x00B18E63, 0x00705D3A, 0x00514E32, 0x0051533F, 0x0049493B, 0x006F665D, 0x00605D48, 0x00565D3C, 0x0056623E, 0x0052603E, 0x005B6945, 0x00738052, 0x0074864B, 0x006F8251, 0x00708352, 0x00718453, 0x00728554, 0x00738655,
        0x00738655, 0x00738655, 0x00738655, 0x00758256, 0x0077865A, 0x00708156, 0x006D7F56, 0x005E6D47, 0x005A6440, 0x00545835, 0x00565737, 0x00616657, 0x004D5342, 0x00464B36, 0x004C4B31, 0x00756B49, 0x00937A4E, 0x00C7A06C, 0x00CD9F65, 0x00CBA06D,
        0x00CBA06D, 0x00CCA16E, 0x00CCA16E, 0x00CCA16E, 0x00CCA16E, 0x00CBA06D, 0x00CBA06D, 0x00D7A36E, 0x00CBA06D, 0x00A98E62, 0x00716541, 0x004A4B2B, 0x00454C31, 0x003A4329, 0x005B644A, 0x005C5B41, 0x006A6F50, 0x0068754F, 0x00607447, 0x00697E51,
        0x0074865D, 0x00748260, 0x00737D5F, 0x0076885F, 0x0075875E, 0x0074865D, 0x0073855C, 0x0072845B, 0x00708259, 0x006F8158, 0x006F8158, 0x006E8059, 0x00768460, 0x005F6B47, 0x0069764A, 0x006A7644, 0x004B5227, 0x0056543C, 0x006D655E, 0x004D5232,
        0x00494E2E, 0x00504F2D, 0x007F6C4B, 0x009A754F, 0x00C79A6E, 0x00C8A46E, 0x00BEA567, 0x00C99E6B, 0x00CA9F6C, 0x00CBA06D, 0x00CBA06D, 0x00C99E6B, 0x00C99E6B, 0x00CA9F6C, 0x00CBA06D, 0x00C8A26B, 0x00A78C5A, 0x00776C46, 0x004D5036, 0x00414A36,
        0x004C5142, 0x006A6759, 0x005D5244, 0x00556040, 0x005B6646, 0x005F6A49, 0x00707E5A, 0x00798862, 0x006E8156, 0x006F8257, 0x0075895C, 0x006E8057, 0x0071835A, 0x0073855C, 0x0072845B, 0x0071835A, 0x00708259, 0x006F8158, 0x00708259, 0x00626F4F,
        0x007B8862, 0x00657343, 0x00525F2B, 0x005A6435, 0x00585939, 0x006D6558, 0x00625654, 0x00615F54, 0x005E5D48, 0x0076704D, 0x008C7646, 0x00C39B66, 0x00CC9E68, 0x00C7A06C, 0x00BBA06E, 0x00CBA06D, 0x00CCA16E, 0x00CCA16E, 0x00CBA06D, 0x00CA9F6C,
        0x00CA9F6C, 0x00CCA16E, 0x00CDA26F, 0x00B99069, 0x00917C5C, 0x00626450, 0x00475248, 0x004E554E, 0x00747267, 0x0059553D, 0x00666344, 0x00607348, 0x006B7D56, 0x00768762, 0x007C8C63, 0x006C7D52, 0xFF7B8666, 0xFFFFFFF9, 0xFFFDF9FF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFF, 0xCEE9ECDC, 0x0066714B, 0x00768656, 0x00808E64, 0x007C8A66, 0x00798763, 0x00778660, 0x00706D51, 0x00675E51, 0x00675E54, 0x004D5134, 0x004B5531,
        0x00555236, 0x00998360, 0x00CCA775, 0x00D3A673, 0x00D4A774, 0x00D4A774, 0x00D4A774, 0x00D3A673, 0x00D2A572, 0x00D3A673, 0x00D3A673, 0x00CBA470, 0x00CFA772, 0x00D5AB76, 0x00CFA773, 0x00A58457, 0x00887550, 0x005A5235, 0x0056563E, 0x00504B36,
        0x007B7366, 0x005F5C47, 0x00535D2F, 0x00616D3B, 0x00727D57, 0x00788460, 0x00728455, 0x00738157, 0x0079875D, 0x0078865C, 0x00768559, 0x0078875B, 0x00778758, 0x00758556, 0x00788859, 0x0078885F, 0x0078885F, 0x00738459, 0x00758359, 0x00707F53,
        0x006F7C50, 0x006F7C50, 0x00637042, 0x0061584E, 0x0073725E, 0x00505637, 0x00414728, 0x004D4A2E, 0x00887657, 0x00AE9164, 0x00D0AB71, 0x00D0A370, 0x00D0A370, 0x00CFA26F, 0x00CFA26F, 0x00CFA26F, 0x00CEA16E, 0x00CEA16E, 0x00CEA16E, 0x00C3A26A,
        0x00CEA46F, 0x00D4A676, 0x00B89268, 0x007D6B46, 0x00555134, 0x00494B35, 0x00474533, 0x00766D63, 0x0054523A, 0x00545D35, 0x00667549, 0x006D7D54, 0x00708057, 0x00717F4F, 0x006F8047, 0x006F8251, 0x00708352, 0x00718453, 0x00728554, 0x00738655,
        0x00738655, 0x00738655, 0x00738655, 0x00758254, 0x00758556, 0x00708155, 0x0072855A, 0x006E7E55, 0x00727D57, 0x00656946, 0x00575836, 0x00676858, 0x00555646, 0x004F503C, 0x00545037, 0x007C704E, 0x009A8155, 0x00CBA470, 0x00D0A169, 0x00CCA16E,
        0x00CBA06D, 0x00CBA06D, 0x00CBA06D, 0x00CBA06D, 0x00CBA06D, 0x00CBA06D, 0x00CCA16E, 0x00D5A16C, 0x00CCA16E, 0x00B79A6E, 0x0080724E, 0x00504C2F, 0x004B4E34, 0x00464C33, 0x00676D54, 0x005F5E42, 0x00626747, 0x0069774E, 0x006D8154, 0x006C8154,
        0x00697C51, 0x006E7D57, 0x00798463, 0x0075875E, 0x0075875E, 0x0074865D, 0x0073855C, 0x0072845B, 0x0071835A, 0x00708259, 0x006F8158, 0x00718459, 0x006F7E58, 0x0066734D, 0x0069764A, 0x0064713D, 0x004F5629, 0x00545339, 0x006E675E, 0x00545535,
        0x004A4D2D, 0x00524F30, 0x00867151, 0x00A67F59, 0x00CFA074, 0x00CBA36E, 0x00BB9F62, 0x00C99E6B, 0x00CA9F6C, 0x00CCA16E, 0x00CBA06D, 0x00CA9F6C, 0x00C99E6B, 0x00C99E6B, 0x00CA9F6C, 0x00D2A671, 0x00B49365, 0x0082724E, 0x0057563C, 0x004D5340,
        0x0054594A, 0x006D6A5B, 0x005B5244, 0x0064704C, 0x006E7A56, 0x0073805A, 0x0073825C, 0x0074845B, 0x0075885D, 0x00788B60, 0x0075885D, 0x0076885F, 0x0073855C, 0x0071835A, 0x0071835A, 0x0072845B, 0x0071835A, 0x0071835A, 0x0071835A, 0x006B7957,
        0x006E7C53, 0x00627040, 0x00525F2B, 0x004C5627, 0x00555634, 0x00766F5E, 0x00655B54, 0x00676358, 0x0064614C, 0x007E7553, 0x00967E50, 0x00CA9F6C, 0x00CF9F6B, 0x00C8A06C, 0x00C0A16E, 0x00CCA16E, 0x00CCA16E, 0x00CDA26F, 0x00CCA16E, 0x00CA9F6C,
        0x00CA9F6C, 0x00CBA06D, 0x00CCA16E, 0x00C59872, 0x009E8563, 0x00706D58, 0x00525B4E, 0x00545950, 0x00787567, 0x005F5B43, 0x006D6B4C, 0x0076885F, 0x00768762, 0x00768762, 0x007A8A61, 0x006B7C51, 0xFF7A8565, 0xFFFFFFF9, 0xFFFFFBFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFF, 0xCAE6E9D9, 0x0067724C, 0x007A8A5B, 0x007F8D63, 0x00788662, 0x00778563, 0x0073825C, 0x006C6E50, 0x00665F4E, 0x006B6352, 0x004F502E, 0x00485028,
        0x005B5335, 0x00A38764, 0x00D5AC7B, 0x00D4A774, 0x00D3A673, 0x00D3A673, 0x00D3A673, 0x00D3A673, 0x00D3A673, 0x00D2A572, 0x00D2A572, 0x00D1A570, 0x00D1A570, 0x00D6A976, 0x00D3A97A, 0x00AD8B60, 0x008D7754, 0x00605438, 0x005B573E, 0x004E4A31,
        0x00756E5F, 0x005B5941, 0x00586234, 0x00626F3B, 0x00616D43, 0x0068774B, 0x006F854B, 0x00717F55, 0x0076845A, 0x0077855B, 0x0077865A, 0x0079885C, 0x00768657, 0x00758556, 0x007A8A5B, 0x0077885C, 0x0075865A, 0x00748559, 0x00778758, 0x00708051,
        0x006F7C4E, 0x00717E50, 0x00657244, 0x00615A4B, 0x006E6E56, 0x00464D2C, 0x003B411E, 0x004E482B, 0x00907959, 0x00BB9769, 0x00D6AC71, 0x00D1A471, 0x00D1A471, 0x00D1A471, 0x00D0A370, 0x00CFA26F, 0x00CFA26F, 0x00CEA16E, 0x00CDA06D, 0x00C7A367,
        0x00CFA36D, 0x00D2A272, 0x00BB966A, 0x008C7954, 0x005D5837, 0x0047462A, 0x0048442B, 0x006E6659, 0x0058573B, 0x00616C3E, 0x00667843, 0x00647746, 0x006E7F53, 0x00717F4F, 0x006D7E45, 0x00708352, 0x00708352, 0x00718453, 0x00728554, 0x00738655,
        0x00738655, 0x00738655, 0x00728554, 0x00788656, 0x00758555, 0x00708253, 0x006D8154, 0x00697A4F, 0x00707B53, 0x00676C45, 0x00545632, 0x006A6758, 0x005B5947, 0x0054533F, 0x0058533A, 0x00817252, 0x00A58960, 0x00D0A776, 0x00D3A16C, 0x00CCA16E,
        0x00CBA06D, 0x00CA9F6C, 0x00CA9F6C, 0x00CA9F6C, 0x00CA9F6C, 0x00CBA06D, 0x00CCA16E, 0x00D8A26D, 0x00CEA070, 0x00C0A075, 0x008B7855, 0x004D472A, 0x004A492F, 0x004A4A32, 0x0065644F, 0x00646446, 0x00656A4A, 0x0068754F, 0x006A7D52, 0x006B8053,
        0x0073875A, 0x0076875C, 0x00728057, 0x0074865D, 0x0074865D, 0x0073855C, 0x0073855C, 0x0072845B, 0x0071835A, 0x0071835A, 0x0071835A, 0x00718556, 0x006B7B52, 0x00707E55, 0x006F7C50, 0x0065723E, 0x00565E2F, 0x00535335, 0x006D6859, 0x00595538,
        0x00514F31, 0x00595435, 0x008D7858, 0x00AF8764, 0x00D3A276, 0x00CCA26D, 0x00C2A065, 0x00C99E6B, 0x00CBA06D, 0x00CCA16E, 0x00CCA16E, 0x00CA9F6C, 0x00C99E6B, 0x00C89D6A, 0x00C99E6B, 0x00D9A472, 0x00C3996E, 0x008D7754, 0x005E5A42, 0x00595C4C,
        0x005E6152, 0x00706D5E, 0x005C5443, 0x00627046, 0x006C7A50, 0x00728056, 0x006F8055, 0x00718257, 0x006E8057, 0x006C7E55, 0x0074865D, 0x00788A61, 0x0071835A, 0x006F8158, 0x0073855C, 0x0073855C, 0x0071835A, 0x006F8158, 0x006E8057, 0x0075835F,
        0x00707E54, 0x006C7B48, 0x00596632, 0x00495324, 0x00545632, 0x0076715C, 0x006B6258, 0x0070675A, 0x0068614D, 0x00817656, 0x009D8458, 0x00CDA271, 0x00D19F6B, 0x00CB9E6B, 0x00C4A16F, 0x00CCA16E, 0x00CDA26F, 0x00CDA26F, 0x00CCA16E, 0x00CA9F6C,
        0x00CA9F6C, 0x00CBA06D, 0x00CCA16E, 0x00CD9A72, 0x00A18360, 0x00736C53, 0x00555848, 0x00535647, 0x0073715F, 0x005B5A40, 0x006A6D4D, 0x00788A63, 0x00738361, 0x00728260, 0x00798862, 0x006D7E53, 0xFF7B8666, 0xFFFFFFF8, 0xFFFFFBFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFDFF, 0xCEE7EADB, 0x0068734D, 0x00768657, 0x0079875E, 0x00798765, 0x007D8B69, 0x007B8965, 0x006B7251, 0x0065614E, 0x0069624E, 0x00484922, 0x0046481E,
        0x005D5232, 0x00A58764, 0x00D8AC7D, 0x00D5A875, 0x00D3A673, 0x00D2A572, 0x00D2A572, 0x00D3A673, 0x00D3A673, 0x00D2A572, 0x00D0A370, 0x00D4A56F, 0x00D1A26E, 0x00D3A575, 0x00D1A67B, 0x00AF8B65, 0x008C7353, 0x00625438, 0x005D563B, 0x00464426,
        0x00706A57, 0x005E5C44, 0x00525C2E, 0x00616E3A, 0x00727E54, 0x00708051, 0x00708749, 0x00707E54, 0x00738157, 0x00728056, 0x00748357, 0x0078875B, 0x00768657, 0x00758556, 0x007A8A5B, 0x00748756, 0x00758857, 0x00718453, 0x00768656, 0x00758556,
        0x00727F51, 0x00717E50, 0x00687547, 0x005C5845, 0x00686A4D, 0x003E4621, 0x003B3F1B, 0x0050482A, 0x00927959, 0x00BD9669, 0x00D5A66E, 0x00CFA26F, 0x00CFA26F, 0x00D0A370, 0x00D0A370, 0x00CFA26F, 0x00CFA26F, 0x00CEA16E, 0x00CDA06D, 0x00CCA567,
        0x00CFA068, 0x00D09F6F, 0x00BD976D, 0x008E7C57, 0x005E5A37, 0x004A4829, 0x004C4728, 0x0070695A, 0x00515133, 0x00535F2D, 0x00687B42, 0x006B7E4B, 0x006B7D4E, 0x00728050, 0x0074844E, 0x00708253, 0x00718354, 0x00728455, 0x00728455, 0x00738556,
        0x00738556, 0x00728455, 0x00728455, 0x00798757, 0x00718151, 0x006E8051, 0x006C8053, 0x0068794E, 0x006C784E, 0x00666B44, 0x00555831, 0x006D6655, 0x005A5644, 0x00544E3B, 0x00575037, 0x00837152, 0x00AF9069, 0x00D1A77A, 0x00D19E6C, 0x00CBA06D,
        0x00CBA06D, 0x00CBA06D, 0x00CBA06D, 0x00CBA06D, 0x00CBA06D, 0x00CBA06D, 0x00CBA06D, 0x00D8A16E, 0x00CC9E6E, 0x00C2A279, 0x008D7A59, 0x004C4427, 0x0049452D, 0x004B4833, 0x00625F4A, 0x00565638, 0x00666B4B, 0x00707C58, 0x006B7D54, 0x00667A4F,
        0x006C8053, 0x00738458, 0x00758458, 0x0073855C, 0x0073855C, 0x0073855C, 0x0072845B, 0x0072845B, 0x0072845B, 0x0072845B, 0x0072845B, 0x00718753, 0x00708156, 0x00717E58, 0x006D794F, 0x0064703E, 0x00545C2D, 0x00525333, 0x006D6957, 0x005D5538,
        0x00555134, 0x00615C3D, 0x00927D5E, 0x00B28A67, 0x00CF9D73, 0x00CFA06D, 0x00CAA46A, 0x00C99E6B, 0x00CBA06D, 0x00CCA16E, 0x00CCA16E, 0x00CA9F6C, 0x00C99E6B, 0x00C89D6A, 0x00C89D6A, 0x00D69E6F, 0x00C89C73, 0x00927959, 0x00635D46, 0x005D6050,
        0x005E6152, 0x006F6C5D, 0x005A5342, 0x00667647, 0x00748455, 0x0078875B, 0x00718257, 0x0075865B, 0x0071835A, 0x006B7D54, 0x00788A63, 0x0072845B, 0x006D7F56, 0x00708259, 0x0076885F, 0x0073855C, 0x006F8158, 0x006D7F56, 0x006B7D54, 0x0065744E,
        0x0068764C, 0x00687646, 0x0055612F, 0x004C5628, 0x00555733, 0x00716D54, 0x00756E5D, 0x00716357, 0x00675E4A, 0x007F7456, 0x009F865E, 0x00C99F72, 0x00D29D6B, 0x00CD9C6A, 0x00CAA26E, 0x00CDA26F, 0x00CDA26F, 0x00CDA26F, 0x00CCA16E, 0x00CA9F6C,
        0x00C99E6B, 0x00CA9F6C, 0x00CCA16E, 0x00D39F7A, 0x00A2825F, 0x0072674B, 0x00565743, 0x00545442, 0x0074705D, 0x005B5D40, 0x006A7150, 0x0071815F, 0x00718060, 0x00738262, 0x007A8963, 0x006D7E53, 0xFF7B8665, 0xFFFFFFF8, 0xFFFFFCFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFDFF, 0xD1EAEDDE, 0x0066704C, 0x00728155, 0x007B8960, 0x007F8D6B, 0x00808D6D, 0x00778561, 0x00656C4B, 0x00615E49, 0x00675F48, 0x0046441B, 0x00494B1D,
        0x005F5635, 0x009F8364, 0x00D0A97D, 0x00D6A976, 0x00D4A774, 0x00D3A673, 0x00D3A673, 0x00D3A673, 0x00D3A673, 0x00D2A572, 0x00D0A370, 0x00D4A36B, 0x00D1A16D, 0x00D1A576, 0x00CEA57E, 0x00AC8C69, 0x00866E50, 0x00615336, 0x005B5336, 0x004F4D2E,
        0x006A6451, 0x0064614C, 0x00555D35, 0x00576136, 0x00636D49, 0x00606D47, 0x00758A53, 0x00748258, 0x00758359, 0x00728056, 0x00738256, 0x0079885C, 0x00788859, 0x00758556, 0x00768657, 0x00768956, 0x00798C59, 0x006F8251, 0x00738354, 0x00778758,
        0x00717E52, 0x006A764C, 0x00657147, 0x005E5845, 0x00646648, 0x003B421D, 0x00393F1C, 0x0050482B, 0x008C7456, 0x00BD976D, 0x00D7A973, 0x00CDA06D, 0x00CEA16E, 0x00CEA16E, 0x00CEA16E, 0x00CEA16E, 0x00CEA16E, 0x00CEA16E, 0x00CEA16E, 0x00CCA365,
        0x00CFA06A, 0x00D3A478, 0x00BD9973, 0x00807150, 0x0053512F, 0x004A4826, 0x004E4825, 0x00665F50, 0x005E5E40, 0x00596436, 0x00657545, 0x0066774C, 0x00677650, 0x00768357, 0x006F7E4B, 0x00718354, 0x00728455, 0x00728455, 0x00738556, 0x00738556,
        0x00738556, 0x00728455, 0x00728455, 0x00778456, 0x006D7D4E, 0x006F8054, 0x00718459, 0x00708156, 0x0069744C, 0x00636743, 0x00585A36, 0x006E6756, 0x005A5441, 0x00504A37, 0x00544C35, 0x007F6F52, 0x00AE936E, 0x00D0A67B, 0x00CF9F6F, 0x00CA9F6C,
        0x00CBA06D, 0x00CBA06D, 0x00CCA16E, 0x00CCA16E, 0x00CBA06D, 0x00CBA06D, 0x00CA9F6C, 0x00D3A16D, 0x00CCA071, 0x00C2A47B, 0x008B7A59, 0x004F462B, 0x004F4B33, 0x0055503B, 0x006F6A55, 0x00605F43, 0x00626649, 0x00646E50, 0x006B7B59, 0x0071835E,
        0x006E8057, 0x006D7E52, 0x00768657, 0x0072845B, 0x0072845B, 0x0072845B, 0x0072845B, 0x0072845B, 0x0072845B, 0x0072845B, 0x0072845B, 0x006D834F, 0x0078895E, 0x006F7B57, 0x006C7751, 0x00677146, 0x00535A2F, 0x00555537, 0x006B6754, 0x005E5338,
        0x00575035, 0x00605C3F, 0x008F7D5E, 0x00B38E6C, 0x00CE9E74, 0x00CE9F6C, 0x00CAA16A, 0x00C99E6B, 0x00CBA06D, 0x00CCA16E, 0x00CCA16E, 0x00CA9F6C, 0x00C99E6B, 0x00C99E6B, 0x00C99E6B, 0x00D59E73, 0x00C99D78, 0x0091795D, 0x00655E4A, 0x005C5F4F,
        0x00585B4B, 0x006D6B59, 0x005A5340, 0x00647248, 0x006D7B51, 0x0077855C, 0x0074845B, 0x00718158, 0x0074865D, 0x0076885F, 0x0072845B, 0x0071835A, 0x006D7F56, 0x0073855C, 0x00778960, 0x0071835A, 0x006E8057, 0x006F8158, 0x006F8158, 0x0072805C,
        0x006D7B52, 0x0069764A, 0x00566133, 0x004F572E, 0x00585937, 0x00716D54, 0x006D6853, 0x006B5B4E, 0x00615844, 0x007C7155, 0x00A18965, 0x00CAA076, 0x00D1A070, 0x00CE9D6B, 0x00CAA06B, 0x00CCA16E, 0x00CDA26F, 0x00CDA26F, 0x00CCA16E, 0x00CA9F6C,
        0x00CA9F6C, 0x00CBA06D, 0x00CCA16E, 0x00D1A381, 0x009A7E5C, 0x00696144, 0x0053523D, 0x0053523E, 0x00746F5A, 0x00595A40, 0x00666B4E, 0x00738262, 0x00778569, 0x007A896A, 0x007B8965, 0x00697A4F, 0xFF788362, 0xFFFFFFF7, 0xFFFFFDFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFDFF, 0xD5E9EBDF, 0x00656F4B, 0x00758458, 0x00849269, 0x007B8868, 0x00657252, 0x00505E3A, 0x00505637, 0x00605A47, 0x00726751, 0x004D4B22, 0x00494C1E,
        0x00514E2F, 0x0088755A, 0x00C4A782, 0x00D6A976, 0x00D5A875, 0x00D4A774, 0x00D4A774, 0x00D4A774, 0x00D3A673, 0x00D2A572, 0x00D1A471, 0x00D2A46A, 0x00D2A671, 0x00D1A87B, 0x00C7A37D, 0x00A38768, 0x007A684B, 0x005D5234, 0x00574F31, 0x00575733,
        0x00696350, 0x005D5947, 0x00464A2D, 0x003E4326, 0x004D513E, 0x0049513A, 0x004F5F36, 0x00717F55, 0x0078865C, 0x0078865C, 0x00768559, 0x0079885C, 0x0079895A, 0x00758556, 0x00748455, 0x00748756, 0x00788B5A, 0x00738556, 0x00768559, 0x00717F55,
        0x005F6A42, 0x00515C36, 0x0047512D, 0x00635C49, 0x0067664A, 0x003A401D, 0x003A4120, 0x00454128, 0x0079684D, 0x00B0936C, 0x00D2AD7B, 0x00CFA26F, 0x00CFA26F, 0x00CEA16E, 0x00CDA06D, 0x00CDA06D, 0x00CEA16E, 0x00CEA16E, 0x00CFA26F, 0x00C99E65,
        0x00D2A370, 0x00D6A983, 0x00B29374, 0x006D6345, 0x00444727, 0x00454624, 0x004F4924, 0x0067604F, 0x005C5B41, 0x004A512E, 0x00475231, 0x00485339, 0x004F5A40, 0x006C7652, 0x007B885A, 0x00738458, 0x00738458, 0x00748559, 0x00748559, 0x00748559,
        0x00748559, 0x00738458, 0x00738458, 0x00778359, 0x00738157, 0x0073835A, 0x00667851, 0x00576541, 0x00434D29, 0x00474A2A, 0x00515133, 0x00706A57, 0x00595542, 0x004F4B38, 0x00524C35, 0x0074684C, 0x00A58D69, 0x00C5A277, 0x00CDA376, 0x00CBA06D,
        0x00CBA06D, 0x00CCA16E, 0x00CCA16E, 0x00CCA16E, 0x00CCA16E, 0x00CBA06D, 0x00CBA06D, 0x00CEA26D, 0x00CBA575, 0x00B99F77, 0x007F7050, 0x00494529, 0x004C4934, 0x00514D3A, 0x00746E5B, 0x0056533E, 0x0051533D, 0x004C543D, 0x00505D45, 0x00607051,
        0x0072835E, 0x0077885D, 0x00738354, 0x0072845B, 0x0072845B, 0x0072845B, 0x0072845B, 0x0072845B, 0x0072845B, 0x0072845B, 0x0072845B, 0x006E8352, 0x006F7E58, 0x00596345, 0x004E5637, 0x00474F2A, 0x00404420, 0x00555438, 0x006E6A58, 0x0060553A,
        0x00535034, 0x00575739, 0x00807557, 0x00AE906D, 0x00CDA178, 0x00CD9F6F, 0x00C49B64, 0x00C99E6B, 0x00CA9F6C, 0x00CBA06D, 0x00CA9F6C, 0x00C99E6B, 0x00C99E6B, 0x00CA9F6C, 0x00CBA06D, 0x00D0A279, 0x00BD9B77, 0x00837257, 0x005E5D49, 0x00565C4B,
        0x00545747, 0x006F6B59, 0x005B523E, 0x00505A3C, 0x004A5535, 0x005A6544, 0x0073815F, 0x0071805A, 0x006C7E57, 0x0076885F, 0x006D8055, 0x0076885F, 0x0072845B, 0x0076885F, 0x0076885F, 0x006F8158, 0x00708259, 0x0074865D, 0x00708259, 0x00677454,
        0x00525D3C, 0x004B5531, 0x00424A25, 0x003E4421, 0x00555537, 0x0078745B, 0x00615C47, 0x00645545, 0x005B5440, 0x00766F54, 0x009D8C6B, 0x00C5A179, 0x00D4A677, 0x00CFA06C, 0x00C69F68, 0x00CBA06D, 0x00CCA16E, 0x00CCA16E, 0x00CBA06D, 0x00CA9F6C,
        0x00CA9F6C, 0x00CCA16E, 0x00CDA26F, 0x00C29E80, 0x008A7559, 0x005F5C40, 0x0050523C, 0x00534F3C, 0x00716A59, 0x00575340, 0x0062654F, 0x006A785C, 0x00707D63, 0x00778569, 0x007D8B69, 0x006A7A51, 0xFF768160, 0xFFFCFFF4, 0xFFFEFCFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFBFF, 0xD5E9EBDF, 0x00646D4C, 0x0079875D, 0x0087946E, 0x006D7A5A, 0x004B5838, 0x003E4C2A, 0x004B5035, 0x00635C4D, 0x00776C56, 0x004D4B22, 0x0042491C,
        0x003A3E21, 0x00625A43, 0x00A59374, 0x00D6A976, 0x00D7AA77, 0x00D6A976, 0x00D5A875, 0x00D4A774, 0x00D2A572, 0x00D2A572, 0x00D2A572, 0x00D6AA6F, 0x00D5AB76, 0x00CBA67A, 0x00B59774, 0x008E795A, 0x006A5C3F, 0x00585032, 0x00575233, 0x004F4F2B,
        0x0076705D, 0x00615B50, 0x004F4F3D, 0x00666757, 0x009F9D9C, 0x009FA19B, 0x00666F5A, 0x00606E44, 0x00728056, 0x007B895F, 0x0077865A, 0x0077865A, 0x00788859, 0x00768657, 0x00768657, 0x00738556, 0x00728357, 0x0077885D, 0x0079875E, 0x00606C48,
        0x004C5534, 0x00474F30, 0x00394122, 0x00695C4E, 0x006A664E, 0x003C4122, 0x003B4325, 0x00373923, 0x005E533D, 0x0095815E, 0x00BBA173, 0x00D4A774, 0x00D3A673, 0x00D0A370, 0x00CEA16E, 0x00CDA06D, 0x00CDA06D, 0x00CEA16E, 0x00CFA26F, 0x00CCA26D,
        0x00D4A77B, 0x00C89D7C, 0x00967B61, 0x005C573E, 0x0042472A, 0x00474A2A, 0x00524E2B, 0x00726B5A, 0x004B4833, 0x0050533D, 0x007A7F70, 0x00979B95, 0x0080867B, 0x0062694E, 0x00768258, 0x00748559, 0x00748559, 0x0075865A, 0x0075865A, 0x0075865A,
        0x00748559, 0x00748559, 0x00738458, 0x0079845E, 0x00788460, 0x006D7B57, 0x0050603E, 0x00414E2E, 0x002F3719, 0x003B3C22, 0x004F4E34, 0x006D6956, 0x00575642, 0x004E503A, 0x004E4C34, 0x00645C3F, 0x00927E5B, 0x00B6986F, 0x00CBA67A, 0x00CEA370,
        0x00CDA26F, 0x00CCA16E, 0x00CBA06D, 0x00CBA06D, 0x00CCA16E, 0x00CDA26F, 0x00CEA370, 0x00CDA672, 0x00C6A577, 0x00A08C63, 0x00645B3A, 0x00444329, 0x004B4D37, 0x00474632, 0x00686753, 0x005E5A48, 0x007A7A6A, 0x00929788, 0x007C8675, 0x0057644E,
        0x00606F50, 0x007A8963, 0x007A895D, 0x0073855C, 0x0073855C, 0x0073855C, 0x0072845B, 0x0072845B, 0x0072845B, 0x0072845B, 0x0071835A, 0x00728657, 0x005A6846, 0x00485039, 0x00323821, 0x0024290C, 0x00343618, 0x0056543C, 0x00726C5F, 0x00645B40,
        0x00525135, 0x004C5033, 0x006B6647, 0x009E8662, 0x00C49E74, 0x00CCA372, 0x00C59F68, 0x00C99E6B, 0x00CA9F6C, 0x00CA9F6C, 0x00C99E6B, 0x00C89D6A, 0x00C99E6B, 0x00CCA16E, 0x00CEA370, 0x00C4A179, 0x00A68E6A, 0x006A6245, 0x004F543F, 0x004F5746,
        0x00535646, 0x00746E5B, 0x005F513E, 0x00696F5E, 0x00707663, 0x005B634C, 0x00667256, 0x00798765, 0x006E8059, 0x0073865B, 0x0074885B, 0x0076885F, 0x0072845B, 0x0075875E, 0x0075875E, 0x006F8158, 0x0073855C, 0x0072845B, 0x0064764D, 0x00404C30,
        0x00353E23, 0x00293113, 0x00272C0F, 0x002F3316, 0x004E4D33, 0x007A7560, 0x00635D4A, 0x005E5442, 0x0057523D, 0x006B6A50, 0x008E8363, 0x00B59873, 0x00CFA578, 0x00CDA36E, 0x00C6A167, 0x00CA9F6C, 0x00CBA06D, 0x00CBA06D, 0x00CBA06D, 0x00CBA06D,
        0x00CBA06D, 0x00CDA26F, 0x00CFA471, 0x00A89177, 0x00776E53, 0x00595D44, 0x00545944, 0x00575445, 0x00766D5F, 0x005E594A, 0x006B6C5C, 0x0069765C, 0x0066735B, 0x006E7B61, 0x007E8C6A, 0x006F7F56, 0xFF737E5D, 0xFFF7FBEF, 0xFFFEFDFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFDFF, 0xD9EBEDE1, 0x00636C4B, 0x0076845A, 0x00828F69, 0x00657252, 0x004F5B3D, 0x00586644, 0x005D5F49, 0x00696053, 0x006F614E, 0x003F3F17, 0x003E481D,
        0x0031381D, 0x0044432E, 0x007C7457, 0x00D6A976, 0x00D7AA77, 0x00D8AB78, 0x00D6A976, 0x00D4A774, 0x00D2A572, 0x00D2A572, 0x00D3A673, 0x00D9B072, 0x00D6AE79, 0x00C3A275, 0x00A28864, 0x0079674A, 0x005A4F33, 0x00555031, 0x00585634, 0x00575831,
        0x00756E5D, 0x00665E57, 0x007B796E, 0x00827F7A, 0x008C8790, 0x009A989E, 0x00767C71, 0x004B592F, 0x0068764C, 0x0079875D, 0x00768559, 0x00738256, 0x00758556, 0x00778758, 0x0079895A, 0x00798A5E, 0x006E7F54, 0x0076865D, 0x0077845E, 0x00515C3B,
        0x00485032, 0x00596045, 0x0050573C, 0x006A5A4E, 0x006B6450, 0x003E4225, 0x003C452A, 0x002E331E, 0x0047422D, 0x007C6D4D, 0x00A18E63, 0x00D9AC79, 0x00D7AA77, 0x00D3A673, 0x00CFA26F, 0x00CDA06D, 0x00CDA06D, 0x00CEA16E, 0x00CFA26F, 0x00D2AA76,
        0x00D5AA7F, 0x00B28A6D, 0x0079614B, 0x0053503B, 0x00475036, 0x004A5031, 0x00565431, 0x006F6859, 0x00615D4B, 0x00727264, 0x00727371, 0x00909096, 0x00989B99, 0x005F644F, 0x0057623A, 0x0075865A, 0x0075865A, 0x0075865A, 0x0076875B, 0x0075865A,
        0x0075865A, 0x00748559, 0x00748559, 0x007A8362, 0x00737E5D, 0x005F6C4C, 0x00465536, 0x00505C40, 0x004C5239, 0x00505038, 0x00595641, 0x00676651, 0x00545640, 0x004E513B, 0x00484B32, 0x00565033, 0x00806F4E, 0x00A78D65, 0x00C8A67B, 0x00D1A673,
        0x00CFA471, 0x00CBA06D, 0x00C99E6B, 0x00C99E6B, 0x00CBA06D, 0x00CFA471, 0x00D1A673, 0x00CEA975, 0x00BDA172, 0x008A784F, 0x00514A29, 0x0047482E, 0x00565943, 0x00474834, 0x00636450, 0x00575144, 0x00807E73, 0x00BDC1B6, 0x00B0B8AD, 0x0064705E,
        0x00505D43, 0x00707E5A, 0x0078865C, 0x0074865D, 0x0073855C, 0x0073855C, 0x0073855C, 0x0072845B, 0x0072845B, 0x0071835A, 0x0071835A, 0x006A7E51, 0x00505D3D, 0x00626855, 0x00585C49, 0x0042462D, 0x00535538, 0x005F5B48, 0x006B655A, 0x00665F46,
        0x0054553B, 0x00464E30, 0x005A5839, 0x008B7754, 0x00B8966B, 0x00CDA574, 0x00D1AB75, 0x00C99E6B, 0x00C99E6B, 0x00C99E6B, 0x00C89D6A, 0x00C89D6A, 0x00C99E6B, 0x00CDA26F, 0x00CFA471, 0x00B59C72, 0x008F7F5B, 0x00535034, 0x00424934, 0x00495343,
        0x00535646, 0x0079725F, 0x0061523F, 0x00A2A59C, 0x00D0D4C9, 0x00808675, 0x004A543D, 0x00707D5D, 0x00778962, 0x00718558, 0x00738758, 0x0071835A, 0x006E8057, 0x0073855C, 0x0074865D, 0x0071835A, 0x0075875E, 0x006C7E55, 0x0053653C, 0x0068725B,
        0x006F785E, 0x00535940, 0x0040442B, 0x00464930, 0x00514E39, 0x00726C59, 0x00635D4A, 0x00615745, 0x0052513C, 0x00616248, 0x007E7658, 0x00A58B67, 0x00C7A074, 0x00CCA46F, 0x00C6A469, 0x00C99E6B, 0x00CA9F6C, 0x00CBA06D, 0x00CBA06D, 0x00CBA06D,
        0x00CCA16E, 0x00CEA370, 0x00CFA471, 0x008B7B64, 0x00615D45, 0x004D553E, 0x00505643, 0x00545142, 0x00736A5D, 0x0060574D, 0x00706E63, 0x007D8A72, 0x006C7862, 0x006B7860, 0x007E8C6A, 0x00708057, 0xFF707B5A, 0xFFF6FBEC, 0xFFFFFEFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFBFF, 0xD5EBEEDF, 0x00636E46, 0x00778653, 0x007C8A60, 0x00636C51, 0x0067705C, 0x00CCD3C4, 0x00AA9CA0, 0x00695F58, 0x00625D48, 0x004F4E2C, 0x0044451E,
        0x00474526, 0x00645F4A, 0x00635B4E, 0x007F7147, 0x00AB956B, 0x00D3B388, 0x00DEB588, 0x00E1B082, 0x00E5B683, 0x00E4B581, 0x00DAAE79, 0x00C7A784, 0x00BB9C7B, 0x009A8161, 0x00745F40, 0x005C4E32, 0x005B5035, 0x005A543D, 0x0058543C, 0x004F4E32,
        0x00747359, 0x005E5D49, 0x0089897B, 0x009D9D97, 0x00818181, 0x00919197, 0x0073757D, 0x0056663D, 0x0068784F, 0x0077875E, 0x0077885D, 0x0074855A, 0x0075865A, 0x0077885C, 0x0075865A, 0x00788B5A, 0x00748657, 0x007B8C61, 0x00737E5D, 0x00454D36,
        0x0084857B, 0x00C5C3C3, 0x00979399, 0x00625B4C, 0x0067614E, 0x003D3B1D, 0x0045461F, 0x00404218, 0x003D3F15, 0x00464720, 0x00696945, 0x00AA8E5F, 0x00C9A779, 0x00D9AF82, 0x00DAA77C, 0x00E0A97E, 0x00E1AC81, 0x00DCAB7F, 0x00D9AA7E, 0x00C2A487,
        0x00A58B6D, 0x00796347, 0x00615336, 0x005D5538, 0x004F4C30, 0x003F4228, 0x003B4025, 0x006A6352, 0x00605C49, 0x00909181, 0x00898B85, 0x00919394, 0x00949696, 0x00686B5B, 0x00586140, 0x0077885C, 0x0076875B, 0x0075865B, 0x0074855A, 0x0074855A,
        0x0074845B, 0x0075855C, 0x0076865D, 0x00718558, 0x007A8864, 0x0059604B, 0x00787B72, 0x0093928E, 0x009A9792, 0x00A3A196, 0x00545444, 0x0063684B, 0x00474B2E, 0x004D4F32, 0x00555236, 0x005A5338, 0x00554A2F, 0x0073644A, 0x00A08F75, 0x00C7A675,
        0x00D5AF7F, 0x00D4A879, 0x00D4A375, 0x00D2A173, 0x00D0A475, 0x00D5AF7F, 0x00CCAB7A, 0x00A79C7C, 0x007F7655, 0x005F5739, 0x00464324, 0x004A482A, 0x00434528, 0x003C3F25, 0x00666B50, 0x005D5849, 0x007E7C71, 0x00858781, 0x00919792, 0x00727B71,
        0x004D5943, 0x006B7955, 0x0079885C, 0x0074875C, 0x0074875C, 0x0074875C, 0x0074875C, 0x0074875C, 0x0074875C, 0x0074875C, 0x0074875C, 0x006C7959, 0x004D5342, 0x00888987, 0x00918E90, 0x00989590, 0x00959388, 0x00544F46, 0x006F6964, 0x0058573B,
        0x005A573B, 0x00585136, 0x00584C30, 0x0069563B, 0x008C7458, 0x00AE9176, 0x00BFA186, 0x00D7AE77, 0x00D8A975, 0x00D2A16F, 0x00CC9B6B, 0x00CFA074, 0x00D1AA7E, 0x00C5A57C, 0x00B79E74, 0x007E796A, 0x00565240, 0x00535139, 0x00504F33, 0x00504F35,
        0x00605D48, 0x00726C5F, 0x00564F46, 0x006C6B6F, 0x00787977, 0x007F8377, 0x00515B44, 0x00637050, 0x0072845D, 0x0076885F, 0x0075875E, 0x0074865F, 0x0072845D, 0x0073855E, 0x006F815A, 0x006D7F58, 0x00768861, 0x006B7D56, 0x004A5C35, 0x008A8D8B,
        0x009D9E9C, 0x007C7A79, 0x008D8A86, 0x008E8C82, 0x00494435, 0x00817B68, 0x006D6951, 0x00655941, 0x00695E48, 0x00635A46, 0x00635947, 0x007F6F58, 0x00A58D6F, 0x00C1A17D, 0x00CFAC81, 0x00D6A771, 0x00D6A672, 0x00D5A172, 0x00D29F74, 0x00D4A67D,
        0x00CEA983, 0x00B89D78, 0x009E8B66, 0x00636051, 0x005E5D49, 0x0053543A, 0x005B5D3F, 0x005C5E40, 0x00707157, 0x0051503C, 0x00787566, 0x00929992, 0x00636C5F, 0x00626F55, 0x0078895E, 0x006F824F, 0xFF727F59, 0xFFFEFFF8, 0xFFFBF5FF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFDFF, 0xD5EBEEDF, 0x00616C44, 0x00748454, 0x00808E64, 0x00697559, 0x0057604C, 0x00909985, 0x00888277, 0x00625E4C, 0x00605F43, 0x003E401C, 0x00373A13,
        0x003E401C, 0x004D4D2F, 0x004B4A30, 0x003F3E22, 0x00635D40, 0x008E7E61, 0x00A99173, 0x00B79A7B, 0x00BEA07D, 0x00BDA07B, 0x00B69B76, 0x00A39065, 0x0088774C, 0x006D5D33, 0x0060532D, 0x005B522D, 0x00534D2A, 0x00494423, 0x00423F20, 0x0049472F,
        0x00706D58, 0x00595844, 0x00727264, 0x0083847A, 0x00737470, 0x00878A88, 0x00737877, 0x005C6C43, 0x006A7A51, 0x0076865D, 0x0075865B, 0x00728358, 0x00738458, 0x00748559, 0x00728357, 0x00738458, 0x0078895D, 0x00798A5F, 0x006F7C56, 0x004D5739,
        0x007C806D, 0x00ADAEA5, 0x008F8D8C, 0x00696154, 0x006A6451, 0x003A371B, 0x003F3E1C, 0x0043441D, 0x003E3F18, 0x00343410, 0x0042411F, 0x006C5E34, 0x0088764D, 0x00AE946C, 0x00BE9D76, 0x00BB9771, 0x00BD9973, 0x00BB9C75, 0x00B1946D, 0x008E7C57,
        0x0073633E, 0x005E502C, 0x004A411F, 0x003B3615, 0x00383919, 0x00383B1B, 0x0034391A, 0x0070685B, 0x00595543, 0x00797B68, 0x008B8F84, 0x00B1B4B2, 0x00B1B5AF, 0x00747A63, 0x00535E36, 0x00738458, 0x00738458, 0x00728357, 0x00728358, 0x00738459,
        0x0074845B, 0x0075855C, 0x0075855C, 0x00738758, 0x0072815B, 0x00646D53, 0x00BDC2B3, 0x00F9FAF1, 0x00B7B6AC, 0x007B7B6B, 0x00565743, 0x00656B4C, 0x003B4021, 0x003C3F1F, 0x003F3D1E, 0x00423D1C, 0x004C4321, 0x00605732, 0x00665A36, 0x009B8256,
        0x00B4976B, 0x00C4A176, 0x00CDA77D, 0x00CDA77D, 0x00C7A479, 0x00BB9E72, 0x00A58C60, 0x006E6740, 0x005C5730, 0x0048451F, 0x00363411, 0x003B3A18, 0x00393C1C, 0x003A3F1F, 0x005E6344, 0x0065614F, 0x00787769, 0x0075786F, 0x00838A83, 0x006F796C,
        0x00505D45, 0x006B7955, 0x0079885C, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x005D6B49, 0x00636A55, 0x00DDDFD9, 0x00FBFAF6, 0x00B9B9AD, 0x00838371, 0x00555244, 0x006B655E, 0x00555432,
        0x004C4B29, 0x004E4928, 0x005B5230, 0x00625634, 0x006C5B3A, 0x00867350, 0x00A38F6C, 0x00BA9968, 0x00C39F6F, 0x00CDA679, 0x00CDA57B, 0x00C7A37B, 0x00BD9D79, 0x00A78F6B, 0x00917F5A, 0x00504E36, 0x00535236, 0x004F5030, 0x004A4B29, 0x00434422,
        0x004B4B2D, 0x006F6D55, 0x00595542, 0x00646464, 0x006F706C, 0x00797E6F, 0x00545F45, 0x00667452, 0x0073855E, 0x00778960, 0x00778960, 0x0074865F, 0x0071835C, 0x0073855E, 0x0071835C, 0x006F815A, 0x00768861, 0x006C7E57, 0x0051633C, 0x0070746F,
        0x00B9BAB6, 0x00DFDFD9, 0x009C9A92, 0x00757368, 0x00625D4E, 0x00716C57, 0x005A563E, 0x0059502E, 0x00595133, 0x00564F34, 0x005D553E, 0x0070634D, 0x00837258, 0x00998165, 0x00AE9172, 0x00C0A273, 0x00C5A477, 0x00C8A67B, 0x00C5A47D, 0x00B89C79,
        0x00A08B6B, 0x00807555, 0x00686344, 0x005A5749, 0x005E5C4A, 0x0055553D, 0x00525339, 0x0054553B, 0x006F6F57, 0x005B5947, 0x00959284, 0x00C5CDC2, 0x007F8979, 0x0068755B, 0x007A8B60, 0x00708350, 0xFF6D7A54, 0xFFFDFFF7, 0xFFFFFAFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFDFF, 0xD1EAEDDE, 0x00606D47, 0x00728252, 0x007F8D64, 0x00748062, 0x00525C45, 0x005F6952, 0x00636149, 0x00616046, 0x00747357, 0x00505131, 0x004F502E,
        0x00565834, 0x00494B27, 0x003F411D, 0x00454B34, 0x00464930, 0x00504B32, 0x0062573C, 0x00716347, 0x0077674A, 0x00756646, 0x00726343, 0x005C5827, 0x00534F1F, 0x004F4B1B, 0x00535023, 0x0057532A, 0x00504E26, 0x004A4820, 0x0048451F, 0x0054503D,
        0x00777360, 0x005F5D4B, 0x00616252, 0x00727565, 0x00737869, 0x00868D7E, 0x007F887B, 0x0066764D, 0x00708057, 0x0076865D, 0x0074855A, 0x00728358, 0x00738458, 0x00748559, 0x00728357, 0x0077885D, 0x0076875C, 0x00728358, 0x0078865C, 0x005E6A46,
        0x00565E40, 0x00626851, 0x005C604D, 0x00686053, 0x00746D5C, 0x004E4934, 0x004D4A2E, 0x004D4B2C, 0x00444223, 0x00373516, 0x00464426, 0x003C401C, 0x004B4B27, 0x00615D3A, 0x00766C4A, 0x00817553, 0x00817553, 0x00766C4A, 0x00685F3D, 0x00565229,
        0x004D4920, 0x004C4A22, 0x0042411B, 0x0043431F, 0x004B4C2A, 0x00454926, 0x00474A2A, 0x00776E65, 0x00595445, 0x00616350, 0x006E7364, 0x00878C83, 0x00848B7C, 0x00697152, 0x00647242, 0x00728455, 0x00728357, 0x00728357, 0x00738458, 0x00738459,
        0x0075865B, 0x0076865D, 0x0076865D, 0x00728756, 0x007A8B60, 0x00606B4B, 0x00818972, 0x00B2B6A3, 0x00878976, 0x00575943, 0x00585B41, 0x006A6D53, 0x00494D30, 0x004D4D2F, 0x00494826, 0x0043401A, 0x00433F16, 0x00534D22, 0x00544E21, 0x00655635,
        0x00756443, 0x00826D4D, 0x008E7757, 0x00957E5E, 0x008E7959, 0x007A6948, 0x005F502F, 0x004D4920, 0x0047451C, 0x003C3A12, 0x00393812, 0x003F411D, 0x003C401D, 0x00474B28, 0x00656A4A, 0x005E5A47, 0x00676755, 0x00636859, 0x00798275, 0x00768270,
        0x005E6C50, 0x00707F59, 0x0079885C, 0x0072855A, 0x0072855A, 0x0072855A, 0x0072855A, 0x0072855A, 0x0072855A, 0x0072855A, 0x0072855A, 0x00728259, 0x00626B50, 0x00ADB2A3, 0x00BEC1B2, 0x00757763, 0x004F5238, 0x00555440, 0x00716E60, 0x00464422,
        0x0043411E, 0x00474320, 0x00514D2A, 0x005B5530, 0x005C5631, 0x00615A33, 0x00655E37, 0x008C7751, 0x00957E58, 0x00A08864, 0x00A28967, 0x00927D5D, 0x00807151, 0x006A5F41, 0x004F472A, 0x00454626, 0x005E5F3D, 0x00484B24, 0x003E411A, 0x00393C15,
        0x00434422, 0x00737355, 0x005E5D41, 0x005F615B, 0x00696D62, 0x00757B68, 0x005C684A, 0x006D7B57, 0x0074865F, 0x0075875E, 0x0076885F, 0x0075875E, 0x0071835A, 0x0073855C, 0x0074865D, 0x0071835A, 0x0075875E, 0x006F8158, 0x005D6F46, 0x008A9085,
        0x00FAFEF3, 0x00DCDED2, 0x00666757, 0x00525240, 0x0055513E, 0x006B6651, 0x0058533E, 0x00484219, 0x0047411C, 0x00494627, 0x00575239, 0x00605A43, 0x00615640, 0x00685A44, 0x007B6B54, 0x00847A58, 0x00857957, 0x0087795C, 0x00887C60, 0x007F755D,
        0x0066644C, 0x004C4F39, 0x003A412C, 0x004F4C3E, 0x00575445, 0x0053523E, 0x00474631, 0x004B4A35, 0x00696854, 0x00545142, 0x00939082, 0x009AA494, 0x00677160, 0x00637155, 0x007E8F64, 0x00788B5A, 0xFF717E58, 0xFFF6FAEF, 0xFFF9F5FF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDF9FE, 0xCEE5EADB, 0x00626F49, 0x00738256, 0x00788761, 0x007A8668, 0x00616F53, 0x005E6D4E, 0x0058573B, 0x005B5A40, 0x00787560, 0x005C5845, 0x005E5B46,
        0x00646349, 0x004A4B2B, 0x0041431F, 0x004E4E30, 0x00413F20, 0x00353213, 0x003A3312, 0x00443B19, 0x004B411F, 0x00514521, 0x00534723, 0x00434A1F, 0x00444A21, 0x0043471E, 0x0042451E, 0x0050502C, 0x00605E3B, 0x005E5C3A, 0x00544F2E, 0x005F5A4B,
        0x00716D5B, 0x00565442, 0x004C4E3A, 0x005E644D, 0x00677056, 0x00717D61, 0x00717F63, 0x006F7F56, 0x0074845B, 0x0076865D, 0x0074855A, 0x00738459, 0x0076875B, 0x0076875B, 0x00748559, 0x0075845E, 0x00728259, 0x00718257, 0x00819064, 0x00758458,
        0x0058633B, 0x004D5733, 0x004C5534, 0x00696455, 0x00757061, 0x005A5643, 0x00605D48, 0x0066654B, 0x0055543A, 0x003D3C22, 0x00444327, 0x004B5237, 0x0051563B, 0x00474A30, 0x00494A30, 0x005C5B41, 0x0057563C, 0x004B4A30, 0x00535238, 0x00505431,
        0x004F5330, 0x00454828, 0x00353719, 0x00525135, 0x0066654B, 0x0058573D, 0x0068664E, 0x00786F66, 0x005A5546, 0x00595C46, 0x00646C55, 0x00656E5A, 0x00616B54, 0x006D7850, 0x0080905A, 0x00748657, 0x00748657, 0x00748559, 0x0075865A, 0x0075865A,
        0x0076875C, 0x0077885D, 0x0077885D, 0x00718753, 0x00849667, 0x0078855F, 0x005B6646, 0x005E654A, 0x0064694E, 0x00585D3E, 0x00545939, 0x006C6B5D, 0x00555243, 0x00514D3A, 0x00565239, 0x005C593A, 0x0047441E, 0x0047431A, 0x00545125, 0x005F5C40,
        0x005C583C, 0x00565236, 0x00575035, 0x00575035, 0x00545034, 0x00534F33, 0x004E4B2F, 0x004D4B29, 0x00464422, 0x003C391A, 0x00525032, 0x00616044, 0x00515238, 0x0054553B, 0x0067674F, 0x0064624A, 0x006C6E58, 0x00676E59, 0x0079856F, 0x007D8C71,
        0x006F7E5E, 0x0076855F, 0x0077865A, 0x0072855A, 0x0072855A, 0x0072855A, 0x0072855A, 0x0072855A, 0x0072855A, 0x0072855A, 0x0072855A, 0x0075865A, 0x00636E4D, 0x0069715A, 0x0070765F, 0x005E6445, 0x004E5431, 0x0056573D, 0x00696755, 0x004F482D,
        0x00534C31, 0x00534F33, 0x00565236, 0x005A583A, 0x005C5C3E, 0x00565737, 0x004C4F2F, 0x00585033, 0x0060583B, 0x00696144, 0x006A6348, 0x005D583F, 0x0057533A, 0x0055553D, 0x00484B32, 0x00444426, 0x005F6040, 0x00505131, 0x004F5030, 0x004F4F31,
        0x0059583C, 0x0079785C, 0x005B5A40, 0x00767B6C, 0x007B816E, 0x00858E74, 0x0072805E, 0x00788761, 0x0073855C, 0x006E8057, 0x006E8057, 0x0075875E, 0x00708259, 0x0073855C, 0x0076885F, 0x0074865D, 0x0074865D, 0x0071835A, 0x00697B52, 0x00737B6A,
        0x00CBD1BE, 0x00898F78, 0x0054583F, 0x00676A51, 0x0058563E, 0x006E6954, 0x00534E39, 0x00615A39, 0x005C5738, 0x00575336, 0x00575438, 0x0058573D, 0x00535238, 0x00535238, 0x005D5C42, 0x00605E46, 0x005E5B46, 0x005D5946, 0x005B5947, 0x005B5B4B,
        0x00595C4D, 0x00555C4F, 0x00525B4E, 0x004C493B, 0x00524F40, 0x005B5849, 0x00545240, 0x00595745, 0x00737061, 0x00545142, 0x00807D6F, 0x008E9A84, 0x0076836B, 0x00758465, 0x00798960, 0x006C7E4F, 0xFF717D59, 0xFFFFFFF8, 0xFFFFFBFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCFBFD, 0xCAE3E8D9, 0x00626E4A, 0x00738459, 0x0073825C, 0x007A8969, 0x00738262, 0x0070815C, 0x0064654B, 0x00575642, 0x00757264, 0x006B655E, 0x006A655C,
        0x00696658, 0x004A4934, 0x00414326, 0x0036381B, 0x0037391C, 0x0037391C, 0x0036381A, 0x0037391B, 0x003B3B1D, 0x003F3D1F, 0x00403C1F, 0x004B5237, 0x0052593E, 0x004C5136, 0x003C3F25, 0x00424127, 0x0059553D, 0x0066624A, 0x00645E47, 0x006D6957,
        0x006C6855, 0x0052513C, 0x004A4F34, 0x005F6748, 0x00677251, 0x0065744E, 0x00667851, 0x00708057, 0x0073835A, 0x0073835A, 0x00728358, 0x00738459, 0x0075865A, 0x0076875B, 0x0075865A, 0x006F7D59, 0x0076865D, 0x0075865A, 0x00758556, 0x00768656,
        0x00768355, 0x006F7B51, 0x005E6941, 0x00605C49, 0x006F6B59, 0x006B6755, 0x00777360, 0x0074705D, 0x00535139, 0x00343319, 0x003B3A20, 0x00524F3A, 0x00565540, 0x0051503B, 0x0052513C, 0x005A5944, 0x0053503B, 0x004C4934, 0x005C5742, 0x005C5F49,
        0x00585B45, 0x00494A36, 0x00353622, 0x00504E3C, 0x00696455, 0x005C5649, 0x006B6558, 0x007A7167, 0x00524F3A, 0x004B5132, 0x00646F4F, 0x00667256, 0x00687555, 0x00758256, 0x0076884D, 0x00748657, 0x00758758, 0x00758758, 0x0075865A, 0x0075865A,
        0x0075865A, 0x0074855A, 0x0074855A, 0x00738857, 0x006D7F50, 0x007A885E, 0x0073805A, 0x0067714D, 0x00686F4C, 0x005B613E, 0x004F5532, 0x006F6865, 0x00655F5A, 0x00696259, 0x006D6657, 0x0066614C, 0x00413C23, 0x003E3A1D, 0x00524D2C, 0x00605F4A,
        0x00595B45, 0x00585A44, 0x00545741, 0x004A4D37, 0x00444630, 0x004B4D37, 0x005F5E49, 0x00615C47, 0x00514C37, 0x003B3724, 0x00534F3C, 0x006D6957, 0x00676253, 0x00646153, 0x00676456, 0x00525135, 0x005F6346, 0x005D6749, 0x00637253, 0x006C7D5C,
        0x006D7E59, 0x0074845B, 0x00768559, 0x0072855A, 0x0072855A, 0x0072855A, 0x0072855A, 0x0072855A, 0x0072855A, 0x0072855A, 0x0072855A, 0x00748657, 0x0076825E, 0x00616B4D, 0x005D6546, 0x005E673F, 0x004D552C, 0x00545638, 0x0072715D, 0x006A5F51,
        0x006A5F51, 0x00685F51, 0x00645D4C, 0x005A5644, 0x0054533F, 0x00585945, 0x00626450, 0x00535139, 0x00504E36, 0x00494931, 0x004C4F39, 0x004C4F39, 0x004A5039, 0x004D503A, 0x003D402A, 0x0045432B, 0x0053503B, 0x005B5744, 0x0064604E, 0x00605C4A,
        0x00676351, 0x006F6B59, 0x0054503E, 0x0059614A, 0x0060694E, 0x006E7959, 0x006B7A54, 0x0076875C, 0x0075885D, 0x0076885F, 0x00798B64, 0x0076885F, 0x0071835A, 0x0073855C, 0x00778960, 0x0075875E, 0x0073855C, 0x0073855C, 0x0071835A, 0x00677258,
        0x00677055, 0x005C6544, 0x00505734, 0x004D5232, 0x00555438, 0x006E6A52, 0x006F6956, 0x00675F4E, 0x0068614E, 0x005E5841, 0x00535034, 0x00545436, 0x00575A3A, 0x00515835, 0x004C5632, 0x0057503F, 0x00514C3D, 0x00494637, 0x00474638, 0x00555348,
        0x00656358, 0x0069675D, 0x00646258, 0x0052503E, 0x00545240, 0x006B6859, 0x006D6A5B, 0x00696657, 0x007B7869, 0x00585644, 0x006E6C5A, 0x006F7E5F, 0x00707E62, 0x007A8969, 0x00798960, 0x00697B4C, 0xFF717D59, 0xFFFDFFF5, 0xFFFCF9FF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFF, 0xC6DFE6D7, 0x005C6A48, 0x0076865D, 0x0071825D, 0x00788767, 0x00758762, 0x0072865B, 0x006A6B51, 0x004E4D38, 0x00656253, 0x0069645B, 0x00676259,
        0x00625F51, 0x00484733, 0x00404028, 0x00474D3C, 0x00454F3E, 0x00445240, 0x00465645, 0x004F6150, 0x005B6B5A, 0x005D6858, 0x00576151, 0x00414532, 0x004E503D, 0x00535542, 0x004A4A38, 0x0044432F, 0x004C4B37, 0x00625E4B, 0x00716D5A, 0x0067654D,
        0x00605E46, 0x00545639, 0x00595F40, 0x006E7854, 0x00748259, 0x006F8055, 0x006F8356, 0x006E7E55, 0x006E7E55, 0x006F7F56, 0x00708156, 0x00718257, 0x00738458, 0x00748559, 0x00748559, 0x00768460, 0x0077875E, 0x0077885C, 0x00718152, 0x00748454,
        0x007B885A, 0x007B885C, 0x0069744C, 0x00605F45, 0x006E6C54, 0x00777360, 0x00827E6C, 0x00777360, 0x00595641, 0x0049482E, 0x0059583C, 0x006C614B, 0x00625A43, 0x00716D55, 0x00918F77, 0x00A0A088, 0x009D9B83, 0x0088826B, 0x006E664F, 0x00696A56,
        0x005E5F4B, 0x00575745, 0x004C493A, 0x00535042, 0x006D695E, 0x00777368, 0x00807970, 0x00726C59, 0x0058583A, 0x00586139, 0x00728057, 0x0072805C, 0x00778561, 0x007E8B5D, 0x00788950, 0x00738655, 0x00738655, 0x00748657, 0x00748657, 0x00748559,
        0x00738458, 0x00728357, 0x00728358, 0x00798D60, 0x00718256, 0x0078865C, 0x0078865C, 0x00768159, 0x0079815C, 0x006B724D, 0x00595F3C, 0x006A615D, 0x006F6760, 0x00827B72, 0x007D776A, 0x00655E4D, 0x0049442F, 0x0058543B, 0x005D5940, 0x006C6954,
        0x00656751, 0x0072755F, 0x007B836C, 0x007A826B, 0x0071745E, 0x00676953, 0x00706D58, 0x0063624E, 0x005B5A46, 0x00474533, 0x00524F40, 0x006F695C, 0x00787267, 0x00767065, 0x00696259, 0x005A5B3B, 0x006D7350, 0x006F7B57, 0x006A7C55, 0x006F8359,
        0x0072845B, 0x00738459, 0x00748258, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x0073865B, 0x0076875B, 0x007D8A64, 0x0075805F, 0x007A855F, 0x00778156, 0x005A6338, 0x0056583A, 0x006D6B59, 0x00786C62,
        0x007A7164, 0x00776E61, 0x006A6255, 0x00605B4C, 0x00625D4E, 0x00646250, 0x00656351, 0x0065624D, 0x006F6E59, 0x006A6D57, 0x00696F58, 0x0060694F, 0x005A6047, 0x00676A51, 0x00696951, 0x00595641, 0x00565240, 0x00635D50, 0x00756F64, 0x00756E65,
        0x007C766B, 0x00706A5D, 0x005B5647, 0x006C7757, 0x00717C5B, 0x0078855F, 0x0075865B, 0x0077885C, 0x0072855A, 0x0072845B, 0x0072845D, 0x0076895E, 0x0073865B, 0x0074875C, 0x00778A5F, 0x0076895E, 0x0073865B, 0x0073865B, 0x0074875C, 0x007C8969,
        0x006E7A56, 0x00778359, 0x00677146, 0x004B532A, 0x00565737, 0x0068644C, 0x007F7867, 0x007F786F, 0x007D7568, 0x0068614D, 0x00545034, 0x00595735, 0x00656743, 0x00656D48, 0x00616C46, 0x00776D5C, 0x00857E6D, 0x008B8775, 0x007B7967, 0x006C695A,
        0x006D6657, 0x0073685A, 0x00776A5C, 0x0056563E, 0x00585742, 0x00706E5C, 0x00767364, 0x00696657, 0x00747260, 0x00605F4A, 0x0073735B, 0x007A8B66, 0x00768664, 0x00798967, 0x00798960, 0x006C7D51, 0xFF707C58, 0xFFFAFEF2, 0xFFFFFDFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFFFF, 0xC2DDE4D5, 0x005A6846, 0x00758760, 0x0072835E, 0x00748564, 0x0073865F, 0x006E8454, 0x006C724F, 0x004B5030, 0x004A4E31, 0x00474A30, 0x00464930,
        0x004A4D33, 0x00404427, 0x00404526, 0x00353523, 0x00282E1D, 0x001C2816, 0x001B2B19, 0x00273928, 0x00304231, 0x00303D2F, 0x002A3326, 0x002D2C17, 0x002D2C17, 0x0032311C, 0x003B3B23, 0x0042422A, 0x0045462C, 0x0048492F, 0x00494C32, 0x004A4A2C,
        0x004D4E2E, 0x00525633, 0x005F6742, 0x006C774F, 0x006F7D53, 0x006D7E52, 0x006C8051, 0x006D7D54, 0x006E7E55, 0x00708057, 0x00728358, 0x00738459, 0x00738458, 0x00748559, 0x0075865A, 0x00798862, 0x0075855C, 0x007A8B5F, 0x007A8A5B, 0x007F8F60,
        0x007B875D, 0x007C875F, 0x0079835F, 0x00646747, 0x00585A3D, 0x0053533B, 0x005B5A46, 0x00605F4B, 0x005A5A42, 0x00535538, 0x00575A3A, 0x0054492E, 0x003E371C, 0x004A492D, 0x006C7053, 0x007E8366, 0x00818366, 0x006A674B, 0x00423B20, 0x00423F23,
        0x004A472B, 0x005C583F, 0x00626048, 0x00615F47, 0x0064634E, 0x0062614D, 0x00585945, 0x00514E32, 0x005B5E37, 0x00697543, 0x00798959, 0x00728259, 0x0074835D, 0x00768357, 0x007B8B56, 0x00748756, 0x00758857, 0x00768958, 0x00768859, 0x00768859,
        0x0076875B, 0x0075865A, 0x0075865A, 0x006A7C53, 0x00798A5F, 0x0079875D, 0x00717F55, 0x00737F55, 0x007C855D, 0x00747B56, 0x00555B38, 0x005B5843, 0x005B5843, 0x00615F47, 0x00616046, 0x00616046, 0x005D5C40, 0x00676749, 0x0059593B, 0x00494229,
        0x00545037, 0x0075785E, 0x0092977C, 0x009A9F84, 0x0084876D, 0x005D5940, 0x00494229, 0x004F5336, 0x00585C3F, 0x00595A40, 0x005F5F47, 0x006C6C54, 0x0073705B, 0x00696552, 0x005B5744, 0x005D5F3B, 0x00707850, 0x0076845A, 0x00708457, 0x0074895C,
        0x00768A5D, 0x00738458, 0x0079875D, 0x0074875C, 0x0074875C, 0x0074875C, 0x0074875C, 0x0074875C, 0x0074875C, 0x0074875C, 0x0074875C, 0x0074855A, 0x00717D59, 0x00737E5D, 0x007A855D, 0x007C8759, 0x006C754A, 0x00585A3C, 0x00585546, 0x006A6550,
        0x00726D58, 0x00716A56, 0x0067614A, 0x0067614A, 0x006E6950, 0x00666148, 0x00555037, 0x00635B44, 0x00959179, 0x00A9AC92, 0x00A9AE93, 0x00868B70, 0x00585C3F, 0x00585539, 0x0060593E, 0x006E6E50, 0x006D6C52, 0x006F6B58, 0x007B7667, 0x00787265,
        0x00746F60, 0x005F5C47, 0x00535139, 0x00707D57, 0x0075835A, 0x0078875B, 0x00768859, 0x00758758, 0x00728659, 0x0074865D, 0x0074865F, 0x0075885D, 0x0075885D, 0x0075885D, 0x0076895E, 0x0076895E, 0x0074875C, 0x0073865B, 0x0073865B, 0x0074835D,
        0x00839167, 0x00788656, 0x006C7945, 0x00576132, 0x00535531, 0x0058543C, 0x00635C4D, 0x00616252, 0x00676652, 0x0068634A, 0x00696143, 0x006A6244, 0x005F5B3E, 0x004E4D31, 0x0043462D, 0x00767259, 0x00949379, 0x00A4A78D, 0x008C9176, 0x00606349,
        0x004E4A31, 0x005E543C, 0x00756750, 0x00686A4C, 0x0067694C, 0x006E6D58, 0x006C6A58, 0x005C5A48, 0x005E5D48, 0x00595B3E, 0x00747658, 0x00798C61, 0x00748560, 0x00778863, 0x007B8B62, 0x00738458, 0xFF717D59, 0xFFF6FBEC, 0xFFFCFBFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFF9FBFB, 0xBEDBE2D3, 0x005A6747, 0x00758760, 0x0071815F, 0x00728361, 0x0073875D, 0x006F8554, 0x00818B5D, 0x00677045, 0x00596237, 0x004E562D, 0x004C542B,
        0x00515931, 0x004A522A, 0x004B522D, 0x00564B2D, 0x00544C2E, 0x004F4F31, 0x004A5233, 0x00485234, 0x00454C31, 0x0043462C, 0x00444329, 0x00464327, 0x00484529, 0x004A4A2C, 0x004E4E30, 0x004D5030, 0x004B512E, 0x004B512E, 0x004B522F, 0x00494A28,
        0x00555733, 0x00656945, 0x00717A52, 0x00717D53, 0x006E7D51, 0x00708155, 0x006C8051, 0x00708057, 0x00728259, 0x0074845B, 0x0076875C, 0x0077885D, 0x0076875B, 0x0076875B, 0x0077885C, 0x0071805A, 0x00798960, 0x00809165, 0x00758458, 0x007B8A5E,
        0x007C875F, 0x007F8965, 0x007E8667, 0x007B7F5B, 0x00696C4C, 0x00606147, 0x005E5D48, 0x005E5D49, 0x00606048, 0x00616345, 0x00606441, 0x006C6446, 0x00636041, 0x005E6343, 0x005A6544, 0x00545F3E, 0x00535C3B, 0x005B5E3E, 0x00605E3F, 0x00615C35,
        0x0069633E, 0x0063603A, 0x005C5C38, 0x005D5E3C, 0x00595C3C, 0x00575C3D, 0x005A5F40, 0x00676546, 0x00797D53, 0x007B8953, 0x007A8C57, 0x0077885D, 0x007C8B65, 0x00768258, 0x00818F5F, 0x00778A59, 0x00788B5A, 0x00798C5B, 0x007A8C5D, 0x007B8D5E,
        0x007B8D5E, 0x007B8C60, 0x007A8B5F, 0x007C8E67, 0x007B8A64, 0x00738157, 0x007B895F, 0x007C885E, 0x007C855D, 0x00838966, 0x00707555, 0x00545632, 0x005A5C38, 0x004F512D, 0x00484A26, 0x00555733, 0x004C4E2A, 0x004F512D, 0x00484C28, 0x00584D31,
        0x00524C2F, 0x00525234, 0x00474C2D, 0x00454A2B, 0x004F4F31, 0x00524C2F, 0x005C5135, 0x00465026, 0x004F572F, 0x00535B33, 0x00535733, 0x00525633, 0x00515232, 0x00515133, 0x00575537, 0x0070734C, 0x007C845B, 0x007D8C60, 0x00728657, 0x00758B5A,
        0x00768A5B, 0x0075865A, 0x00839167, 0x0075885D, 0x0075885D, 0x0075885D, 0x0075885D, 0x0075885D, 0x0075885D, 0x0075885D, 0x0075885D, 0x0073835A, 0x00788460, 0x007D8867, 0x0077825A, 0x007D8959, 0x007D865B, 0x00626447, 0x00585547, 0x00504E2F,
        0x004D4B2C, 0x004F4E2C, 0x00575533, 0x00585332, 0x00514B28, 0x004B4522, 0x004D4422, 0x004B3F27, 0x005A533A, 0x0049482C, 0x00484C2F, 0x004B5031, 0x00424021, 0x00494123, 0x004E4325, 0x00464922, 0x00565735, 0x004F4E32, 0x0053503B, 0x004E4B36,
        0x004D4B33, 0x00545436, 0x00676846, 0x0078865D, 0x007C8B5F, 0x007C8C5D, 0x00798C5B, 0x00758857, 0x0073875A, 0x00778960, 0x00758760, 0x0075885D, 0x0076895E, 0x0075885D, 0x0075885D, 0x0075885D, 0x0074875C, 0x0072855A, 0x0072855A, 0x0076875C,
        0x00778758, 0x007F8F5A, 0x007E8C56, 0x0065703E, 0x00666942, 0x005A563E, 0x00514A3B, 0x004A5037, 0x004A4E31, 0x004F4C2D, 0x005B5231, 0x005E5436, 0x00524830, 0x00494130, 0x004E483D, 0x00494B2D, 0x00454A2B, 0x00404829, 0x003F4A2A, 0x00424B2A,
        0x00464929, 0x004D4829, 0x00524729, 0x004B4F2C, 0x004C4E30, 0x004A4A32, 0x004D4C38, 0x004D4C38, 0x0056563E, 0x00606244, 0x00878B68, 0x00798D60, 0x00798B64, 0x007C8D68, 0x007A8A61, 0x00728358, 0xFF747F5E, 0xFFF9FEEF, 0xFFFFFEFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFF, 0xBEDBDFD3, 0x00596444, 0x0077875E, 0x00788662, 0x00778765, 0x0071835C, 0x0073875A, 0x00718459, 0x00708358, 0x00708358, 0x006F8257, 0x006D8055,
        0x006B7E53, 0x006A7D52, 0x00697C51, 0x006B7C50, 0x006C7D51, 0x006D7E52, 0x006E7F53, 0x006E7F53, 0x006E7F53, 0x006E7F53, 0x006D7E52, 0x00697A4E, 0x0068794D, 0x0068794D, 0x0067784C, 0x0066774B, 0x0066774B, 0x0065764A, 0x0065764A, 0x0066764D,
        0x0066764D, 0x0066764D, 0x0067774E, 0x006A7A51, 0x006D7D54, 0x00708057, 0x00728259, 0x00728259, 0x00728259, 0x0073835A, 0x0073835A, 0x0074845B, 0x0074845B, 0x0075855C, 0x0075855C, 0x0077875E, 0x0078885F, 0x0078885F, 0x0078885F, 0x0078885F,
        0x00798960, 0x00798960, 0x00798960, 0x007B8B62, 0x007C8C63, 0x007C8C63, 0x007D8D64, 0x007E8E65, 0x007E8E65, 0x007F8F66, 0x007F8F66, 0x00829066, 0x00819064, 0x007F8E62, 0x007D8C60, 0x007B8B5C, 0x0079895A, 0x00778757, 0x00768656, 0x0083936A,
        0x00829269, 0x007F8F66, 0x007D8D64, 0x007B8B62, 0x007B8B62, 0x007C8C63, 0x007D8D64, 0x0076865D, 0x0076865D, 0x0076865D, 0x0076865D, 0x0076865D, 0x0076865D, 0x0076865D, 0x0076865D, 0x0076865D, 0x0077875E, 0x0077875E, 0x0077875E, 0x0078885F,
        0x0078885F, 0x0078885F, 0x00798960, 0x007A8B5F, 0x00798A5E, 0x0077885C, 0x0076875B, 0x0076875B, 0x0077885C, 0x00798A5E, 0x007A8B5F, 0x00778563, 0x00788664, 0x00788664, 0x00798765, 0x007A8866, 0x007A8866, 0x007B8967, 0x007B8967, 0x007C8B65,
        0x00798862, 0x0075845E, 0x0072815B, 0x0071805A, 0x0072815B, 0x0075845E, 0x00778660, 0x007B8965, 0x007B8965, 0x007A8864, 0x007A8864, 0x007A8864, 0x007A8864, 0x007A8864, 0x007A8864, 0x007C8B65, 0x007A8963, 0x00788761, 0x00778660, 0x00778660,
        0x00788761, 0x007A8963, 0x007C8B65, 0x00758760, 0x00758760, 0x00758760, 0x00758760, 0x00758760, 0x00758760, 0x00758760, 0x00758760, 0x00798F5F, 0x00788E5E, 0x00768C5C, 0x00768C5C, 0x00778D5D, 0x00758B5B, 0x00728858, 0x006F8555, 0x00707D5D,
        0x00717E5E, 0x00738060, 0x00738060, 0x00738060, 0x00717E5E, 0x006F7C5C, 0x006E7B5B, 0x00718047, 0x006D7B45, 0x006A7743, 0x006D7949, 0x00737E50, 0x00788258, 0x00778058, 0x00747D55, 0x00737B5C, 0x00707859, 0x006D7556, 0x006C7455, 0x006E7657,
        0x00737B5C, 0x00798162, 0x007D8566, 0x00778A59, 0x00778A59, 0x00768958, 0x00768958, 0x00768958, 0x00768958, 0x00758857, 0x00758857, 0x00778A59, 0x00778A59, 0x00778A59, 0x00778A59, 0x00778A59, 0x00778A59, 0x00778A59, 0x00778A59, 0x00778660,
        0x00788761, 0x007A8963, 0x007A8963, 0x00788761, 0x0074835D, 0x006F7E58, 0x006B7A54, 0x006C7554, 0x006D7655, 0x006F7857, 0x00717A59, 0x00717A59, 0x00717A59, 0x006F7857, 0x006F7857, 0x00656F41, 0x00677045, 0x006A7249, 0x006D754D, 0x006F7552,
        0x00707555, 0x00707457, 0x00707457, 0x006C785A, 0x00697557, 0x00667254, 0x00677355, 0x006C785A, 0x00737F61, 0x00798567, 0x007C886A, 0x0078895E, 0x007E8C68, 0x00768462, 0x007B8A64, 0x00748559, 0xFF73825C, 0xFFF3FCE7, 0xFFFDFFFC, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFAFE, 0xBEDEE3D4, 0x005D6945, 0x00768859, 0x0074855A, 0x006F805B, 0x006D7F58, 0x00718459, 0x0072845D, 0x0072845D, 0x0072845D, 0x0072845D, 0x0072845D,
        0x0071835C, 0x0070825B, 0x0070825B, 0x00728259, 0x00718158, 0x00718158, 0x00708057, 0x006F7F56, 0x006E7E55, 0x006E7E55, 0x006D7D54, 0x006E7E55, 0x006D7D54, 0x006D7D54, 0x006C7C53, 0x006B7B52, 0x006B7B52, 0x006A7A51, 0x006A7A51, 0x006C7D52,
        0x006B7C51, 0x006B7C51, 0x006B7C51, 0x006C7D52, 0x006E7F54, 0x00708156, 0x00718257, 0x00718257, 0x00718257, 0x00728358, 0x00738459, 0x00738459, 0x0074855A, 0x0075865B, 0x0075865B, 0x0078895E, 0x0078895E, 0x0078895E, 0x00798A5F, 0x00798A5F,
        0x00798A5F, 0x00798A5F, 0x00798A5F, 0x007C8D62, 0x007C8D62, 0x007C8D62, 0x007C8D62, 0x007D8E63, 0x007D8E63, 0x007D8E63, 0x007D8E63, 0x007F8E62, 0x007F8E62, 0x007F8F60, 0x007F8F60, 0x007F8F5F, 0x007F8F5F, 0x007F8F5F, 0x007E8F5C, 0x007B8C61,
        0x007B8C61, 0x007D8E63, 0x007E8F64, 0x007F9065, 0x007E8F64, 0x007E8F64, 0x007D8E63, 0x007C8D62, 0x007C8D62, 0x007C8D62, 0x007C8D62, 0x007C8D62, 0x007C8D62, 0x007C8D62, 0x007C8D62, 0x0077885D, 0x0078895E, 0x0078895E, 0x0078895E, 0x0078895E,
        0x0078895E, 0x0078895E, 0x0078895E, 0x007C8B65, 0x007B8A64, 0x007A8963, 0x00798862, 0x00798862, 0x007A8963, 0x007B8A64, 0x007C8B65, 0x007C8B65, 0x007C8B65, 0x007D8C66, 0x007D8C66, 0x007E8D67, 0x007F8E68, 0x007F8E68, 0x007F8E68, 0x0084946B,
        0x0083936A, 0x00819168, 0x007F8F66, 0x007E8E65, 0x007F8F66, 0x00809067, 0x00819168, 0x007F8F66, 0x007F8F66, 0x007F8F66, 0x007E8E65, 0x007E8E65, 0x007E8E65, 0x007D8D64, 0x007D8D64, 0x007C8C63, 0x007B8B62, 0x007A8A61, 0x0078885F, 0x0078885F,
        0x0078885F, 0x0078885F, 0x00798960, 0x00788A61, 0x00788A61, 0x00788A61, 0x00798B62, 0x00798B62, 0x007A8C63, 0x007A8C63, 0x007A8C63, 0x00778B61, 0x00768A60, 0x0075895F, 0x00768A60, 0x00788C62, 0x00798D63, 0x00798D63, 0x00788C62, 0x0082916B,
        0x0082916B, 0x0083926C, 0x0083926C, 0x0082916B, 0x0081906A, 0x007F8E68, 0x007E8D67, 0x00818F5F, 0x007E8C5C, 0x007C895B, 0x007E8A60, 0x00838E66, 0x0086906C, 0x00858E6D, 0x00848D6C, 0x00828F69, 0x00828F69, 0x00818E68, 0x00808D67, 0x007F8C66,
        0x007D8A64, 0x007C8963, 0x007B8862, 0x0078885F, 0x0077875E, 0x0077875E, 0x0077875E, 0x0077875E, 0x0076865D, 0x0076865D, 0x0076865D, 0x0077875E, 0x0077875E, 0x0077875E, 0x0077875E, 0x0077875E, 0x0077875E, 0x0077875E, 0x0077875E, 0x0075855C,
        0x0077875E, 0x00798960, 0x007C8C63, 0x007D8D64, 0x007E8E65, 0x007D8D64, 0x007D8D64, 0x007F8C66, 0x00808D67, 0x00828F69, 0x0083906A, 0x0083906A, 0x00828F69, 0x00818E68, 0x00808D67, 0x007F8B5B, 0x00808B5D, 0x00828C61, 0x00858F65, 0x00868F67,
        0x00878E6B, 0x00868D6C, 0x00868D6C, 0x00818F6B, 0x007F8D69, 0x007D8B67, 0x007B8965, 0x007B8965, 0x007C8A66, 0x007E8C68, 0x007E8C68, 0x007C8C63, 0x00818F6D, 0x00798567, 0x007E8C6A, 0x0072815B, 0xFF727F5F, 0xFFF4FBEE, 0xFFFAFBFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFCFE, 0xC6E2E8D7, 0x00616F45, 0x00758954, 0x00798C5B, 0x0073855C, 0x0074865F, 0x0076885F, 0x0070815C, 0x0070815C, 0x0071825D, 0x0071825D, 0x0070815C,
        0x0070815C, 0x006F805B, 0x006F805B, 0x0071805A, 0x006F7E58, 0x006D7C56, 0x006B7A54, 0x006A7953, 0x006A7953, 0x006A7953, 0x006A7953, 0x006C7B55, 0x006C7B55, 0x006C7B55, 0x006C7B55, 0x006C7B55, 0x006C7B55, 0x006C7B55, 0x006C7B55, 0x006E7F53,
        0x006D7E52, 0x006C7D51, 0x006C7D51, 0x006C7D51, 0x006D7E52, 0x006E7F53, 0x006F8054, 0x00708155, 0x00708155, 0x00718256, 0x00728357, 0x00738458, 0x00748559, 0x0075865A, 0x0075865A, 0x0075865A, 0x0075865A, 0x0076875B, 0x0076875B, 0x0076875B,
        0x0076875B, 0x0077885C, 0x0077885C, 0x00798A5E, 0x00798A5E, 0x00798A5E, 0x00798A5E, 0x0078895D, 0x0078895D, 0x0078895D, 0x0078895D, 0x007A8A5B, 0x007B8B5C, 0x007B8B5C, 0x007C8C5C, 0x007D8D5D, 0x007E8F5C, 0x007E8F5C, 0x007E8F5C, 0x0078895D,
        0x00798A5E, 0x007A8B5F, 0x007B8C60, 0x007A8B5F, 0x00798A5E, 0x0077885C, 0x0076875B, 0x0077885C, 0x0077885C, 0x0077885C, 0x0077885C, 0x0077885C, 0x0077885C, 0x0077885C, 0x0077885C, 0x00798A5E, 0x00798A5E, 0x00798A5E, 0x00798A5E, 0x00798A5E,
        0x0078895D, 0x0078895D, 0x0078895D, 0x00798765, 0x00798765, 0x00788664, 0x00778563, 0x00778563, 0x00788664, 0x00798765, 0x00798765, 0x007C8C63, 0x007C8C63, 0x007C8C63, 0x007D8D64, 0x007D8D64, 0x007E8E65, 0x007E8E65, 0x007E8E65, 0x007B8C60,
        0x007B8C60, 0x007B8C60, 0x007B8C60, 0x007B8C60, 0x007B8C60, 0x007A8B5F, 0x007A8B5F, 0x007D8E63, 0x007D8E63, 0x007E8F64, 0x007E8F64, 0x007E8F64, 0x007D8E63, 0x007C8D62, 0x007B8C61, 0x00798A5E, 0x00798A5E, 0x00798A5E, 0x0078895D, 0x0078895D,
        0x0078895D, 0x0078895D, 0x0078895D, 0x0074885B, 0x0075895C, 0x0075895C, 0x00768A5D, 0x00778B5E, 0x00788C5F, 0x00788C5F, 0x00798D60, 0x00758563, 0x00748462, 0x00738361, 0x00748462, 0x00768664, 0x00788866, 0x007A8A68, 0x007A8A68, 0x007E8F63,
        0x007E8F63, 0x007D8E62, 0x007D8E62, 0x007C8D61, 0x007C8D61, 0x007B8C60, 0x007B8C60, 0x007A8B60, 0x00798A5F, 0x0078885F, 0x00798862, 0x007B8965, 0x007D8B69, 0x007D8A6A, 0x007C886A, 0x00778B5E, 0x00788C5F, 0x007B8F62, 0x007C9063, 0x007C9063,
        0x007A8E61, 0x00778B5E, 0x00768A5D, 0x00798763, 0x00798763, 0x00798763, 0x00798763, 0x00798763, 0x00788662, 0x00788662, 0x00788662, 0x00798763, 0x00798763, 0x00798763, 0x00798763, 0x00798763, 0x00798763, 0x00798763, 0x00798763, 0x00798A5E,
        0x00798A5E, 0x007A8B5F, 0x007B8C60, 0x007D8E62, 0x007F9064, 0x00809165, 0x00819266, 0x007D9162, 0x007E9263, 0x007F9364, 0x007F9364, 0x007F9364, 0x007E9263, 0x007D9162, 0x007C9061, 0x007C8D5A, 0x007D8D5D, 0x007E8E5F, 0x007F8E62, 0x00808E64,
        0x007F8D64, 0x007F8C66, 0x007E8B65, 0x007B8C61, 0x007C8D62, 0x007D8E63, 0x007E8F64, 0x007D8E63, 0x007D8E63, 0x007C8D62, 0x007C8D62, 0x007B8C61, 0x007F8D69, 0x00798666, 0x007F8C6C, 0x006E7C5A, 0xFF788369, 0xFFFDFFFB, 0xFFFDFCFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFDFF, 0xBADEE4D1, 0x00617044, 0x006F844D, 0x007E915E, 0x007B8D64, 0x00788866, 0x0071825D, 0x0077885D, 0x0077885D, 0x0077885D, 0x0076875C, 0x0075865B,
        0x0074855A, 0x00728358, 0x00718257, 0x00718256, 0x00708155, 0x006F8054, 0x006F8054, 0x006E7F53, 0x006E7F53, 0x006E7F53, 0x006F8054, 0x006C7D51, 0x006C7D51, 0x006C7D51, 0x006D7E52, 0x006D7E52, 0x006E7F53, 0x006E7F53, 0x006E7F53, 0x006D7E53,
        0x006D7E53, 0x006D7E53, 0x006D7E53, 0x006E7F54, 0x006F8055, 0x00708156, 0x00718257, 0x00738459, 0x00738459, 0x0074855A, 0x0075865B, 0x0076875C, 0x0077885D, 0x0078895E, 0x0078895E, 0x00798A5F, 0x00798A5F, 0x00798A5F, 0x007A8B60, 0x007A8B60,
        0x007A8B60, 0x007A8B60, 0x007A8B60, 0x007C8D62, 0x007C8D62, 0x007C8D62, 0x007C8D62, 0x007C8D62, 0x007C8D62, 0x007C8D62, 0x007C8D62, 0x007E8C62, 0x007E8C62, 0x007E8D61, 0x007E8D61, 0x007E8E5F, 0x007E8E5F, 0x007D8D5E, 0x007D8D5D, 0x007F9065,
        0x007E8F64, 0x007C8D62, 0x007B8C61, 0x007A8B60, 0x007B8C61, 0x007B8C61, 0x007C8D62, 0x007B8C61, 0x007B8C61, 0x007B8C61, 0x007B8C61, 0x007B8C61, 0x007B8C61, 0x007B8C61, 0x007B8C61, 0x007C8D62, 0x007C8D62, 0x007B8C61, 0x007B8C61, 0x007A8B60,
        0x007A8B60, 0x007A8B60, 0x007A8B60, 0x007A8864, 0x007A8864, 0x00798763, 0x00788662, 0x00788662, 0x00798763, 0x007A8864, 0x007A8864, 0x007C8C63, 0x007C8C63, 0x007C8C63, 0x007D8D64, 0x007D8D64, 0x007D8D64, 0x007E8E65, 0x007E8E65, 0x007B8C61,
        0x007C8D62, 0x007D8E63, 0x007E8F64, 0x007E8F64, 0x007E8F64, 0x007E8F64, 0x007D8E63, 0x007D8D64, 0x007E8E65, 0x007F8F66, 0x00809067, 0x007F8F66, 0x007E8E65, 0x007C8C63, 0x007B8B62, 0x007C8D62, 0x007C8D62, 0x007C8D62, 0x007C8D62, 0x007C8D62,
        0x007D8E63, 0x007D8E63, 0x007E8F64, 0x007A8B60, 0x007A8B60, 0x007A8B60, 0x007A8B60, 0x007B8C61, 0x007B8C61, 0x007C8D62, 0x007C8D62, 0x007B8D66, 0x007A8C65, 0x007A8C65, 0x007A8C65, 0x007A8C65, 0x007B8D66, 0x007B8D66, 0x007C8E67, 0x007E9061,
        0x007E9061, 0x007D8F60, 0x007D8F60, 0x007D8F60, 0x007D8F60, 0x007E9061, 0x007E9061, 0x007B8E63, 0x007B8E63, 0x007B8D64, 0x007B8D64, 0x007B8D66, 0x007C8D68, 0x007C8D68, 0x007C8D68, 0x007B9161, 0x007B9161, 0x007B9161, 0x007A9060, 0x00798F5F,
        0x00788E5E, 0x00778D5D, 0x00778D5D, 0x00798862, 0x00798862, 0x00788761, 0x00788761, 0x00788761, 0x00788761, 0x00778660, 0x00778660, 0x00788761, 0x00788761, 0x00788761, 0x00788761, 0x00788761, 0x00788761, 0x00788761, 0x00788761, 0x007B8C60,
        0x007B8C60, 0x007A8B5F, 0x007A8B5F, 0x007A8B5F, 0x007B8C60, 0x007B8C60, 0x007C8D61, 0x007A905F, 0x007A905F, 0x007B9160, 0x007B9160, 0x007A905F, 0x00798F5E, 0x00788E5D, 0x00788E5D, 0x007D9162, 0x007D9162, 0x007E9263, 0x007E9265, 0x007D9065,
        0x007C8F64, 0x007B8D64, 0x007B8D64, 0x007F9162, 0x00819364, 0x00839566, 0x00829465, 0x00809263, 0x007D8F60, 0x007C8E5F, 0x007B8D5E, 0x00778A57, 0x007E8F64, 0x007E8D67, 0x0084936D, 0x006D7D54, 0xFF7B8769, 0xFFFBFFF6, 0xFFF6F5FE, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFF, 0xB7DAE0CF, 0x00626F49, 0x005D6F40, 0x0067774E, 0x006A7959, 0x006C7A5E, 0x00697859, 0x006B7C50, 0x006B7C50, 0x006B7C50, 0x006A7B4F, 0x00697A4E,
        0x0068794D, 0x0067784C, 0x0066774B, 0x00667849, 0x00667849, 0x00667849, 0x00667849, 0x00667849, 0x00657748, 0x00647647, 0x00637546, 0x00667849, 0x00667849, 0x00657748, 0x00647647, 0x00637546, 0x00627445, 0x00627445, 0x00617344, 0x00677553,
        0x00677553, 0x00677553, 0x00677553, 0x00677553, 0x00687654, 0x00697755, 0x00697755, 0x006C7A58, 0x006C7A58, 0x006D7B59, 0x006E7C5A, 0x006F7D5B, 0x006F7D5B, 0x00707E5C, 0x00707E5C, 0x00748260, 0x00748260, 0x00748260, 0x00748260, 0x00758361,
        0x00758361, 0x00758361, 0x00758361, 0x00758361, 0x00768462, 0x00768462, 0x00778563, 0x00778563, 0x00788664, 0x00788664, 0x00788664, 0x007A8564, 0x00798463, 0x00798463, 0x00788460, 0x00788460, 0x0077845E, 0x0077845E, 0x0077845E, 0x00758361,
        0x00758361, 0x00758361, 0x00768462, 0x00778563, 0x00788664, 0x00798765, 0x007A8866, 0x007B8967, 0x007B8967, 0x007B8967, 0x007B8967, 0x007B8967, 0x007B8967, 0x007B8967, 0x007B8967, 0x00788664, 0x00788664, 0x00778563, 0x00778563, 0x00768462,
        0x00768462, 0x00768462, 0x00768462, 0x007A8963, 0x007A8963, 0x00798862, 0x00798862, 0x00798862, 0x00798862, 0x007A8963, 0x007A8963, 0x007A8866, 0x007A8866, 0x007A8866, 0x007A8866, 0x007A8866, 0x007A8866, 0x007B8967, 0x007B8967, 0x007D8B67,
        0x007D8B67, 0x007D8B67, 0x007E8C68, 0x007E8C68, 0x007F8D69, 0x007F8D69, 0x00808E6A, 0x007B8967, 0x007C8A68, 0x007D8B69, 0x007E8C6A, 0x007E8C6A, 0x007D8B69, 0x007B8967, 0x007A8866, 0x007C8A66, 0x007B8965, 0x00798763, 0x00778561, 0x00778561,
        0x00788662, 0x00798763, 0x007A8864, 0x007B8965, 0x007A8864, 0x007A8864, 0x007A8864, 0x00798763, 0x00798763, 0x00798763, 0x00788662, 0x00798B62, 0x007A8C63, 0x007A8C63, 0x007A8C63, 0x00798B62, 0x00798B62, 0x00788A61, 0x00788A61, 0x007B8B62,
        0x007A8A61, 0x007A8A61, 0x007A8A61, 0x007B8B62, 0x007C8C63, 0x007E8E65, 0x007F8F66, 0x007A8D62, 0x007B8E63, 0x007B8E63, 0x007B8E63, 0x007A8D62, 0x007A8C63, 0x007A8C63, 0x007B8D64, 0x007E9268, 0x007E9268, 0x007D9167, 0x007D9167, 0x007C9066,
        0x007C9066, 0x007C9066, 0x007C9066, 0x007D8E63, 0x007D8E63, 0x007D8E63, 0x007D8E63, 0x007D8E63, 0x007C8D62, 0x007C8D62, 0x007C8D62, 0x007D8E63, 0x007D8E63, 0x007D8E63, 0x007D8E63, 0x007D8E63, 0x007D8E63, 0x007D8E63, 0x007D8E63, 0x007E8D67,
        0x007F8E68, 0x007F8E68, 0x0081906A, 0x0082916B, 0x0083926C, 0x0083926C, 0x0084936D, 0x0082966B, 0x0082966B, 0x0082966B, 0x0082966B, 0x0081956A, 0x0081956A, 0x00809469, 0x00809469, 0x0080926B, 0x0080926B, 0x0080926B, 0x007F916A, 0x007E9069,
        0x007D8E69, 0x007D8E69, 0x007C8D68, 0x00819168, 0x00829269, 0x0084946B, 0x0083936A, 0x00809067, 0x007E8E65, 0x007D8D64, 0x007E8E65, 0x007D915C, 0x007F9162, 0x007B8C61, 0x00798A5E, 0x00647647, 0xFF7E8D67, 0xFFFAFFF1, 0xFFFDFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFAFE, 0xC6DEE2D7, 0x008F987E, 0x00838F71, 0x007E8772, 0x007D8777, 0x007D8874, 0x007D8A72, 0x00848F6E, 0x00848F6E, 0x0085906F, 0x04869170, 0x04869170,
        0x04869170, 0x04869170, 0x0085906F, 0x0084926E, 0x0084926E, 0x0084926E, 0x0084926E, 0x0082906C, 0x00808E6A, 0x007E8C68, 0x007D8B67, 0x007B8965, 0x007A8864, 0x00788662, 0x00768460, 0x0073815D, 0x00707E5A, 0x006E7C58, 0x006D7B57, 0x006C7560,
        0x006B745F, 0x006B745F, 0x006A735E, 0x0069725D, 0x0069725D, 0x0068715C, 0x0068715C, 0x006B745F, 0x006B745F, 0x006C7560, 0x006C7560, 0x006D7661, 0x006D7661, 0x006D7661, 0x006E7762, 0x006D7661, 0x006D7661, 0x006D7661, 0x006E7762, 0x006E7762,
        0x006E7762, 0x006E7762, 0x006E7762, 0x006E7762, 0x006E7762, 0x006F7863, 0x006F7863, 0x00707964, 0x00717A65, 0x00727B66, 0x00727B66, 0x00727865, 0x00727865, 0x00727964, 0x00727964, 0x00737B64, 0x00737B64, 0x00737B64, 0x00737C62, 0x006C7560,
        0x006E7762, 0x00707964, 0x00727B66, 0x00727B66, 0x00717A65, 0x006E7762, 0x006D7661, 0x006C7560, 0x006C7560, 0x006C7560, 0x006C7560, 0x006C7560, 0x006C7560, 0x006C7560, 0x006C7560, 0x006D7661, 0x006D7661, 0x006D7661, 0x006D7661, 0x006D7661,
        0x006C7560, 0x006C7560, 0x006C7560, 0x006F7B5D, 0x006F7B5D, 0x006F7B5D, 0x006F7B5D, 0x006F7B5D, 0x006F7B5D, 0x006F7B5D, 0x006F7B5D, 0x006D7760, 0x006D7760, 0x006D7760, 0x006D7760, 0x006D7760, 0x006D7760, 0x006D7760, 0x006D7760, 0x006D7760,
        0x006C765F, 0x006C765F, 0x006C765F, 0x006C765F, 0x006D7760, 0x006E7861, 0x006F7962, 0x006F7863, 0x00707964, 0x00707964, 0x00717A65, 0x00707964, 0x00707964, 0x006E7762, 0x006E7762, 0x006F7962, 0x006D7760, 0x0069735C, 0x00667059, 0x00646E57,
        0x00646E57, 0x00656F58, 0x00667059, 0x006A725B, 0x006A725B, 0x0069715A, 0x00687059, 0x00687059, 0x00676F58, 0x00666E57, 0x00666E57, 0x00626F4F, 0x00647151, 0x00667353, 0x00667353, 0x00667353, 0x00657252, 0x00647151, 0x00647151, 0x00626E52,
        0x00626E52, 0x00626E52, 0x00626E52, 0x00636F53, 0x00657155, 0x00667256, 0x00677357, 0x00647250, 0x00647250, 0x00657351, 0x00657351, 0x00647250, 0x00647250, 0x0063714F, 0x0063714F, 0x00616F53, 0x00637155, 0x00657357, 0x00677559, 0x00677559,
        0x00667458, 0x00647256, 0x00637155, 0x00677553, 0x00677553, 0x00677553, 0x00667452, 0x00667452, 0x00667452, 0x00667452, 0x00657351, 0x00667452, 0x00667452, 0x00667452, 0x00667452, 0x00667452, 0x00667452, 0x00667452, 0x00667452, 0x00647054,
        0x00657155, 0x00667256, 0x00687458, 0x00687458, 0x00697559, 0x00687458, 0x00687458, 0x00677559, 0x00677559, 0x00677559, 0x00677559, 0x00667458, 0x00667458, 0x00667458, 0x00667458, 0x0069765C, 0x0069765C, 0x0069765C, 0x0068755B, 0x00677559,
        0x00677559, 0x00667458, 0x00667458, 0x00697559, 0x00697559, 0x00687458, 0x00687458, 0x00677357, 0x00667256, 0x00677357, 0x00687458, 0x006A7B50, 0x006B7955, 0x006A7856, 0x006A7953, 0x0067784D, 0xFF8A9874, 0xFFF0F9E5, 0xFFFDFFFE, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFDFF, 0xFFFFFFFE, 0xF4F6FAEF, 0xFFFDFFF9, 0xFFFDFFFF, 0xFFFBFFFF, 0xFFF9FFF7, 0xF4F8FFEF, 0xFFFDFFF6, 0xFFFEFFF7, 0xFFFEFFF7, 0xFFFFFFF8, 0xFFFFFFF8,
        0xFFFFFFF8, 0xFFFFFFF8, 0xFFFFFFF8, 0xFFFDFFF7, 0xFFFDFFF7, 0xFFFDFFF7, 0xFFFDFFF7, 0xFFFCFFF6, 0xFFFBFFF5, 0xFBFAFFF4, 0xFBFAFFF4, 0xFFFDFFF7, 0xFFFDFFF7, 0xFFFDFFF7, 0xFFFBFFF5, 0xFBF9FFF3, 0xF7F7FEF1, 0xF4F6FDF0, 0xF4F5FCEF, 0xFFFAFFF6,
        0xFFFAFFF6, 0xFFFAFFF6, 0xFFFAFFF6, 0xFFF9FEF5, 0xFBF8FDF4, 0xFBF8FDF4, 0xFBF7FCF3, 0xFFF9FEF5, 0xFFF9FEF5, 0xFFF9FEF5, 0xFFF9FEF5, 0xFFF9FEF5, 0xFFF9FEF5, 0xFFF9FEF5, 0xFFF9FEF5, 0xF7F5FAF1, 0xF7F5FAF1, 0xF7F5FAF1, 0xF7F6FBF2, 0xF7F6FBF2,
        0xF7F6FBF2, 0xF7F6FBF2, 0xF7F6FBF2, 0xF7F5FAF1, 0xF7F6FBF2, 0xF7F6FBF2, 0xF7F6FBF2, 0xFBF7FCF3, 0xFBF7FCF3, 0xFBF7FCF3, 0xFBF7FCF3, 0xFFF9FBF5, 0xFFF9FBF5, 0xFFF9FBF5, 0xFBF9FCF3, 0xFBFAFDF4, 0xFBFAFEF3, 0xFBFAFEF3, 0xFBFBFFF4, 0xF7F6FBF2,
        0xFBF7FCF3, 0xFFF9FEF5, 0xFFFAFFF6, 0xFBF8FDF4, 0xF7F5FAF1, 0xF0F1F6ED, 0xECEFF4EB, 0xE8EEF3EA, 0xE8EEF3EA, 0xE8EEF3EA, 0xE8EEF3EA, 0xE8EEF3EA, 0xE8EEF3EA, 0xE8EEF3EA, 0xE8EEF3EA, 0xE8EDF2E9, 0xE8EDF2E9, 0xE8EDF2E9, 0xE8EDF2E9, 0xE8EDF2E9,
        0xE8EDF2E9, 0xE8EEF3EA, 0xE8EEF3EA, 0xE4ECF2E7, 0xE4ECF2E7, 0xE4ECF2E7, 0xE4EDF3E8, 0xE4EDF3E8, 0xE4ECF2E7, 0xE4ECF2E7, 0xE4ECF2E7, 0xE4ECF2E7, 0xE4ECF2E7, 0xE1EBF1E6, 0xE1EBF1E6, 0xE1EBF1E6, 0xE1EBF1E6, 0xE1EBF1E6, 0xE1EBF1E6, 0xE1EBF1E6,
        0xE1EBF1E6, 0xE1EBF1E6, 0xE1EBF1E6, 0xE1EBF1E6, 0xE4ECF2E7, 0xE4ECF2E7, 0xE4ECF2E7, 0xE4ECF1E8, 0xE4ECF1E8, 0xE4ECF1E8, 0xE4ECF1E8, 0xE4ECF1E8, 0xE4ECF1E8, 0xE4EBF0E7, 0xE4EBF0E7, 0xE1EBF1E6, 0xE1EAF0E5, 0xD9E7EDE2, 0xD5E5EBE0, 0xD1E3E9DE,
        0xD1E2E8DD, 0xD1E3E9DE, 0xD1E3E9DE, 0xD1E5E9DE, 0xD1E5E9DE, 0xD1E5E9DE, 0xD1E4E8DD, 0xD1E4E8DD, 0xCEE3E7DC, 0xCEE3E7DC, 0xCEE3E7DC, 0xC6DEE5D8, 0xCAE0E7DA, 0xCEE1E8DB, 0xCEE1E8DB, 0xCAE0E7DA, 0xCADFE6D9, 0xCAE0E7DA, 0xCEE1E8DB, 0xD1E2E8DD,
        0xCEE1E7DC, 0xCEE1E7DC, 0xCEE1E7DC, 0xD1E2E8DD, 0xD1E2E8DD, 0xD1E3E9DE, 0xD1E3E9DE, 0xCEE5E7DB, 0xCEE5E7DB, 0xCEE5E7DB, 0xCEE6E8DC, 0xCAE6E9DA, 0xCAE6E9DA, 0xC6E5E8D8, 0xC6E4E7D7, 0xCAE0E4D9, 0xCEE2E6DB, 0xCEE3E7DC, 0xCEE3E7DC, 0xCAE1E5DA,
        0xC2DDE1D6, 0xBAD9DDD2, 0xB7D6DACF, 0xAFD4DBCC, 0xAFD4DBCC, 0xAFD4DBCC, 0xAFD4DBCC, 0xAFD4DBCC, 0xAFD3DACB, 0xAFD3DACB, 0xAFD3DACB, 0xAFD3DACB, 0xAFD3DACB, 0xAFD3DACB, 0xAFD3DACB, 0xAFD3DACB, 0xAFD3DACB, 0xAFD3DACB, 0xAFD3DACB, 0xABD2D9CA,
        0xABD2D9CA, 0xABD2D9CA, 0xABD2D9CA, 0xABD1D8C9, 0xA7D0D7C8, 0xA7D0D7C8, 0xA7CFD6C7, 0xB3D5D9CD, 0xB3D5D9CD, 0xB3D5D9CD, 0xB3D5D9CD, 0xB3D5D9CD, 0xB3D6DACE, 0xB3D6DACE, 0xB3D6DACE, 0xB3D5D9CD, 0xAFD4D8CC, 0xAFD4D8CC, 0xABD4D9CA, 0xABD3D8C9,
        0xA7D3D9C8, 0xABD4DAC9, 0xABD4DAC9, 0xB3D3DACD, 0xAFD1D8CB, 0xA7CED5C8, 0xA4CBD2C5, 0xA0C9D0C3, 0x9CC7CEC1, 0x98C6CDC0, 0x98C5CCBF, 0x91C5CDBC, 0x9CC8CFC2, 0xABCED4C9, 0x9CCCD5C1, 0x8DCAD6BA, 0xFFD2DCC5, 0xFFFBFFF7, 0xFFFAF9FF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF
};

static GUI_CONST_STORAGE GUI_BITMAP _bmPlatine_250x200 = {
  250,                                  // XSize
  200,                                  // YSize
  1000,                                 // BytesPerLine
  32,                                   // BitsPerPixel
  (unsigned char *)_acPlatine_250x200,  // Pointer to picture data
  NULL,                                 // Pointer to palette
  GUI_DRAW_BMP8888
};

/*********************************************************************
*
*       bmJLink_300x132
*/
static GUI_CONST_STORAGE unsigned long _acJLink_300x132[] = {
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFE, 0xFFFEFFFD, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFCFDF9, 0xFFFDFFFE, 0xFFEFF2F0, 0xFBE9ECEA, 0xFFF6F9F7, 0xFFFDFFFE,
        0xFFFDFFFE, 0xFFFAFDFB, 0xFFFBFEFC, 0xFFFBFBFB, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCFCFC, 0xFFFAFAFA, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFFFD, 0xFFFAFBF9, 0xFFFBFCFA, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFF3F5EF, 0xDEE0E2DC, 0x3F909691, 0x157B817C, 0x04737974, 0x2A868C87, 0x64A1A7A2,
        0x96BAC0BB, 0xD1D6DCD7, 0xFFEFF5F0, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFDFEFC, 0xFFFDFEFC, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFF9FAF8, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFC, 0xFBECEDE9, 0xA7C5C7C1, 0x3690928C, 0x00666862, 0x005C625D, 0x005A605B, 0x005B615C, 0x005E645F, 0x005F6560,
        0x00606661, 0x00696F6A, 0x08757B76, 0x3B8E8F8D, 0x64A3A4A2, 0xA7C3C4C2, 0xE6E1E2E0, 0xFFF4F5F3, 0xFFFDFEFC, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFF9F9F9, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFE, 0xFFFEFFFD, 0xDEDDDEDC, 0x60A2A39F, 0x006B6C68, 0x00565852, 0x005D5F59, 0x00696B65, 0x00696F6A, 0x006C726D, 0x006D736E, 0x00696F6A, 0x00666C67,
        0x00666C67, 0x00666C67, 0x00666C67, 0x00676866, 0x00696A68, 0x006C6D6B, 0x00727371, 0x197F807E, 0x4B979896, 0x86B3B4B2, 0xB0C7C8C6, 0xF7E8E8E8, 0xFFF1F1F1, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFEFFFD, 0xFFFFFFFE, 0xFFFFFFFE,
        0xFFFEFFFD, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFCFDFB, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xE2E0E4DE, 0x6DA7ABA5, 0x006B6F69, 0x0051554F, 0x004E524C, 0x004D514B, 0x004A4E48, 0x004B4F49, 0x00535751, 0x005A5E58, 0x00646862, 0x006C706A, 0x006F736D,
        0x006F736D, 0x006E726C, 0x006D716B, 0x006D746D, 0x006B726B, 0x00686F68, 0x00656C65, 0x00636A63, 0x00636A63, 0x00646B64, 0x00656C65, 0x0071756F, 0x1D81857F, 0x549B9F99, 0x8AB6BAB4, 0xC0CFD3CD, 0xEEE5E9E3, 0xFFF6FAF4, 0xFFFDFFFB, 0xFFFFFEFF,
        0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFDFCFE, 0xFFFDFCFE, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFDFCFE, 0xFFFDFCFE, 0xFFFEFDFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFEFEFE, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFF, 0xFFFBFAFC, 0xFFFFFEFF, 0xFFFEFEFE, 0xFFFCFCFC, 0xFFFCFDFB, 0xFFF9FAF8, 0xFFFFFFFE, 0xFFFFFFFE,
        0xFFFFFFFE, 0xFFFDFEFC, 0xFFFCFDFB, 0xFFFFFFFE, 0xFFFFFFFE, 0xD5D9DAD8, 0x69A4A5A3, 0x006C706A, 0x0061655F, 0x005B5F59, 0x005F635D, 0x00646862, 0x00636761, 0x0060645E, 0x005F635D, 0x004F534D, 0x004C504A, 0x00474B45, 0x00444842, 0x00464A44,
        0x004E524C, 0x005A5E58, 0x00626660, 0x00656C65, 0x00666D66, 0x00686F68, 0x00697069, 0x00697069, 0x00697069, 0x00686F68, 0x00686F68, 0x006A6E68, 0x00676B65, 0x00646862, 0x00646862, 0x006A6E68, 0x0D797D77, 0x368D918B, 0x4F9A9E98, 0xA3C0C1BF,
        0xC9D2D3D1, 0xFBEBECEA, 0xFFFEFFFD, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFEFFFD, 0xFFFCFDFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFEFEFE, 0xFFFEFEFE, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFDFDFD, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFAFC, 0xFFFFFEFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFFFFFE, 0xFFFCFDFB, 0xFFFFFFFE, 0xFFFFFFFE,
        0xFFFAFBF9, 0xFFFFFFFE, 0xFFFFFFFE, 0xF2E7E8E6, 0x7DAFB0AE, 0x08777876, 0x00545553, 0x00585C56, 0x005C605A, 0x0060645E, 0x005E625C, 0x005A5E58, 0x00595D57, 0x005C605A, 0x005F635D, 0x00656963, 0x00656963, 0x00636761, 0x005E625C, 0x00575B55,
        0x004E524C, 0x00474B45, 0x00444842, 0x00464D46, 0x004A514A, 0x00535A53, 0x005B625B, 0x00626962, 0x00676E67, 0x00697069, 0x006A716A, 0x00686C66, 0x00696D67, 0x006A6E68, 0x00686C66, 0x00656963, 0x00636761, 0x00646862, 0x00666A64, 0x00666862,
        0x0071736D, 0x1982847E, 0x3F93958F, 0x69A8AAA4, 0xA7C5C7C1, 0xE6E4E6E0, 0xFFF9FBF5, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFDFDFD, 0xFFFEFEFE,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFDFDFD, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFDFF, 0xFFFFFFFF, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFF7F8F4, 0xFFFBFCF8, 0xFFFEFFFB,
        0xFFFDFEFA, 0xFBECEDE9, 0x8EB9BAB6, 0x04777874, 0x00555652, 0x005B5C58, 0x00686965, 0x0061655F, 0x0061655F, 0x0060645E, 0x005D615B, 0x005A5E58, 0x00585C56, 0x005A5E58, 0x005C605A, 0x00535751, 0x00585C56, 0x0060645E, 0x00676B65, 0x006A6E68,
        0x006B6F69, 0x00696D67, 0x00676B65, 0x00596059, 0x00525952, 0x00495049, 0x00424942, 0x00404740, 0x00444B44, 0x004B524B, 0x00505750, 0x00626660, 0x00656963, 0x00686C66, 0x006A6E68, 0x00696D67, 0x00686C66, 0x00696D67, 0x00696D67, 0x0063695E,
        0x00656B60, 0x00656B60, 0x0063695E, 0x0062685D, 0x00676D62, 0x0072786D, 0x087B8176, 0x4F979A98, 0x7DADB0AE, 0xC0CDD0CE, 0xFBEAEDEB, 0xFFFBFEFC, 0xFFFDFFFE, 0xFFFDFFFE, 0xFFFDFFFE, 0xFFFAFDFB, 0xFFFBFEFC, 0xFFFCFFFD, 0xFFFCFFFD, 0xFFFBFEFC,
        0xFFFBFEFC, 0xFFFBFEFC, 0xFFFCFFFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCFCFC, 0xFFFAFAFA, 0xFFFFFFFE, 0xFFFBFCFA, 0xFFF9FAF6, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFEFF0EC,
        0x8EB8B9B5, 0x117D7E7A, 0x005D5E5A, 0x005B5C58, 0x00666763, 0x00676864, 0x005C5D59, 0x005F635D, 0x005A5E58, 0x005A5E58, 0x0060645E, 0x0061655F, 0x005C605A, 0x00585C56, 0x00595D57, 0x005D615B, 0x005B5F59, 0x00595D57, 0x00595D57, 0x005A5E58,
        0x005E625C, 0x0061655F, 0x00646862, 0x00676E67, 0x00676E67, 0x00666D66, 0x00626962, 0x005C635C, 0x00535A53, 0x004B524B, 0x00464D46, 0x00424640, 0x00474B45, 0x004E524C, 0x00565A54, 0x005D615B, 0x00636761, 0x00676B65, 0x006A6E68, 0x006A7065,
        0x006A7065, 0x006B7166, 0x006A7065, 0x00696F64, 0x00676D62, 0x00666C61, 0x00656B60, 0x00616560, 0x00636762, 0x00686C67, 0x00727671, 0x26848883, 0x60A0A49F, 0x9BBDC1BC, 0xC4D0D4CF, 0xFFF5F8F6, 0xFFF8FBF9, 0xFFFDFFFE, 0xFFFDFFFE, 0xFFFDFFFE,
        0xFFFCFFFD, 0xFFFBFEFC, 0xFFFBFEFC, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFFFD, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFCFDF9, 0xFFFFFFFC, 0xFFF9FBF5, 0x86B6B8B2, 0x00747571,
        0x005B5C58, 0x00555652, 0x00646561, 0x006A6B67, 0x00636460, 0x005F605C, 0x0060615D, 0x0060645E, 0x005A5E58, 0x00585C56, 0x005D615B, 0x005E625C, 0x005B5F59, 0x005E625C, 0x00646862, 0x005C605A, 0x005C605A, 0x005C605A, 0x005D615B, 0x005D615B,
        0x005D615B, 0x005C605A, 0x005A5E58, 0x00585F58, 0x00575E57, 0x00575E57, 0x00575E57, 0x00585F58, 0x005A615A, 0x005C635C, 0x005D645D, 0x00626660, 0x005B5F59, 0x0050544E, 0x00464A44, 0x0040443E, 0x0041453F, 0x00444842, 0x00474B45, 0x00555D53,
        0x00575F55, 0x005D655B, 0x00636B61, 0x00697167, 0x006A7268, 0x00687066, 0x00666E64, 0x00656C65, 0x00656C65, 0x00646B64, 0x00626962, 0x005F665F, 0x005F665F, 0x00626962, 0x00656C65, 0x00707671, 0x26838984, 0x64A2A8A3, 0xA7C1C7C2, 0xD9DAE0DB,
        0xFFECF2ED, 0xFFF8FEF9, 0xFFFBFFFC, 0xFFFAFAFA, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFE, 0xFFFDFEFC, 0xFFFFFFFE, 0xFFFAFBF7, 0xFFFFFFFC, 0xFFF7F9F3, 0x26878983, 0x00252721, 0x001F211B,
        0x0030322C, 0x0041433D, 0x00454741, 0x00484A44, 0x00575953, 0x0062645E, 0x005F615B, 0x005C605A, 0x005E625C, 0x0061655F, 0x0061655F, 0x005E625C, 0x005B5F59, 0x005C605A, 0x005E625C, 0x005E625C, 0x005E625C, 0x005D615B, 0x005E625C, 0x005E625C,
        0x005D615B, 0x005B5F59, 0x00585C56, 0x00555C55, 0x00575E57, 0x005A615A, 0x005D645D, 0x005E655E, 0x005D645D, 0x005C635C, 0x005B625B, 0x005F635D, 0x0060645E, 0x0061655F, 0x00626660, 0x005F635D, 0x005A5E58, 0x00555953, 0x0051554F, 0x00444B44,
        0x00434A43, 0x00424942, 0x00454C45, 0x004B524B, 0x00555C55, 0x005F665F, 0x00666D66, 0x00687066, 0x00676F65, 0x00646C62, 0x00626A60, 0x0061695F, 0x0061695F, 0x00636B61, 0x00656D63, 0x00616762, 0x005D635E, 0x00585E59, 0x00585E59, 0x00626863,
        0x0D787E79, 0x43929893, 0x6DA5ABA6, 0xCDD3D3D3, 0xE6DFDFDF, 0xFFF0F0F0, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFFFD, 0xFFFEFFFD, 0xFFFFFFFE, 0xFFFAFBF7, 0xFFFFFFFC, 0x69A8AAA4, 0x00191B15, 0x0011130D, 0x00171913,
        0x0013150F, 0x00171913, 0x001F211B, 0x0021231D, 0x00292B25, 0x00373933, 0x003F413B, 0x00484C46, 0x00535751, 0x005B5F59, 0x005D615B, 0x005E625C, 0x0061655F, 0x0061655F, 0x005D615B, 0x0060645E, 0x005E625C, 0x005D615B, 0x005D615B, 0x005D615B,
        0x005C605A, 0x005A5E58, 0x00585C56, 0x005B625B, 0x005C635C, 0x005F665F, 0x00616861, 0x00646B64, 0x00656C65, 0x00666D66, 0x00666D66, 0x00646862, 0x00636761, 0x0061655F, 0x0060645E, 0x005F635D, 0x005F635D, 0x005E625C, 0x005E625C, 0x005F6560,
        0x00606661, 0x005E645F, 0x00565C57, 0x004D534E, 0x00454B46, 0x00434944, 0x00434944, 0x004C544A, 0x0050584E, 0x00586056, 0x0060685E, 0x00656D63, 0x00666E64, 0x00646C62, 0x00626A60, 0x00606661, 0x00626863, 0x00636964, 0x00606661, 0x005D635E,
        0x005B615C, 0x005D635E, 0x005F6560, 0x005E5E5E, 0x006C6C6C, 0x21818181, 0x54999999, 0x86B1B1B1, 0xBCCBCBCB, 0xEEE4E4E4, 0xFFF5F5F5, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFF, 0xFFFCFBFD, 0xFFFFFDFC, 0xFFFFFFFB, 0xFFFDFBF3, 0x003E4138, 0x000F160F, 0x000D140F, 0x0011150F,
        0x0010140E, 0x0010140E, 0x0010140E, 0x0010140E, 0x0010140E, 0x0010140E, 0x0011150F, 0x00191D17, 0x00222620, 0x002E322C, 0x00383C36, 0x0040443E, 0x004A4E48, 0x00565A54, 0x005E625C, 0x005C605B, 0x005F635E, 0x00616560, 0x00616560, 0x005E625D,
        0x005D615C, 0x0060645F, 0x00626661, 0x0061655F, 0x0061655F, 0x00626660, 0x00626660, 0x00636761, 0x00636761, 0x00636761, 0x00626660, 0x00666A64, 0x00666A64, 0x00656963, 0x00656963, 0x00646862, 0x00626660, 0x0060645E, 0x005F635D, 0x005E625C,
        0x005E625C, 0x005E625C, 0x0060645E, 0x00626660, 0x00636761, 0x00626660, 0x0061655F, 0x00505750, 0x004C534C, 0x00464D46, 0x00434A43, 0x00454C45, 0x004C534C, 0x00545B54, 0x00596059, 0x00616861, 0x00616861, 0x00626962, 0x00616861, 0x00616861,
        0x00606760, 0x005F665F, 0x005E655E, 0x00646B64, 0x00646B64, 0x00626962, 0x005F665F, 0x005F665F, 0x00656C65, 0x006F766F, 0x0D777E77, 0x4B9A9C96, 0x79AFB1AB, 0xB8CED0CA, 0xEEE8EAE4, 0xFFF7F9F3, 0xFFFEFFFA, 0xFFFFFFFB, 0xFFFFFFFB, 0xFFFCFDFB,
        0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFEFFFD, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFDFEFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE,
        0xFFFEFEFE, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFF, 0xFFFDFCFE, 0xFFFFFFFE, 0xFFFFFFFA, 0xDEE5E3DB, 0x00272A21, 0x000A110A, 0x000E1510, 0x0010140E,
        0x0010140E, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x0010140E, 0x0010140E, 0x000A0E08, 0x000D110B, 0x0011150F, 0x00141812, 0x00171B15, 0x001E221C, 0x00272B25, 0x002F332D, 0x0040443F, 0x00484C47, 0x00535752, 0x005B5F5A, 0x005F635E,
        0x00626661, 0x00646863, 0x00666A65, 0x00656963, 0x00656963, 0x00636761, 0x0061655F, 0x005F635D, 0x005E625C, 0x005E625C, 0x005F635D, 0x005D615B, 0x005F635D, 0x00626660, 0x00656963, 0x00666A64, 0x00666A64, 0x00656963, 0x00646862, 0x006A6E68,
        0x00686C66, 0x00666A64, 0x00646862, 0x00646862, 0x00626660, 0x0060645E, 0x005E625C, 0x00656C65, 0x00646B64, 0x00626962, 0x005E655E, 0x00585F58, 0x00515851, 0x004B524B, 0x00474E47, 0x00414841, 0x00464D46, 0x004D544D, 0x00565D56, 0x005C635C,
        0x00616861, 0x00636A63, 0x00636A63, 0x005E655E, 0x005F665F, 0x005F665F, 0x005D645D, 0x005C635C, 0x005D645D, 0x00616861, 0x00646B64, 0x00656761, 0x00666862, 0x006A6C66, 0x0073756F, 0x21858781, 0x5CA1A39D, 0x9FC1C3BD, 0xC9D6D8D2, 0xFFF4F5F3,
        0xFFFAFBF9, 0xFFFEFFFD, 0xFFFDFEFC, 0xFFFDFEFC, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFF, 0xFFFFFEFF, 0xFFFFFEFD, 0xFFFFFEF9, 0xA7CBC9C1, 0x0013160D, 0x00091009, 0x000C130E, 0x000F130D,
        0x000E120C, 0x000E120C, 0x000D110B, 0x000D110B, 0x000E120C, 0x000E120C, 0x000F130D, 0x000E120D, 0x000E120D, 0x000D110C, 0x000B0F0A, 0x000A0E09, 0x000C100B, 0x0010140F, 0x00141813, 0x00131712, 0x001A1E19, 0x00242823, 0x0030342F, 0x003C403B,
        0x00484C47, 0x00555954, 0x005D615C, 0x005F635D, 0x00636761, 0x00686C66, 0x00696D67, 0x00676B65, 0x00646862, 0x00626660, 0x00626660, 0x00656963, 0x00646862, 0x00636761, 0x0061655F, 0x0061655F, 0x00636761, 0x00656963, 0x00666A64, 0x00636761,
        0x00626660, 0x00626660, 0x00636761, 0x00656963, 0x00676B65, 0x00676B65, 0x00676B65, 0x00616861, 0x00626962, 0x00646B64, 0x00656C65, 0x00656C65, 0x00646B64, 0x00636A63, 0x00616861, 0x00606760, 0x00596059, 0x004E554E, 0x00454C45, 0x00424942,
        0x00444B44, 0x004A514A, 0x004E554E, 0x00545B54, 0x00585F58, 0x005E655E, 0x00636A63, 0x00646B64, 0x00616861, 0x005E655E, 0x005B625B, 0x00646660, 0x00656761, 0x00646660, 0x00646660, 0x00646660, 0x00666862, 0x006A6C66, 0x006D6F69, 0x0D797A78,
        0x368D8E8C, 0x75AAABA9, 0xB0C6C7C5, 0xE2DEDFDD, 0xFFF0F1EF, 0xFFFCFDFB, 0xFFFFFFFE, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFEFEFE, 0xFFFDFDFD, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFF, 0xFFFFFEFF, 0xFFFFFCFB, 0xFFFFFFFB, 0x86BBB9B1, 0x000E1108, 0x000E150E, 0x0009100B, 0x000D110B,
        0x000D110B, 0x000C100A, 0x000C100A, 0x000C100A, 0x000C100A, 0x000D110B, 0x000D110B, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000E120D, 0x000D110C, 0x000C100B, 0x00111510, 0x0010140F, 0x000E120D, 0x000D110C, 0x0010140F,
        0x00171B16, 0x0020241F, 0x00272B26, 0x00353933, 0x003E423C, 0x004A4E48, 0x00555953, 0x005C605A, 0x00626660, 0x00686C66, 0x006C706A, 0x00656963, 0x00646862, 0x00636761, 0x0061655F, 0x0061655F, 0x00626660, 0x00656963, 0x00686C66, 0x00626660,
        0x00626660, 0x00626660, 0x00636761, 0x00656963, 0x00676B65, 0x00686C66, 0x00686C66, 0x00656C65, 0x00646B64, 0x00636A63, 0x00626962, 0x00636A63, 0x00656C65, 0x00676E67, 0x00686F68, 0x00626962, 0x00646B64, 0x00666D66, 0x00656C65, 0x005F665F,
        0x00575E57, 0x004E554E, 0x00484F48, 0x00474E47, 0x00474E47, 0x00474E47, 0x004B524B, 0x00535A53, 0x005B625B, 0x00626962, 0x00666D66, 0x005F635D, 0x0060645E, 0x0061655F, 0x00626660, 0x00636761, 0x00626660, 0x0061655F, 0x0060645E, 0x00646863,
        0x00636762, 0x00616560, 0x00616560, 0x006B6F6A, 0x1D80847F, 0x4F999D98, 0x71A9ADA8, 0xCDD3D6D4, 0xE6E0E3E1, 0xFFF1F4F2, 0xFFFCFFFD, 0xFFFDFFFE, 0xFFFBFEFC, 0xFFFCFFFD, 0xFFFDFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE,
        0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFDFDFD, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFDFDFD, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFF, 0xFFFFFEFF, 0xFFFFFCFB, 0xFFFFFFFB, 0x69ADABA3, 0x000D1007, 0x00111811, 0x00060D08, 0x000C100A,
        0x000C100A, 0x000B0F09, 0x000B0F09, 0x000B0F09, 0x000B0F09, 0x000C100A, 0x000C100A, 0x000A0E09, 0x000A0E09, 0x000B0F0A, 0x000C100B, 0x000D110C, 0x000D110C, 0x000B0F0A, 0x000A0E09, 0x000E120D, 0x000F130E, 0x000F130E, 0x000E120D, 0x000E120D,
        0x000E120D, 0x000F130E, 0x00111510, 0x00131711, 0x00171B15, 0x001E221C, 0x00252923, 0x002E322C, 0x00393D37, 0x00474B45, 0x0050544E, 0x005D615B, 0x0061655F, 0x00676B65, 0x006A6E68, 0x006A6E68, 0x00686C66, 0x00666A64, 0x00656963, 0x00626660,
        0x00626660, 0x00626660, 0x0061655F, 0x0060645E, 0x0060645E, 0x0060645E, 0x0060645E, 0x005E655E, 0x005F665F, 0x00616861, 0x00626962, 0x00636A63, 0x00626962, 0x00616861, 0x00616861, 0x00656C65, 0x00656C65, 0x00656C65, 0x00656C65, 0x00656C65,
        0x00676E67, 0x00686F68, 0x00686F68, 0x00676E67, 0x00606760, 0x00565D56, 0x004F564F, 0x004A514A, 0x00474E47, 0x00454C45, 0x00434A43, 0x005A5E58, 0x005C605A, 0x005F635D, 0x00636761, 0x00666A64, 0x00666A64, 0x00636761, 0x0061655F, 0x00636762,
        0x00666A65, 0x00696D68, 0x00696D68, 0x00666A65, 0x00626661, 0x00616560, 0x00636762, 0x00606361, 0x006F7270, 0x2E878A88, 0x609FA2A0, 0x92B7BAB8, 0xC9D1D4D2, 0xFFEBEEEC, 0xFFFCFFFD, 0xFFFEFFFD, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFDFEFC,
        0xFFFEFFFD, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFF9F9FF, 0xFFFDFCFE, 0xFFFFFFFE, 0xFFFFFFFB, 0x439B9991, 0x00070A01, 0x000E150E, 0x00080F0A, 0x000C100A,
        0x000B0F09, 0x000B0F09, 0x000A0E08, 0x000A0E08, 0x000B0F09, 0x000B0F09, 0x000C100A, 0x000C0F0D, 0x000B0E0C, 0x000A0D0B, 0x00090C0A, 0x000A0D0B, 0x000C0F0D, 0x000D100E, 0x000E110F, 0x000C100B, 0x000E120D, 0x0010140F, 0x00121611, 0x00121611,
        0x00111510, 0x000F130E, 0x000E120D, 0x0011150F, 0x0011150F, 0x0010140E, 0x000F130D, 0x0010140E, 0x00131711, 0x00191D17, 0x001E221C, 0x002B2F29, 0x00343832, 0x0040443E, 0x004C504A, 0x00555953, 0x005E625C, 0x00656963, 0x006A6E68, 0x00646862,
        0x00656963, 0x00666A64, 0x00666A64, 0x00646862, 0x00636761, 0x00626660, 0x00626660, 0x00606760, 0x00616861, 0x00626962, 0x00626962, 0x00616861, 0x005F665F, 0x005D645D, 0x005C635C, 0x00626962, 0x00626962, 0x00626962, 0x00626962, 0x00616861,
        0x00606760, 0x00606760, 0x005F665F, 0x00606760, 0x00626962, 0x00636A63, 0x00656C65, 0x00646B64, 0x005F665F, 0x00575E57, 0x00515851, 0x00454C45, 0x00424942, 0x003F463F, 0x00404740, 0x00454C45, 0x004F564F, 0x00596059, 0x005F665F, 0x00606661,
        0x005E645F, 0x005E645F, 0x005F6560, 0x005F6560, 0x00606661, 0x00636964, 0x00686E69, 0x00676D68, 0x00646A65, 0x00606661, 0x005B615C, 0x005C625D, 0x00676D68, 0x0D777D78, 0x26848A85, 0x75ADAEAA, 0x9BBEBFBB, 0xD1D9DAD6, 0xFFF0F1ED, 0xFFFDFEFA,
        0xFFFFFFFC, 0xFFFFFFFC, 0xFFFEFFFB, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFF9F9FF, 0xFFFDFCFE, 0xFFFFFFFE, 0xFFFFFFFB, 0x268D8B83, 0x00040700, 0x00091009, 0x000B120D, 0x000B0F09,
        0x000B0F09, 0x000A0E08, 0x000A0E08, 0x000A0E08, 0x000A0E08, 0x000B0F09, 0x000B0F09, 0x000B0E0C, 0x000A0D0B, 0x000A0D0B, 0x00090C0A, 0x00080B09, 0x00090C0A, 0x000A0D0B, 0x000C0F0D, 0x00090D08, 0x00090D08, 0x000A0E09, 0x000B0F0A, 0x000C100B,
        0x000D110C, 0x000D110C, 0x000D110C, 0x000D110B, 0x000E120C, 0x0010140E, 0x0011150F, 0x0011150F, 0x0010140E, 0x0010140E, 0x0010140E, 0x000C100A, 0x0010140E, 0x00161A14, 0x001B1F19, 0x00232721, 0x002D312B, 0x00383C36, 0x0041453F, 0x00565A54,
        0x00595D57, 0x005E625C, 0x0061655F, 0x00626660, 0x00636761, 0x00646862, 0x00656963, 0x00626962, 0x00616861, 0x00606760, 0x005F665F, 0x005F665F, 0x00606760, 0x00626962, 0x00636A63, 0x00606760, 0x00606760, 0x005F665F, 0x005F665F, 0x00606760,
        0x00616861, 0x00626962, 0x00636A63, 0x00646B64, 0x00646B64, 0x00636A63, 0x00646B64, 0x00646B64, 0x00646B64, 0x00626962, 0x00616861, 0x00646B64, 0x00606760, 0x00596059, 0x00505750, 0x00474E47, 0x00414841, 0x003D443D, 0x003B423B, 0x00424942,
        0x00474E47, 0x00535A53, 0x00616861, 0x00686F68, 0x00666D66, 0x00616861, 0x005F665F, 0x00606661, 0x00626863, 0x00636964, 0x00636964, 0x00636964, 0x00636964, 0x00636964, 0x00646A65, 0x005E5F5B, 0x00636460, 0x006E6F6B, 0x117D7E7A, 0x43949591,
        0x7DB0B1AD, 0xB8CDCECA, 0xDEDFE0DC, 0xFFFCFCFC, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFF, 0xFFFEFDFF, 0xFFFFFFFE, 0xFFFFFEF9, 0x1987857D, 0x00060900, 0x00080F08, 0x000C130E, 0x000B0F09,
        0x000B0F09, 0x000A0E08, 0x000A0E08, 0x000A0E08, 0x000A0E08, 0x000B0F09, 0x000B0F09, 0x00080B09, 0x000A0D0B, 0x000D100E, 0x000D100E, 0x000C0F0D, 0x000B0E0C, 0x000A0D0B, 0x00090C0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000C100B, 0x000C100B,
        0x000C100B, 0x000B0F0A, 0x000A0E09, 0x000B0F09, 0x000B0F09, 0x000B0F09, 0x000C100A, 0x000E120C, 0x000F130D, 0x0010140E, 0x0011150F, 0x0011150F, 0x00131711, 0x00131711, 0x0011150F, 0x000F130D, 0x0010140E, 0x00161A14, 0x001A1E18, 0x001F231D,
        0x00272B25, 0x00333731, 0x0040443E, 0x004B4F49, 0x00545852, 0x005C605A, 0x0060645E, 0x00646B64, 0x00646B64, 0x00626962, 0x00616861, 0x00616861, 0x00606760, 0x00606760, 0x00606760, 0x005E655E, 0x005E655E, 0x005E655E, 0x005E655E, 0x005E655E,
        0x005D645D, 0x005D645D, 0x005D645D, 0x00616861, 0x00616861, 0x00616861, 0x00626962, 0x00626962, 0x00636A63, 0x00646B64, 0x00646B64, 0x00606760, 0x00616861, 0x00636A63, 0x00626962, 0x005F665F, 0x005C635C, 0x005B625B, 0x005A615A, 0x00505750,
        0x00484F48, 0x00424942, 0x00434A43, 0x00464D46, 0x004A514A, 0x004F564F, 0x00545B54, 0x005D635E, 0x005F6560, 0x00626863, 0x00656B66, 0x00666C67, 0x00646A65, 0x00616762, 0x005E645F, 0x00666763, 0x00676864, 0x00666763, 0x00636460, 0x0062635F,
        0x00656662, 0x006B6C68, 0x0071726E, 0x328A8A8A, 0x589B9B9B, 0x92B8B8B8, 0xD5D7D7D7, 0xFFEEEEEE, 0xFFFAFAFA, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFEFEFE, 0xFFFEFEFE, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFFFF,
        0xFFFDFFFF, 0xFFFCFEFE, 0xFFFAFFFE, 0xFFFAFFFE, 0xFFFBFFFF, 0xFFFAFFFF, 0xFFFAFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFEFEFE,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFDFF, 0xFFFFFFFF, 0xFFFCFDF9, 0xFFFFFFF9, 0x00696C63, 0x00070903, 0x0010110D, 0x000B0C0A, 0x000A0E08,
        0x000A0E08, 0x000A0E08, 0x000A0E08, 0x000A0E08, 0x000A0E08, 0x000A0E08, 0x000A0E08, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09,
        0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000E120D, 0x000E120D, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x0010140F, 0x0010140F, 0x0010140F,
        0x00121611, 0x00141813, 0x00171B16, 0x001C201B, 0x00242823, 0x002E322D, 0x00343833, 0x00454943, 0x004C504A, 0x00555953, 0x005D615B, 0x00636761, 0x00656963, 0x00666A64, 0x00676B65, 0x00636761, 0x00626660, 0x0061655F, 0x00626660, 0x00646862,
        0x00646862, 0x00636761, 0x0061655F, 0x00616861, 0x00626962, 0x00626962, 0x00616861, 0x00616861, 0x00616861, 0x00646B64, 0x00666D66, 0x00676B65, 0x00676B65, 0x00686C66, 0x00696D67, 0x00696D67, 0x00696D67, 0x00686C66, 0x00676B65, 0x00696D67,
        0x00676B65, 0x00646862, 0x00646862, 0x00626660, 0x005B5F59, 0x004E524C, 0x00444842, 0x00434741, 0x00464A44, 0x004D514B, 0x00545852, 0x005A5E58, 0x005E625C, 0x0060645E, 0x0061655F, 0x0061655F, 0x00636761, 0x00656963, 0x00666A64, 0x00676B65,
        0x00676B65, 0x00666A64, 0x00656963, 0x00626A60, 0x00626A60, 0x00636A63, 0x00666D66, 0x00727873, 0x328A908B, 0x71A7ADA8, 0x9BBBC0BE, 0xE6E1E2E0, 0xFFEFF0EE, 0xFFFDFEFC, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFEFFFD, 0xFFFEFDFF,
        0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE,
        0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFDFDFD, 0xFFFCFCFC, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFDFDFD, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFCFCFC, 0xFFFFFFFF,
        0xFFFDFDFD, 0xFFFBFBFB, 0xFFFDFDFD, 0xFFFDFFFF, 0xFFFDFFFF, 0xFFFBFFFF, 0xFFF9FEFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFCFF, 0xFFFFFFFF, 0xFFFDFEFA, 0xFFFFFFF9, 0x0064675E, 0x00060802, 0x000F100C, 0x000C0D0B, 0x000A0E08,
        0x000A0E08, 0x000A0E08, 0x000A0E08, 0x000A0E08, 0x000A0E08, 0x000A0E08, 0x000A0E08, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09,
        0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D110C, 0x000D110C, 0x000D110C, 0x000D110C, 0x000D110C, 0x000E120D, 0x000E120D, 0x000E120D, 0x0010140F,
        0x00111510, 0x00111510, 0x00121611, 0x00121611, 0x00141813, 0x00181C17, 0x001B1F1A, 0x00191D17, 0x001E221C, 0x00272B25, 0x00323630, 0x003E423C, 0x00494D47, 0x00535751, 0x00595D57, 0x0060645E, 0x0061655F, 0x00636761, 0x00656963, 0x00656963,
        0x00636761, 0x0060645E, 0x005D615B, 0x00616861, 0x00616861, 0x00606760, 0x005E655E, 0x005E655E, 0x005F665F, 0x00626962, 0x00656C65, 0x0061655F, 0x0061655F, 0x00626660, 0x00646862, 0x00676B65, 0x006A6E68, 0x006D716B, 0x006F736D, 0x006B6F69,
        0x006A6E68, 0x006A6E68, 0x006A6E68, 0x006B6F69, 0x006A6E68, 0x00686C66, 0x00676B65, 0x00636761, 0x005E625C, 0x00565A54, 0x004E524C, 0x004A4E48, 0x00494D47, 0x004A4E48, 0x004C504A, 0x00575B55, 0x005B5F59, 0x0060645E, 0x00656963, 0x00686C66,
        0x00696D67, 0x00686C66, 0x00676B65, 0x00636B61, 0x00656D63, 0x00666D66, 0x00646B64, 0x00606661, 0x005E645F, 0x00606661, 0x00636866, 0x006C6D6B, 0x1D80817F, 0x549B9C9A, 0x8AB4B5B3, 0xB8CBCCCA, 0xEEE4E5E3, 0xFFFAFBF9, 0xFFFFFFFE, 0xFFFEFEFE,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFDFDFD, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFDFDFD, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFFFDFE,
        0xFFFFFEFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFDFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFCFCFC, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFCFF, 0xFFFFFFFF, 0xFFFEFFFB, 0xFFFCFFF6, 0x005B5E55, 0x00060802, 0x000F100C, 0x000D0E0C, 0x000A0E08,
        0x000A0E08, 0x000A0E08, 0x000A0E08, 0x000A0E08, 0x000A0E08, 0x000A0E08, 0x000A0E08, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09,
        0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000C100B, 0x000C100B, 0x000C100B, 0x000C100B, 0x000D110C,
        0x000F130E, 0x0010140F, 0x0010140F, 0x0010140F, 0x000F130E, 0x0010140F, 0x00111510, 0x00141812, 0x00151913, 0x00171B15, 0x00191D17, 0x001C201A, 0x0021251F, 0x00272B25, 0x002B2F29, 0x003E423C, 0x00434741, 0x004C504A, 0x00555953, 0x005C605A,
        0x0061655F, 0x00656963, 0x00676B65, 0x00616861, 0x00616861, 0x00616861, 0x00606760, 0x005E655E, 0x005D645D, 0x005E655E, 0x005F665F, 0x00656963, 0x00656963, 0x00676B65, 0x00676B65, 0x00676B65, 0x00666A64, 0x00666A64, 0x00656963, 0x00686C66,
        0x00696D67, 0x006A6E68, 0x00696D67, 0x00676B65, 0x00686C66, 0x006B6F69, 0x006E726C, 0x00696D67, 0x006A6E68, 0x006B6F69, 0x006A6E68, 0x00686C66, 0x00636761, 0x005E625C, 0x005B5F59, 0x004E524C, 0x004E524C, 0x004E524C, 0x0050544E, 0x00555953,
        0x005C605A, 0x00636761, 0x00676B65, 0x00656D63, 0x00676F65, 0x00697069, 0x006A716A, 0x00696F6A, 0x00696F6A, 0x006A706B, 0x006B706E, 0x00666765, 0x00686967, 0x00676866, 0x00656664, 0x00696A68, 0x0D787977, 0x368C8D8B, 0x4F989997, 0xABC3C3C3,
        0xC9D2D2D2, 0xFBE9E9E9, 0xFFFAFAFA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFAFAFA, 0xFFFCFCFC, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFF,
        0xFFFFFEFF, 0xFFFFFDFE, 0xFFFFFDFE, 0xFFFFFDFD, 0xFFFFFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFDFDFD, 0xFFFEFEFE, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFCFF, 0xFFFFFFFF, 0xFFFFFFFC, 0xFFF6F9F0, 0x004F5249, 0x00050701, 0x000E0F0B, 0x000E0F0D, 0x000A0E08,
        0x000A0E08, 0x000A0E08, 0x000A0E08, 0x000A0E08, 0x000A0E08, 0x000A0E08, 0x000A0E08, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09,
        0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000A0E09, 0x000A0E09, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000C100B, 0x000C100B, 0x000B0F0A,
        0x000D110C, 0x000F130E, 0x0010140F, 0x00111510, 0x00111510, 0x00111510, 0x00121611, 0x000F130D, 0x0011150F, 0x00131711, 0x00151913, 0x00151913, 0x00171B15, 0x00191D17, 0x001B1F19, 0x00161A14, 0x001B1F19, 0x00232721, 0x002C302A, 0x00353933,
        0x003F433D, 0x00484C46, 0x004E524C, 0x005E625C, 0x0061655F, 0x00656963, 0x00686C66, 0x00686C66, 0x00686C66, 0x00676B65, 0x00676B65, 0x0060645E, 0x00626660, 0x00656963, 0x00676B65, 0x00686C66, 0x00686C66, 0x00686C66, 0x00686C66, 0x00666A64,
        0x00676B65, 0x00686C66, 0x00676B65, 0x00666A64, 0x00666A64, 0x00686C66, 0x00696D67, 0x00656963, 0x00666A64, 0x00676B65, 0x00686C66, 0x00696D67, 0x00696D67, 0x00686C66, 0x00686C66, 0x006D716B, 0x006A6E68, 0x00656963, 0x005F635D, 0x00585C56,
        0x0051554F, 0x004C504A, 0x00494D47, 0x0051594F, 0x00555D53, 0x005C635C, 0x00636A63, 0x00686E69, 0x006B716C, 0x006B716C, 0x006B706E, 0x006B6F6A, 0x006E726D, 0x0070746F, 0x006E726D, 0x006B6F6A, 0x006A6E69, 0x006C706B, 0x006E726D, 0x006B6C6A,
        0x00737472, 0x1D80817F, 0x43929391, 0x71A8A9A7, 0xA7C3C4C2, 0xE2DEDFDD, 0xFFEFF0EE, 0xFFFEFFFD, 0xFFFEFFFD, 0xFFFEFFFD, 0xFFFEFFFD, 0xFFFDFEFC, 0xFFFDFEFC, 0xFFFEFFFD, 0xFFFFFFFE, 0xFFFDFEFC, 0xFFFDFEFC, 0xFFFDFEFC, 0xFFFEFFFD, 0xFFFFFFFE,
        0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFEFEFE,
        0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFCFCFC, 0xFFFDFDFD, 0xFFFEFEFE, 0xFFFFFEFF,
        0xFFFFFCFD, 0xFFFEF9FA, 0xFFFFFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFDFF, 0xFFFFFFFF, 0xFFFFFFFC, 0xFBEFF2E9, 0x0044473E, 0x00060802, 0x000D0E0A, 0x000E0F0D, 0x000A0E08,
        0x000A0E08, 0x000A0E08, 0x000A0E08, 0x000A0E08, 0x000A0E08, 0x000A0E08, 0x000A0E08, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09,
        0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000C100B, 0x000C100B, 0x000C100B, 0x000C100B, 0x000C100B, 0x000C100B,
        0x000C100B, 0x000B0F0A, 0x000B0F0A, 0x000C100B, 0x000C100B, 0x000C100B, 0x000C100B, 0x000C100A, 0x000F130D, 0x0011150F, 0x00131711, 0x00131711, 0x00131711, 0x00131711, 0x00141812, 0x00151913, 0x00171B15, 0x00181C16, 0x00181C16, 0x00191D17,
        0x001A1E18, 0x001E221C, 0x0021251F, 0x0030342E, 0x00363A34, 0x0040443E, 0x004B4F49, 0x00555953, 0x005E625C, 0x00666A64, 0x006B6F69, 0x00686C66, 0x00696D67, 0x006A6E68, 0x00696D67, 0x00676B65, 0x00676B65, 0x00686C66, 0x006A6E68, 0x00656963,
        0x00646862, 0x00636761, 0x00656963, 0x00676B65, 0x00696D67, 0x00696D67, 0x00686C66, 0x006E726C, 0x006C706A, 0x00696D67, 0x00676B65, 0x00676B65, 0x00696D67, 0x006C706A, 0x006E726C, 0x00676B65, 0x00676B65, 0x00696D67, 0x00696D67, 0x00696D67,
        0x00686C66, 0x00666A64, 0x00656963, 0x00575F55, 0x00525A50, 0x004C534C, 0x00495049, 0x004B514C, 0x00515752, 0x00585E59, 0x005C615F, 0x006E726D, 0x006F736E, 0x0070746F, 0x00717570, 0x006F736E, 0x006E726D, 0x0070746F, 0x00727671, 0x00777874,
        0x00757672, 0x0071726E, 0x006D6E6A, 0x006C6D69, 0x0072736F, 0x0D7B7C78, 0x1D838480, 0x43939492, 0x75ABACAA, 0xBCCDCECC, 0xF7E9EAE8, 0xFFF8F9F7, 0xFFFEFFFD, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE,
        0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFEFEFE, 0xFFFDFDFD, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFE,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFDFD, 0xFFF9FBFB, 0xFFF9FEFD, 0xFFFBFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFDFDFD, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFF, 0xFFFFFFFF, 0xFFFFFFFC, 0xEAE8EBE2, 0x00393C33, 0x00070903, 0x000D0E0A, 0x000E0F0D, 0x00090D07,
        0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08,
        0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000B0F0A, 0x000B0F0A, 0x000C100B, 0x000C100B, 0x000C100B, 0x000C100B, 0x000D110C, 0x000D110C, 0x000C100B,
        0x000B0F0A, 0x000A0E09, 0x000A0E09, 0x000B0F0A, 0x000C100B, 0x000C100B, 0x000C100B, 0x000A0E08, 0x000B0F09, 0x000C100A, 0x000D110B, 0x000D110B, 0x0010140E, 0x00131711, 0x00161A14, 0x00181C16, 0x00191D17, 0x001B1F19, 0x001B1F19, 0x001A1E18,
        0x00181C16, 0x00161A14, 0x00161A14, 0x0012140E, 0x00151711, 0x001A1C16, 0x0021231D, 0x002A2C26, 0x00353731, 0x0040423C, 0x00474943, 0x00555953, 0x005B5F59, 0x00636761, 0x00696D67, 0x006B6F69, 0x006B6F69, 0x006D716B, 0x006E726C, 0x0070746E,
        0x006C706A, 0x00686C66, 0x00666A64, 0x00676B65, 0x00676B65, 0x00656963, 0x00646862, 0x0061655F, 0x00636761, 0x00666A64, 0x00686C66, 0x00696D67, 0x00686C66, 0x00676B65, 0x00666A64, 0x006D716B, 0x006C706A, 0x006A6E68, 0x00696D67, 0x00696D67,
        0x00696D67, 0x006A6E68, 0x006B6F69, 0x00656D63, 0x00666E64, 0x00666D66, 0x00656C65, 0x00606661, 0x00595F5A, 0x00525853, 0x004D5250, 0x004D534E, 0x00505651, 0x00585E59, 0x00616762, 0x00686E69, 0x006A706B, 0x006D736E, 0x00707671, 0x0072746E,
        0x0072746E, 0x0071736D, 0x0070726C, 0x006E706A, 0x006E706A, 0x006F716B, 0x0070726C, 0x006A6B67, 0x006C6D69, 0x006E6F6B, 0x0072736F, 0x157F807C, 0x4B999A96, 0x92BABBB7, 0xC4D2D3CF, 0xFBECEDE9, 0xFFF2F3EF, 0xFFFCFDF9, 0xFFFFFFFC, 0xFFFFFFFC,
        0xFFFFFFFC, 0xFFFEFFFB, 0xFFFCFDF9, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFDFDFD, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFF8F8F8, 0xFFF9F9F9, 0xFFF8F8F8, 0xFFF5F5F5, 0xFFF3F3F3, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFCFCFC, 0xFFFDFDFD, 0xFFFEFEFE,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFBFBFB, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFF9FEFD,
        0xFFFBFFFF, 0xFFF7FCFB, 0xF7E8EEED, 0xD5D7DDDC, 0xCDD3D9D8, 0xE2DDE5E4, 0xFFEBF3F2, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFCFCFC, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFF9F9F9, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFF, 0xFFFEFEFE, 0xFFFFFFFC, 0xE2E3E6DD, 0x0032352C, 0x00080A04, 0x000C0D09, 0x000D0E0C, 0x00090D07,
        0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08,
        0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000C100B, 0x000C100B, 0x000C100B, 0x000B0F0A,
        0x000A0E09, 0x000A0E09, 0x000B0F0A, 0x000D110C, 0x000F130E, 0x000F130E, 0x000E120D, 0x000D110B, 0x000D110B, 0x000D110B, 0x000B0F09, 0x000A0E08, 0x000B0F09, 0x000E120C, 0x0010140E, 0x000C100A, 0x000D110B, 0x0010140E, 0x00141812, 0x00181C16,
        0x001A1E18, 0x001B1F19, 0x001B1F19, 0x0020221C, 0x001F211B, 0x001C1E18, 0x00191B15, 0x00161812, 0x00171913, 0x00191B15, 0x001B1D17, 0x0020241E, 0x00292D27, 0x00383C36, 0x00454943, 0x0051554F, 0x005B5F59, 0x00646862, 0x006A6E68, 0x006C706A,
        0x006D716B, 0x006E726C, 0x006C706A, 0x006A6E68, 0x00686C66, 0x00676B65, 0x00666A64, 0x00676B65, 0x00676B65, 0x00676B65, 0x00676B65, 0x00676B65, 0x00676B65, 0x00676B65, 0x00676B65, 0x00676B65, 0x00696D67, 0x006D716B, 0x006F736D, 0x006F736D,
        0x006D716B, 0x00696D67, 0x00676B65, 0x00636B61, 0x00646C62, 0x00666D66, 0x00666D66, 0x00666C67, 0x00666C67, 0x00676D68, 0x00676C6A, 0x00646B64, 0x005C635C, 0x00545B54, 0x00505750, 0x004E554E, 0x004E554E, 0x00525952, 0x00575E57, 0x00696C63,
        0x006C6F66, 0x0072756C, 0x00777A71, 0x007A7D74, 0x00797C73, 0x0075786F, 0x0072756C, 0x006E6F6B, 0x0071726E, 0x00747571, 0x00737470, 0x0071726E, 0x0070716D, 0x0070716D, 0x0072736F, 0x157E7F7B, 0x328D8E8A, 0x69A6A7A3, 0x9BBFC0BC, 0xCDD6D7D3,
        0xF7EBECE8, 0xFFFCFDF9, 0xFFFFFFFC, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFEDEDED, 0xFBE9E9E9, 0xEEE4E4E4, 0xDEDCDCDC, 0xD1D6D6D6, 0xD1D5D5D5, 0xD5D7D7D7, 0xDEDBDBDB, 0xEAE1E1E1, 0xF7E7E7E7,
        0xFFEDEDED, 0xFFF1F1F1, 0xFFF4F4F4, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFF4F4F4, 0xFBEAEAEA, 0xFBEAEAEA, 0xFFF2F2F2, 0xFFFBFBFB, 0xFFFEFEFE, 0xFFFDFDFD, 0xFFFAFFFF,
        0xFFEDF3F2, 0xCDD3DBDA, 0x9FBDC5C4, 0x00B1B9B8, 0x00B1BCBA, 0x9BBCC7C5, 0xB0C6D1CF, 0xC9D2D2D2, 0xD5D8D8D8, 0xDEDBDBDB, 0xD5D7D7D7, 0xC4CFCFCF, 0xB8CACACA, 0xC0CECECE, 0xCDD4D4D4, 0xFFECECEC, 0xFFF2F2F2, 0xFFFAFAFA, 0xFFFEFEFE, 0xFFFEFEFE,
        0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFF, 0xFFFEFEFE, 0xFFFFFFFC, 0xD9E0E3DA, 0x002E3128, 0x00090B05, 0x000C0D09, 0x000C0D0B, 0x00090D07,
        0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08,
        0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A,
        0x000A0E09, 0x00090D08, 0x000A0E09, 0x000C100B, 0x000C100B, 0x000A0E09, 0x00080C07, 0x00080C06, 0x00090D07, 0x000B0F09, 0x000B0F09, 0x000A0E08, 0x000A0E08, 0x000B0F09, 0x000C100A, 0x00121610, 0x0010140E, 0x000E120C, 0x000F130D, 0x00121610,
        0x00161A14, 0x00171B15, 0x00181C16, 0x00191B15, 0x001B1D17, 0x001C1E18, 0x001C1E18, 0x001B1D17, 0x00191B15, 0x00191B15, 0x001A1C16, 0x00161A14, 0x00161A14, 0x00151913, 0x00151913, 0x00191D17, 0x00232721, 0x0031352F, 0x003B3F39, 0x00484C46,
        0x00525650, 0x005E625C, 0x00656963, 0x00676B65, 0x00676B65, 0x00696D67, 0x006C706A, 0x00676B65, 0x00676B65, 0x00676B65, 0x00676B65, 0x00666A64, 0x00676B65, 0x00676B65, 0x00676B65, 0x00666A64, 0x00666A64, 0x00666A64, 0x00666A64, 0x00676B65,
        0x00696D67, 0x006A6E68, 0x006B6F69, 0x00687066, 0x00697167, 0x00697069, 0x00686F68, 0x00666C67, 0x00656B66, 0x00646A65, 0x00656A68, 0x00666D66, 0x00646B64, 0x00656C65, 0x00697069, 0x00686F68, 0x00616861, 0x005B625B, 0x005A615A, 0x0052554C,
        0x0051544B, 0x0052554C, 0x00575A51, 0x0060635A, 0x006A6D64, 0x0071746B, 0x0074776E, 0x00797A76, 0x00787975, 0x00767773, 0x00757672, 0x00767773, 0x00757672, 0x00737470, 0x0071726E, 0x006D6E6A, 0x006D6E6A, 0x006D6E6A, 0x006D6E6A, 0x00737470,
        0x1D82837F, 0x47969793, 0x69A6A7A3, 0xBCCBCBCB, 0xE2DDDDDD, 0xFFF3F3F3, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xF7E8EAEA, 0xEAE1E3E3, 0x00DDDFDF, 0x00D3D5D5, 0x00C7C9C9, 0x00B4B9B8, 0x00AFB4B3, 0x00AFB4B3, 0x00B1B6B5, 0x7DADB2B1,
        0x79ACB1B0, 0x86B1B6B5, 0x8AB4B9B8, 0x9BBBC0BF, 0xB0C6CBCA, 0xC0CED3D2, 0xE6E0E5E4, 0xE2DEE3E2, 0xF2E6EBEA, 0xFFEBF0EF, 0xFFF1F6F5, 0xE6DFE5E4, 0x7DADB3B2, 0x60A0A6A5, 0x82B0B8B7, 0x79ACB4B3, 0xA3BFCAC8, 0xABC4CFCD, 0xD1D6E1DF, 0xC9D2DDDB,
        0x96BAC5C3, 0x7DADB8B6, 0x00AEBBB9, 0x00B3C0BE, 0x00B9C7C5, 0x00BDCBC9, 0x00BCCAC8, 0x00B0B8B7, 0x00A7B2B0, 0x00A0ABA9, 0x0097A5A1, 0x00A4B2AE, 0x00A2B2AB, 0x00A3B5AE, 0x4F98AAA3, 0x64A2ACA6, 0x6DA6B0AA, 0x8EB6BDB8, 0xBCCBD2CF, 0xD9DADFDD,
        0xF2E5E7E7, 0xFFF1F3F3, 0xFFFDFFFF, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFFFDFD, 0xFFFFFEFE, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFDFE, 0xFFFFFDFF, 0xFFFFFBFC, 0xFFFFFFFC, 0xC0D5D6CD, 0x0021241B, 0x000E100A, 0x000A0E09, 0x000A0D0B, 0x00080C06,
        0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08,
        0x00090D08, 0x00090D08, 0x00090D08, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000D0E0A,
        0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000D0E0A, 0x000D0E0A, 0x000E0F0B, 0x000C100B, 0x000C100B, 0x000A100B, 0x000B110C, 0x000B110C, 0x000D110C, 0x000D110C, 0x000D110C, 0x000D110C, 0x000E120D,
        0x000E120D, 0x000E120D, 0x000E120D, 0x00141813, 0x00141813, 0x00161A15, 0x00181C17, 0x001A1E19, 0x001B1F1A, 0x001D211C, 0x001E221D, 0x00181C16, 0x00171B15, 0x00161A14, 0x00151913, 0x00141812, 0x00131711, 0x00121610, 0x00121610, 0x001C201B,
        0x001F231E, 0x00252924, 0x0030342F, 0x003D413C, 0x004C504B, 0x00585C57, 0x005F635E, 0x00646862, 0x00656963, 0x00676B65, 0x00696D67, 0x006A6E68, 0x00696D67, 0x00696D67, 0x00686C66, 0x00656963, 0x00656963, 0x00656963, 0x00666A64, 0x00676B65,
        0x00676B65, 0x00676B65, 0x00676B65, 0x00676B65, 0x00676B65, 0x00686C66, 0x00696D67, 0x006A6E68, 0x006B6F69, 0x006C706A, 0x006B6F69, 0x006A6E68, 0x006A6E68, 0x00696D67, 0x00676B65, 0x00656963, 0x00646862, 0x00666A64, 0x00676B65, 0x006C706A,
        0x00696D67, 0x00636761, 0x005D615B, 0x00565A54, 0x00525650, 0x004E524C, 0x004D514B, 0x005D6259, 0x0062675E, 0x00696D67, 0x0070746E, 0x00757974, 0x00767A75, 0x00757974, 0x00747775, 0x00757771, 0x00757771, 0x00767872, 0x00757771, 0x0072746E,
        0x006F716B, 0x006C6E68, 0x006A6C66, 0x006F716B, 0x00757771, 0x1D848680, 0x4F9C9E98, 0x86B5B7B1, 0xB8CED0CA, 0xEEE7E9E3, 0xFFF9FBF5, 0xFFFEFFFD, 0xFFFEFFFD, 0xFFFFFFFE, 0xFFFDFEFC, 0xFFFCFDFB, 0xFFFFFFFE, 0xFFFEFFFD, 0xFFFCFDFB, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFEFEFE, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xF2E5E7E7, 0x00DCDEDE, 0x00D4D6D6, 0x00C5C7C7, 0x00B6B8B8, 0x009EA4A3, 0x009EA4A3, 0x00959B9A, 0x00929897, 0x00969C9B,
        0x008F9594, 0x00878D8C, 0x008D9392, 0x009AA09F, 0x00B6BCBB, 0x00ADB3B2, 0x009DA3A2, 0x009FA5A4, 0x82B0B6B5, 0x7DAEB4B3, 0x9BBBC1C0, 0x7DADB3B2, 0x00989E9D, 0x00959D9C, 0x00A6AEAD, 0x009EA6A5, 0x009BA6A4, 0x009DA8A6, 0x00A5B0AE, 0x009CA7A5,
        0x00A0ABA9, 0x00A3AEAC, 0x00A3B0AE, 0x00AAB7B5, 0x00B5C3C1, 0x00B8C6C4, 0x00AFBDBB, 0x00B3BEBC, 0x00ADB8B6, 0x00AFBAB8, 0x00ACBAB6, 0x00BDCBC7, 0x00BBCBC4, 0x00B3C3BC, 0x00A9B9B2, 0x00A0ACA6, 0x0099A59F, 0x0098A29C, 0x009EA7A4, 0x00A5ACA9,
        0x71A7ADAC, 0x7DAEB3B2, 0x92B7BCBB, 0xC9D2D7D6, 0xE2DDDFDF, 0xFBE9EBEB, 0xFFF4F6F6, 0xFFFBFBFB, 0xFFFDFDFD, 0xFFFFFDFD, 0xFFFFFEFE, 0xFFFFFDFF, 0xFFFFFFFF, 0xFFFFFFFC, 0xB4D0D1C8, 0x001A1D14, 0x00090B05, 0x000A0E09, 0x000B0E0C, 0x00080C06,
        0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08,
        0x00090D08, 0x00090D08, 0x00090D08, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000C0D09,
        0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000E0F0B, 0x000E0F0B, 0x000D0E0A, 0x000D0E0A, 0x000E0F0B, 0x000C100B, 0x000C100B, 0x000A100B, 0x000B110C, 0x000B110C, 0x000D110C, 0x000D110C, 0x000D110C, 0x000D110C, 0x000E120D,
        0x000E120D, 0x000E120D, 0x000E120D, 0x000F130E, 0x0010140F, 0x00111510, 0x00121611, 0x00141813, 0x00151914, 0x00161A15, 0x00171B16, 0x00181C16, 0x00181C16, 0x00181C16, 0x00171B15, 0x00171B15, 0x00171B15, 0x00171B15, 0x00171B15, 0x00131712,
        0x00131712, 0x00131712, 0x00161A15, 0x001A1E19, 0x001F231E, 0x00242823, 0x00272B26, 0x00383C36, 0x0040443E, 0x004D514B, 0x005B5F59, 0x00656963, 0x006A6E68, 0x006B6F69, 0x006A6E68, 0x006B6F69, 0x006B6F69, 0x00696D67, 0x00686C66, 0x00666A64,
        0x00666A64, 0x00666A64, 0x00676B65, 0x00656963, 0x00666A64, 0x00676B65, 0x00696D67, 0x006A6E68, 0x006B6F69, 0x006B6F69, 0x006B6F69, 0x006C706A, 0x006D716B, 0x006F736D, 0x006E726C, 0x006C706A, 0x00696D67, 0x00686C66, 0x00676B65, 0x00646862,
        0x00646862, 0x00636761, 0x00636761, 0x00636761, 0x00636761, 0x00646862, 0x00646862, 0x00575C53, 0x00555A51, 0x00525650, 0x0051554F, 0x00555954, 0x005D615C, 0x00656964, 0x006A6D6B, 0x00787A74, 0x00797B75, 0x007A7C76, 0x007B7D77, 0x007B7D77,
        0x007A7C76, 0x007A7C76, 0x00797B75, 0x00767872, 0x0071736D, 0x006E706A, 0x006D6F69, 0x006D6F69, 0x0070726C, 0x08797B75, 0x1981837D, 0x69A4A5A3, 0x8AB4B5B3, 0xCDD5D6D4, 0xFFECEDEB, 0xFFFDFEFC, 0xFFFFFFFE, 0xFFFEFFFD, 0xFFFFFFFE, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xF7E7E9E9, 0xE2DEE0E0, 0x00D4D6D6, 0x00C2C4C4, 0x00B2B4B4, 0x008C9493, 0x008E9695, 0x00798180, 0x006E7675, 0x0078807F,
        0x006E7675, 0x005F6766, 0x0068706F, 0x00707B79, 0x009AA5A3, 0x009EA9A7, 0x00717C7A, 0x006D7876, 0x00B2BDBB, 0x00B5C0BE, 0x008E9997, 0x00969C9B, 0x00919998, 0x00919998, 0x00A2AAA9, 0x00A6B1AF, 0x009BA6A4, 0x00A4B1AF, 0x0099A6A4, 0x009FAAA8,
        0x00ABB6B4, 0x00ADB8B6, 0x009FACAA, 0x009AA7A5, 0x009EACAA, 0x00A1AFAD, 0x00A0AEAC, 0x00AAB7B5, 0x0098A5A3, 0x009EABA9, 0x009CAAA6, 0x00ACBAB6, 0x00AFBDB7, 0x00A9B7B1, 0x00A6B6AF, 0x009EACA6, 0x009BA9A3, 0x009FABA5, 0x00A3AEAB, 0x00A2ADAA,
        0x009FAAA8, 0x00A0ABA9, 0x00A5B0AE, 0x009FA7A6, 0x00A2AAA9, 0x6DA6AEAD, 0x7DADB3B2, 0x92B7BDBC, 0xB4C7CDCC, 0xDEDBE0DF, 0xFBE9EEED, 0xFFF5F4F8, 0xFFFCFCFC, 0xFFFFFFFC, 0xA7C7CAC1, 0x00181B12, 0x00070B05, 0x00090D08, 0x00090C0A, 0x00080C06,
        0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08,
        0x00090D08, 0x00090D08, 0x00090D08, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000C0D09,
        0x000C0D09, 0x000C0D09, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000E0F0B, 0x000D0E0A, 0x000D0E0A, 0x000E0F0B, 0x000C100B, 0x000C100B, 0x000A100B, 0x000B110C, 0x000B110C, 0x000D110C, 0x000D110C, 0x000D110C, 0x000D110C, 0x000E120D,
        0x000E120D, 0x000E120D, 0x000E120D, 0x000D110C, 0x000D110C, 0x000E120D, 0x000F130E, 0x0010140F, 0x00111510, 0x00111510, 0x00111510, 0x00151913, 0x00151913, 0x00161A14, 0x00161A14, 0x00171B15, 0x00181C16, 0x00181C16, 0x00191D17, 0x00181C17,
        0x00161A15, 0x00141813, 0x00121611, 0x00111510, 0x00111510, 0x00111510, 0x00121611, 0x00171B15, 0x00181C16, 0x001C201A, 0x00232721, 0x002E322C, 0x003B3F39, 0x00474B45, 0x004E524C, 0x005B5F59, 0x0061655F, 0x00676B65, 0x006B6F69, 0x006C706A,
        0x006C706A, 0x006C706A, 0x006D716B, 0x00696D67, 0x00696D67, 0x00676B65, 0x00666A64, 0x00656963, 0x00666A64, 0x00686C66, 0x006A6E68, 0x006C706A, 0x006D716B, 0x006C706A, 0x006B6F69, 0x00696D67, 0x00696D67, 0x006A6E68, 0x006C706A, 0x00676B65,
        0x00676B65, 0x00676B65, 0x00666A64, 0x00656963, 0x00646862, 0x00636761, 0x00636761, 0x006D7269, 0x006D7269, 0x006C706A, 0x00696D67, 0x00646863, 0x005E625D, 0x00595D58, 0x00565957, 0x00575953, 0x005B5D57, 0x0062645E, 0x006A6C66, 0x0072746E,
        0x00787A74, 0x007C7E78, 0x007E807A, 0x007A7C76, 0x00797B75, 0x00797B75, 0x00787A74, 0x00747670, 0x006E706A, 0x006A6C66, 0x006A6C66, 0x00646563, 0x00626361, 0x00686967, 0x04747573, 0x2E898A88, 0x60A0A19F, 0x9FBFC0BE, 0xF2E6E7E5, 0xFFFDFDFD,
        0xFFFFFFFF, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFECEEEE, 0xEEE4E6E6, 0x00D8DADA, 0x00C6C8C8, 0x00B6B8B8, 0x0097A2A0, 0x009AA5A3, 0x0085908E, 0x0076817F, 0x00798482,
        0x006A7573, 0x00576260, 0x005D6866, 0x0064716F, 0x00626F6D, 0x00515E5C, 0x005F6C6A, 0x0097A4A2, 0x00AEBBB9, 0x00869391, 0x0093A09E, 0x008B9392, 0x00899190, 0x00858D8C, 0x008E9997, 0x0099A4A2, 0x0093A09E, 0x00B7C4C2, 0x00A4B1AF, 0x0097A2A0,
        0x00A5B0AE, 0x00B2BDBB, 0x00B2BFBD, 0x00A5B2B0, 0x0093A19F, 0x00909E9C, 0x009AA8A6, 0x0094A2A0, 0x00798785, 0x008D9A98, 0x008E9C98, 0x00909E9A, 0x008F9D97, 0x008B9993, 0x008B9791, 0x008F9D97, 0x0097A59F, 0x00A2B0AA, 0x00A6B4B0, 0x009DACA8,
        0x0092A09E, 0x00909E9C, 0x0095A3A1, 0x0098A6A4, 0x0098A6A4, 0x0096A3A1, 0x00929F9D, 0x008E9B99, 0x00909B99, 0x00939E9C, 0x4B96A19F, 0x8EB5B8BC, 0x9FBDC2C1, 0xBCCBD1CC, 0x60A3A89F, 0x000E130A, 0x00080C06, 0x000C100B, 0x000B0E0C, 0x00080C06,
        0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08,
        0x00090D08, 0x00090D08, 0x00090D08, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000C0D09,
        0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000E0F0B, 0x000C100B, 0x000C100B, 0x000A100B, 0x000B110C, 0x000B110C, 0x000D110C, 0x000D110C, 0x000D110C, 0x000D110C, 0x000E120D,
        0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000F130E, 0x000F130E, 0x000F130E, 0x0010140F, 0x0010140F, 0x0010140F, 0x0010140E, 0x0010140E, 0x0011150F, 0x00121610, 0x00131711, 0x00141812, 0x00141812, 0x00151913, 0x00181C17,
        0x00181C17, 0x00171B16, 0x00161A15, 0x00151914, 0x00151914, 0x00151914, 0x00151914, 0x000F130D, 0x000F130D, 0x000E120C, 0x000E120C, 0x00121610, 0x00171B15, 0x001C201A, 0x001F231D, 0x00292D27, 0x00323630, 0x0041453F, 0x004E524C, 0x00585C56,
        0x0060645E, 0x00686C66, 0x006D716B, 0x006C706A, 0x006D716B, 0x006F736D, 0x006F736D, 0x006E726C, 0x006D716B, 0x006D716B, 0x006D716B, 0x00676B65, 0x00696D67, 0x006C706A, 0x006D716B, 0x006C706A, 0x006B6F69, 0x006A6E68, 0x006A6E68, 0x006A6E68,
        0x006B6F69, 0x006C706A, 0x006C706A, 0x006B6F69, 0x006A6E68, 0x00696D67, 0x00686C66, 0x0063685F, 0x00666B62, 0x006A6E68, 0x006E726C, 0x00717570, 0x00717570, 0x0070746F, 0x006F7270, 0x006C706A, 0x00676B65, 0x005E625C, 0x00585C56, 0x00555953,
        0x00585C56, 0x005C605A, 0x0060645E, 0x0070746E, 0x00747872, 0x007B7F79, 0x0081857F, 0x00828680, 0x007E827C, 0x00787C76, 0x00757973, 0x006C706B, 0x006E726D, 0x006D716C, 0x006B6F6A, 0x00646863, 0x00555954, 0x00545853, 0x00686C67, 0xDEDBDBDB,
        0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFEFF1F1, 0xF7E8EAEA, 0xDEDCDEDE, 0xBCCCCECE, 0x00BEC0C0, 0x00B4BFBD, 0x00ADB8B6, 0x0098A3A1, 0x00848F8D, 0x00798482,
        0x00717C7A, 0x006D7876, 0x00717C7A, 0x00798684, 0x0083908E, 0x00778482, 0x00697674, 0x00818E8C, 0x00A0ADAB, 0x00879492, 0x008A9795, 0x008D9594, 0x008E9695, 0x008E9997, 0x00919C9A, 0x008B9896, 0x00899694, 0x00B9C7C5, 0x00A9B7B5, 0x0098A3A1,
        0x00A6B1AF, 0x00BAC5C3, 0x00C1CECC, 0x00B2BFBD, 0x0097A5A3, 0x008E9C9A, 0x0095A3A1, 0x007B8C89, 0x005F706D, 0x007C8A88, 0x007F8D89, 0x00778581, 0x007E8A84, 0x0086928C, 0x0086908A, 0x00818D87, 0x0089958F, 0x00939F99, 0x0096A4A0, 0x0091A09C,
        0x008C9D9A, 0x008FA09D, 0x0095A6A3, 0x0093A4A1, 0x0092A3A0, 0x0092A3A0, 0x0096A4A2, 0x0098A6A4, 0x0098A6A4, 0x0096A3A1, 0x0093A09E, 0x008C9396, 0x008B9392, 0x009AA19C, 0x007F887E, 0x00070F05, 0x000A0E08, 0x000C100B, 0x000D0E0C, 0x00080C06,
        0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08,
        0x00090D08, 0x00090D08, 0x00090D08, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000C0D09,
        0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000E0F0B, 0x000C100B, 0x000C100B, 0x000A100B, 0x000B110C, 0x000B110C, 0x000D110C, 0x000D110C, 0x000D110C, 0x000D110C, 0x000E120D,
        0x000E120D, 0x000E120D, 0x000E120D, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000E120C, 0x000F130D, 0x000F130D, 0x000F130D, 0x0010140E, 0x0010140E, 0x0011150F, 0x0011150F, 0x00141813,
        0x00141813, 0x00141813, 0x00131712, 0x00131712, 0x00121611, 0x00121611, 0x00121611, 0x00131711, 0x00141812, 0x00151913, 0x00151913, 0x00151913, 0x00131711, 0x0011150F, 0x000F130D, 0x000E120C, 0x00121610, 0x00171B15, 0x001D211B, 0x00242822,
        0x002E322C, 0x003A3E38, 0x00434741, 0x00565A54, 0x005D615B, 0x00676B65, 0x006E726C, 0x0070746E, 0x006F736D, 0x006E726C, 0x006D716B, 0x006C706A, 0x006B6F69, 0x00696D67, 0x00666A64, 0x00646862, 0x00656963, 0x00676B65, 0x00696D67, 0x00666A64,
        0x00676B65, 0x00696D67, 0x006A6E68, 0x006B6F69, 0x006A6E68, 0x00686C66, 0x00676B65, 0x0061665D, 0x0061665D, 0x0061655F, 0x00626660, 0x00636762, 0x00656964, 0x00676B66, 0x00686B69, 0x00666A64, 0x00696D67, 0x006D716B, 0x006F736D, 0x006D716B,
        0x00676B65, 0x005F635D, 0x005B5F59, 0x00575B55, 0x005A5E58, 0x005E625C, 0x00646862, 0x006A6E68, 0x0071756F, 0x00767A74, 0x00787C76, 0x0070746F, 0x00747873, 0x006E726D, 0x00666A65, 0x005B5F5A, 0x004C504B, 0x004A4E49, 0x00535752, 0x75A9A9A9,
        0xFFFBFBFB, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFF7F9F9, 0xFFF3F5F5, 0xFFECEEEE, 0xEAE2E4E4, 0xD9DADCDC, 0xB8C9CFCE, 0xA3BFC5C4, 0x86B2B8B7, 0x60A0A6A5, 0x00909695,
        0x008F9594, 0x00959B9A, 0x00959B9A, 0x00798482, 0x00747F7D, 0x009CA7A5, 0x00ADB8B6, 0x00879290, 0x008A9593, 0x008F9A98, 0x008E9997, 0x00818C8A, 0x00808B89, 0x0086918F, 0x008B9896, 0x0083908E, 0x00818F8D, 0x009CAAA8, 0x008D9B99, 0x0095A09E,
        0x009DA8A6, 0x00A9B4B2, 0x00A8B5B3, 0x00A2AFAD, 0x00A3B1AF, 0x00A8B6B4, 0x00A6B4B2, 0x00829592, 0x00748784, 0x00879895, 0x00798884, 0x006B7975, 0x00717D77, 0x0079837D, 0x006E7570, 0x00676D68, 0x00686F6A, 0x006C7670, 0x00737E7B, 0x007B8985,
        0x00818F8D, 0x00849592, 0x00879895, 0x0095A8A5, 0x0094A5A2, 0x0093A4A1, 0x0097A8A5, 0x009FADAB, 0x00A2B0AE, 0x00A1AEAC, 0x009FACAA, 0x009BA7A9, 0x00919E9C, 0x0097A39D, 0x0079847A, 0x000B140A, 0x00091009, 0x00090D08, 0x000A0B09, 0x00080C06,
        0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08,
        0x00090D08, 0x00090D08, 0x00090D08, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0C08,
        0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000E0F0B, 0x000C100B, 0x000C100B, 0x000A100B, 0x000B110C, 0x000B110C, 0x000D110C, 0x000D110C, 0x000D110C, 0x000D110C, 0x000E120D,
        0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000D110C, 0x000D110C, 0x000D110C, 0x000D110C, 0x000D110C, 0x0010140E, 0x0010140E, 0x0010140E, 0x0011150F, 0x0011150F, 0x0011150F, 0x0011150F, 0x0011150F, 0x00131712,
        0x00131712, 0x00131712, 0x00131712, 0x00131712, 0x00121611, 0x00131712, 0x00131712, 0x00141812, 0x00131711, 0x0010140E, 0x000F130D, 0x000F130D, 0x0010140E, 0x00131711, 0x00141812, 0x00151913, 0x00141812, 0x00121610, 0x000E120C, 0x000C100A,
        0x000E120C, 0x00121610, 0x00161A14, 0x001C201A, 0x00242822, 0x0030342E, 0x003D413B, 0x00494D47, 0x00555953, 0x0060645E, 0x00676B65, 0x006C706A, 0x006C706A, 0x006B6F69, 0x00696D67, 0x00686C66, 0x00686C66, 0x006A6E68, 0x006D716B, 0x00676B65,
        0x00686C66, 0x00686C66, 0x00676B65, 0x00666A64, 0x00636761, 0x0060645E, 0x005F635D, 0x00656A61, 0x00656A61, 0x00666A64, 0x00666A64, 0x00656964, 0x00636762, 0x00616560, 0x00606361, 0x00636A63, 0x00636A63, 0x00636A63, 0x00646B64, 0x00656C65,
        0x00686F68, 0x006B726B, 0x006C736C, 0x006F766F, 0x006D746D, 0x00676E67, 0x00606760, 0x005D645D, 0x005E655E, 0x005E655E, 0x005C635C, 0x006B716C, 0x00676D68, 0x005A605B, 0x00535954, 0x004F5550, 0x00505651, 0x005A605B, 0x005D635E, 0x368C8C8C,
        0xFFFCFCFC, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFFFF, 0xFFFDFFFF, 0xFFFCFEFE, 0xFFF9FBFB, 0xFFF8FAFA, 0xFFF6F8F8, 0xFFF2F4F4, 0xFFEEF0F0, 0xEEE3E5E5, 0xC9D2D4D4,
        0xB0C6C8C8, 0x96B9BBBB, 0x79ABADAD, 0x5C9EA4A3, 0x00949A99, 0x008D9392, 0x00999F9E, 0x00919796, 0x00848A89, 0x007A807F, 0x008C9291, 0x00808B89, 0x007C8785, 0x007C8987, 0x00869391, 0x0083918F, 0x00879593, 0x0083918F, 0x0083918F, 0x00838E8C,
        0x00808B89, 0x00848F8D, 0x00818E8C, 0x00869391, 0x00A2B0AE, 0x00B4C2C0, 0x00A9B7B5, 0x00718683, 0x008C9F9C, 0x009BACA9, 0x0083928E, 0x00848F8C, 0x008B958F, 0x00818883, 0x005F6560, 0x0050514D, 0x0050514D, 0x00535752, 0x005C6360, 0x006A7370,
        0x0074817F, 0x007A8886, 0x007C8A88, 0x00758683, 0x007D8E8B, 0x008B9997, 0x0099A7A5, 0x00A3B0AE, 0x00A4B1AF, 0x009FACAA, 0x009CA7A5, 0x009EABAD, 0x009AA8A6, 0x009EACA6, 0x0078867B, 0x000A1309, 0x00070E07, 0x00080C07, 0x000A0B09, 0x00080C06,
        0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08,
        0x00090D08, 0x00090D08, 0x00090D08, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0C08,
        0x000B0C08, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000E0F0B, 0x000C100B, 0x000C100B, 0x000A100B, 0x000B110C, 0x000B110C, 0x000D110C, 0x000D110C, 0x000D110C, 0x000D110C, 0x000E120D,
        0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x0010140E, 0x0010140E, 0x0010140E, 0x0011150F, 0x0011150F, 0x00121610, 0x00121610, 0x00121610, 0x0010140F,
        0x0010140F, 0x0010140F, 0x0010140F, 0x0010140F, 0x00111510, 0x00121611, 0x00131712, 0x0011150F, 0x0011150F, 0x00121610, 0x00121610, 0x00131711, 0x00121610, 0x00121610, 0x00121610, 0x00131711, 0x00141812, 0x00151913, 0x00151913, 0x00141812,
        0x00131711, 0x00121610, 0x00121610, 0x0010140E, 0x0011150F, 0x00131711, 0x00141812, 0x00181C16, 0x0021251F, 0x002C302A, 0x00353933, 0x00464A44, 0x004E524C, 0x005A5E58, 0x00636761, 0x00696D67, 0x006A6E68, 0x00696D67, 0x00696D67, 0x006B6F69,
        0x006B6F69, 0x006C706A, 0x006C706A, 0x006B6F69, 0x006A6E68, 0x00686C66, 0x00676B65, 0x00656A61, 0x00656A61, 0x00646862, 0x00646862, 0x00656964, 0x00666A65, 0x00686C67, 0x00696C6A, 0x005D645D, 0x005E655E, 0x005E655E, 0x005F665F, 0x005F665F,
        0x005F665F, 0x005E655E, 0x005D645D, 0x00636A63, 0x00656C65, 0x00656C65, 0x00636A63, 0x00636A63, 0x00636A63, 0x005F665F, 0x005A615A, 0x004C534C, 0x00454C45, 0x00424942, 0x004C534C, 0x00525952, 0x005A615A, 0x00666D66, 0x005D645D, 0x368C8C8C,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFDFDFD, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFFFF, 0xFFFDFFFF, 0xFFFDFFFF, 0xFFFDFFFF, 0xFFFDFFFF, 0xFFFFFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFE, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFEFCFC, 0xFFF5F3F3, 0xF2E6EBEA, 0xEAE2E7E6, 0xC0CED3D2, 0xABC3C8C7, 0x82AFB4B3, 0x6DA6ABAA, 0x4F989D9C, 0x00929796, 0x00838E8C, 0x00838E8C, 0x007E8B89, 0x00818E8C, 0x007C8A88, 0x0082908E, 0x00748280, 0x008B9C99, 0x00818C8A,
        0x006E7977, 0x00697472, 0x00697674, 0x00768381, 0x00A0AEAC, 0x00BFCDCB, 0x00B6C4C2, 0x005A6F6C, 0x0090A5A2, 0x0099AAA7, 0x00788783, 0x008D9895, 0x00A0AAA4, 0x008F9691, 0x00646A65, 0x006A6763, 0x0064635F, 0x005E5F5B, 0x005A5D5B, 0x005A615E,
        0x005D6866, 0x00616E6C, 0x0064716F, 0x006E7C7A, 0x00707E7C, 0x00748280, 0x007A8785, 0x00828F8D, 0x008E9997, 0x0098A3A1, 0x009EA9A7, 0x0093A2A4, 0x009BACA9, 0x00A7B5AF, 0x007A887D, 0x000A1309, 0x00060D06, 0x00090D08, 0x000A0B09, 0x00080C06,
        0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08,
        0x00090D08, 0x00090D08, 0x00090D08, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0C08,
        0x000B0C08, 0x000B0C08, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000D0E0A, 0x000D0E0A, 0x000E0F0B, 0x000C100B, 0x000C100B, 0x000A100B, 0x000B110C, 0x000B110C, 0x000D110C, 0x000D110C, 0x000D110C, 0x000D110C, 0x000E120D,
        0x000E120D, 0x000E120D, 0x000E120D, 0x0010140F, 0x0010140F, 0x0010140F, 0x0010140F, 0x0010140F, 0x0010140F, 0x0010140F, 0x0010140F, 0x000E120C, 0x000E120C, 0x000F130D, 0x000F130D, 0x0010140E, 0x0011150F, 0x0011150F, 0x00121610, 0x00131712,
        0x00131712, 0x00111510, 0x00111510, 0x0010140F, 0x00111510, 0x00121611, 0x00131712, 0x00121610, 0x00121610, 0x00121610, 0x00121610, 0x00121610, 0x00121610, 0x00121610, 0x00121610, 0x00121610, 0x00121610, 0x0011150F, 0x0011150F, 0x00121610,
        0x00131711, 0x00131711, 0x00131711, 0x00141812, 0x00161A14, 0x00161A14, 0x00141812, 0x0011150F, 0x0010140E, 0x00121610, 0x00151913, 0x00181C16, 0x001C201A, 0x00232721, 0x002E322C, 0x003B3F39, 0x004B4F49, 0x005A5E58, 0x00636761, 0x006D716B,
        0x006C706A, 0x006C706A, 0x006B6F69, 0x006A6E68, 0x00696D67, 0x00676B65, 0x00666A64, 0x00656A61, 0x00666B62, 0x00676B65, 0x00686C66, 0x00676B66, 0x00656964, 0x00636762, 0x00616462, 0x00626962, 0x00626962, 0x00636A63, 0x00636A63, 0x00626962,
        0x00616861, 0x005F665F, 0x005E655E, 0x005B625B, 0x005F665F, 0x00616861, 0x00606760, 0x00606760, 0x00606760, 0x005A615A, 0x00525952, 0x00484F48, 0x003B423B, 0x003A413A, 0x004F564F, 0x00585F58, 0x00606760, 0x006B726B, 0x005C635C, 0x43929292,
        0xFFFFFFFF, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFAFAFA, 0xFFF8F8F8, 0xD1D5D5D5, 0x009F9F9F, 0x00909E9C, 0x0093A09E, 0x0098A3A1, 0x0097A1A1, 0x00909C9C, 0x007F8E90, 0x00778B8C, 0x008CA4A4, 0x00859895,
        0x00738683, 0x006D7E7A, 0x006B7C78, 0x00778682, 0x009EAEA7, 0x00BBCBC4, 0x00B7C5BF, 0x004B5F64, 0x00A5BABC, 0x007F9394, 0x00809291, 0x00768783, 0x007A8A83, 0x0072837A, 0x0055655A, 0x0057615B, 0x005F6661, 0x00696D68, 0x00686965, 0x006B6C68,
        0x0070746F, 0x00676E69, 0x00646E68, 0x00626D6A, 0x00606B68, 0x005F6A67, 0x00646D6A, 0x0067706D, 0x006B726F, 0x006C7370, 0x006E7572, 0x00737F79, 0x007A8680, 0x008B958F, 0x00676E69, 0x000E140F, 0x00080C07, 0x00050904, 0x000B0C08, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08,
        0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00040803, 0x00090D08, 0x00121611, 0x000A0E09, 0x00030702, 0x00080C07, 0x000A0E09, 0x000C140A, 0x00060E04, 0x00050D03, 0x00050D03, 0x00081006, 0x00081006, 0x000D150B, 0x00040C02, 0x00050B0A,
        0x00090F0E, 0x00040908, 0x000C110F, 0x000D110C, 0x000C0D09, 0x000C0E08, 0x000A0C06, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000C100B, 0x000C100B, 0x000C100B, 0x000D110C, 0x000D110C,
        0x000D110C, 0x000D110C, 0x000D110C, 0x000E120C, 0x000E120C, 0x000E120C, 0x000E120C, 0x000E120C, 0x000F130D, 0x000F130D, 0x000F130D, 0x000E120D, 0x000F130E, 0x000F130E, 0x000F130E, 0x0010140F, 0x00111510, 0x00111510, 0x00111510, 0x00131410,
        0x00131410, 0x00131410, 0x00131410, 0x00131410, 0x00131410, 0x00131410, 0x00131410, 0x000F160F, 0x000F160F, 0x000F160F, 0x000F160F, 0x000E150E, 0x000E150E, 0x000E150E, 0x000E150E, 0x0011150F, 0x0011150F, 0x0011150F, 0x0011150F, 0x0011150F,
        0x0011150F, 0x0011150F, 0x0011150F, 0x00131712, 0x00131712, 0x00131712, 0x00141813, 0x00141813, 0x00141813, 0x00141813, 0x00151914, 0x00131712, 0x00121611, 0x00111510, 0x00111510, 0x00141813, 0x00191D18, 0x001F231E, 0x00222621, 0x00313530,
        0x003C403B, 0x004C504B, 0x00575B56, 0x005E625D, 0x00636762, 0x006A6E69, 0x006F736E, 0x00666A65, 0x00666A65, 0x00666A65, 0x00646863, 0x00626661, 0x00616560, 0x00636762, 0x00646863, 0x0060645F, 0x006A6E69, 0x00626661, 0x0060645F, 0x00676B66,
        0x00656964, 0x00646863, 0x00616560, 0x005F6560, 0x00606661, 0x00636964, 0x00676D68, 0x00646A65, 0x00575D58, 0x00454B46, 0x00383E39, 0x00494F4A, 0x00505651, 0x00393F3A, 0x00575D58, 0x00595F5A, 0x005F6560, 0x00636964, 0x005B615C, 0x589C9C9C,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFBE9E9E9, 0xA7C1C1C1, 0x00A1AEAC, 0x00ACB7B5, 0x00B3BBBA, 0x00ABB3B3, 0x00A8B2B2, 0x009DAAAC, 0x008A9E9F, 0x0099AEAF, 0x00A0B1AE,
        0x0095A6A3, 0x008D9B99, 0x0084938F, 0x007F8D89, 0x008C9A94, 0x008E9C96, 0x00727E78, 0x00415052, 0x00839392, 0x00798988, 0x008B9C99, 0x007E8F8C, 0x007E8F8B, 0x006A7975, 0x0041514A, 0x0047534D, 0x003E4842, 0x004B514C, 0x00545853, 0x00595D58,
        0x00616762, 0x0066706A, 0x006B7771, 0x0065706D, 0x005D6865, 0x00535E5B, 0x004F5855, 0x00505956, 0x00505956, 0x004E5552, 0x00484F4C, 0x00404C46, 0x0044504A, 0x0057615B, 0x00444B46, 0x00020803, 0x00070B06, 0x00070B06, 0x000D0E0A, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08,
        0x00090D08, 0x00090D08, 0x00090D08, 0x000E120D, 0x000A0E09, 0x00080C07, 0x00060A05, 0x00050904, 0x000B0F0A, 0x0010140F, 0x00090D08, 0x00060A04, 0x000D110B, 0x000B0F09, 0x000A0E08, 0x00070B05, 0x000C100A, 0x00020600, 0x000F130D, 0x000F1413,
        0x00000100, 0x00101513, 0x000B0E0C, 0x00010500, 0x000D0E0A, 0x00070903, 0x0010120C, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000C100B, 0x000C100B, 0x000C100B, 0x000C100B, 0x000D110C,
        0x000D110C, 0x000D110C, 0x000D110C, 0x000D110B, 0x000E120C, 0x000E120C, 0x000E120C, 0x000E120C, 0x000E120C, 0x000F130D, 0x000F130D, 0x000F130E, 0x000F130E, 0x000F130E, 0x0010140F, 0x0010140F, 0x00111510, 0x00111510, 0x00111510, 0x00141511,
        0x00141511, 0x00141511, 0x00141511, 0x00141511, 0x00141511, 0x00141511, 0x00141511, 0x000F160F, 0x000F160F, 0x000F160F, 0x000F160F, 0x000E150E, 0x000E150E, 0x000E150E, 0x000E150E, 0x0011150F, 0x0011150F, 0x0011150F, 0x0011150F, 0x0011150F,
        0x0011150F, 0x0011150F, 0x0011150F, 0x00121611, 0x00121611, 0x00121611, 0x00131712, 0x00131712, 0x00131712, 0x00131712, 0x00131712, 0x00171B16, 0x00161A15, 0x00141813, 0x00121611, 0x00121611, 0x00121611, 0x00141813, 0x00141813, 0x00121611,
        0x00161A15, 0x001C201B, 0x00222621, 0x00282C27, 0x00333732, 0x003F433E, 0x00494D48, 0x00595D58, 0x005E625D, 0x00666A65, 0x006B6F6A, 0x006C706B, 0x006A6E69, 0x00676B66, 0x00666A65, 0x00696D68, 0x00686C67, 0x00646863, 0x00656964, 0x00626661,
        0x005C605B, 0x005F635E, 0x00636762, 0x00636964, 0x00666C67, 0x00656B66, 0x005B615C, 0x004D534E, 0x00444A45, 0x00444A45, 0x00484E49, 0x00535954, 0x00585E59, 0x00404641, 0x005B615C, 0x005A605B, 0x00606661, 0x00636964, 0x005B615C, 0x609F9F9F,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFCFCFC, 0xF2E6E6E6, 0x86B1BCBA, 0x00B6BEBD, 0x00BAC0BF, 0x00ABB0B1, 0x00ACB4B4, 0x00A8B4B6, 0x009DACAE, 0x00B4C8C9, 0x00CAD8D7,
        0x00BCCAC8, 0x00AAB7B5, 0x00A1AEAC, 0x0096A19E, 0x008B9693, 0x0074807A, 0x00444E48, 0x00353F39, 0x004D5653, 0x005C6764, 0x007C8987, 0x007B8987, 0x0091A1A0, 0x007D8F8E, 0x0057696A, 0x003F514A, 0x0026342E, 0x002B3731, 0x00363D38, 0x00383F3A,
        0x003B4741, 0x00495751, 0x0052645D, 0x005E6C68, 0x005B6965, 0x0057625F, 0x00525D5A, 0x00545D5A, 0x00505956, 0x00434C49, 0x00363D3A, 0x00333F39, 0x002E3A34, 0x003B453F, 0x00323934, 0x00030904, 0x000A0E09, 0x00070B06, 0x00090A06, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08,
        0x00090D08, 0x00090D08, 0x00090D08, 0x00080C07, 0x00060A05, 0x00080C07, 0x00090D08, 0x00070B06, 0x00070B06, 0x00070B06, 0x00080C07, 0x000D0E0A, 0x00090A06, 0x000B0C08, 0x0011120E, 0x0012130F, 0x00060703, 0x00050602, 0x000F100C, 0x00080C07,
        0x000E120D, 0x000D110C, 0x00020601, 0x000D110C, 0x000F100C, 0x000E0F0B, 0x000C0D09, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000C100B, 0x000C100B, 0x000C100B, 0x000C100B, 0x000D110C,
        0x000D110C, 0x000D110C, 0x000D110C, 0x000D110B, 0x000D110B, 0x000D110B, 0x000E120C, 0x000E120C, 0x000E120C, 0x000E120C, 0x000F130D, 0x000F130E, 0x000F130E, 0x000F130E, 0x0010140F, 0x0010140F, 0x00111510, 0x00111510, 0x00111510, 0x00141511,
        0x00141511, 0x00141511, 0x00141511, 0x00141511, 0x00141511, 0x00141511, 0x00141511, 0x000F160F, 0x000F160F, 0x000F160F, 0x000F160F, 0x000E150E, 0x000E150E, 0x000E150E, 0x000E150E, 0x0010140E, 0x0010140E, 0x0010140E, 0x0010140E, 0x0010140E,
        0x0010140E, 0x0010140E, 0x0010140E, 0x0010140F, 0x00111510, 0x00111510, 0x00111510, 0x00111510, 0x00121611, 0x00121611, 0x00121611, 0x00131712, 0x00131712, 0x00131712, 0x00131712, 0x00131712, 0x00131712, 0x00121611, 0x00121611, 0x00141813,
        0x00141813, 0x00141813, 0x00141813, 0x00141813, 0x00161A15, 0x001B1F1A, 0x001F231E, 0x00292D28, 0x0030342F, 0x00393D38, 0x00444843, 0x004E524D, 0x00585C57, 0x0060645F, 0x00646863, 0x00646863, 0x005F635E, 0x00656964, 0x00676B66, 0x00636762,
        0x00626661, 0x00636762, 0x00666A65, 0x00646A65, 0x00616762, 0x00575D58, 0x00484E49, 0x003D433E, 0x003F4540, 0x004B514C, 0x00565C57, 0x00575D58, 0x005B615C, 0x00444A45, 0x005D635E, 0x005B615C, 0x00616762, 0x00626863, 0x005C625D, 0x6DA5A5A5,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFF9F9F9, 0xE6E0E8E7, 0xD5D8DEDD, 0xD1D6DBDA, 0xB4C7CBCC, 0xABC4C9CA, 0x9BBBC4C7, 0x00B0BDBF, 0x00D0E2E3, 0x00E3EFEF,
        0x00C8D4D4, 0x00ADBAB8, 0x00ACB9B7, 0x00A5B0AE, 0x008F9A97, 0x00757E7B, 0x0047504D, 0x003E433A, 0x00323630, 0x00434A45, 0x00586360, 0x00657171, 0x0092A1A3, 0x0084979A, 0x00697C81, 0x00415550, 0x002C3D39, 0x002C3A36, 0x0027322F, 0x0027322F,
        0x0025332F, 0x002A3B37, 0x002D413C, 0x003A4844, 0x0045534F, 0x004C5A56, 0x004F5A57, 0x00515C59, 0x00555E5B, 0x004E5754, 0x00434C49, 0x0035413B, 0x002A3630, 0x002F3933, 0x002A312C, 0x00060C07, 0x000A0E09, 0x00070B06, 0x00090A06, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08,
        0x00090D08, 0x00090D08, 0x00090D08, 0x00080C07, 0x00080C07, 0x000A0E09, 0x00070B06, 0x000A0E09, 0x000D110C, 0x000B0F0A, 0x000F130E, 0x000C0D0B, 0x000D0E0C, 0x000E0F0D, 0x00030402, 0x000D0E0C, 0x00070806, 0x00151614, 0x00151614, 0x0013150F,
        0x00090B05, 0x000B0D07, 0x000F110B, 0x0011120E, 0x00040803, 0x000C100B, 0x000A0E09, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000B0F0A, 0x000C100B, 0x000C100B, 0x000C100B, 0x000C100B,
        0x000D110C, 0x000D110C, 0x000D110C, 0x000D110B, 0x000D110B, 0x000D110B, 0x000D110B, 0x000E120C, 0x000E120C, 0x000E120C, 0x000E120C, 0x000F130E, 0x000F130E, 0x000F130E, 0x0010140F, 0x0010140F, 0x00111510, 0x00111510, 0x00111510, 0x00121611,
        0x00121611, 0x00121611, 0x00121611, 0x00121611, 0x00121611, 0x00121611, 0x00121611, 0x000F160F, 0x000F160F, 0x000F160F, 0x000F160F, 0x000E150E, 0x000E150E, 0x000E150E, 0x000E150E, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D,
        0x000F130D, 0x000F130D, 0x000F130D, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x0010140F, 0x0010140F, 0x0010140F, 0x0010140F, 0x0010140F, 0x00111510, 0x00121611, 0x00141813, 0x00151914, 0x00161A15, 0x00161A15, 0x00161A15, 0x00151914,
        0x00161A15, 0x00181C17, 0x00191D18, 0x00191D18, 0x00181C17, 0x00161A15, 0x00151914, 0x00131712, 0x00141813, 0x00171B16, 0x001B1F1A, 0x00212520, 0x002B2F2A, 0x00353934, 0x003C403B, 0x0050544F, 0x00535752, 0x005D615C, 0x005F635E, 0x00646863,
        0x006B6F6A, 0x00676B66, 0x00656964, 0x00595F5A, 0x004E544F, 0x00414742, 0x003C423D, 0x00454B46, 0x00515752, 0x00575D58, 0x00575D58, 0x00515752, 0x00555B56, 0x00434944, 0x005C625D, 0x005A605B, 0x00626863, 0x00616762, 0x005D635E, 0x7DADADAD,
        0xFFFEFEFE, 0xFFFFFFFF, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFBFFFF, 0xFFF9FEFD, 0xFFFCFEFE, 0xFFF7F6F8, 0xFFF5F7F8, 0xF7E8EDF0, 0xBCCBD7D9, 0x00D6E3E5, 0x00DAE8E7,
        0x00BDCBCA, 0x00AAB8B7, 0x00B3C0BE, 0x00A9B6B4, 0x008D9A98, 0x007A8582, 0x00626D6A, 0x00585D54, 0x00414841, 0x004D544F, 0x004C5754, 0x005D6B6A, 0x008D9FA0, 0x007B8E91, 0x005F7378, 0x004E645F, 0x004B5C58, 0x0043524E, 0x002C3734, 0x0036413E,
        0x00374642, 0x00384945, 0x00364C47, 0x00283733, 0x00354440, 0x003C4A46, 0x00364440, 0x00343F3C, 0x003B4643, 0x00454E4B, 0x0048514E, 0x003B4741, 0x00303C36, 0x002F3933, 0x00272E29, 0x00080E09, 0x00060A05, 0x00060A05, 0x000A0B07, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08,
        0x00090D08, 0x00090D08, 0x00090D08, 0x00080C07, 0x000D110C, 0x000E120D, 0x00030702, 0x00080C07, 0x000F130E, 0x00050904, 0x00060A05, 0x00030200, 0x0012110D, 0x000D0C08, 0x001A1915, 0x000E0D09, 0x00070602, 0x00020100, 0x007A7975, 0x008F8E84,
        0x000B0901, 0x00070800, 0x00181812, 0x00020400, 0x000A0E09, 0x00090C0A, 0x000A0F0D, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000C100B, 0x000C100B,
        0x000C100B, 0x000C100B, 0x000D110C, 0x000D110B, 0x000D110B, 0x000D110B, 0x000D110B, 0x000E120C, 0x000E120C, 0x000E120C, 0x000E120C, 0x000E120D, 0x000E120D, 0x000F130E, 0x000F130E, 0x0010140F, 0x0010140F, 0x00111510, 0x00111510, 0x00121611,
        0x00121611, 0x00121611, 0x00121611, 0x00121611, 0x00121611, 0x00121611, 0x00121611, 0x000F160F, 0x000F160F, 0x000F160F, 0x000F160F, 0x000E150E, 0x000E150E, 0x000E150E, 0x000E150E, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D,
        0x000F130D, 0x000F130D, 0x000F130D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x00121611, 0x00121611, 0x00121611, 0x00121611, 0x00121611, 0x00121611, 0x00131712, 0x00131712, 0x00131712,
        0x00131712, 0x00131712, 0x00141813, 0x00161A15, 0x00181C17, 0x001A1E19, 0x001A1E19, 0x001B1F1A, 0x001B1F1A, 0x001B1F1A, 0x001A1E19, 0x00181C17, 0x00181C17, 0x00191D18, 0x001A1E19, 0x001D211C, 0x00292D28, 0x00333732, 0x003B3F3A, 0x00474B46,
        0x0050544F, 0x00545853, 0x005B5F5A, 0x00434944, 0x003F4540, 0x003C423D, 0x00434944, 0x00555B56, 0x00616762, 0x005D635E, 0x00525853, 0x004D534E, 0x00515752, 0x00444A45, 0x005D635E, 0x005C625D, 0x00636964, 0x005F6560, 0x005C625D, 0x8EB5B5B5,
        0xFFFEFEFE, 0xFFFFFFFF, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFDFD, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFDFF, 0xFFFFFEFF, 0xFFFBFEFF, 0xE2DDE4E7, 0x00BDC9CB, 0x00C1D5D6,
        0x00BACCCD, 0x00BFD1D0, 0x00C5D7D6, 0x00B8C9C6, 0x00A1B2AF, 0x0095A3A1, 0x008E9D99, 0x007A8680, 0x006A7572, 0x006E7C78, 0x005A6866, 0x00677875, 0x00889A99, 0x006D8280, 0x004C6061, 0x00495C59, 0x0051625F, 0x00515E5C, 0x00343F3D, 0x003F4A48,
        0x00384543, 0x002C3D3A, 0x00233633, 0x002A3935, 0x0032413D, 0x0033423E, 0x00283632, 0x001D2B27, 0x00222D2A, 0x002C3734, 0x00343F3C, 0x00404C46, 0x0039453F, 0x00353F39, 0x00272E29, 0x000B110C, 0x00040803, 0x00060A05, 0x000A0B07, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08,
        0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00050904, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x00010500, 0x00030702, 0x002A2E29, 0x0053504B, 0x0015120D, 0x000D0A05, 0x000E0B06, 0x009C9994, 0x006E6B66, 0x00040100, 0x002A2722, 0x00CFCBC0,
        0x0057554A, 0x00040300, 0x000C0D04, 0x00070903, 0x0010140F, 0x000E1311, 0x00060B0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000C100B,
        0x000C100B, 0x000C100B, 0x000C100B, 0x000C100A, 0x000D110B, 0x000D110B, 0x000D110B, 0x000D110B, 0x000E120C, 0x000E120C, 0x000E120C, 0x000D110C, 0x000D110C, 0x000E120D, 0x000E120D, 0x000F130E, 0x000F130E, 0x0010140F, 0x0010140F, 0x000F1510,
        0x000F1510, 0x000F1510, 0x000F1510, 0x000F1510, 0x000F1510, 0x000F1510, 0x000F1510, 0x000F160F, 0x000F160F, 0x000F160F, 0x000F160F, 0x000E150E, 0x000E150E, 0x000E150E, 0x000E150E, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D,
        0x000F130D, 0x000F130D, 0x000F130D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x0010140F, 0x000F130E, 0x000F130E, 0x000E120D, 0x000E120D, 0x000E120D, 0x000F130E, 0x0010140F, 0x00161A15,
        0x00151914, 0x00141813, 0x00131712, 0x00141813, 0x00151914, 0x00151914, 0x00161A15, 0x00171B16, 0x001A1E19, 0x001C201B, 0x001D211C, 0x001D211C, 0x001D211C, 0x001D211C, 0x001E221D, 0x00171B16, 0x001D211C, 0x001C201B, 0x0020241F, 0x001D211C,
        0x001B1F1A, 0x00292D28, 0x0030342F, 0x00353B36, 0x00404641, 0x004C524D, 0x00555B56, 0x005C625D, 0x00606661, 0x005A605B, 0x00505651, 0x004F5550, 0x00535954, 0x00494F4A, 0x00606661, 0x005E645F, 0x00666C67, 0x005E645F, 0x005C625D, 0x9FBDBDBD,
        0xFFFEFEFE, 0xFFFFFFFF, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFCFD, 0xFFFFFBFD, 0xFFFFFCFE, 0xFFFDFEFF, 0xF2E6EBEE, 0x8EB5BEC1, 0x00B7CFCF,
        0x00C3DBDB, 0x00DCF1F2, 0x00D2E8E6, 0x00C3D9D7, 0x00C3D8D5, 0x00B7CCC9, 0x00B0C5C2, 0x00A7BBBC, 0x009EB3B1, 0x009DB2B0, 0x007D928F, 0x007A8F8C, 0x00839994, 0x00647A75, 0x00394E46, 0x00344542, 0x003E4B49, 0x004E5957, 0x00454B4A, 0x00535958,
        0x00444F4D, 0x00394644, 0x002E3F3C, 0x00263531, 0x00283733, 0x00283733, 0x00253430, 0x0022302C, 0x0022302C, 0x0026312E, 0x00293431, 0x002D3933, 0x002D3933, 0x002A342E, 0x001E2520, 0x000A100B, 0x00040803, 0x00080C07, 0x000C0D09, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08,
        0x00090D08, 0x00090D08, 0x00090D08, 0x000E120D, 0x00020601, 0x00060A05, 0x00090D08, 0x000B0F0A, 0x00020601, 0x0010140F, 0x00515550, 0x00FFFFF6, 0x00C7C5BB, 0x003D3B31, 0x0018160C, 0x00747268, 0x00E2E0D6, 0x00706E64, 0x00050300, 0x00A49E91,
        0x00B9B6A8, 0x001B190E, 0x000C0A02, 0x0012140E, 0x00050904, 0x000E1311, 0x00060C0B, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000C100B,
        0x000C100B, 0x000C100B, 0x000C100B, 0x000C100A, 0x000C100A, 0x000D110B, 0x000D110B, 0x000D110B, 0x000D110B, 0x000D110B, 0x000E120C, 0x000C100B, 0x000C100B, 0x000D110C, 0x000D110C, 0x000E120D, 0x000E120D, 0x000F130E, 0x000F130E, 0x000E140F,
        0x000E140F, 0x000E140F, 0x000E140F, 0x000E140F, 0x000E140F, 0x000E140F, 0x000E140F, 0x000F160F, 0x000F160F, 0x000F160F, 0x000F160F, 0x000E150E, 0x000E150E, 0x000E150E, 0x000E150E, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D,
        0x000F130D, 0x000F130D, 0x000F130D, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x0010140F, 0x0010140F, 0x0010140F, 0x000C100B, 0x000C100B, 0x000D110C, 0x000D110C, 0x000E120D, 0x000F130E, 0x0010140F, 0x0010140F, 0x000D110C,
        0x000E120D, 0x0010140F, 0x00121611, 0x00121611, 0x00111510, 0x0010140F, 0x0010140F, 0x00121611, 0x00131712, 0x00141813, 0x00141813, 0x00151914, 0x00181C17, 0x001B1F1A, 0x001E221D, 0x001E221D, 0x00232722, 0x001C201B, 0x001E221D, 0x00171B16,
        0x00242823, 0x003F433E, 0x002A2E29, 0x003E443F, 0x004C524D, 0x00595F5A, 0x005C625D, 0x005C625D, 0x005C625D, 0x00565C57, 0x004F5550, 0x00505651, 0x00545A55, 0x004B514C, 0x00616762, 0x005E645F, 0x00666C67, 0x005E645F, 0x005E645F, 0xABC3C3C3,
        0xFFFEFEFE, 0xFFFFFFFF, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFBFBFB, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFEFE, 0xFFFFFBFC, 0xFFFFFDFF, 0xFFFFFDFF, 0xFFFEFDFF, 0xFFF6FBFE, 0xC0CED5D8, 0x8AB4D0D0,
        0x00CCE6E6, 0x00E4FEFE, 0x00C8E3E0, 0x00BFD7D5, 0x00D3EBE9, 0x00C7DEDA, 0x00B8CFCB, 0x00CBE6EA, 0x00C9E2E4, 0x00CCE6E6, 0x00ADC5C3, 0x00A0B7B2, 0x0097AEA6, 0x00778C83, 0x0041574B, 0x00455250, 0x00333E3C, 0x00383E3D, 0x00282D2C, 0x00323736,
        0x002D3332, 0x003A4543, 0x0043504E, 0x00374844, 0x0033423E, 0x002D3C38, 0x002E3D39, 0x00303E3A, 0x002E3C38, 0x002A3532, 0x0026312E, 0x0024302A, 0x0028342E, 0x0026302A, 0x001B221D, 0x000B110C, 0x00060A05, 0x00090D08, 0x000B0C08, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08,
        0x00090D08, 0x00090D08, 0x00090D08, 0x00060A05, 0x000A0E09, 0x000D110C, 0x00020601, 0x000B0F0A, 0x000C100B, 0x00000300, 0x00151914, 0x00717062, 0x00EAE9DB, 0x00F8F7E9, 0x007C7B6D, 0x00151406, 0x005B5A4C, 0x00E4E3D5, 0x00979688, 0x00C6C1B2,
        0x00FAF4E7, 0x003D392E, 0x00090800, 0x000B0D07, 0x000A0E09, 0x00080D0C, 0x00090F0E, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A,
        0x000C100B, 0x000C100B, 0x000C100B, 0x000C100A, 0x000C100A, 0x000C100A, 0x000D110B, 0x000D110B, 0x000D110B, 0x000D110B, 0x000D110B, 0x000C100B, 0x000C100B, 0x000C100B, 0x000D110C, 0x000D110C, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E140F,
        0x000E140F, 0x000E140F, 0x000E140F, 0x000E140F, 0x000E140F, 0x000E140F, 0x000E140F, 0x000F160F, 0x000F160F, 0x000F160F, 0x000F160F, 0x000E150E, 0x000E150E, 0x000E150E, 0x000E150E, 0x0010140E, 0x0010140E, 0x0010140E, 0x0010140E, 0x0010140E,
        0x0010140E, 0x0010140E, 0x0010140E, 0x000F130E, 0x000F130E, 0x000F130E, 0x0010140F, 0x0010140F, 0x0010140F, 0x0010140F, 0x0010140F, 0x000F130E, 0x000F130E, 0x0010140F, 0x0010140F, 0x0010140F, 0x0010140F, 0x0010140F, 0x000F130E, 0x0010140F,
        0x0010140F, 0x00111510, 0x0010140F, 0x000F130E, 0x000E120D, 0x000E120D, 0x000F130E, 0x000F130E, 0x0010140F, 0x00121611, 0x00121611, 0x00121611, 0x00121611, 0x00141813, 0x00161A15, 0x00131712, 0x001D211C, 0x00191D18, 0x001C201B, 0x001D211C,
        0x00484C47, 0x006D716C, 0x00333732, 0x00505651, 0x00565C57, 0x005A605B, 0x00595F5A, 0x005B615C, 0x005D635E, 0x00575D58, 0x004D534E, 0x004E544F, 0x00515752, 0x00484E49, 0x005E645F, 0x005B615C, 0x00666C67, 0x005E645F, 0x00606661, 0xB0C6C6C6,
        0xFFFEFEFE, 0xFFFFFFFF, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xE6E0E5E4,
        0xE2DDE3E2, 0xD1D5DDDC, 0xBCCCD7D5, 0x00C6D4D2, 0x00C4D7D4, 0x00C3D8D5, 0x00C1D6D3, 0x00CCF0F6, 0x00D7F9FF, 0x00D8F7FA, 0x00BED7D9, 0x00A7BCBA, 0x00AEBCBA, 0x00A6B1AE, 0x0087918B, 0x00727D7B, 0x005D6866, 0x0043504E, 0x0033403E, 0x00253331,
        0x0022302E, 0x0033413F, 0x00485956, 0x002B3E3B, 0x0021322F, 0x002D3B39, 0x00313E3C, 0x00434E4C, 0x00565E5D, 0x003F4544, 0x00292F2E, 0x00263234, 0x002D3836, 0x00212B25, 0x001C251B, 0x00070F05, 0x00070903, 0x000E0D09, 0x000B0908, 0x000C110F,
        0x00070C0A, 0x00010604, 0x00070A08, 0x000C0F0D, 0x000C0D0B, 0x00000100, 0x00090A08, 0x000A0B09, 0x000D0E0C, 0x00050806, 0x000C0F0D, 0x00050806, 0x000D1210, 0x00050A08, 0x00040907, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00060600, 0x00393933, 0x00C3C3BD, 0x00F6F4EC, 0x00B5B3AB, 0x0026241A, 0x00727066, 0x00FFFEF4, 0x00FDF2E4,
        0x00BEB7A8, 0x00201F11, 0x000E1207, 0x000D1209, 0x000B0F09, 0x000D0E0A, 0x00090A08, 0x000B0C08, 0x000C0D09, 0x000C0D09, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A,
        0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000B0F09, 0x000B0F09, 0x000C100A, 0x000C100A, 0x000C100A, 0x000C100A, 0x000D110B, 0x000D110B, 0x000C120D, 0x000C120D, 0x000C120D, 0x000C120D, 0x000C120D, 0x000D130E, 0x000D130E, 0x000D130E, 0x000E140F,
        0x000E140F, 0x000E140F, 0x000E140F, 0x000F1510, 0x000F1510, 0x000F1510, 0x000F1510, 0x000F160F, 0x000F160F, 0x000F160F, 0x000F160F, 0x000F160F, 0x000E150E, 0x000E150E, 0x000D140D, 0x000E150E, 0x000E150E, 0x000E150E, 0x000E150E, 0x000E150E,
        0x000E150E, 0x000E150E, 0x000E150E, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E,
        0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000E120C, 0x000E120C, 0x000E120C, 0x000E120C, 0x000E120C, 0x000F130D, 0x000F130D, 0x000F130D, 0x00161713, 0x00161713, 0x001D1E1A, 0x00111510, 0x00171B16,
        0x005D635E, 0x00676D68, 0x00383E39, 0x00585F58, 0x00555C55, 0x00545B54, 0x00565D56, 0x00596059, 0x00596059, 0x00565D56, 0x00525952, 0x00535A53, 0x004C534C, 0x004A514A, 0x005B625B, 0x00656C65, 0x005E655E, 0x005E655E, 0x00616861, 0xD1D5D5D5,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFCFC,
        0xFFF7FCFB, 0xFFEEF4F3, 0xE6DFE7E6, 0xC9D1DCDA, 0xB4C7D5D3, 0x00C0D1CE, 0x00BBCCC9, 0x00CDEAF1, 0x00D7F4F9, 0x00DAF3F7, 0x00C3D8DA, 0x00ABBDBC, 0x00AEBCBA, 0x00A9B7B3, 0x00929E98, 0x00859290, 0x00828F8D, 0x007F8D8B, 0x00778583, 0x0061726F,
        0x004D5E5B, 0x004E5F5C, 0x00586B68, 0x00435451, 0x00334441, 0x00354341, 0x00293634, 0x002A3533, 0x00384341, 0x00343C3B, 0x00313938, 0x00283436, 0x002B3836, 0x001F2B25, 0x0020291F, 0x000A1208, 0x00070903, 0x000B0A06, 0x000F0D0C, 0x00030904,
        0x00030904, 0x00080E09, 0x00050904, 0x00010500, 0x000B0C08, 0x0010110D, 0x000A0B07, 0x000B0C08, 0x000C0D09, 0x000A0B07, 0x000E120D, 0x00060A05, 0x00040A05, 0x00040A05, 0x000D130E, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x000C0B07, 0x00080802, 0x001B1B15, 0x0085827D, 0x00FAF8F0, 0x00DAD7CF, 0x0088867C, 0x00B4B2A8, 0x00F5EADC,
        0x00756E5F, 0x00050400, 0x00080C01, 0x000E130A, 0x00060A05, 0x00070806, 0x000C0D0B, 0x000B0C08, 0x000C0D09, 0x000C0D09, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A,
        0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000B0F09, 0x000B0F09, 0x000B0F09, 0x000C100A, 0x000C100A, 0x000C100A, 0x000C100A, 0x000D110B, 0x000B110C, 0x000C120D, 0x000C120D, 0x000C120D, 0x000C120D, 0x000C120D, 0x000D130E, 0x000D130E, 0x000E140F,
        0x000E140F, 0x000E140F, 0x000E140F, 0x000E140F, 0x000F1510, 0x000F1510, 0x000F1510, 0x000F160F, 0x000F160F, 0x000F160F, 0x000F160F, 0x000F160F, 0x000E150E, 0x000E150E, 0x000D140D, 0x000E150E, 0x000E150E, 0x000E150E, 0x000E150E, 0x000E150E,
        0x000E150E, 0x000E150E, 0x000E150E, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E,
        0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000E120C, 0x000E120C, 0x000E120C, 0x000E120C, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000E0F0B, 0x000E0F0B, 0x00131410, 0x0010140F, 0x000E120D,
        0x002E342F, 0x003D433E, 0x00414742, 0x00585F58, 0x005B625B, 0x005B625B, 0x00596059, 0x00596059, 0x00596059, 0x00555C55, 0x00505750, 0x00515851, 0x004A514A, 0x004C534C, 0x005C635C, 0x00646B64, 0x005E655E, 0x005F665F, 0x00656C65, 0xD5D8D8D8,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFE,
        0xFFFFFFFF, 0xFFFDFFFF, 0xFFFBFFFF, 0xFFF8FEFD, 0xF7E8F0EF, 0xC0CDD8D6, 0x92B7C2C0, 0x00C8DBE0, 0x00D3E6EB, 0x00DBECEF, 0x00CBDDDE, 0x00B5C5C4, 0x00AEBFBC, 0x00A7B8B4, 0x0095A4A0, 0x00818F8D, 0x007D8B89, 0x007F908D, 0x008A9B98, 0x008B9E9B,
        0x00839693, 0x007C8F8C, 0x00798E8B, 0x006F807D, 0x005E6F6C, 0x005A6866, 0x0042504E, 0x002D3A38, 0x00293432, 0x00202B29, 0x00212C2A, 0x00222E30, 0x0024312F, 0x001A2620, 0x001E291F, 0x000C140A, 0x00080C06, 0x00060703, 0x000C0A09, 0x000A100B,
        0x00000601, 0x00060C07, 0x000A0E09, 0x00090D08, 0x00030400, 0x000A0B07, 0x00070804, 0x000B0A06, 0x000A0B07, 0x00090A06, 0x00050602, 0x00060A05, 0x000A0E09, 0x00060C07, 0x00000601, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x000D0E0A, 0x00080703, 0x00070701, 0x000C0C06, 0x0046443C, 0x00DAD8D0, 0x00FCF9F1, 0x00B8B6AC, 0x00CCC1B3,
        0x00C4BCAF, 0x00464439, 0x00000400, 0x00171B15, 0x000E120D, 0x000E0F0D, 0x000C0D0B, 0x000B0C08, 0x000C0D09, 0x000C0D09, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A,
        0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000B0F09, 0x000B0F09, 0x000B0F09, 0x000C100A, 0x000C100A, 0x000C100A, 0x000C100A, 0x000C100A, 0x000B110C, 0x000B110C, 0x000B110C, 0x000C120D, 0x000C120D, 0x000C120D, 0x000C120D, 0x000D130E, 0x000D130E,
        0x000E140F, 0x000E140F, 0x000E140F, 0x000E140F, 0x000F1510, 0x000F1510, 0x000F1510, 0x000F160F, 0x000F160F, 0x000F160F, 0x000F160F, 0x000F160F, 0x000E150E, 0x000E150E, 0x000D140D, 0x000E150E, 0x000E150E, 0x000E150E, 0x000E150E, 0x000E150E,
        0x000E150E, 0x000E150E, 0x000E150E, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E,
        0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000E120C, 0x000E120C, 0x000E120C, 0x000E120C, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000D0E0A, 0x0012130F, 0x0011120E, 0x00111510, 0x000F130E,
        0x00101611, 0x00222823, 0x00515752, 0x005B625B, 0x005A615A, 0x00575E57, 0x00545B54, 0x00565D56, 0x00596059, 0x00585F58, 0x00535A53, 0x00565D56, 0x004C534C, 0x00525952, 0x005F665F, 0x00646B64, 0x005F665F, 0x005F665F, 0x00697069, 0xE2DDDDDD,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFF,
        0xFFFFFEFE, 0xFFFFFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFFFF, 0xFFEDF2F1, 0xE2DDE2E1, 0xB4C7D0D4, 0xB8CAD3D7, 0xB8CAD3D6, 0x00BDC9C9, 0x00AEBCBB, 0x00ADBBB9, 0x00ABBCB9, 0x00A3B4B0, 0x0096A7A4, 0x0091A29F, 0x008E9F9C, 0x008D9E9B, 0x00869996,
        0x00809390, 0x007F9491, 0x00839895, 0x008D9B99, 0x00808E8C, 0x007E8C8A, 0x0072807E, 0x005D6B69, 0x004C5957, 0x00384543, 0x00313E3C, 0x002C393B, 0x002C3937, 0x001F2B25, 0x001C271D, 0x00040D03, 0x000A0E08, 0x00090A06, 0x000B0C0A, 0x00050B06,
        0x00090F0A, 0x00090F0A, 0x00000300, 0x00080C07, 0x000D0E0A, 0x0011120E, 0x00090A06, 0x000B0A06, 0x000D0C08, 0x0010110D, 0x000C0D09, 0x000F100C, 0x00090D08, 0x000A0E09, 0x00070B06, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00090A06, 0x000A0B07, 0x001C1D19, 0x000B0B05, 0x00020200, 0x00403E36, 0x00C7C5BD, 0x00F2F0E8, 0x00E8DCD0,
        0x00FFF7EA, 0x00B4B2A7, 0x001F2219, 0x00050903, 0x00010500, 0x00141513, 0x000A0A0A, 0x000B0C08, 0x000C0D09, 0x000C0D09, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A,
        0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000B0F09, 0x000B0F09, 0x000B0F09, 0x000B0F09, 0x000C100A, 0x000C100A, 0x000C100A, 0x000C100A, 0x000B110C, 0x000B110C, 0x000B110C, 0x000B110C, 0x000C120D, 0x000C120D, 0x000C120D, 0x000C120D, 0x000D130E,
        0x000D130E, 0x000D130E, 0x000E140F, 0x000E140F, 0x000E140F, 0x000E140F, 0x000F1510, 0x000F160F, 0x000F160F, 0x000F160F, 0x000F160F, 0x000F160F, 0x000E150E, 0x000E150E, 0x000D140D, 0x000E150E, 0x000E150E, 0x000E150E, 0x000E150E, 0x000E150E,
        0x000E150E, 0x000E150E, 0x000E150E, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E,
        0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000E120C, 0x000E120C, 0x000E120C, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x0010140E, 0x000E0F0B, 0x00181915, 0x00141511, 0x000E120D, 0x00131712,
        0x00121813, 0x00272D28, 0x00575D58, 0x005D645D, 0x00565D56, 0x00505750, 0x00525952, 0x00575E57, 0x00585F58, 0x00545B54, 0x00505750, 0x00525952, 0x00424942, 0x004D544D, 0x005A615A, 0x00606760, 0x00616861, 0x00606760, 0x006E756E, 0xEEE3E3E3,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFE,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFE, 0xFFFDFBFB, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFDFE, 0xFFF2F6F7, 0xF7E7EBEC, 0xD5D7DCDD, 0xA7C2CCCC, 0x8EB6C3C1, 0x79ABB9B7, 0x00A1AFAD, 0x00A6B4B2, 0x009FADAB, 0x0096A4A2, 0x008D9E9B, 0x00899A97,
        0x00869794, 0x00849794, 0x00869996, 0x00919F9D, 0x00879593, 0x008B9997, 0x008C9A98, 0x0083918F, 0x00758683, 0x00677875, 0x0060716E, 0x006C797B, 0x006B7977, 0x0056645E, 0x003B463C, 0x00040D03, 0x00080F08, 0x000A0E09, 0x000E0F0D, 0x00060D06,
        0x00030A03, 0x000A110A, 0x00090D07, 0x00060A04, 0x00090B05, 0x00070903, 0x00090B05, 0x000B0B05, 0x00030300, 0x00020200, 0x00050701, 0x000C0E08, 0x00090B05, 0x00080C06, 0x00090D07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00111412, 0x000E0F0D, 0x00030400, 0x00080905, 0x001E1E18, 0x00020200, 0x003B3833, 0x00C9C7BF, 0x00ADA195,
        0x00B2A99F, 0x00C8C6BC, 0x002E3128, 0x00000300, 0x00171A18, 0x00060606, 0x00121212, 0x000B0C08, 0x000C0D09, 0x000C0D09, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A,
        0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000A0E08, 0x000B0F09, 0x000B0F09, 0x000B0F09, 0x000B0F09, 0x000C100A, 0x000C100A, 0x000C100A, 0x000B110C, 0x000B110C, 0x000B110C, 0x000B110C, 0x000C120D, 0x000C120D, 0x000C120D, 0x000C120D, 0x000D130E,
        0x000D130E, 0x000D130E, 0x000D130E, 0x000E140F, 0x000E140F, 0x000E140F, 0x000E140F, 0x000F160F, 0x000F160F, 0x000F160F, 0x000F160F, 0x000F160F, 0x000E150E, 0x000E150E, 0x000D140D, 0x000E150E, 0x000E150E, 0x000E150E, 0x000E150E, 0x000E150E,
        0x000E150E, 0x000E150E, 0x000E150E, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E,
        0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000E120C, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x0010140E, 0x0010140E, 0x0010140E, 0x000D0E0A, 0x00151612, 0x0011120E, 0x000A0E09, 0x0010140F,
        0x00161C17, 0x00323833, 0x00535954, 0x005C635C, 0x00555C55, 0x00535A53, 0x005A615A, 0x005B625B, 0x00545B54, 0x004E554E, 0x004F564F, 0x005D645D, 0x00464D46, 0x00545B54, 0x005F665F, 0x00626962, 0x00656C65, 0x00606760, 0x00707770, 0xFBEAEAEA,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFAFA,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFE, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFBFDFD, 0xFFFCFEFE, 0xFFF8FDFC, 0xFFF2F8F7, 0xF7E8EDEE, 0xDEDCE4E4, 0xABC4CCCB, 0x8EB5C0BE, 0x6DA6B1AF, 0x5C9EA9A7, 0x009CA9A7,
        0x0099A6A4, 0x008F9D9B, 0x00859391, 0x008B9896, 0x00859290, 0x00889694, 0x008B9997, 0x00849592, 0x007D908D, 0x007A8D8A, 0x00778A87, 0x008E9D9F, 0x0097A5A3, 0x008C9A94, 0x00627065, 0x000A1309, 0x00060D06, 0x00080C07, 0x00080B09, 0x000C130C,
        0x00000600, 0x00060D06, 0x00060A04, 0x00000200, 0x00191B15, 0x000A0C06, 0x00050701, 0x00302D28, 0x00413E39, 0x0033332D, 0x00181812, 0x00000200, 0x000D0F09, 0x000C0E08, 0x00010500, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00040705, 0x000B0E0C, 0x00121311, 0x000B0C08, 0x00090A06, 0x0011110B, 0x00060600, 0x00494943, 0x00D8CCC2,
        0x003C3329, 0x00222016, 0x000C0F06, 0x00000200, 0x00111412, 0x000D0D0D, 0x00070608, 0x000B0C08, 0x000C0D09, 0x000C0D09, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A,
        0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000A0E08, 0x000A0E08, 0x000A0E08, 0x000B0F09, 0x000B0F09, 0x000B0F09, 0x000B0F09, 0x000C100A, 0x000A100B, 0x000B110C, 0x000B110C, 0x000B110C, 0x000B110C, 0x000C120D, 0x000C120D, 0x000C120D, 0x000D130E,
        0x000D130E, 0x000D130E, 0x000D130E, 0x000D130E, 0x000E140F, 0x000E140F, 0x000E140F, 0x000F160F, 0x000F160F, 0x000F160F, 0x000F160F, 0x000F160F, 0x000E150E, 0x000E150E, 0x000D140D, 0x000E150E, 0x000E150E, 0x000E150E, 0x000E150E, 0x000E150E,
        0x000E150E, 0x000E150E, 0x000E150E, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E,
        0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x0010140E, 0x0010140E, 0x0010140E, 0x0010140E, 0x0010110D, 0x0010110D, 0x0010110D, 0x000E120D, 0x000F130E,
        0x00121813, 0x00383E39, 0x00555B56, 0x005B625B, 0x00555C55, 0x00555C55, 0x00596059, 0x00565D56, 0x00515851, 0x00525952, 0x005A615A, 0x00596059, 0x00414841, 0x00585F58, 0x00636A63, 0x00636A63, 0x00676E67, 0x00606760, 0x04747B74, 0xFFF0F0F0,
        0xFFFEFEFE, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFFFF,
        0xFFFBFFFF, 0xFFFCFEFE, 0xFFFBFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFCFC, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFBFFFF, 0xFFFAFFFE, 0xFFEDF3F2, 0xD5D8DEDD, 0xABC4CAC9,
        0x86B1B9B8, 0x69A4ACAB, 0x549AA2A1, 0x0097A4A2, 0x00909D9B, 0x008C9A98, 0x00889996, 0x00809390, 0x007E918E, 0x007E9390, 0x007B908D, 0x007D8C8E, 0x00859693, 0x008C9C95, 0x006C7A6F, 0x00061107, 0x00040B04, 0x00080C07, 0x00070A08, 0x00010900,
        0x000D150B, 0x00050D03, 0x00020700, 0x00262B22, 0x007A7D74, 0x0035382F, 0x00030600, 0x00605E56, 0x009A9890, 0x00908E86, 0x004E4F46, 0x00020300, 0x000D1007, 0x000F1209, 0x000C0F06, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x000D0F0F, 0x00050806, 0x000C0F0D, 0x00141513, 0x00070804, 0x000E0D09, 0x00393933, 0x00767670, 0x00F4E8DE,
        0x009B9288, 0x00110F05, 0x00070903, 0x00131712, 0x00060808, 0x000C0B0D, 0x000E0D0F, 0x000B0C08, 0x000C0D09, 0x000C0D09, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A,
        0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000A0E08, 0x000A0E08, 0x000A0E08, 0x000B0F09, 0x000B0F09, 0x000B0F09, 0x000B0F09, 0x000B0F09, 0x000A100B, 0x000A100B, 0x000B110C, 0x000B110C, 0x000B110C, 0x000B110C, 0x000B110C, 0x000C120D, 0x000C120D,
        0x000D130E, 0x000D130E, 0x000D130E, 0x000D130E, 0x000E140F, 0x000E140F, 0x000E140F, 0x000F160F, 0x000F160F, 0x000F160F, 0x000F160F, 0x000F160F, 0x000E150E, 0x000E150E, 0x000D140D, 0x000E150E, 0x000E150E, 0x000E150E, 0x000E150E, 0x000E150E,
        0x000E150E, 0x000E150E, 0x000E150E, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E,
        0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x0010140E, 0x0010140E, 0x0010140E, 0x0010140E, 0x00151612, 0x0011120E, 0x0012130F, 0x0010140F, 0x00121611,
        0x00131914, 0x003E443F, 0x005C625D, 0x005A615A, 0x00575E57, 0x00535A53, 0x00515851, 0x00525952, 0x00535A53, 0x00525952, 0x004F564F, 0x00373E37, 0x00262D26, 0x004F564F, 0x005F665F, 0x005E655E, 0x00656C65, 0x00626962, 0x197E857E, 0xFFF4F4F4,
        0xFFFDFDFD, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFF9FFFE,
        0xFFFAFFFF, 0xFFFBFFFF, 0xFFFBFFFF, 0xFFFAFCFC, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFBFFFA, 0xFFFDFFFC, 0xFFFFFFFE, 0xFFFEFFFD, 0xFFFFFEFE, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFDFF, 0xFFFDFDFD, 0xFFFDFFFF, 0xFFFDFFFF, 0xFFFDFFFF, 0xFFFBFFFF,
        0xFFFBFFFF, 0xFFECF2F1, 0xE2DEE4E3, 0xABC3CECC, 0x86B2BFBD, 0x609FADAB, 0x4391A29F, 0x00869996, 0x00829794, 0x00819894, 0x007A918D, 0x008B9A9C, 0x00869794, 0x008B9B94, 0x006D7B70, 0x00040F05, 0x00030B04, 0x00090F0A, 0x00090C0A, 0x00040C02,
        0x00070F05, 0x00010900, 0x00444940, 0x00A6ABA2, 0x00D5D8CF, 0x0034372E, 0x00000300, 0x00626058, 0x008D8B83, 0x007E7C74, 0x0054554C, 0x000A0B02, 0x0012130A, 0x00070A01, 0x000B0E05, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00070C0B, 0x00080A0A, 0x000C0F0D, 0x00070A08, 0x000D0E0A, 0x0012130F, 0x00BAB9B5, 0x00F9F9F3, 0x00FFF3E9,
        0x00B0A79E, 0x000C0901, 0x00090B05, 0x000E120D, 0x00080A0A, 0x000E0D0F, 0x000B0A0C, 0x000B0C08, 0x000C0D09, 0x000C0D09, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A,
        0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000A0E08, 0x000A0E08, 0x000A0E08, 0x000A0E08, 0x000B0F09, 0x000B0F09, 0x000B0F09, 0x000B0F09, 0x000A100B, 0x000A100B, 0x000A100B, 0x000B110C, 0x000B110C, 0x000B110C, 0x000B110C, 0x000B110C, 0x000C120D,
        0x000C120D, 0x000D130E, 0x000D130E, 0x000D130E, 0x000D130E, 0x000E140F, 0x000E140F, 0x000F160F, 0x000F160F, 0x000F160F, 0x000F160F, 0x000F160F, 0x000E150E, 0x000E150E, 0x000D140D, 0x000E150E, 0x000E150E, 0x000E150E, 0x000E150E, 0x000E150E,
        0x000E150E, 0x000E150E, 0x000E150E, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E,
        0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130D, 0x000F130D, 0x000F130D, 0x0010140E, 0x0010140E, 0x0010140E, 0x0010140E, 0x0010140E, 0x00141511, 0x00141511, 0x0011120E, 0x000C100B, 0x00131712,
        0x00171D18, 0x00444A45, 0x005E645F, 0x005B625B, 0x00596059, 0x00545B54, 0x00525952, 0x00575E57, 0x00585F58, 0x00444B44, 0x002B322B, 0x00343B34, 0x00282F28, 0x005A615A, 0x006A716A, 0x00626962, 0x00656C65, 0x00626962, 0x21828982, 0xFFF7F7F7,
        0xFFFDFDFD, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFF7F7F7, 0xF7E7E7E7, 0xD1D6D6D6, 0xABC3C3C3, 0x82AFAFAF, 0x609F9F9F, 0x3B8D9C98, 0x00869591, 0x008B9995, 0x00717D77, 0x000A140E, 0x00060D08, 0x00091009, 0x00080C06, 0x00020706,
        0x00040606, 0x003D3E3A, 0x00D7D7D1, 0x00D2D0C6, 0x00CECABF, 0x00463E31, 0x000B0400, 0x00343630, 0x00707168, 0x008F8E84, 0x0059574C, 0x000A0800, 0x00040500, 0x00060A05, 0x00070C0B, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00090D07, 0x00090D07, 0x00090D07, 0x0009100D, 0x00030A05, 0x000B0F0A, 0x000C0D09, 0x000D0A05, 0x00060200, 0x0098928B, 0x00F9F1EA, 0x00797465,
        0x00211D12, 0x000F1007, 0x000A0E09, 0x00070C0A, 0x00070A08, 0x00090A06, 0x000E0E08, 0x000B0D07, 0x000B0D07, 0x000B0C08, 0x000C0D09, 0x000C0D09, 0x000C0D0B, 0x000C0D0B, 0x000C0D0B, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A,
        0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000D110C, 0x000D110C, 0x000B110C, 0x000B110C, 0x000B110C, 0x000B110C,
        0x000B110C, 0x000B110C, 0x000C120D, 0x000C120D, 0x000D130E, 0x000D130E, 0x000E140F, 0x000D150E, 0x00111912, 0x000E160F, 0x00141B14, 0x000D140D, 0x00080C06, 0x00131711, 0x000D110B, 0x000F160F, 0x000F160F, 0x000F160F, 0x000F160F, 0x000F160F,
        0x000F160F, 0x000F160F, 0x000F160F, 0x000D140D, 0x000D140D, 0x000D140D, 0x000D140D, 0x000D140D, 0x000D140D, 0x000D140D, 0x000D140D, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E,
        0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x0010140F, 0x0010140F, 0x0010140F, 0x0010140F, 0x0010140F, 0x000E120D, 0x0010140F, 0x000C100B, 0x00121813, 0x000D130E,
        0x001A201B, 0x004B524D, 0x005E6560, 0x005B6359, 0x0050584E, 0x00586056, 0x005B625B, 0x00575E57, 0x00343A35, 0x002F3530, 0x00424843, 0x00585E59, 0x00343A35, 0x00555B56, 0x00636964, 0x005D635E, 0x00656B66, 0x00646A65, 0x1D7F8580, 0xFFF8FEF9,
        0xFFFAFFFB, 0xFFFBFFFC, 0xFFFDFFFC, 0xFFFDFFFC, 0xFFFDFFFC, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCFCFC, 0xFFFBFBFB, 0xFFF8F8F8, 0xFFF2F2F2, 0xFFEBEBEB, 0xB4C7D2CF, 0x8EB6C1BE, 0x7DAEB7B4, 0x2A858C87, 0x000B110C, 0x00060A05, 0x000D110B, 0x000B0D07, 0x00090E0D,
        0x00050806, 0x0020211D, 0x00898983, 0x00DCD9D1, 0x00D2CEC3, 0x00352F22, 0x00130B00, 0x0061635D, 0x005A5B52, 0x0095948A, 0x00454338, 0x00060400, 0x00111209, 0x000B0F0A, 0x00080D0C, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00090D07, 0x00090D07, 0x00090D07, 0x00010805, 0x00080E09, 0x00050904, 0x000E0F0B, 0x002B2823, 0x00534F4A, 0x004F4942, 0x00D7CFC8, 0x00736E5F,
        0x00070300, 0x00101108, 0x000B0F0A, 0x00060B09, 0x00060907, 0x00090A06, 0x000E0E08, 0x000B0D07, 0x000B0D07, 0x000B0C08, 0x000C0D09, 0x000C0D09, 0x000C0D0B, 0x000C0D0B, 0x000C0D0B, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A,
        0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000C100B, 0x000D110C, 0x000B110C, 0x000B110C, 0x000B110C, 0x000B110C,
        0x000B110C, 0x000B110C, 0x000C120D, 0x000C120D, 0x000D130E, 0x000D130E, 0x000D130E, 0x000B130C, 0x000D150E, 0x00050D06, 0x00141B14, 0x00131A13, 0x00151913, 0x000E120C, 0x000F130D, 0x000C130C, 0x000C130C, 0x000C130C, 0x000E150E, 0x00101710,
        0x00101710, 0x000E150E, 0x000C130C, 0x000D140D, 0x000D140D, 0x000D140D, 0x000D140D, 0x000D140D, 0x000D140D, 0x000D140D, 0x000D140D, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E,
        0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x0010140F, 0x0010140F, 0x0010140F, 0x0010140F, 0x000E120D, 0x000F130E, 0x000D110C, 0x00121813, 0x000E140F,
        0x001C221D, 0x004C534E, 0x005F6661, 0x00596157, 0x005D655B, 0x005F665F, 0x00464D46, 0x00343B34, 0x00373D38, 0x00474D48, 0x003C423D, 0x002E342F, 0x002E342F, 0x00585E59, 0x00626863, 0x00626863, 0x00656B66, 0x00616762, 0x2E878D88, 0xFFF9FEFC,
        0xFFFAFFFD, 0xFFFAFFFD, 0xFFFCFFFD, 0xFFFAFDFB, 0xFFFCFDFB, 0xFFFDFEFC, 0xFFFFFFFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFFFE, 0xFFF7FCFA, 0xFFF1F6F4, 0x92B9BDB8, 0x001C1D19, 0x00040501, 0x0010100A, 0x000E0E08, 0x00080A0A,
        0x000B0E0C, 0x00020300, 0x00292923, 0x00A4A29A, 0x00DEDCD2, 0x00444035, 0x000A0600, 0x004B4D47, 0x00909188, 0x005F5E54, 0x0068665B, 0x000D0B01, 0x00101108, 0x00070B06, 0x00030807, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00090D07, 0x00090D07, 0x00090D07, 0x000C110F, 0x00090F0A, 0x00070B06, 0x00030400, 0x00484842, 0x00FFFCF7, 0x00BEBBB3, 0x00B0AAA3, 0x00CCC7B8,
        0x00403C31, 0x00050600, 0x000B0F0A, 0x00070C0A, 0x000B0E0C, 0x00161713, 0x000B0B05, 0x000B0D07, 0x000B0D07, 0x000B0C08, 0x000C0D09, 0x000C0D09, 0x000C0D0B, 0x000C0D0B, 0x000C0D0B, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A,
        0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000C100B, 0x000D110C, 0x000B110C, 0x000B110C, 0x000B110C, 0x000B110C,
        0x000B110C, 0x000B110C, 0x000C120D, 0x000C120D, 0x000D130E, 0x000D130E, 0x000D130E, 0x000F1710, 0x000B130C, 0x00070E07, 0x00101710, 0x000D110B, 0x00151913, 0x000D110B, 0x00151711, 0x00111811, 0x00101710, 0x000F160F, 0x000E150E, 0x000D140D,
        0x000E150E, 0x00101710, 0x00111811, 0x000D140D, 0x000D140D, 0x000D140D, 0x000D140D, 0x000D140D, 0x000D140D, 0x000D140D, 0x000D140D, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E,
        0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x0010140F, 0x0010140F, 0x0010140F, 0x0010140F, 0x000D110C, 0x000F130E, 0x000E120D, 0x00111712, 0x000E140F,
        0x00212722, 0x00505752, 0x00636A65, 0x00596157, 0x005D645D, 0x00444B44, 0x002B322B, 0x003E443F, 0x00838984, 0x00BFC4C2, 0x00B8BDBB, 0x00A3A9A4, 0x00848A85, 0x00747A75, 0x00646A65, 0x00646A65, 0x005B615C, 0x005A605B, 0x549AA09B, 0xFFFBFFFF,
        0xFFFBFFFF, 0xFFFDFFFF, 0xFFFDFFFF, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xC4D4D3CF, 0x0023221E, 0x00040300, 0x0010100A, 0x000F0C07, 0x00040705,
        0x0010110F, 0x00000100, 0x00050500, 0x00363630, 0x00B4B2AA, 0x00524F47, 0x00050300, 0x0040423C, 0x0065665D, 0x0058574D, 0x00514F44, 0x000B0900, 0x00050600, 0x00131712, 0x00000504, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00090D07, 0x00090D07, 0x00090D07, 0x00060907, 0x00070B06, 0x00171814, 0x000A0905, 0x00161610, 0x00A9A6A1, 0x00FAF8F0, 0x00E0DDD5, 0x00F2EDDE,
        0x00B6B2A7, 0x00191A11, 0x00070B06, 0x000E1311, 0x00050806, 0x000B0C08, 0x000F0F09, 0x000B0D07, 0x000B0D07, 0x000B0C08, 0x000C0D09, 0x000C0D09, 0x000C0D0B, 0x000C0D0B, 0x000C0D0B, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A,
        0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000D0E0A, 0x000E0F0B, 0x000E0F0B, 0x000C100B, 0x000C100B, 0x000B110C, 0x000B110C, 0x000B110C, 0x000A100B,
        0x000A100B, 0x000B110C, 0x000B110C, 0x000C120D, 0x000C120D, 0x000D130E, 0x000D130E, 0x000D140D, 0x000A110A, 0x00131A13, 0x0010140E, 0x000E120C, 0x00141610, 0x00141610, 0x0010120C, 0x0010140E, 0x00141812, 0x00171B15, 0x00161A14, 0x0011150F,
        0x000D110B, 0x000E120C, 0x0010140E, 0x000D140D, 0x000D140D, 0x000D140D, 0x000D140D, 0x000D140D, 0x000D140D, 0x000D140D, 0x000D140D, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E,
        0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000E120D, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x0010140F, 0x0010140F, 0x0010140F, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F1510, 0x000F1510,
        0x00282E29, 0x00555C57, 0x00676E69, 0x00616861, 0x005D645D, 0x00404740, 0x00585E59, 0x00939994, 0x00D2D7D5, 0x00FBFFFE, 0x00FBFFFE, 0x00F8FDFB, 0x00F1F6F4, 0x00EDF2F0, 0x00D9DEDC, 0x00BDC2C0, 0x00848987, 0x00626765, 0x00909593, 0xFFFDFFFF,
        0xFFFDFFFF, 0xFFFDFFFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFDFC, 0xFFFDF9F8, 0xFFFEFAF9, 0xBCD3D0CC, 0x0024231F, 0x00060501, 0x0010100A, 0x00070701, 0x000C0D09,
        0x000A0B07, 0x000B0C08, 0x0013120E, 0x00020200, 0x004A4A44, 0x0032322C, 0x00040400, 0x0031332D, 0x006A6B62, 0x00908F85, 0x003D3B30, 0x00110F05, 0x000B0C03, 0x00050904, 0x00090E0D, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00090D07, 0x00090D07, 0x00090D07, 0x0010110F, 0x00050602, 0x00070602, 0x0012110D, 0x00020200, 0x002D2D27, 0x00CACBC2, 0x00C7C5BD, 0x00C3BEAF,
        0x00FFFFF7, 0x0095968D, 0x00070B06, 0x00040907, 0x000F1210, 0x00080905, 0x00060600, 0x000B0D07, 0x000B0D07, 0x000B0C08, 0x000C0D09, 0x000C0D09, 0x000C0D0B, 0x000C0D0B, 0x000C0D0B, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A,
        0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000C100B, 0x000C100B, 0x000A100B, 0x000A100B, 0x000B110C, 0x000A100B,
        0x000A100B, 0x000B110C, 0x000B110C, 0x000C120D, 0x000C120D, 0x000D130E, 0x000D130E, 0x000A110A, 0x00131A13, 0x00151913, 0x00010500, 0x000C0E08, 0x00010300, 0x000E100A, 0x0015150F, 0x000D110B, 0x000E120C, 0x0010140E, 0x0011150F, 0x0010140E,
        0x0010140E, 0x0010140E, 0x0010140E, 0x000D140D, 0x000D140D, 0x000D140D, 0x000D140D, 0x000D140D, 0x000D140D, 0x000D140D, 0x000D140D, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E,
        0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000E120D, 0x000E120D, 0x000E120D, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x0010140F, 0x0010140F, 0x000F130E, 0x000F130E, 0x000D130E, 0x00101611,
        0x002E342F, 0x00585F5A, 0x00686F6A, 0x00656C65, 0x005C635C, 0x00646A65, 0x00B9BFBA, 0x00E9EEEC, 0x00F4F9F7, 0x00F1F6F5, 0x00EBF0EF, 0x00F1F6F4, 0x00F3F8F6, 0x00F4F9F7, 0x00F4F9F7, 0x00FBFFFE, 0x00F0F5F3, 0x00CED3D1, 0x00CACFCD, 0xFFF8FAFB,
        0xFFF9FBFC, 0xFFFCFBFD, 0xFFFEFDFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xDEE0DFDB, 0x002C2D29, 0x00060703, 0x000B0F09, 0x00050903, 0x000F0E0A,
        0x00080703, 0x000F100C, 0x000F100C, 0x00070804, 0x00040501, 0x000E0F0B, 0x00090A06, 0x00141610, 0x001E1F16, 0x00313026, 0x006D6B60, 0x000B0900, 0x000D0E05, 0x00090D08, 0x00050A09, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090706, 0x0023221E, 0x00070602, 0x0012110D, 0x001C1C16, 0x00020200, 0x0054554C, 0x00BFC2B9, 0x005A5546,
        0x00736F64, 0x00A4A59C, 0x001A1E19, 0x00000100, 0x00050806, 0x000E0F0B, 0x00161610, 0x000B0D07, 0x000B0D07, 0x000B0C08, 0x000C0D09, 0x000C0D09, 0x000C0D0B, 0x000C0D0B, 0x000C0D0B, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A,
        0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000B0F0A, 0x000C100B, 0x000A100B, 0x000A100B, 0x000A100B, 0x000A100B,
        0x000A100B, 0x000A100B, 0x000B110C, 0x000B110C, 0x000C120D, 0x000C120D, 0x000C120D, 0x000E120C, 0x000E120C, 0x00040802, 0x004D4F49, 0x008D8F89, 0x00777973, 0x004B4B45, 0x001B1B15, 0x000C0E08, 0x000A0C06, 0x000A0C06, 0x000F110B, 0x00171913,
        0x001A1C16, 0x00151711, 0x0010120C, 0x000D140D, 0x000D140D, 0x000D140D, 0x000D140D, 0x000D140D, 0x000D140D, 0x000D140D, 0x000D140D, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E,
        0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x00111510, 0x000F130E, 0x0010140F, 0x000D130E, 0x00121813,
        0x00323833, 0x00555C57, 0x005F6661, 0x006D736E, 0x005B615C, 0x00878D88, 0x00F4F9F7, 0x00FBFFFE, 0x00F5FAF9, 0x00F4F9F8, 0x00F0F5F4, 0x00EEF3F2, 0x00F1F6F5, 0x00F4F9F8, 0x00F0F5F4, 0x00F0F5F4, 0x00F2F7F6, 0x00F3F8F7, 0x00F7FCFB, 0x00F9FCFA,
        0xFFFBFCFA, 0xFFFCFDFB, 0xFFFEFFFD, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBF7F6, 0xFFFFFFFE, 0xFFFFFFFE, 0xF2E8E9E5, 0x00313530, 0x00000601, 0x00050D06, 0x0009110A, 0x000B0B05,
        0x000A0A04, 0x000B0A06, 0x00040501, 0x00121311, 0x00020503, 0x00050806, 0x00060808, 0x003B3D37, 0x0072736A, 0x00838278, 0x006B695E, 0x00121006, 0x000D0E05, 0x00070B06, 0x00040908, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00090D07, 0x00090D07, 0x00090D07, 0x00171312, 0x009D9A96, 0x008C8985, 0x00090804, 0x000F0F09, 0x00090B05, 0x00050800, 0x0074776E, 0x00B7B2A3,
        0x001F1B10, 0x000E0F06, 0x00040803, 0x00101513, 0x000B0E0C, 0x000C0D09, 0x000B0B05, 0x000B0D07, 0x000B0D07, 0x000B0C08, 0x000C0D09, 0x000C0D09, 0x000C0D0B, 0x000C0D0B, 0x000C0D0B, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A,
        0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000B0F0A, 0x000C100B, 0x000A100B, 0x000A100B, 0x000A100B, 0x000A100B,
        0x000A100B, 0x000A100B, 0x000B110C, 0x000B110C, 0x000C120D, 0x000C120D, 0x000C120D, 0x000D110B, 0x00131711, 0x00141812, 0x00A7A9A3, 0x00A7A9A3, 0x00A8A8A2, 0x00BFBFB9, 0x00C9C9C3, 0x00A5A7A1, 0x00848680, 0x0051534D, 0x00242620, 0x000B0D07,
        0x00070903, 0x000D0F09, 0x00141610, 0x000D140D, 0x000D140D, 0x000D140D, 0x000D140D, 0x000D140D, 0x000D140D, 0x000D140D, 0x000D140D, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E,
        0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x00111510, 0x000E120D, 0x00111510, 0x000D130E, 0x00131914,
        0x00323833, 0x004C534E, 0x004F5651, 0x00545A55, 0x00434944, 0x00838886, 0x00F6FBF9, 0x00F0F5F4, 0x00F3F8F7, 0x00F8FDFC, 0x00FBFFFF, 0x00FBFFFF, 0x00F3F8F7, 0x00EDF2F1, 0x00F3F8F7, 0x00F5FAF9, 0x00F3F8F7, 0x00F3F8F7, 0x00F1F6F5, 0x00FBFDF7,
        0x00F9FBF5, 0x00F8FAF4, 0x00FAFAF4, 0xFFFDFDF7, 0xFFFFFEF9, 0xFFFFFFFA, 0xFFFFFFFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFEFFFD, 0xEAE3E7E2, 0x00323833, 0x00000702, 0x00000A02, 0x00000D05, 0x000D0D07,
        0x000E0E08, 0x00090804, 0x000E0F0B, 0x00020503, 0x000E1010, 0x00030807, 0x00060B0A, 0x00060802, 0x0015160D, 0x00222117, 0x00131106, 0x00121006, 0x00020300, 0x000E120D, 0x00050A09, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090403, 0x0073706C, 0x00F7F4F0, 0x00666561, 0x00030300, 0x000D0F09, 0x000A0F06, 0x00010600, 0x00B5B0A1,
        0x00878378, 0x00070800, 0x000B0F0A, 0x00080D0B, 0x00040705, 0x000C0D09, 0x000A0A04, 0x000B0D07, 0x000B0D07, 0x000B0C08, 0x000C0D09, 0x000C0D09, 0x000C0D0B, 0x000C0D0B, 0x000C0D0B, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A,
        0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000B0F0A, 0x000B0F0A, 0x000A100B, 0x000A100B, 0x000A100B, 0x00090F0A,
        0x000A100B, 0x000A100B, 0x000B110C, 0x000B110C, 0x000C120D, 0x000C120D, 0x000C120D, 0x0010140E, 0x000C100A, 0x0012140E, 0x00B8BAB4, 0x0031312B, 0x00040400, 0x0025251F, 0x003B3833, 0x00696B65, 0x008A8C86, 0x00B4B6B0, 0x00C9CBC5, 0x00B9BBB5,
        0x008B8D87, 0x00585A54, 0x00373933, 0x000D140D, 0x000D140D, 0x000D140D, 0x000D140D, 0x000D140D, 0x000D140D, 0x000D140D, 0x000D140D, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E,
        0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000F130E, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000F130E, 0x000F130E, 0x000F130E, 0x0010140F, 0x000D110C, 0x00111510, 0x000D130E, 0x00141A15,
        0x00313732, 0x00454C47, 0x00434A45, 0x00474D48, 0x003B413C, 0x00797E7C, 0x00ECF1EF, 0x00EDF2F1, 0x00EFF4F3, 0x00E4E9E8, 0x00EDF1F2, 0x00EDF2F1, 0x00F9FEFD, 0x00F9FEFD, 0x00F1F6F5, 0x00E8EDEC, 0x00E9EEED, 0x00F1F6F5, 0x00EFF4F3, 0x00F5F8EF,
        0x00F1F4EB, 0x00EFF0E7, 0x00EEEFE6, 0x00F0F1E8, 0x00F6F4EC, 0x00F8F6EE, 0xFFF9F7EF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFFFE, 0xFFFDFFFE, 0xFFFAFDFB, 0xF7E9EDE8, 0x00353934, 0x00020601, 0x000B0F09, 0x00050903, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00060A04, 0x00080C06, 0x00060A04, 0x000A0E08, 0x00030701, 0x000C100A, 0x00070B05, 0x00000200, 0x00090900, 0x00131307, 0x00919086, 0x006A6860, 0x00060200, 0x00221D1A, 0x009B9695, 0x00A09B9A, 0x00CDCBC0,
        0x00DBD9CE, 0x00212016, 0x00070800, 0x0011130D, 0x00090A06, 0x000B0E0C, 0x00060B09, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07,
        0x00090D07, 0x00090D07, 0x00090D07, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000C100B, 0x000C100B, 0x000C100B, 0x000A100B,
        0x000A100B, 0x000A100B, 0x000B110C, 0x000B110C, 0x000B110C, 0x000B110C, 0x000B110C, 0x000D140D, 0x000D110B, 0x001C1C16, 0x00B9B6B1, 0x002F2C27, 0x0013130D, 0x00121610, 0x000B120B, 0x00000F06, 0x002B2F29, 0x00362D29, 0x003E3531, 0x00595651,
        0x00898B85, 0x00AAA7A2, 0x00D7CECA, 0x00BFC3B8, 0x0067685E, 0x00100E06, 0x00343129, 0x00292520, 0x00161610, 0x00131712, 0x000B110C, 0x0010140E, 0x0010140E, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000E120C, 0x000E120C, 0x000F130E,
        0x000F130E, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000F130E, 0x000F130E, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000D1211, 0x000B100E, 0x00111412, 0x000D110C, 0x001B1E15,
        0x003B3C32, 0x0044453B, 0x003C3E32, 0x004D392E, 0x002F2D22, 0x006D7C74, 0x00E8F7F3, 0x00C8CDCC, 0x00ECE6E7, 0x00F7EFEF, 0x00F3F0EC, 0x00DDE4F5, 0x00F0F7FF, 0x00DBE3E2, 0x00C8D1C7, 0x00DBE3D8, 0x00E3EBE4, 0x00E0E5E6, 0x00E5EBF2, 0x00DAE6E6,
        0x00E1EBE5, 0x00FFFFF7, 0x00FEFBE6, 0x00E5D8B8, 0x00F2D9AF, 0x00ECC898, 0x00F4C996, 0x00FAD494, 0x82FFE3B0, 0xD5FFF5D8, 0xFFFFFEF5, 0xFFFFFEFF, 0xFFFFFDFF, 0xFFFFFDFE, 0xFFFFFEF9, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFDFF, 0xFFFFFBFF,
        0xFFFFF9FF, 0xFFFFF9FF, 0xFFFFF9FF, 0xFFFDFFFF, 0xFFFDFFFF, 0xFFFDFEFF, 0xFFFDFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFE, 0xFFFFFFFE, 0xFFFFFEFD, 0xFFFFFEFD, 0xFFFFFFFE, 0xFFFEFFFD, 0xFFFCFFFD, 0xFFFBFEFC, 0xFFFFFEF7,
        0xFFFFFFFA, 0xFFFFFFFB, 0xFFFFFFFC, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFDFDFD, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFFFE, 0xFFFDFFFE, 0xFFF9FCFA, 0xF7E8ECE7, 0x00363A35, 0x00000300, 0x000A0E08, 0x00070B05, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x000E120C, 0x000E120C, 0x00070B05, 0x00070B05, 0x000D110B, 0x00050903, 0x00070B05, 0x005C605A, 0x00474338, 0x00131106, 0x00050300, 0x0018150D, 0x00060300, 0x00201D19, 0x00D3CFCE, 0x00EDE9E8, 0x00E6E4D9,
        0x00AFADA2, 0x00242319, 0x000B0C03, 0x000A0C06, 0x00010200, 0x000E110F, 0x00070C0A, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07,
        0x00090D07, 0x00090D07, 0x00090D07, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000C100B, 0x000C100B, 0x000C100B, 0x000A100B,
        0x000A100B, 0x000A100B, 0x000B110C, 0x000B110C, 0x000B110C, 0x000B110C, 0x000B110C, 0x000D140D, 0x000D110B, 0x001E1E18, 0x00B8B5B0, 0x002C2924, 0x0013130D, 0x00121610, 0x000B120B, 0x00000B03, 0x009CA09A, 0x00E1D8D4, 0x00998E8A, 0x00090601,
        0x0010120C, 0x000B0803, 0x001D1410, 0x0054584D, 0x00C8C9BF, 0x00312F27, 0x00A9A69E, 0x00B4B0AB, 0x0023231D, 0x000E120D, 0x000D130E, 0x0010140E, 0x0010140E, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000E120C, 0x000E120C, 0x000F130E,
        0x000F130E, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000F130E, 0x000F130E, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000D1211, 0x000B100E, 0x00111412, 0x000E120D, 0x001C1E18,
        0x00393C33, 0x0041453A, 0x003D3E34, 0x00433529, 0x0029281A, 0x00788271, 0x00DFE4CF, 0x00A3977F, 0x00C6AA8B, 0x00DEBF98, 0x00E9CC9F, 0x00E0DECC, 0x00FFFFF0, 0x00F0DFC5, 0x00937E63, 0x0088775D, 0x00D4CDBC, 0x00F4FCF2, 0x00DAE8E6, 0x00F9FFFE,
        0x00FAFFFE, 0x00F4FBF4, 0x00FFFFF8, 0x00E8E8D8, 0x00D4CFBA, 0x00D3C8B2, 0x00CFC3AB, 0x00D1B597, 0x00D7B38D, 0x26E3B984, 0x36F3C78C, 0x71FFDDA8, 0xC4FFF0CF, 0xFFF9FDF2, 0xFFEDFFFF, 0xFFFFFDFF, 0xFFFFFDFF, 0xFFFCFDFF, 0xFFFCFEFE, 0xFFFBFFFE,
        0xFFFAFFFB, 0xFFFAFFF9, 0xFFFAFFF8, 0xFFFFFFFA, 0xFFFFFFFA, 0xFFFFFFFC, 0xFFFFFFFE, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFEFCFF, 0xFFFAFBFF, 0xFFFBFDFF, 0xFFFDFDFF, 0xFFFFFEFF, 0xFFFFFFFE, 0xFFFFFFFC, 0xFFFFFFF9, 0xFFFFFFF9, 0xFFFFFFFE,
        0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFEFD, 0xFFFFFDFC, 0xFFFDFDFD, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFFFE, 0xFFFDFFFE, 0xFFFCFFFD, 0xFFEDF1EC, 0x00414540, 0x00000400, 0x000A0E08, 0x00080C06, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00000300, 0x00030701, 0x000A0E08, 0x00050903, 0x000C100A, 0x00050903, 0x001F231D, 0x00BCC0BA, 0x00E9E0D7, 0x00A59E95, 0x0049433C, 0x00050200, 0x00110E09, 0x0013130D, 0x004F504C, 0x00E4E8E3, 0x00838176,
        0x00110F04, 0x000C0B01, 0x000D0E05, 0x00060802, 0x00141511, 0x00050806, 0x00070C0A, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07,
        0x00090D07, 0x00090D07, 0x00090D07, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000C100B, 0x000C100B, 0x000C100B, 0x000A100B,
        0x000A100B, 0x000A100B, 0x000B110C, 0x000B110C, 0x000B110C, 0x000B110C, 0x000B110C, 0x000D140D, 0x000D110B, 0x0023231D, 0x00B7B4AF, 0x00282520, 0x0013130D, 0x0011150F, 0x000B120B, 0x00000D02, 0x00ABAEA5, 0x00EEE4DD, 0x00AFA59E, 0x0036342C,
        0x00ADB0A7, 0x00A4A29A, 0x00726861, 0x001F2318, 0x00ADAEA4, 0x0047453D, 0x00CECBC3, 0x00999590, 0x001D1D17, 0x00060A05, 0x00161C17, 0x0010140E, 0x0010140E, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000E120C, 0x000E120C, 0x000F130E,
        0x000F130E, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000F130E, 0x000F130E, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000D1210, 0x000B100E, 0x0010140F, 0x000E120D, 0x001D211B,
        0x00383C36, 0x003F443B, 0x00393E35, 0x00363937, 0x00101A14, 0x008F9C8E, 0x00F9FCE6, 0x00988C68, 0x00BA9C6B, 0x00E1BA7C, 0x00E2B974, 0x00D5C89A, 0x00F1DAAC, 0x00FDDBAD, 0x00E8C096, 0x00CCA987, 0x00DFD0B6, 0x00E9EEDF, 0x00DEF1E8, 0x00F7F8F6,
        0x00FDFFFF, 0x00EDF3F2, 0x00F2FCFC, 0x00F3FFFF, 0x00EFFFFF, 0x00E7FCFE, 0x00D2E9EB, 0x00BFE2E6, 0x00BCD5D1, 0x00B7BFAE, 0x00B4AB8A, 0x00BCA377, 0x11D4AD79, 0x3BF1C38D, 0x58FFD49C, 0x96EBE0BA, 0xBCFAF1CC, 0xEEFFFFE4, 0xFFFFFFED, 0xFFFFFFF0,
        0xFFFFFDF0, 0xFFFFFDF4, 0xFFFFFFF9, 0xFFFAFDFF, 0xFFFAFEFF, 0xFFFCFDFF, 0xFFFFFDFF, 0xFFFFFEFD, 0xFFFFFFFC, 0xFFFFFFFB, 0xFFFFFFF9, 0xFFFFFDFA, 0xFFFFFDFC, 0xFFFFFEFD, 0xFFFCFEFF, 0xFFFAFDFF, 0xFFF6FCFF, 0xFFF2FCFF, 0xFFF2FBFF, 0xFFF8FCFF,
        0xFFF8FBFF, 0xFFF8FBFF, 0xFFFAFCFD, 0xFFFDFDFD, 0xFFFEFEFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFEFC, 0xFFFDFFFE, 0xFFFDFFFE, 0xFFF5F9F4, 0x00515550, 0x00020601, 0x000A0E08, 0x00080C06, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x000D110B, 0x00040802, 0x000C100A, 0x00080C06, 0x00080C06, 0x00070B05, 0x00050903, 0x005B5F59, 0x00E3D7D1, 0x00E6DCD5, 0x00C8C0B9, 0x00737068, 0x0024211C, 0x00000200, 0x000C100A, 0x006E756E, 0x00A9A79C,
        0x00201E13, 0x000B0A00, 0x0017180F, 0x00070903, 0x0012130F, 0x00020503, 0x000D1210, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07,
        0x00090D07, 0x00090D07, 0x00090D07, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000C100B, 0x000C100B, 0x000C100B, 0x000A100B,
        0x000A100B, 0x000A100B, 0x000B110C, 0x000B110C, 0x000B110C, 0x000B110C, 0x000B110C, 0x000C130C, 0x000D110B, 0x00282822, 0x00B6B3AE, 0x0023201B, 0x0013130D, 0x0011150F, 0x000C130C, 0x000B1B10, 0x00A9ACA3, 0x00E6DCD5, 0x00B2A8A1, 0x00413E36,
        0x00C9CCC3, 0x00DAD7CF, 0x009C928B, 0x00292D22, 0x00B2B3A9, 0x0039372F, 0x00C0BDB5, 0x008F8B86, 0x0020201A, 0x00131712, 0x000C120D, 0x0010140E, 0x0010140E, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000E120C, 0x000E120C, 0x000F130E,
        0x000F130E, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000F130E, 0x000F130E, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000D1210, 0x000B110C, 0x000E140F, 0x000D130E, 0x001E241F,
        0x00373E39, 0x003B423D, 0x00373F38, 0x0023373C, 0x00172C2E, 0x008CA2A0, 0x00E0F1E8, 0x009FA594, 0x00ABA78A, 0x00ACA27A, 0x00C9BA8C, 0x00DED2AA, 0x00E6D5AE, 0x00E2CDA7, 0x00CEB895, 0x00B5A489, 0x00E1DAC7, 0x00EDF1E6, 0x00DBE5DF, 0x00EDEBEB,
        0x00FDFDFD, 0x00FBFEFF, 0x00EEF7FB, 0x00E3F5FC, 0x00DDF7FE, 0x00B5D9E1, 0x00A9D0D9, 0x00B4DBCB, 0x00BAE4DD, 0x00BEEBEF, 0x00BEE4F0, 0x00BDD2DA, 0x00BEBCB4, 0x00C8AD92, 0x00D0A67C, 0x00E9B37E, 0x00E8B682, 0x3BE6BC8D, 0x5CE9C69E, 0x86ECD3B1,
        0xB4F2E4C7, 0xDEFBF4DB, 0xF2FFFEE6, 0xFFFFFCF3, 0xFFFFFEF5, 0xFFFFFFF8, 0xFFFFFFFB, 0xFFFFFFFE, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFF, 0xFFFDFFFF, 0xFFFBFFFF, 0xFFFAFFFF, 0xFFFAFFFF, 0xFFF8FFFF, 0xFFF8FEFF,
        0xFFF8FEFF, 0xFFFAFEFF, 0xFFFBFEFF, 0xFFFDFFFF, 0xFFFFFFFF, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCFFFD, 0xFFFDFFFE, 0xFFFDFFFE, 0xFFF7FBF6, 0x005B5F5A, 0x00010500, 0x00090D07, 0x00090D07, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x000A0E08, 0x00060A04, 0x00090D07, 0x00090D07, 0x00040802, 0x000E120C, 0x00000300, 0x00040802, 0x00605551, 0x00E5DCD8, 0x00C4BEB9, 0x00B6B2AD, 0x0095938B, 0x00282920, 0x00090C03, 0x000A0D04, 0x00ABA99E,
        0x00918F84, 0x00040300, 0x000E0F06, 0x000D0F09, 0x00000100, 0x000C0F0D, 0x00090E0C, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07,
        0x00090D07, 0x00090D07, 0x00090D07, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000C100B, 0x000C100B, 0x000C100B, 0x000A100B,
        0x000A100B, 0x000A100B, 0x000B110C, 0x000B110C, 0x000B110C, 0x000B110C, 0x000B110C, 0x000B120B, 0x000D110B, 0x002F2F29, 0x00B4B1AC, 0x001D1A15, 0x0013130D, 0x0010140E, 0x000C130C, 0x00000B00, 0x00B9BAB0, 0x00F0E5DD, 0x009B9088, 0x004F4D43,
        0x00DDDED4, 0x00D4D2C8, 0x004A3F37, 0x001C2015, 0x00B8B9AF, 0x0029271F, 0x00B3B0A8, 0x00A29E99, 0x0011110B, 0x00191D18, 0x000F1510, 0x0010140E, 0x0010140E, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000E120C, 0x000E120C, 0x000F130E,
        0x000F130E, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000F130E, 0x000F130E, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000B110C, 0x000D130E, 0x000D140F, 0x00202724,
        0x00363F3C, 0x0036413E, 0x00343F3C, 0x0024342D, 0x001C2B27, 0x00A6B6B5, 0x00D6EAEB, 0x007E9694, 0x00B6CFCB, 0x00D1E8E0, 0x00C2D5CC, 0x00DCD9D1, 0x00D7DAD1, 0x00D5E3D7, 0x00D7EBDE, 0x00B6CCC0, 0x00D2E0DA, 0x00E2E4E4, 0x00F5F0F2, 0x00E5E7E7,
        0x00E7E9EA, 0x00FCFEFF, 0x00F7FBFC, 0x00F6FFFF, 0x00EDFFFF, 0x00CDECEB, 0x00CEF3F1, 0x00C2E2E8, 0x00B1D1D6, 0x00A1C1C6, 0x00A3C4C7, 0x00B3D3D8, 0x00C0E2E8, 0x00BFE4EC, 0x00BBE0E8, 0x00B0CFC0, 0x00B0C8B6, 0x00B3BFA9, 0x00BEB9A0, 0x00D1B99B,
        0x00E4BC99, 0x00F2BD98, 0x4BFBBE96, 0x6DF8D7A5, 0x7DFADBAE, 0x9FFDE3BE, 0xC4FFEDD0, 0xEEFFF5E3, 0xFFFFFCF3, 0xFFFFFFFF, 0xFFFBFEFF, 0xFFF5FBFF, 0xFFF9FEFF, 0xFFFBFFFF, 0xFFFFFFFC, 0xFFFFFFF9, 0xFFFFFFF6, 0xFFFFFFF5, 0xFFFFFFF4, 0xFFF8FCFF,
        0xFFF9FDFF, 0xFFFAFDFF, 0xFFFDFFFF, 0xFFFDFFFF, 0xFFFFFFFF, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFFFE, 0xFFFCFFFD, 0xFFFAFDFB, 0xFFF3F7F2, 0x00616560, 0x00000200, 0x00080C06, 0x000A0E08, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00030701, 0x000F130D, 0x000A0E08, 0x00080C06, 0x00020600, 0x000D110B, 0x000C100A, 0x00080C06, 0x000F0C08, 0x00413C39, 0x00B8B4AF, 0x00CFCBC6, 0x00BFBCB4, 0x00A3A098, 0x00333127, 0x00050300, 0x0037352A,
        0x00CCCABF, 0x00403F35, 0x000F1007, 0x0012140E, 0x000E0F0B, 0x000C0F0D, 0x00030806, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07,
        0x00090D07, 0x00090D07, 0x00090D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000C100B, 0x000C100B, 0x000C100B, 0x000A100B,
        0x000A100B, 0x000A100B, 0x000B110C, 0x000B110C, 0x000B110C, 0x000B110C, 0x000B110C, 0x000B120B, 0x000D110B, 0x0034342E, 0x00B3B0AB, 0x0017140F, 0x0014140E, 0x000F130D, 0x000C130C, 0x000F1D11, 0x00BBBCB2, 0x00EEE3DB, 0x0091867E, 0x00342F26,
        0x007A7B71, 0x00A8A39A, 0x00A69B93, 0x0033372C, 0x00AFB0A6, 0x00424038, 0x00BCB9B1, 0x00A39F9A, 0x0010100A, 0x000E120D, 0x00141A15, 0x0010140E, 0x0010140E, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000E120C, 0x000E120C, 0x000F130E,
        0x000F130E, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000F130E, 0x000F130E, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120C, 0x000B110C, 0x000C120D, 0x000E1512, 0x001F2A27,
        0x0033403E, 0x0033403E, 0x00313F3E, 0x003C4229, 0x002F311D, 0x00B0B2A6, 0x00E2EBE8, 0x008BA3A3, 0x008FB0B3, 0x009EC1C4, 0x00BBDCDF, 0x00DAE3F1, 0x00D9ECF9, 0x00C4E9F1, 0x00ABDADE, 0x0089B4B7, 0x00BDD8DC, 0x00C9CDD2, 0x00CDC2CA, 0x00E0E6E5,
        0x00EAEFEE, 0x00FFFFFE, 0x00FFFDFC, 0x00F4F8F3, 0x00DDEBE5, 0x00C8E1D7, 0x00B8D8CD, 0x00A2D0E1, 0x00B4DDE6, 0x00C6E6E5, 0x00C9E2D8, 0x00BAD2C8, 0x00A9C4C0, 0x00A0C3C7, 0x00A0C6D2, 0x00B8E2EE, 0x00C1E8F1, 0x00C9EEF2, 0x00CEEDEC, 0x00CDE4DF,
        0x00C6DACE, 0x00C2D1C3, 0x00C0CDBD, 0x00CCC3A2, 0x00CBC0A0, 0x00CBBF9D, 0x00D0C09B, 0x60DAC59F, 0x69E4CEA4, 0x79F0D7AB, 0x82F8DEB0, 0xC9FFF4D1, 0xD9FFF8D9, 0xEEFFFEE4, 0xFFFFFFEE, 0xFFFFFFF6, 0xFFFFFFFB, 0xFFFDFFFF, 0xFFFBFEFF, 0xFFFFFFFC,
        0xFFFFFFFC, 0xFFFFFDFC, 0xFFFEFCFB, 0xFFFCFCFC, 0xFFFDFDFD, 0xFFFEFEFE, 0xFFFCFEFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFFFE, 0xFFFCFFFD, 0xFFFBFEFC, 0xFFF7FBF6, 0x006D716C, 0x00000400, 0x00080C06, 0x00090D07, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00050903, 0x000B0F09, 0x00010500, 0x00060A04, 0x000A0E08, 0x0010140E, 0x00060A04, 0x00040802, 0x000B0E0C, 0x00000200, 0x00272824, 0x0093908B, 0x00CCC9C1, 0x00E1DAD1, 0x00D0C7BD, 0x0041372D, 0x0049473C,
        0x00DFDDD2, 0x007B7A70, 0x00040500, 0x00000200, 0x00141511, 0x00030604, 0x00090E0C, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07,
        0x00090D07, 0x00090D07, 0x00090D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000C100B, 0x000C100B, 0x000C100B, 0x000A100B,
        0x000A100B, 0x000A100B, 0x000B110C, 0x000B110C, 0x000B110C, 0x000B110C, 0x000B110C, 0x000A110A, 0x000D110B, 0x00393933, 0x00B2AFAA, 0x0013100B, 0x0014140E, 0x000F130D, 0x000C130C, 0x00101C10, 0x00C1C0B6, 0x00ECE1D9, 0x009A8D85, 0x00605B52,
        0x00919086, 0x006F6A61, 0x00736860, 0x0035392E, 0x00B0B1A7, 0x00312F27, 0x00B1AEA6, 0x00A7A39E, 0x001F1F19, 0x000C100B, 0x00070D08, 0x0010140E, 0x0010140E, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000E120C, 0x000E120C, 0x000F130E,
        0x000F130E, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000F130E, 0x000F130E, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120C, 0x000B120B, 0x000B120D, 0x000C1512, 0x00212C2A,
        0x00334140, 0x0030403F, 0x00303F41, 0x002D3C27, 0x003D4233, 0x00CAC7C2, 0x00DDE3E2, 0x00859B99, 0x00AECECD, 0x00CBEBEA, 0x00BFDAD7, 0x00C9DAE3, 0x00C6E0E7, 0x00C1E3E9, 0x00C2E8ED, 0x00A5C8CC, 0x00CFE4E6, 0x009FA4A7, 0x006A6567, 0x006D7875,
        0x009AA19E, 0x00EFF2F0, 0x00FCFCFC, 0x00E9EEED, 0x00DFEDEB, 0x00D3EEEB, 0x00C9ECE8, 0x00CEEBD2, 0x00BAD8C5, 0x00A6C6BB, 0x00A3C5C4, 0x00B2D5D9, 0x00BCDFE9, 0x00BCDCE9, 0x00B7D4E2, 0x0095C4C2, 0x0095C3C4, 0x009AC5C8, 0x00A5CFD4, 0x00B5DEE7,
        0x00C5EBF7, 0x00CBEFFF, 0x00CDF1FF, 0x00CFEEF7, 0x00CEE9ED, 0x00CCDFDC, 0x00CDD6C9, 0x00D0CFB5, 0x00D4CBA6, 0x00DACA9C, 0x00DFCA97, 0x00DCC18F, 0x00E0C698, 0x71E5CEA8, 0x92E8D6B7, 0xB4EBDEC8, 0xDEF1E8DB, 0xFFF8F2EB, 0xFFFDFAF6, 0xFFFFFFF3,
        0xFFFFFFF5, 0xFFFFFFF7, 0xFFFFFFF9, 0xFFFFFFFC, 0xFFFFFFFF, 0xFFF9FCFF, 0xFFF8FBFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFFFE, 0xFFFDFFFE, 0xFFFDFFFE, 0xFFFDFFFC, 0x117B7F7A, 0x00060A05, 0x000A0E08, 0x00070B05, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x000A0E08, 0x000B0F09, 0x000A0E08, 0x000A0E08, 0x00030701, 0x00080C06, 0x00040802, 0x0011150F, 0x00050E0B, 0x00030A07, 0x00070B06, 0x00090903, 0x004F4942, 0x00A1988F, 0x00DED2C8, 0x00E7D8CF, 0x00D4D2C7,
        0x00EAE8DD, 0x006E6D63, 0x00050600, 0x00080A04, 0x000C0D09, 0x000A0D0B, 0x000A0F0D, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07,
        0x00090D07, 0x00090D07, 0x00090D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000C100B, 0x000C100B, 0x000C100B, 0x000A100B,
        0x000A100B, 0x000A100B, 0x000B110C, 0x000B110C, 0x000B110C, 0x000B110C, 0x000B110C, 0x000A110A, 0x000D110B, 0x003B3B35, 0x00B1AEA9, 0x00100D08, 0x0014140E, 0x000E120C, 0x000D140D, 0x00101D0F, 0x00D1D1C5, 0x00EADED4, 0x0081756B, 0x006E6A5F,
        0x00DDDDD1, 0x00A39F94, 0x00AEA298, 0x0043473C, 0x00A8A99F, 0x0035332B, 0x009B9890, 0x0065615C, 0x0010100A, 0x000F130E, 0x000D130E, 0x0010140E, 0x0010140E, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000E120C, 0x000E120C, 0x000F130E,
        0x000F130E, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000F130E, 0x000F130E, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120C, 0x000B120B, 0x000B120D, 0x000C1512, 0x00202D2B,
        0x00344241, 0x002D3F40, 0x002E4041, 0x00123132, 0x00182B30, 0x00848B94, 0x00A7B2BA, 0x007A9397, 0x0091B1B0, 0x00A8C7C0, 0x00CCE3DB, 0x00DFF4EB, 0x00DDF2EA, 0x00D5E9E4, 0x00C5D8D5, 0x009BA9A7, 0x00DEE9E7, 0x00DDE4DF, 0x00CACEC9, 0x007E8D85,
        0x007F8983, 0x00EAEFED, 0x00F7F9FA, 0x00E1EAEE, 0x00D7EAF1, 0x00AACBD4, 0x00A7D2DB, 0x00B3CDDD, 0x00BFDCEB, 0x00C8E8F5, 0x00BEE2EA, 0x00AAD0D2, 0x009CC4BF, 0x009EC8BD, 0x00A8D1C2, 0x00D2DCE6, 0x00D5E1EB, 0x00D4E4EB, 0x00CADEE3, 0x00BBD4D6,
        0x00ADCCCB, 0x00A8CBC7, 0x00A8CEC8, 0x00B5D7DD, 0x00BCDEE4, 0x00C7E8F1, 0x00CEF1FB, 0x00CEF1FE, 0x00C6EBF9, 0x00BDE1F1, 0x00B7DBED, 0x00C9D1D0, 0x00CACEC8, 0x00CDCABB, 0x00D4C6AA, 0x00DEC39E, 0x4FEEC997, 0x4FFFD298, 0x5CFFDB9D, 0xB0ECDBC6,
        0xC4F2E3D0, 0xE6FCEFDF, 0xFFFFFAF0, 0xFFFFFFFB, 0xFFFFFFFF, 0xFFFBFEFF, 0xFFF7FDFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFEFFFB, 0x328C8D89, 0x00060703, 0x000D0F09, 0x000A0C06, 0x00080C06,
        0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x000D0B0A, 0x000D0B0A, 0x00110F0E, 0x000F0D0C, 0x00080605, 0x00060403, 0x0032302F, 0x00A09E9D, 0x00D9D3C8,
        0x006C685D, 0x0023241A, 0x000A0F06, 0x00060D06, 0x00020601, 0x000D0E0C, 0x000D0B0A, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07,
        0x00090D07, 0x00090D07, 0x00090D07, 0x00080D04, 0x00080D04, 0x00090D07, 0x00090D07, 0x00090D08, 0x00090D08, 0x000A0E09, 0x000A0D0B, 0x0012110D, 0x00040A05, 0x00080F0A, 0x000C0D09, 0x00140B08, 0x0019100D, 0x00131410, 0x000F1D17, 0x00151F19,
        0x00161D18, 0x000E1510, 0x00070E09, 0x00080F0A, 0x00070E09, 0x00050F09, 0x000A140E, 0x000A110A, 0x00070B05, 0x004A4A44, 0x00A8A5A0, 0x000C0904, 0x0014140E, 0x000E120C, 0x000A110A, 0x001C251B, 0x00CBCCC3, 0x00EDE5DE, 0x007C766F, 0x002E2F26,
        0x00C2C5BC, 0x00D8D2CB, 0x00B2A29C, 0x00383C31, 0x00A4A59B, 0x00424038, 0x00C4C1B9, 0x00A29E99, 0x0015150F, 0x00131712, 0x00040A05, 0x0010140E, 0x0010140E, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000E120C, 0x000E120C, 0x0010120C,
        0x0011120E, 0x000D0E0A, 0x00141511, 0x00131412, 0x000B0C0A, 0x00101010, 0x000F0F0F, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000F130E, 0x000F130E, 0x00090F0A, 0x000F1613, 0x00262F2C,
        0x00374240, 0x0033403E, 0x002B3836, 0x00293932, 0x001F2923, 0x009EA3A1, 0x008C9795, 0x00859E9A, 0x00C3E4E0, 0x00C0DCDC, 0x00C4D8D9, 0x00D5DFE6, 0x00C6DCE1, 0x00C5E7E7, 0x00C5E5E4, 0x00ADC2C0, 0x00E4ECEB, 0x00E9EEED, 0x00EFF6F3, 0x00D6DBDC,
        0x009FA5A4, 0x00E7EEEB, 0x00EEF8F2, 0x00E0EFEB, 0x00DFF5F3, 0x00D1EEF2, 0x00CEEEF3, 0x00BDDEE1, 0x00AFD0D3, 0x00A3C4C7, 0x00A6C7CA, 0x00B3D4D7, 0x00BDDEE1, 0x00BDDEE1, 0x00B7D8DB, 0x00A2C3C6, 0x00A0C1C4, 0x00A3C4C7, 0x00B0D1D4, 0x00C2E3E6,
        0x00CEEFF2, 0x00CEEFF2, 0x00CAEBEE, 0x00BFE0E3, 0x00B8D9DC, 0x00AFD0D3, 0x00AACBCE, 0x00ADCED1, 0x00B7D8DB, 0x00C4E5E8, 0x00CCEDF0, 0x00D5F6F9, 0x00D2F3F6, 0x00D0EFF2, 0x00C9E8EB, 0x00C1E0E3, 0x00B9D6DA, 0x00B2CFD3, 0x00ADCACE, 0x00C6C9AF,
        0x00CECDB3, 0x96DED2BA, 0xA7EEDAC1, 0xBCFBE3CB, 0xD1FFF1D6, 0xE6FFFBE0, 0xF7FFFFE7, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFE, 0xFFFEFFFD, 0xFFFFFFFE, 0xFFFFFFFC, 0x47979894, 0x000D0E0A, 0x000C0E08, 0x000A0C06, 0x00080C06,
        0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00060501, 0x000C0B07, 0x000F0E0A, 0x000A0905, 0x0011100C, 0x000C0B07, 0x0033322E, 0x005D5C58, 0x00BAB4A9,
        0x00504C41, 0x00030400, 0x00020700, 0x00020902, 0x00111510, 0x000A0B09, 0x000B0908, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07,
        0x00090D07, 0x00090D07, 0x00090D07, 0x00080D04, 0x00080D04, 0x00090D07, 0x00090D07, 0x00090D08, 0x00090D08, 0x000A0E09, 0x000A0D0B, 0x000D0E0A, 0x00050B06, 0x00080E09, 0x000D0C08, 0x00130C09, 0x00161511, 0x0014241D, 0x001A3C32, 0x002E594E,
        0x00395E54, 0x00334E45, 0x001C2E27, 0x000D1711, 0x0009100B, 0x000B110C, 0x00101712, 0x000A110A, 0x00060A04, 0x004C4C46, 0x00A6A39E, 0x000C0904, 0x0013130D, 0x000F130D, 0x000A110A, 0x001A2319, 0x00CCCDC4, 0x00DFD7D0, 0x00767069, 0x00313229,
        0x0060635A, 0x009D9790, 0x00685852, 0x0045493E, 0x00A2A399, 0x001B1911, 0x006F6C64, 0x006C6863, 0x00050500, 0x000D110C, 0x001D231E, 0x0010140E, 0x0010140E, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000E120C, 0x000E120C, 0x0012140E,
        0x00171913, 0x000B0C08, 0x000D0E0A, 0x00181917, 0x00141513, 0x00131412, 0x00141414, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000F130E, 0x000F130E, 0x00090F0A, 0x00101714, 0x0027302D,
        0x00374240, 0x0033403E, 0x002B3836, 0x001D2D26, 0x00434D47, 0x00F4F9F7, 0x00D1DCDA, 0x007C9591, 0x008BACA8, 0x00A6C2C2, 0x00D5E9EA, 0x00E0EAF1, 0x00D1E7EC, 0x00C3E5E5, 0x00B0D0CF, 0x0099AEAC, 0x00DFE7E6, 0x00EEF3F2, 0x00F3FAF7, 0x00E0E5E6,
        0x00ABB1B0, 0x00EFF6F3, 0x00EFF9F3, 0x00D9E8E4, 0x00CDE3E1, 0x00B5D2D6, 0x00AECED3, 0x00B6D7DA, 0x00C1E2E5, 0x00C9EAED, 0x00C2E3E6, 0x00B1D2D5, 0x00A4C5C8, 0x00A1C2C5, 0x00A5C6C9, 0x00BFE0E3, 0x00C2E3E6, 0x00C0E1E4, 0x00B6D7DA, 0x00A9CACD,
        0x00A3C4C7, 0x00A8C9CC, 0x00AFD0D3, 0x00BADBDE, 0x00C6E7EA, 0x00D2F3F6, 0x00D4F5F8, 0x00CCEDF0, 0x00BFE0E3, 0x00B7D8DB, 0x00B4D5D8, 0x00ACCDD0, 0x00B1D2D5, 0x00BCDBDE, 0x00C6E5E8, 0x00CDECEF, 0x00D3F0F4, 0x00D4F1F5, 0x00D4F1F5, 0x00DBECDF,
        0x00DAE6DA, 0x00DBDFD4, 0x00DDD9CE, 0x00E1D8CE, 0x00E8E0D3, 0x00F1EBDE, 0xF2F7F4E6, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFE, 0xFFFCFDFB, 0xFFFEFFFD, 0xFFFFFFFC, 0x6DA8A9A5, 0x00151612, 0x000B0D07, 0x000A0C06, 0x00080C06,
        0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x000F0E0A, 0x0011100C, 0x00050400, 0x000A0905, 0x000A0905, 0x000B0A06, 0x00878682, 0x00C5C4C0, 0x00645E53,
        0x007A766B, 0x000E0F05, 0x00090E05, 0x000D140D, 0x00070B06, 0x000C0D0B, 0x000C0A09, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07,
        0x00090D07, 0x00090D07, 0x00090D07, 0x00080D04, 0x00080D04, 0x00090D07, 0x00090D07, 0x00090D08, 0x00090D08, 0x000A0E09, 0x000A0D0B, 0x000B0C08, 0x00060C07, 0x000A0E09, 0x000C0B07, 0x00120F0B, 0x000E1A14, 0x00153A30, 0x00316E60, 0x003B9784,
        0x0057A594, 0x00589083, 0x0037564D, 0x0016241E, 0x000C100B, 0x000D0E0A, 0x0010110D, 0x000A110A, 0x00050903, 0x004F4F49, 0x00A3A09B, 0x000B0803, 0x0012120C, 0x000F130D, 0x00091009, 0x0020291F, 0x00D1D2C9, 0x00F1E9E2, 0x00666059, 0x0087887F,
        0x0095988F, 0x00DFD9D2, 0x009E8E88, 0x00474B40, 0x00A7A89E, 0x00413F37, 0x007F7C74, 0x0056524D, 0x0010100A, 0x00171B16, 0x00050B06, 0x0010140E, 0x0010140E, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000E120C, 0x000E120C, 0x000C0E08,
        0x00161812, 0x0013150F, 0x0010110D, 0x000F100C, 0x000C0D0B, 0x0010110F, 0x00131412, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000F130E, 0x000F130E, 0x00090F0A, 0x00111815, 0x0028312E,
        0x00384341, 0x0033403E, 0x002C3937, 0x0026362F, 0x003F4943, 0x00DDE2E0, 0x00B8C3C1, 0x00869F9B, 0x00B9DAD6, 0x00C7E3E3, 0x00C1D5D6, 0x00DCE6ED, 0x00C6DCE1, 0x00C3E5E5, 0x00C6E6E5, 0x00B3C8C6, 0x00E3EBEA, 0x00E8EDEC, 0x00F4FBF8, 0x00E0E5E6,
        0x00B0B6B5, 0x00F0F7F4, 0x00F0FAF4, 0x00E0EFEB, 0x00DBF1EF, 0x00CDEAEE, 0x00CBEBF0, 0x00BCDDE0, 0x00AFD0D3, 0x00A5C6C9, 0x00AACBCE, 0x00B8D9DC, 0x00C0E1E4, 0x00BBDCDF, 0x00B2D3D6, 0x009DBEC1, 0x009EBFC2, 0x00A5C6C9, 0x00B2D3D6, 0x00C0E1E4,
        0x00C8E9EC, 0x00C7E8EB, 0x00C3E4E7, 0x00B6D7DA, 0x00ADCED1, 0x00A5C6C9, 0x00A7C8CB, 0x00B4D5D8, 0x00C3E4E7, 0x00CFF0F3, 0x00D4F5F8, 0x00D2F3F6, 0x00CBECEF, 0x00C4E3E6, 0x00BBDADD, 0x00B6D5D8, 0x00B8D5D9, 0x00BCD9DD, 0x00C0DDE1, 0x00CDECEF,
        0x00D4EFF3, 0x00DFF4F6, 0x00E7F6F9, 0x00E9F5F7, 0x00E8F1F4, 0xEEE4F0F0, 0xEEE3EFEF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFE, 0xFFFCFDFB, 0xFFFEFFFD, 0xFFFFFFFC, 0x8EB8B9B5, 0x001B1C18, 0x00070903, 0x000B0D07, 0x00080C06,
        0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00070602, 0x00020100, 0x000C0B07, 0x001A1915, 0x00080703, 0x00020100, 0x005F5E5A, 0x00DEDDD9, 0x003D372C,
        0x00252116, 0x00070800, 0x000E130A, 0x00020902, 0x00060A05, 0x00070806, 0x000F0D0C, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07,
        0x00090D07, 0x00090D07, 0x00090D07, 0x00080D04, 0x00080D04, 0x00090D07, 0x00090D07, 0x00090D08, 0x00090D08, 0x000A0E09, 0x000A0D0B, 0x00090D08, 0x00090D08, 0x000B0C08, 0x000F0C08, 0x0011100C, 0x00051A12, 0x00154A3D, 0x004C9C8B, 0x0046C6AD,
        0x0069D6C0, 0x0070BEAD, 0x004D786D, 0x0026362F, 0x0010140F, 0x000D0A06, 0x000F0C08, 0x000A110A, 0x00040802, 0x0053534D, 0x009F9C97, 0x000B0803, 0x0011110B, 0x000F130D, 0x00080F08, 0x00273026, 0x00CFD0C7, 0x00E8E0D9, 0x00605A53, 0x008C8D84,
        0x00777A71, 0x00726C65, 0x00A79791, 0x0054584D, 0x008C8D83, 0x0044423A, 0x00C1BEB6, 0x00615D58, 0x00070701, 0x00111510, 0x000D130E, 0x0010140E, 0x0010140E, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000E120C, 0x000E120C, 0x0014170E,
        0x000E100A, 0x0012140E, 0x00161812, 0x0010110D, 0x0011120E, 0x00131412, 0x000A0B09, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x0010140F, 0x000F130E, 0x000A100B, 0x00131A17, 0x002A3330,
        0x00384341, 0x0033403E, 0x002C3937, 0x002B3B34, 0x00454F49, 0x00E1E6E4, 0x00B7C2C0, 0x0077908C, 0x0091B2AE, 0x00B3CFCF, 0x00D6EAEB, 0x00DFE9F0, 0x00D4EAEF, 0x00C5E7E7, 0x00A7C7C6, 0x0097ACAA, 0x00E0E8E7, 0x00F0F5F4, 0x00EEF5F2, 0x00D5DADB,
        0x00B1B7B6, 0x00F3FAF7, 0x00F1FBF5, 0x00DDECE8, 0x00CEE4E2, 0x00B6D3D7, 0x00AFCFD4, 0x00B8D9DC, 0x00C5E6E9, 0x00CEEFF2, 0x00C6E7EA, 0x00B1D2D5, 0x00A1C2C5, 0x009FC0C3, 0x00A4C5C8, 0x00BCDDE0, 0x00BBDCDF, 0x00B6D7DA, 0x00ACCDD0, 0x00A2C3C6,
        0x00A0C1C4, 0x00A7C8CB, 0x00AECFD2, 0x00BEDFE2, 0x00C9EAED, 0x00D1F2F5, 0x00CCEDF0, 0x00BDDEE1, 0x00AECFD2, 0x00A8C9CC, 0x00A8C9CC, 0x00ACCDD0, 0x00B6D7DA, 0x00C6E5E8, 0x00D1F0F3, 0x00D5F4F7, 0x00D2EFF3, 0x00CCE9ED, 0x00C7E4E8, 0x00B3D7DF,
        0x00B9DBE1, 0x00C3E0E7, 0x00CCE6ED, 0x00D7EDF3, 0x00E1F3FA, 0xF7E8FBFF, 0xFFEEFEFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFE, 0xFFFDFEFC, 0xFFFFFFFE, 0xFFFFFFFC, 0xABC6C7C3, 0x0020211D, 0x00030500, 0x000D0F09, 0x00080C06,
        0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00393933, 0x00565650, 0x00080802, 0x00070701, 0x0013130D, 0x00070701, 0x00575751, 0x00E2E2DC, 0x005D574C,
        0x00070300, 0x000F1006, 0x000C1108, 0x00040B04, 0x000C100B, 0x000D0E0C, 0x000D0B0A, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07,
        0x00090D07, 0x00090D07, 0x00090D07, 0x00080D04, 0x00080D04, 0x00090D07, 0x00090D07, 0x00090D08, 0x00090D08, 0x000A0E09, 0x000A0D0B, 0x000B0F0A, 0x00090D08, 0x000B0C08, 0x00110E0A, 0x00100F0B, 0x0000130B, 0x00154A3D, 0x0059A998, 0x004CD1B7,
        0x0066D5BF, 0x0067B7A6, 0x004A756A, 0x00263831, 0x00131410, 0x00100D09, 0x0015120E, 0x00091009, 0x00030701, 0x00575751, 0x009A9792, 0x000A0702, 0x0010100A, 0x0010140E, 0x00060D06, 0x00273026, 0x00DADBD2, 0x00EDE5DE, 0x005C564F, 0x0026271E,
        0x00BABDB4, 0x00CFC9C2, 0x007F6F69, 0x004D5146, 0x0096978D, 0x0047453D, 0x00D3D0C8, 0x00635F5A, 0x00181812, 0x00161A15, 0x000C120D, 0x0010140E, 0x0010140E, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000E120C, 0x000E120C, 0x0012150C,
        0x000D1007, 0x0010130A, 0x0013150F, 0x0011130D, 0x0010110D, 0x0010110D, 0x0011120E, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x0010140F, 0x000E120D, 0x000A100B, 0x00151C19, 0x002C3532,
        0x00384341, 0x00323F3D, 0x002C3937, 0x001B2B24, 0x0056605A, 0x00E8EDEB, 0x00ADB8B6, 0x0090A9A5, 0x00BDDEDA, 0x00C5E1E1, 0x00C1D5D6, 0x00D8E2E9, 0x00C3D9DE, 0x00C1E3E3, 0x00C1E1E0, 0x00BACFCD, 0x00E7EFEE, 0x00ECF1F0, 0x00F6FDFA, 0x00D5DADB,
        0x00B7BDBC, 0x00F2F9F6, 0x00EDF7F1, 0x00DFEEEA, 0x00D7EDEB, 0x00CAE7EB, 0x00CAEAEF, 0x00B7D8DB, 0x00ABCCCF, 0x00A3C4C7, 0x00AACBCE, 0x00BCDDE0, 0x00C6E7EA, 0x00C2E3E6, 0x00B9DADD, 0x009CBDC0, 0x009EBFC2, 0x00A7C8CB, 0x00B5D6D9, 0x00C2E3E6,
        0x00C7E8EB, 0x00C3E4E7, 0x00BCDDE0, 0x00ABCCCF, 0x00A5C6C9, 0x00A2C3C6, 0x00AACBCE, 0x00B9DADD, 0x00C7E8EB, 0x00CDEEF1, 0x00CEEFF2, 0x00C5E6E9, 0x00BEDFE2, 0x00B4D3D6, 0x00ABCACD, 0x00A9C8CB, 0x00B1CED2, 0x00BEDBDF, 0x00C8E5E9, 0x00D4F3F6,
        0x00D4F1F5, 0x00D3F0F4, 0x00D4EDEF, 0xD5D7ECEE, 0xD9DAECED, 0xE6E0EDEF, 0xEEE4F0F2, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFE, 0xFFFEFFFD, 0xFFFFFFFE, 0xFFFEFFFB, 0xCDD6D7D3, 0x002B2C28, 0x00030500, 0x000D0F09, 0x00090D07,
        0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x0044443E, 0x00BEBEB8, 0x00686862, 0x000E0E08, 0x000A0A04, 0x00020200, 0x00383832, 0x00CDCDC7, 0x006A6459,
        0x00100C01, 0x000F1006, 0x00010600, 0x00080F08, 0x00060A05, 0x0010110F, 0x00090706, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07,
        0x00090D07, 0x00090D07, 0x00090D07, 0x00080D04, 0x00080D04, 0x00090D07, 0x00090D07, 0x00090D08, 0x00090D08, 0x000A0E09, 0x000A0D0B, 0x000E0F0B, 0x00070D08, 0x000A0E09, 0x000F0E0A, 0x00120F0B, 0x00010D07, 0x0012372D, 0x004B887A, 0x005DC4AF,
        0x0063BCA9, 0x00569486, 0x00375A50, 0x001A2A23, 0x000C100B, 0x000D0C08, 0x00171410, 0x00091009, 0x00020600, 0x005B5B55, 0x0096938E, 0x00090601, 0x000E0E08, 0x0010140E, 0x00050C05, 0x00262F25, 0x00D2D3CA, 0x00D9D1CA, 0x00635D56, 0x00393A31,
        0x00676A61, 0x00A29C95, 0x003F2F29, 0x0061655A, 0x0087887E, 0x0044423A, 0x00E8E5DD, 0x00716D68, 0x000A0A04, 0x000B0F0A, 0x00101611, 0x0010140E, 0x0010140E, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000E120C, 0x000E120C, 0x0013170C,
        0x0015180F, 0x0012150C, 0x000C0F06, 0x0011130D, 0x0011130D, 0x000C0D09, 0x00151612, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x0010140F, 0x000E120D, 0x000A100B, 0x00171E1B, 0x002E3734,
        0x00394442, 0x00323F3D, 0x002C3937, 0x001C2C25, 0x005E6862, 0x00EBF0EE, 0x00AAB5B3, 0x00839C98, 0x0096B7B3, 0x00ADC9C9, 0x00D7EBEC, 0x00DCE6ED, 0x00D2E8ED, 0x00C3E5E5, 0x00A2C2C1, 0x009EB3B1, 0x00E4ECEB, 0x00F3F8F7, 0x00EFF6F3, 0x00CDD2D3,
        0x00B9BFBE, 0x00F5FCF9, 0x00EDF7F1, 0x00DBEAE6, 0x00C7DDDB, 0x00B0CDD1, 0x00AACACF, 0x00BEDFE2, 0x00C9EAED, 0x00CFF0F3, 0x00C5E6E9, 0x00B0D1D4, 0x00A1C2C5, 0x00A1C2C5, 0x00A7C8CB, 0x00BEDFE2, 0x00BCDDE0, 0x00B6D7DA, 0x00ABCCCF, 0x00A2C3C6,
        0x00A1C2C5, 0x00A8C9CC, 0x00B0D1D4, 0x00C5E6E9, 0x00CBECEF, 0x00CCEDF0, 0x00C3E4E7, 0x00B3D4D7, 0x00A7C8CB, 0x00A5C6C9, 0x00A7C8CB, 0x00B7D8DB, 0x00BFE0E3, 0x00CBEAED, 0x00D0EFF2, 0x00CDECEF, 0x00C6E3E7, 0x00BEDBDF, 0x00B9D6DA, 0x00BDD5D5,
        0x00C3DBDB, 0x00CCE4E4, 0x00D5EDEB, 0xE6DFF4F2, 0xFFEBF9F7, 0xFFF4FCFB, 0xFFFAFFFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFE, 0xFFFDFEFC, 0xFFFFFFFE, 0xFFFDFEFA, 0xEEE6E7E3, 0x003A3B37, 0x00070903, 0x000C0E08, 0x00090D07,
        0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00070800, 0x00717269, 0x0096978E, 0x000C0D04, 0x00111209, 0x0015160D, 0x00020300, 0x00686960, 0x00A29C91,
        0x00120E03, 0x000E0F05, 0x000E130A, 0x00070E07, 0x0010140F, 0x00050604, 0x000C0A09, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07,
        0x00090D07, 0x00090D07, 0x00090D07, 0x00080D04, 0x00080D04, 0x00090D07, 0x00090D07, 0x00090D08, 0x00090D08, 0x000A0E09, 0x000A0D0B, 0x000C0D09, 0x00080E09, 0x00090F0A, 0x000D0C08, 0x00140D0A, 0x000D0C08, 0x000E1E17, 0x00294B41, 0x00559082,
        0x0054867A, 0x0041665C, 0x00223A32, 0x00101C16, 0x00080E09, 0x00090A06, 0x000C0D09, 0x00091009, 0x00010500, 0x005E5E58, 0x0093908B, 0x00090601, 0x000D0D07, 0x0010140E, 0x00040B04, 0x002B342A, 0x00D4D5CC, 0x00E9E1DA, 0x00565049, 0x00919289,
        0x009C9F96, 0x00E9E3DC, 0x0084746E, 0x005B5F54, 0x007D7E74, 0x004E4C44, 0x00C7C4BC, 0x00797570, 0x0012120C, 0x00121611, 0x000D130E, 0x0010140E, 0x0010140E, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000E120C, 0x000E120C, 0x001A1E13,
        0x001C2015, 0x0025281F, 0x00181B12, 0x000C0E08, 0x00141610, 0x0013150F, 0x000D0E0A, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x0010140F, 0x000E120D, 0x000A100B, 0x00181F1C, 0x00303936,
        0x00394442, 0x00323F3D, 0x002C3937, 0x001B2B24, 0x00656F69, 0x00E6EBE9, 0x009EA9A7, 0x0094ADA9, 0x00BDDEDA, 0x00C2DEDE, 0x00C5D9DA, 0x00D7E1E8, 0x00C7DDE2, 0x00C3E5E5, 0x00B7D7D6, 0x00B8CDCB, 0x00E8F0EF, 0x00EDF2F1, 0x00F1F8F5, 0x00C9CECF,
        0x00BAC0BF, 0x00F4FBF8, 0x00EDF7F1, 0x00E2F1ED, 0x00D7EDEB, 0x00CAE7EB, 0x00CAEAEF, 0x00B0D1D4, 0x00AACBCE, 0x00AACBCE, 0x00B4D5D8, 0x00C3E4E7, 0x00C8E9EC, 0x00C0E1E4, 0x00B5D6D9, 0x009EBFC2, 0x009FC0C3, 0x00A5C6C9, 0x00B4D5D8, 0x00C2E3E6,
        0x00C6E7EA, 0x00BFE0E3, 0x00B5D6D9, 0x00A3C4C7, 0x00A2C3C6, 0x00A6C7CA, 0x00AECFD2, 0x00BBDCDF, 0x00C6E7EA, 0x00CBECEF, 0x00CDEEF1, 0x00B1D2D5, 0x00AFD0D3, 0x00AECDD0, 0x00ABCACD, 0x00AECDD0, 0x00B9D6DA, 0x00C8E5E9, 0x00D3F0F4, 0x00D9EDF2,
        0x00D5EBF0, 0x00D0E9EB, 0x00CDE6E8, 0xC9D2E7E8, 0xE2DDEAEC, 0xFFEBF0F3, 0xFFF3F5F6, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFE, 0xFFFDFEFC, 0xFFFFFFFE, 0xFFFCFDF9, 0xFFF2F3EF, 0x00464743, 0x000B0D07, 0x000A0C06, 0x00090D07,
        0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x000B0C03, 0x000D0E05, 0x001C1D14, 0x00070800, 0x008C8D84, 0x0096978E, 0x0053544B, 0x001A1B12, 0x00A7A196,
        0x005D594E, 0x00070800, 0x00000500, 0x00080F08, 0x00090D08, 0x00080907, 0x00100E0D, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07,
        0x00090D07, 0x00090D07, 0x00090D07, 0x00080D04, 0x00080D04, 0x00090D07, 0x00090D07, 0x00090D08, 0x00090D08, 0x000A0E09, 0x000A0D0B, 0x000B0A06, 0x00090F0A, 0x0009100B, 0x00090A06, 0x00160D0A, 0x00170E0B, 0x000A0B07, 0x000C1A14, 0x00132E25,
        0x001A322A, 0x0012271F, 0x0004120C, 0x00030D07, 0x0009100B, 0x000A100B, 0x000C100B, 0x00091009, 0x00010500, 0x0060605A, 0x00918E89, 0x00090601, 0x000D0D07, 0x0011150F, 0x00040B04, 0x0030392F, 0x00D5D6CD, 0x00E3DBD4, 0x0048423B, 0x008B8C83,
        0x006E7168, 0x00746E67, 0x00968680, 0x005D6156, 0x0083847A, 0x005F5D55, 0x00D0CDC5, 0x00D3CFCA, 0x00393933, 0x00030702, 0x00101611, 0x0010140E, 0x0010140E, 0x000F130D, 0x000F130D, 0x000F130D, 0x000F130D, 0x000E120C, 0x000E120C, 0x0075796E,
        0x00868A7F, 0x00AEB2A7, 0x007E8178, 0x001A1D14, 0x00080A04, 0x001C1E18, 0x0011130D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x0010140F, 0x000D110C, 0x000B110C, 0x0019201D, 0x00303936,
        0x00394442, 0x00313E3C, 0x002C3937, 0x001A2A23, 0x006A746E, 0x00F0F5F3, 0x009CA7A5, 0x0079928E, 0x0097B8B4, 0x00B7D3D3, 0x00D9EDEE, 0x00E3EDF4, 0x00D2E8ED, 0x00C1E3E3, 0x00A3C3C2, 0x00A4B9B7, 0x00E3EBEA, 0x00F2F7F6, 0x00F4FBF8, 0x00C9CECF,
        0x00BEC4C3, 0x00F6FDFA, 0x00EBF5EF, 0x00DBEAE6, 0x00C8DEDC, 0x00B5D2D6, 0x00B1D1D6, 0x00C0E1E4, 0x00C9EAED, 0x00CDEEF1, 0x00C2E3E6, 0x00B0D1D4, 0x00A3C4C7, 0x00A5C6C9, 0x00ABCCCF, 0x00BFE0E3, 0x00BDDEE1, 0x00B5D6D9, 0x00A7C8CB, 0x009CBDC0,
        0x009EBFC2, 0x00AECFD2, 0x00BCDDE0, 0x00CBECEF, 0x00C9EAED, 0x00C4E5E8, 0x00BADBDE, 0x00B0D1D4, 0x00A8C9CC, 0x00A6C7CA, 0x00A7C8CB, 0x00BFE0E3, 0x00C5E6E9, 0x00CDECEF, 0x00CCEBEE, 0x00C4E3E6, 0x00B9D6DA, 0x00B0CDD1, 0x00ABC8CC, 0x00BACED9,
        0x00C1D8E0, 0x00CBE7EE, 0x00D6F2F9, 0x00DFF7FD, 0xF7E7F7FE, 0xFFECF4FB, 0xFFEFF1F9, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFE, 0xFFF8F9F7, 0x00636460, 0x00060703, 0x00070804, 0x000B0D07,
        0x000B0D07, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000B0D07, 0x000A0C06, 0x000A0C06, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080F0C, 0x00040A05, 0x000A0E09, 0x00050602, 0x00595651, 0x00D5CFCA, 0x00DDD5CE, 0x00B6AEA7, 0x00979289,
        0x00BBB9AF, 0x002A291F, 0x00040800, 0x000A1005, 0x00050F03, 0x00061206, 0x00000A00, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000B0D07, 0x000C0E08, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06,
        0x00080C06, 0x00080C06, 0x00080C06, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000E0F0B,
        0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x00091009, 0x00030701, 0x0061615B, 0x008F8C87, 0x00090601, 0x0010100A, 0x000E120C, 0x00020902, 0x003D3C32, 0x00D2D1C7, 0x00E1DFD5, 0x004D4B41, 0x003D382F,
        0x00BEB9B0, 0x00DBD4CB, 0x00575047, 0x006C6D63, 0x0078776D, 0x0047443C, 0x00C1BBB4, 0x009F9994, 0x00312E29, 0x000C0D09, 0x000F1510, 0x000E120D, 0x0010140F, 0x000F130E, 0x000D110C, 0x000F130E, 0x00111510, 0x000E120D, 0x00090D08, 0x008D8984,
        0x0046423D, 0x0063605B, 0x008D8A85, 0x0025221D, 0x0012120C, 0x001A1A14, 0x00191913, 0x0011160D, 0x00081006, 0x000C140D, 0x00121D15, 0x0009100B, 0x000B0F0A, 0x001A1915, 0x00140F0E, 0x000D100E, 0x00131614, 0x000A0F0D, 0x001A211E, 0x00343D3A,
        0x00384340, 0x002F3D39, 0x00293733, 0x0013231C, 0x007B8481, 0x00E9EFEE, 0x009BACA9, 0x009DBAB7, 0x00B4D4D3, 0x00BDD4D6, 0x00CDD9DD, 0x00CADAE0, 0x00C4DFE3, 0x00C6E8E8, 0x00B7D3D3, 0x00BBC9C8, 0x00EDF2F1, 0x00EFF4F3, 0x00EEF7F4, 0x00BFC8C5,
        0x00C7CDCC, 0x00F6FEFD, 0x00E4EEEE, 0x00E0EFF1, 0x00D6EDEF, 0x00C7E6E9, 0x00BFE2E5, 0x00AFD0D3, 0x00A9CACD, 0x00A8C9CC, 0x00B3D4D7, 0x00C2E3E6, 0x00C8E9EC, 0x00BFE0E3, 0x00B4D5D8, 0x009ABBBE, 0x009EBFC2, 0x00A9CACD, 0x00B8D9DC, 0x00C4E5E8,
        0x00C3E4E7, 0x00B5D6D9, 0x00A7C8CB, 0x009BBCBF, 0x00A1C2C5, 0x00AECFD2, 0x00BBDCDF, 0x00C5E6E9, 0x00C8E9EC, 0x00C6E7EA, 0x00C2E3E6, 0x00AECFD2, 0x00A8C9CC, 0x00A4C5C8, 0x00A6C7CA, 0x00B1D2D5, 0x00BFE0E3, 0x00CBECEF, 0x00D0F1F4, 0x00CBE6EA,
        0x00C7E2E6, 0x00C5DCDE, 0x00C6DBDD, 0x00CDDFE0, 0xD9DAE7E9, 0xF2E6F2F4, 0xFFEFF9F9, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFEFFFD, 0xFFFDFEFC, 0x0072736F, 0x00080905, 0x00080905, 0x000B0D07,
        0x000B0D07, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000B0D07, 0x000B0D07, 0x000A0C06, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00070E0B, 0x00020803, 0x00080C07, 0x00060703, 0x00080500, 0x006B6762, 0x00D0CAC3, 0x00AFA7A0, 0x00C9C2B9,
        0x00DDD8CF, 0x00A7A59B, 0x001A190F, 0x00050900, 0x00080E03, 0x000B1308, 0x00061004, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000A0C06, 0x00090B05, 0x00080A04, 0x00080A04, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06,
        0x00080C06, 0x00080C06, 0x00080C06, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000D0E0A,
        0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x00050C05, 0x00010500, 0x0062625C, 0x00928F8A, 0x000B0803, 0x000F0F09, 0x000E120C, 0x00060D06, 0x0039382E, 0x00E0DFD5, 0x00D0CEC4, 0x004D4B41, 0x00746F66,
        0x006D685F, 0x00615A51, 0x003C352C, 0x00727369, 0x00747369, 0x00646159, 0x00DAD4CD, 0x00A7A19C, 0x00201D18, 0x000D0E0A, 0x000D130E, 0x000E120D, 0x0010140F, 0x000F130E, 0x000E120D, 0x000F130E, 0x0010140F, 0x000E120D, 0x000A0E09, 0x00635F5A,
        0x00918D88, 0x00585550, 0x00989590, 0x002F2C27, 0x000E0E08, 0x0015150F, 0x000D0D07, 0x000C0F06, 0x00171C13, 0x000D150E, 0x000A120B, 0x000A110C, 0x000D110C, 0x00171612, 0x00120E0D, 0x000D100E, 0x00121513, 0x000A0F0D, 0x001A211E, 0x00343D3A,
        0x0037423F, 0x002E3C38, 0x00273531, 0x0021312A, 0x00919A97, 0x00EFF5F4, 0x008E9F9C, 0x00809D9A, 0x00A0C0BF, 0x00C5DCDE, 0x00DDE9ED, 0x00DCECF2, 0x00C6E1E5, 0x00B8DADA, 0x00A3BFBF, 0x00B3C1C0, 0x00ECF1F0, 0x00F2F7F6, 0x00EFF8F5, 0x00BEC7C4,
        0x00C6CCCB, 0x00F4FCFB, 0x00E5EFEF, 0x00D7E6E8, 0x00BED5D7, 0x00B1D0D3, 0x00B4D7DA, 0x00C3E4E7, 0x00CAEBEE, 0x00CDEEF1, 0x00C2E3E6, 0x00B0D1D4, 0x00A6C7CA, 0x00A8C9CC, 0x00AFD0D3, 0x00C7E8EB, 0x00BFE0E3, 0x00B1D2D5, 0x00A1C2C5, 0x009ABBBE,
        0x00A2C3C6, 0x00B5D6D9, 0x00C5E6E9, 0x00D0F1F4, 0x00C7E8EB, 0x00BADBDE, 0x00AECFD2, 0x00A8C9CC, 0x00A8C9CC, 0x00ABCCCF, 0x00ADCED1, 0x00C5E6E9, 0x00C9EAED, 0x00CBECEF, 0x00C7E8EB, 0x00BCDDE0, 0x00B0D1D4, 0x00A8C9CC, 0x00A4C5C8, 0x00BBD6DA,
        0x00C6E1E5, 0x00D9F0F2, 0x00E2F7F9, 0x00E4F6F7, 0x00E6F3F5, 0xF7E8F4F6, 0xFFECF6F6, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFDFEFC, 0xFFFFFFFE, 0x26878884, 0x000A0B07, 0x000A0B07, 0x000B0D07,
        0x000B0D07, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00030806, 0x000C120D, 0x000C100B, 0x00161713, 0x00020200, 0x00110E09, 0x00706D65, 0x0098928B, 0x002D251E,
        0x007C746D, 0x00C3BDB6, 0x00AAA79F, 0x004A4840, 0x00080900, 0x00020500, 0x0010130A, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000A0C06, 0x00080A04, 0x00070903, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06,
        0x00080C06, 0x00080C06, 0x00080C06, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000D0E0A,
        0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x00091009, 0x00010500, 0x005C5C56, 0x008B8883, 0x00080500, 0x000F0F09, 0x000D110B, 0x00050C05, 0x00444339, 0x00D5D4CA, 0x00D7D5CB, 0x0046443A, 0x008F8A81,
        0x00B6B1A8, 0x00968F86, 0x006C655C, 0x006D6E64, 0x00747369, 0x0057544C, 0x00C7C1BA, 0x00C3BDB8, 0x00393631, 0x000F100C, 0x000D130E, 0x000E120D, 0x000F130E, 0x000F130E, 0x000E120D, 0x000E120D, 0x0010140F, 0x000E120D, 0x000B0F0A, 0x000B0702,
        0x005A5651, 0x00989590, 0x0066635E, 0x0017140F, 0x000E0E08, 0x00262620, 0x00161610, 0x00181910, 0x0014170E, 0x00020902, 0x000A120B, 0x00171E19, 0x000E120D, 0x000E0D09, 0x00161211, 0x000C0F0D, 0x00111412, 0x000A0F0D, 0x001A211E, 0x00333C39,
        0x0036413E, 0x002D3B37, 0x0025332F, 0x002C3C35, 0x00B8C1BE, 0x00E7EDEC, 0x00869794, 0x00A1BEBB, 0x00B8D8D7, 0x00BCD3D5, 0x00CDD9DD, 0x00CDDDE3, 0x00C7E2E6, 0x00C9EBEB, 0x00B6D2D2, 0x00C4D2D1, 0x00EEF3F2, 0x00EDF2F1, 0x00E9F2EF, 0x00BAC3C0,
        0x00D0D6D5, 0x00F5FDFC, 0x00E1EBEB, 0x00E0EFF1, 0x00DDF4F6, 0x00CAE9EC, 0x00B6D9DC, 0x00AFD0D3, 0x00A9CACD, 0x00AACBCE, 0x00B7D8DB, 0x00C6E7EA, 0x00C9EAED, 0x00BBDCDF, 0x00ABCCCF, 0x0092B3B6, 0x009DBEC1, 0x00AFD0D3, 0x00C0E1E4, 0x00C6E7EA,
        0x00BEDFE2, 0x00ADCED1, 0x009FC0C3, 0x009CBDC0, 0x00A6C7CA, 0x00B5D6D9, 0x00C2E3E6, 0x00C8E9EC, 0x00C6E7EA, 0x00C2E3E6, 0x00BEDFE2, 0x00ABCCCF, 0x00A5C6C9, 0x00A2C3C6, 0x00ABCCCF, 0x00BBDCDF, 0x00C9EAED, 0x00CDEEF1, 0x00CCEDF0, 0x00C4DFE3,
        0x00BDD8DC, 0x00BDD4D6, 0x00C3D8DA, 0x00D2E4E5, 0x00E2EFF1, 0xFBEAF6F8, 0xFFEEF8F8, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFDFEFC, 0xFFFFFFFE, 0x549C9D99, 0x000E0F0B, 0x000B0C08, 0x000B0D07,
        0x000B0D07, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000B0D07, 0x000C0E08, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080D0B, 0x000B0F0A, 0x00000300, 0x00020300, 0x0011110B, 0x00020200, 0x0024221A, 0x008B8981, 0x00776D66,
        0x00090100, 0x00302821, 0x00B1ABA4, 0x00E0DAD3, 0x0078756D, 0x00232119, 0x00040200, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000B0D07, 0x000C0E08, 0x000C0E08, 0x000B0D07, 0x000B0D07, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06,
        0x00080C06, 0x00080C06, 0x00080C06, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09,
        0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x00070E07, 0x00030701, 0x005E5E58, 0x008A8782, 0x00080500, 0x000F0F09, 0x000C100A, 0x00030A03, 0x00414036, 0x00D6D5CB, 0x00DEDCD2, 0x00434137, 0x0079746B,
        0x00DAD5CC, 0x00D5CEC5, 0x00777067, 0x00727369, 0x0069685E, 0x0058554D, 0x00B7B1AA, 0x0068625D, 0x00040100, 0x0010110D, 0x00090F0A, 0x000E120D, 0x000F130E, 0x000E120D, 0x000E120D, 0x000E120D, 0x000F130E, 0x000E120D, 0x000D110C, 0x00635F5A,
        0x008E8A85, 0x00B2AFAA, 0x007B7873, 0x001A1712, 0x000F0F09, 0x009C9C96, 0x00696963, 0x000C0901, 0x000E0F06, 0x00181C16, 0x000D140D, 0x00030904, 0x000F130E, 0x00141511, 0x0012100F, 0x000C0F0D, 0x000F1210, 0x000A0F0D, 0x001B221F, 0x00323B38,
        0x00343F3C, 0x002C3A36, 0x0022302C, 0x0041514A, 0x00C7D0CD, 0x00E4EAE9, 0x0081928F, 0x00819E9B, 0x009FBFBE, 0x00C8DFE1, 0x00D8E4E8, 0x00DFEFF5, 0x00C5E0E4, 0x00B2D4D4, 0x0098B4B4, 0x00BCCAC9, 0x00EFF4F3, 0x00F0F5F4, 0x00E8F1EE, 0x00B6BFBC,
        0x00CCD2D1, 0x00F2FAF9, 0x00EBF5F5, 0x00D9E8EA, 0x00B7CED0, 0x00ACCBCE, 0x00B8DBDE, 0x00C6E7EA, 0x00CDEEF1, 0x00CEEFF2, 0x00C0E1E4, 0x00ACCDD0, 0x00A3C4C7, 0x00ABCCCF, 0x00B6D7DA, 0x00CBECEF, 0x00BEDFE2, 0x00AACBCE, 0x009CBDC0, 0x009BBCBF,
        0x00A8C9CC, 0x00BBDCDF, 0x00C8E9EC, 0x00C9EAED, 0x00C1E2E5, 0x00B4D5D8, 0x00A8C9CC, 0x00A3C4C7, 0x00A7C8CB, 0x00B2D3D6, 0x00BADBDE, 0x00CAEBEE, 0x00CBECEF, 0x00C8E9EC, 0x00BCDDE0, 0x00ADCED1, 0x00A5C6C9, 0x00A8C9CC, 0x00AECFD2, 0x00BFDADE,
        0x00CCE7EB, 0x00DDF4F6, 0x00E2F7F9, 0x00DFF1F2, 0xE2DEEBED, 0xEAE1EDEF, 0xF7E8F2F2, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFFFD, 0xFFFFFFFE, 0x79AFB0AC, 0x00161713, 0x000A0B07, 0x000A0C06,
        0x000B0D07, 0x000C0E08, 0x000C0E08, 0x000D0F09, 0x000D0F09, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000A0C06, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07,
        0x00080C07, 0x00080C07, 0x00080C07, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00090C0A, 0x00050904, 0x000F130E, 0x000A0B07, 0x0010120C, 0x000D0F09, 0x00000300, 0x0025281F, 0x00AAA19D,
        0x00645E59, 0x00070100, 0x00221C17, 0x0097918C, 0x00D9D3CE, 0x00ABA7A2, 0x0028241F, 0x000D0F09, 0x000B0D07, 0x00090B05, 0x00090B05, 0x000A0C06, 0x000C0E08, 0x000D0F09, 0x000C0E08, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06,
        0x00080C06, 0x00080C06, 0x00080C06, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09,
        0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x00060D06, 0x00040802, 0x005C5C56, 0x0085827D, 0x00050200, 0x000F0F09, 0x000D110B, 0x00050C05, 0x003E3D33, 0x00D5D4CA, 0x00D0CEC4, 0x00413F35, 0x004C473E,
        0x006C675E, 0x00AFA89F, 0x00302920, 0x0073746A, 0x006D6C62, 0x00706D65, 0x00E5DFD8, 0x005F5954, 0x00110E09, 0x001B1C18, 0x00080E09, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000E120D, 0x000F130E, 0x006C6863,
        0x00DDD9D4, 0x00B9B6B1, 0x00201D18, 0x0013100B, 0x0013130D, 0x00A5A59F, 0x00F9F9F3, 0x004E4841, 0x000E0B03, 0x000F110B, 0x00121912, 0x00030904, 0x000E140F, 0x00141511, 0x000F0D0C, 0x000C0F0D, 0x000E110F, 0x000B100E, 0x001C2320, 0x00313A37,
        0x00343F3C, 0x002B3935, 0x001F2D29, 0x00405049, 0x00E3ECE9, 0x00DDE3E2, 0x00869794, 0x00ABC8C5, 0x00B5D5D4, 0x00B9D0D2, 0x00D4E0E4, 0x00C7D7DD, 0x00C6E1E5, 0x00CDEFEF, 0x00AFCBCB, 0x00CBD9D8, 0x00EBF0EF, 0x00EDF2F1, 0x00EDF6F3, 0x00B3BCB9,
        0x00DBE1E0, 0x00F1F9F8, 0x00E0EAEA, 0x00DFEEF0, 0x00DAF1F3, 0x00C9E8EB, 0x00B3D6D9, 0x00A7C8CB, 0x00A3C4C7, 0x00A5C6C9, 0x00B4D5D8, 0x00C5E6E9, 0x00C9EAED, 0x00BCDDE0, 0x00ADCED1, 0x0093B4B7, 0x009FC0C3, 0x00B1D2D5, 0x00BFE0E3, 0x00C2E3E6,
        0x00B9DADD, 0x00ABCCCF, 0x00A1C2C5, 0x00A1C2C5, 0x00ACCDD0, 0x00BBDCDF, 0x00C6E7EA, 0x00C8E9EC, 0x00C2E3E6, 0x00BADBDE, 0x00B4D5D8, 0x00A5C6C9, 0x00A5C6C9, 0x00AACBCE, 0x00B6D7DA, 0x00C5E6E9, 0x00CBECEF, 0x00C6E7EA, 0x00BEDFE2, 0x00BDD8DC,
        0x00B8D3D7, 0x00BBD2D4, 0x00C5DADC, 0x00D6E8E9, 0xF2E6F3F5, 0xFFECF8FA, 0xFFEDF7F7, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFFFD, 0xFFFFFFFE, 0xA3C2C3BF, 0x00232420, 0x00080905, 0x000A0C06,
        0x000B0D07, 0x000C0E08, 0x000D0F09, 0x000D0F09, 0x000D0F09, 0x000D0F09, 0x000D0F09, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08,
        0x00090D08, 0x00090D08, 0x00090D08, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x000B0C0A, 0x00080905, 0x000D0E0A, 0x00080C07, 0x00000400, 0x00090D07, 0x000D1209, 0x00000300, 0x003B3833,
        0x00A6A39E, 0x00282520, 0x00070300, 0x00100C07, 0x006C6863, 0x00C2BEB9, 0x00B9B5B0, 0x0012140E, 0x000E100A, 0x000A0C06, 0x00080A04, 0x00090B05, 0x000B0D07, 0x000B0D07, 0x000A0C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06,
        0x00080C06, 0x00080C06, 0x00080C06, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09,
        0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C130C, 0x00030701, 0x00595953, 0x008C8984, 0x0015120D, 0x00181812, 0x000A0E08, 0x00000500, 0x0038372D, 0x00D4D3C9, 0x00DBD9CF, 0x00444238, 0x00979289,
        0x00AEA9A0, 0x00D1CAC1, 0x00554E45, 0x00727369, 0x005D5C52, 0x00413E36, 0x00BDB7B0, 0x00433D38, 0x00080500, 0x000C0D09, 0x000C120D, 0x000E120D, 0x000D110C, 0x000E120D, 0x000F130E, 0x000E120D, 0x000D110C, 0x000E120D, 0x00111510, 0x0068645F,
        0x0038342F, 0x009E9B96, 0x00696661, 0x00100D08, 0x000C0C06, 0x009C9C96, 0x00FDFDF7, 0x00DDD3CC, 0x004A443D, 0x00050500, 0x00121610, 0x00151B16, 0x000C120D, 0x000B0F0A, 0x00131412, 0x000D100E, 0x000D100E, 0x000B100E, 0x001E2522, 0x00313A37,
        0x00333E3B, 0x002B3935, 0x001C2A26, 0x004E5E57, 0x00DCE5E2, 0x00D7DDDC, 0x00869794, 0x0088A5A2, 0x009EBEBD, 0x00C7DEE0, 0x00DEEAEE, 0x00D9E9EF, 0x00C4DFE3, 0x00B6D8D8, 0x0091ADAD, 0x00C3D1D0, 0x00EBF0EF, 0x00F0F5F4, 0x00ECF5F2, 0x00AFB8B5,
        0x00D7DDDC, 0x00EDF5F4, 0x00E9F3F3, 0x00D7E6E8, 0x00B4CBCD, 0x00ABCACD, 0x00B6D9DC, 0x00C8E9EC, 0x00CDEEF1, 0x00CBECEF, 0x00BBDCDF, 0x00A7C8CB, 0x009FC0C3, 0x00A8C9CC, 0x00B5D6D9, 0x00C9EAED, 0x00BADBDE, 0x00A8C9CC, 0x009DBEC1, 0x00A0C1C4,
        0x00ADCED1, 0x00BBDCDF, 0x00C4E5E8, 0x00C4E5E8, 0x00BBDCDF, 0x00AFD0D3, 0x00A5C6C9, 0x00A3C4C7, 0x00ABCCCF, 0x00B8D9DC, 0x00C1E2E5, 0x00CAEBEE, 0x00C9EAED, 0x00C2E3E6, 0x00B3D4D7, 0x00A6C7CA, 0x00A3C4C7, 0x00ADCED1, 0x00B7D8DB, 0x00CCE7EB,
        0x00D2EDF1, 0x00DBF2F4, 0x00D9EEF0, 0x00D6E8E9, 0xD9DAE7E9, 0xEEE3EFF1, 0xFFEEF8F8, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFFFD, 0xFFFFFFFE, 0xC9D4D5D1, 0x00353632, 0x00060703, 0x000A0C06,
        0x000B0D07, 0x000C0E08, 0x000D0F09, 0x000D0F09, 0x000E100A, 0x000E100A, 0x000D0F09, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08,
        0x00090D08, 0x00090D08, 0x00090D08, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00090A08, 0x000C0D09, 0x00050602, 0x00080C07, 0x00090D07, 0x00050C05, 0x000C140A, 0x00050D03, 0x00090A06,
        0x003D3E3A, 0x003B3C38, 0x00090804, 0x000E0D09, 0x000C0905, 0x002F2C28, 0x0055524E, 0x0011130D, 0x000E100A, 0x000A0C06, 0x00090B05, 0x000B0D07, 0x000C0E08, 0x000B0D07, 0x00090B05, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06,
        0x00080C06, 0x00080C06, 0x00080C06, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09,
        0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000B120B, 0x00000300, 0x00565650, 0x008B8883, 0x00090601, 0x00020200, 0x00030701, 0x00151C15, 0x0097968C, 0x00D9D8CE, 0x00CECCC2, 0x00454339, 0x00908B82,
        0x00CAC5BC, 0x00AFA89F, 0x00726B62, 0x0078796F, 0x0068675D, 0x006E6B63, 0x00E6E0D9, 0x0056504B, 0x000C0904, 0x00171814, 0x00080E09, 0x000E120D, 0x000D110C, 0x000D110C, 0x000F130E, 0x000E120D, 0x000C100B, 0x000E120D, 0x00121611, 0x00A7A39E,
        0x007D7974, 0x004A4742, 0x0055524D, 0x00100D08, 0x0011110B, 0x00A7A7A1, 0x00F7F7F1, 0x00FFFFF9, 0x00C0B8B1, 0x003E3B36, 0x00080A04, 0x000A100B, 0x000A100B, 0x00141813, 0x00101311, 0x000D100E, 0x000D100E, 0x000C110F, 0x001F2623, 0x00313A37,
        0x00333E3B, 0x002B3935, 0x001B2925, 0x004F5F58, 0x00E3ECE9, 0x00CCD2D1, 0x00859693, 0x00A5C2BF, 0x00BADAD9, 0x00C1D8DA, 0x00CDD9DD, 0x00CADAE0, 0x00C4DFE3, 0x00C8EAEA, 0x00A4C0C0, 0x00D4E2E1, 0x00EDF2F1, 0x00EBF0EF, 0x00E6EFEC, 0x00AEB7B4,
        0x00E2E8E7, 0x00EDF5F4, 0x00E3EDED, 0x00DEEDEF, 0x00D2E9EB, 0x00C5E4E7, 0x00BADDE0, 0x00A9CACD, 0x00A8C9CC, 0x00ACCDD0, 0x00BADBDE, 0x00C7E8EB, 0x00C7E8EB, 0x00B7D8DB, 0x00A7C8CB, 0x0092B3B6, 0x00A3C4C7, 0x00B9DADD, 0x00C4E5E8, 0x00C1E2E5,
        0x00B5D6D9, 0x00A9CACD, 0x00A3C4C7, 0x00A4C5C8, 0x00AECFD2, 0x00BCDDE0, 0x00C7E8EB, 0x00C8E9EC, 0x00C0E1E4, 0x00B2D3D6, 0x00A9CACD, 0x00A1C2C5, 0x00A6C7CA, 0x00B2D3D6, 0x00BFE0E3, 0x00C9EAED, 0x00CAEBEE, 0x00C5E6E9, 0x00BFE0E3, 0x00B0CBCF,
        0x00B3CED2, 0x00BED5D7, 0x00CCE1E3, 0x00DCEEEF, 0xFBEAF7F9, 0xFFEDF9FB, 0xFFEFF9F9, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFEFFFD, 0xFFFFFFFE, 0xE2E1E2DE, 0x0041423E, 0x00050602, 0x000A0C06,
        0x000B0D07, 0x000C0E08, 0x000D0F09, 0x000D0F09, 0x000E100A, 0x000E100A, 0x000E100A, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08,
        0x00090D08, 0x00090D08, 0x00090D08, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x000C0D0B, 0x000A0B07, 0x00090A06, 0x00070B06, 0x00091009, 0x000A110A, 0x00050E04, 0x00060F05, 0x00010702,
        0x00000400, 0x000D110C, 0x00050904, 0x000C0D09, 0x000E0D09, 0x000B0A06, 0x00040300, 0x000E100A, 0x000B0D07, 0x00090B05, 0x000A0C06, 0x000D0F09, 0x000E100A, 0x000D0F09, 0x000B0D07, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06,
        0x00080C06, 0x00080C06, 0x00080C06, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09,
        0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x00091009, 0x00010500, 0x005C5C56, 0x008B8883, 0x00050200, 0x001C1C16, 0x006D716B, 0x00CBD2CB, 0x00D3D2C8, 0x006A695F, 0x009D9B91, 0x00B2B0A6, 0x003B362D,
        0x00656057, 0x007C756C, 0x00463F36, 0x0073746A, 0x0065645A, 0x003F3C34, 0x00948E87, 0x004A443F, 0x000C0904, 0x000F100C, 0x00090F0A, 0x000E120D, 0x000D110C, 0x000D110C, 0x000F130E, 0x000E120D, 0x000C100B, 0x000E120D, 0x00131712, 0x009B9792,
        0x00706C67, 0x00989590, 0x005E5B56, 0x00191611, 0x0012120C, 0x00A8A8A2, 0x00F6F6F0, 0x00FCF0EA, 0x00FDF3EC, 0x005D5954, 0x00050701, 0x00111712, 0x00080E09, 0x00111510, 0x00090C0A, 0x000E110F, 0x000D100E, 0x000D1210, 0x00202724, 0x00313A37,
        0x00333E3B, 0x002B3935, 0x001A2824, 0x00576760, 0x00E4EDEA, 0x00CFD5D4, 0x007E8F8C, 0x0085A29F, 0x00A8C8C7, 0x00CBE2E4, 0x00DDE9ED, 0x00DDEDF3, 0x00C7E2E6, 0x00B9DBDB, 0x0090ACAC, 0x00CCDAD9, 0x00EDF2F1, 0x00EEF3F2, 0x00E7F0ED, 0x00AEB7B4,
        0x00E1E7E6, 0x00EAF2F1, 0x00E3EDED, 0x00D4E3E5, 0x00B9D0D2, 0x00AFCED1, 0x00B1D4D7, 0x00C8E9EC, 0x00CBECEF, 0x00C7E8EB, 0x00B8D9DC, 0x00A6C7CA, 0x00A1C2C5, 0x00ABCCCF, 0x00B8D9DC, 0x00CBECEF, 0x00B7D8DB, 0x00A0C1C4, 0x0096B7BA, 0x009EBFC2,
        0x00AFD0D3, 0x00BDDEE1, 0x00C4E5E8, 0x00C7E8EB, 0x00BBDCDF, 0x00ABCCCF, 0x00A2C3C6, 0x00A4C5C8, 0x00AFD0D3, 0x00BEDFE2, 0x00C7E8EB, 0x00CEEFF2, 0x00C6E7EA, 0x00B7D8DB, 0x00A8C9CC, 0x00A0C1C4, 0x00A4C5C8, 0x00B0D1D4, 0x00BADBDE, 0x00D7F2F6,
        0x00D7F2F6, 0x00D8EFF1, 0x00D5EAEC, 0xD1D5E7E8, 0xDEDBE8EA, 0xEAE2EEF0, 0xFBE9F3F3, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFDFDFD, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFEEEEEE, 0x26848484, 0x00020202, 0x000F100C,
        0x00090A06, 0x00060703, 0x000A0B07, 0x000D0E0A, 0x000B0C08, 0x000A0B07, 0x000C0D09, 0x000F110B, 0x000C0E08, 0x000C0E08, 0x000E100A, 0x000D0F09, 0x000A0C06, 0x000B0D07, 0x000F110B, 0x00060A05, 0x00080C07, 0x00090D08, 0x000A0E09, 0x000A0E09,
        0x000A0E09, 0x000A0E09, 0x000B0F0A, 0x00090D08, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x00090D08, 0x00090D08, 0x00080C07, 0x00080C07, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0D07,
        0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06,
        0x00080C06, 0x00080C06, 0x00080C06, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000C0D09,
        0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0F0D, 0x00080905, 0x00565753, 0x00767571, 0x004B4843, 0x00CAC6C1, 0x00E0DAD3, 0x0078726B, 0x00161610, 0x000D0D07, 0x000F0F09, 0x00A7A7A1, 0x00AFAFA9,
        0x000F0F09, 0x00080802, 0x00030300, 0x00818076, 0x006E6C62, 0x002D2720, 0x00625C55, 0x00312D28, 0x00161610, 0x00090D08, 0x000C130E, 0x000D110C, 0x000D110C, 0x000D110C, 0x000D110C, 0x000D110C, 0x000D110C, 0x000D110C, 0x000D110C, 0x00706F6B,
        0x004F4E4A, 0x001B1A16, 0x00181713, 0x00161511, 0x000B0A06, 0x00B5B4B0, 0x00FFFFFB, 0x00ACADA9, 0x003D3E3A, 0x00090A06, 0x000F130E, 0x000F130E, 0x000C120D, 0x000C120D, 0x000E140F, 0x000B100E, 0x000A0F0D, 0x000C1310, 0x00222B28, 0x00323D3A,
        0x002E3C38, 0x00293733, 0x001E2D29, 0x003B4B44, 0x00D3DCD9, 0x00D3D9D8, 0x00879895, 0x00AFCCC9, 0x00B6D6D5, 0x00C0D7D9, 0x00D2DEE2, 0x00C3D9DE, 0x00C4E1E5, 0x00CDECED, 0x00AAC2C2, 0x00E0E8E8, 0x00ECECEC, 0x00F3F5F5, 0x00E5EEEB, 0x00ACB6B0,
        0x00E6EFEC, 0x00E7F2F0, 0x00DFEBEB, 0x00DAECED, 0x00D5EEF2, 0x00C1E1E6, 0x00B5DADE, 0x00A7C8CB, 0x00A6C7CA, 0x00ACCDD0, 0x00BBDCDF, 0x00C8E9EC, 0x00C5E6E9, 0x00B1D2D5, 0x009FC0C3, 0x0096B7BA, 0x00A4C5C8, 0x00B6D7DA, 0x00BFE0E3, 0x00BBDCDF,
        0x00AECFD2, 0x00A2C3C6, 0x009ABBBE, 0x00A5C6C9, 0x00B2D3D6, 0x00C3E4E7, 0x00CBECEF, 0x00C6E7EA, 0x00B9DADD, 0x00ACCDD0, 0x00A5C6C9, 0x00A4C5C8, 0x00A9CACD, 0x00B7D6D9, 0x00C6E5E8, 0x00D0EFF2, 0x00CEEBEF, 0x00C0DDE1, 0x00B4D1D5, 0x00ADC8CC,
        0x00B5CED2, 0x00C4D9DB, 0x00D3E6E9, 0xEEE3F2F4, 0xFFEDF9FB, 0xFFF0F9FC, 0xFFF1F9F9, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xBCCCCCCC, 0x21818181, 0x0032332F,
        0x00252622, 0x00151612, 0x000B0C08, 0x00070804, 0x00080905, 0x000C0D09, 0x000F100C, 0x000D0F09, 0x000A0C06, 0x000A0C06, 0x000D0F09, 0x000D0F09, 0x000A0C06, 0x00090B05, 0x000B0D07, 0x00070B06, 0x00080C07, 0x00090D08, 0x00090D08, 0x00090D08,
        0x00090D08, 0x00080C07, 0x00080C07, 0x00080C07, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x000A0E09, 0x000B0F0A, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0D07,
        0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06,
        0x00080C06, 0x00080C06, 0x00080C06, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000C0D09,
        0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x00080B09, 0x00000100, 0x0050514D, 0x00868581, 0x00393631, 0x007E7A75, 0x00130D06, 0x000E0801, 0x004D4A45, 0x00C0BDB8, 0x009A9792, 0x000D0A05, 0x00A4A19C,
        0x00BBB8B3, 0x00221F1A, 0x00090601, 0x007F7E74, 0x005C5A50, 0x0067615A, 0x00D2CCC5, 0x004D4944, 0x00060600, 0x000A0E09, 0x000D140F, 0x000D110C, 0x000D110C, 0x000D110C, 0x000D110C, 0x000D110C, 0x000D110C, 0x000D110C, 0x000D110C, 0x0051504C,
        0x007E7D79, 0x009F9E9A, 0x0053524E, 0x00060501, 0x001D1C18, 0x00989793, 0x006F6E6A, 0x00191A16, 0x00020300, 0x00090A06, 0x00111510, 0x000F130E, 0x000E140F, 0x000D130E, 0x00101611, 0x000B100E, 0x000A0F0D, 0x000C1310, 0x00232C29, 0x00323D3A,
        0x002E3C38, 0x00293733, 0x001E2D29, 0x0033433C, 0x00CAD3D0, 0x00CCD2D1, 0x007A8B88, 0x008EABA8, 0x009EBEBD, 0x00C5DCDE, 0x00E0ECF0, 0x00D2E8ED, 0x00BFDCE0, 0x00B4D3D4, 0x0092AAAA, 0x00D9E1E1, 0x00EFEFEF, 0x00F4F6F6, 0x00DBE4E1, 0x00A8B2AC,
        0x00E5EEEB, 0x00EDF8F6, 0x00E4F0F0, 0x00CBDDDE, 0x00B4CDD1, 0x00AACACF, 0x00B3D8DC, 0x00C5E6E9, 0x00C6E7EA, 0x00C1E2E5, 0x00B3D4D7, 0x00A5C6C9, 0x00A4C5C8, 0x00B2D3D6, 0x00C1E2E5, 0x00C6E7EA, 0x00B7D8DB, 0x00A4C5C8, 0x009CBDC0, 0x00A3C4C7,
        0x00B2D3D6, 0x00C0E1E4, 0x00C8E9EC, 0x00BDDEE1, 0x00B2D3D6, 0x00A4C5C8, 0x00A0C1C4, 0x00A8C9CC, 0x00B6D7DA, 0x00C3E4E7, 0x00CAEBEE, 0x00CBECEF, 0x00C4E5E8, 0x00B8D7DA, 0x00A7C6C9, 0x009FBEC1, 0x00A7C4C8, 0x00BCD9DD, 0x00CEEBEF, 0x00DAF5F9,
        0x00D6EFF3, 0x00D2E7E9, 0x00CEE1E4, 0xCDD4E3E5, 0xE2DDE9EB, 0xF7E7F0F3, 0xFFEEF6F6, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFEFEFE, 0xFBE9E9E9, 0xB8CDCECA,
        0x86B4B5B1, 0x2E8B8C88, 0x0060615D, 0x003E3F3B, 0x00262723, 0x00141511, 0x00080905, 0x00090A06, 0x00070804, 0x00070804, 0x000C0D09, 0x000F100C, 0x000E0F0B, 0x000C0D09, 0x000B0C08, 0x000D110C, 0x000C100B, 0x000B0F0A, 0x000A0E09, 0x000A0E09,
        0x000A0E09, 0x000A0E09, 0x000A0E09, 0x00090D08, 0x000A0E09, 0x000A0E09, 0x00090D08, 0x00080C07, 0x00080C07, 0x000A0E09, 0x000C100B, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0D07,
        0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06,
        0x00080C06, 0x00080C06, 0x00080C06, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x000C0D09,
        0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x00131614, 0x00040501, 0x003F403C, 0x0092918D, 0x00040100, 0x00050100, 0x004B453E, 0x00B6B0A9, 0x00E0DDD8, 0x0096938E, 0x00ACA9A4, 0x00A09D98, 0x00181510,
        0x00A29F9A, 0x00B6B3AE, 0x0017140F, 0x00737268, 0x00626056, 0x00716B64, 0x00DED8D1, 0x0046423D, 0x00090903, 0x000A0E09, 0x000D140F, 0x000D110C, 0x000D110C, 0x000D110C, 0x000D110C, 0x000D110C, 0x000D110C, 0x000D110C, 0x000D110C, 0x00020100,
        0x00050400, 0x0051504C, 0x0094938F, 0x0014130F, 0x00070602, 0x00161511, 0x000F0E0A, 0x00070804, 0x00141511, 0x001B1C18, 0x000D110C, 0x00070B06, 0x00080E09, 0x00050B06, 0x00090F0A, 0x000B100E, 0x000A0F0D, 0x000D1411, 0x00232C29, 0x00323D3A,
        0x002E3C38, 0x00283632, 0x001D2C28, 0x002E3E37, 0x00D2DBD8, 0x00C1C7C6, 0x007C8D8A, 0x00B0CDCA, 0x00BBDBDA, 0x00C0D7D9, 0x00D2DEE2, 0x00C6DCE1, 0x00C4E1E5, 0x00C5E4E5, 0x00A5BDBD, 0x00E0E8E8, 0x00ECECEC, 0x00F3F5F5, 0x00E0E9E6, 0x00ACB6B0,
        0x00EDF6F3, 0x00EBF6F4, 0x00DDE9E9, 0x00D4E6E7, 0x00D4EDF1, 0x00C6E6EB, 0x00B5DADE, 0x00AACBCE, 0x00A7C8CB, 0x00ABCCCF, 0x00B9DADD, 0x00C7E8EB, 0x00C3E4E7, 0x00AFD0D3, 0x009BBCBF, 0x0095B6B9, 0x00A7C8CB, 0x00BBDCDF, 0x00C0E1E4, 0x00B5D6D9,
        0x00A6C7CA, 0x009EBFC2, 0x009CBDC0, 0x00B3D4D7, 0x00BEDFE2, 0x00C9EAED, 0x00CAEBEE, 0x00C0E1E4, 0x00B1D2D5, 0x00A6C7CA, 0x00A1C2C5, 0x00A4C5C8, 0x00ADCED1, 0x00BEDDE0, 0x00CBEAED, 0x00CEEDF0, 0x00C7E4E8, 0x00B8D5D9, 0x00ACC9CD, 0x00AFCACE,
        0x00BBD4D8, 0x00CEE3E5, 0x00DCEFF2, 0x00E8F7F9, 0x00ECF8FA, 0xFFEBF4F7, 0xFBEAF2F2, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFBFBFB, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFF9FAF8,
        0xFFFFFFFE, 0xFFFFFFFE, 0xFFF5F6F4, 0xDEDCDDDB, 0x8AB4B5B3, 0x26848583, 0x0060615F, 0x00363733, 0x00282925, 0x00171814, 0x000B0C08, 0x00070804, 0x00090A06, 0x000B0C08, 0x000C0D09, 0x00070B06, 0x00070B06, 0x00080C07, 0x00090D08, 0x00090D08,
        0x00090D08, 0x00080C07, 0x00060A05, 0x000A0E09, 0x000B0F0A, 0x000C100B, 0x000B0F0A, 0x00080C07, 0x00070B06, 0x00080C07, 0x000A0E09, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0D07,
        0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06,
        0x00080C06, 0x00080C06, 0x00080C06, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x000C0D09,
        0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x00030604, 0x00090A06, 0x0050514D, 0x007E7D79, 0x0027241F, 0x00ABA7A2, 0x00E0DAD3, 0x00A29C95, 0x00302D28, 0x00040100, 0x0023201B, 0x00B2AFAA, 0x00928F8A,
        0x00181510, 0x009C9994, 0x00706D68, 0x00706F65, 0x006D6B61, 0x0058524B, 0x00AFA9A2, 0x002B2722, 0x0013130D, 0x000C100B, 0x0009100B, 0x000D110C, 0x000D110C, 0x000D110C, 0x000D110C, 0x000D110C, 0x000D110C, 0x000D110C, 0x000D110C, 0x00151612,
        0x00090A06, 0x002D2E2A, 0x003B3C38, 0x00070804, 0x00141511, 0x00181915, 0x00080905, 0x00141511, 0x00151612, 0x000F100C, 0x00090D08, 0x000E120D, 0x000F1510, 0x000C120D, 0x00101611, 0x000B100E, 0x000A0F0D, 0x000D1411, 0x00242D2A, 0x00333E3B,
        0x002E3C38, 0x00283632, 0x001C2B27, 0x003F4F48, 0x00D1DAD7, 0x00C4CAC9, 0x00829390, 0x008FACA9, 0x00A8C8C7, 0x00D0E7E9, 0x00DBE7EB, 0x00D1E7EC, 0x00C1DEE2, 0x00B3D2D3, 0x0096AEAE, 0x00DDE5E5, 0x00F0F0F0, 0x00F4F6F6, 0x00D6DFDC, 0x00AFB9B3,
        0x00E5EEEB, 0x00E5F0EE, 0x00E6F2F2, 0x00CFE1E2, 0x00B1CACE, 0x00A9C9CE, 0x00B4D9DD, 0x00C5E6E9, 0x00C7E8EB, 0x00C2E3E6, 0x00B0D1D4, 0x009FC0C3, 0x009DBEC1, 0x00AECFD2, 0x00BFE0E3, 0x00C7E8EB, 0x00B1D2D5, 0x0099BABD, 0x0095B6B9, 0x00A6C7CA,
        0x00BADBDE, 0x00C5E6E9, 0x00C7E8EB, 0x00B4D5D8, 0x00A9CACD, 0x009FC0C3, 0x00A2C3C6, 0x00B0D1D4, 0x00C1E2E5, 0x00CAEBEE, 0x00CDEEF1, 0x00C2E3E6, 0x00B8D9DC, 0x00ACCBCE, 0x00A2C1C4, 0x00A2C1C4, 0x00B0CDD1, 0x00C2DFE3, 0x00CFECF0, 0x00D2EDF1,
        0x00D0E9ED, 0x00CEE3E5, 0x00CBDEE1, 0x00D0DFE1, 0x00DCE8EA, 0xFBEAF3F6, 0xFFF6FEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCFCFC, 0xFFFFFFFE,
        0xFFFFFFFE, 0xFFFFFFFE, 0xFFFCFDFB, 0xFFFEFFFD, 0xFFFFFFFE, 0xFFFEFFFD, 0xFFF7F8F6, 0xD9DCDDD9, 0x92BABBB7, 0x21858682, 0x0051524E, 0x002D2E2A, 0x00181915, 0x000E0F0B, 0x00090A06, 0x000D110C, 0x000A0E09, 0x00080C07, 0x00070B06, 0x00090D08,
        0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x00080C07, 0x000A0E09, 0x000C100B, 0x000C100B, 0x000A0E09, 0x00090D08, 0x00090D08, 0x00090D08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0D07,
        0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06,
        0x00080C06, 0x00080C06, 0x00080C06, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x000C0D09,
        0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000D100E, 0x00090A06, 0x003A3B37, 0x0084837F, 0x00413E39, 0x009B9792, 0x0048423B, 0x00080200, 0x002C2823, 0x00A7A39E, 0x00706C67, 0x001B1712, 0x00BDB9B4,
        0x008F8B86, 0x0014100B, 0x00110D08, 0x0079786E, 0x00636157, 0x005C564F, 0x00C7C1BA, 0x002E2A25, 0x000E0E08, 0x000D110C, 0x00080F0A, 0x000D110C, 0x000D110C, 0x000D110C, 0x000D110C, 0x000D110C, 0x000D110C, 0x000D110C, 0x000D110C, 0x0012130F,
        0x000D0E0A, 0x000F100C, 0x000B0C08, 0x000D0E0A, 0x000A0B07, 0x000F100C, 0x00131410, 0x0011120E, 0x000B0C08, 0x000A0B07, 0x000F130E, 0x0010140F, 0x00090F0A, 0x000A100B, 0x000B110C, 0x000B100E, 0x000A0F0D, 0x000E1512, 0x00242D2A, 0x00333E3B,
        0x002E3C38, 0x00273531, 0x001B2A26, 0x003B4B44, 0x00E4EDEA, 0x00BFC5C4, 0x00879895, 0x00B3D0CD, 0x00BDDDDC, 0x00C0D7D9, 0x00D2DEE2, 0x00C6DCE1, 0x00C4E1E5, 0x00C0DFE0, 0x00A4BCBC, 0x00E2EAEA, 0x00ECECEC, 0x00F3F5F5, 0x00D9E2DF, 0x00AEB8B2,
        0x00F0F9F6, 0x00E9F4F2, 0x00DDE9E9, 0x00D6E8E9, 0x00D1EAEE, 0x00C6E6EB, 0x00B1D6DA, 0x00ABCCCF, 0x00A8C9CC, 0x00ACCDD0, 0x00BADBDE, 0x00C8E9EC, 0x00C6E7EA, 0x00B1D2D5, 0x009DBEC1, 0x0094B5B8, 0x00A9CACD, 0x00BEDFE2, 0x00C1E2E5, 0x00B2D3D6,
        0x00A2C3C6, 0x009CBDC0, 0x009EBFC2, 0x00B1D2D5, 0x00BFE0E3, 0x00CCEDF0, 0x00C8E9EC, 0x00B8D9DC, 0x00A7C8CB, 0x00A0C1C4, 0x00A1C2C5, 0x00ADCED1, 0x00B7D8DB, 0x00C7E6E9, 0x00CEEDF0, 0x00CBEAED, 0x00C0DDE1, 0x00B2CFD3, 0x00A9C6CA, 0x00B3CED2,
        0x00BFD8DC, 0x00D2E7E9, 0x00DFF2F5, 0x00E8F7F9, 0xFBEAF6F8, 0xFBE9F2F5, 0xF7E8F0F0, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFF9F9F9, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFF1F2F0, 0xC4D1D2D0, 0x60A1A2A0, 0x006B6C6A, 0x00464745, 0x001B1F1A, 0x00151914, 0x000D110C, 0x00080C07, 0x00070B06,
        0x00080C07, 0x00090D08, 0x00090D08, 0x00080C07, 0x00080C07, 0x00090D08, 0x000A0E09, 0x000B0F0A, 0x000C100B, 0x000C100B, 0x000B0F0A, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0D07,
        0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06,
        0x00080C06, 0x00080C06, 0x00080C06, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x000C0D09,
        0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x00080B09, 0x00070804, 0x00252622, 0x00A09F9B, 0x007B7873, 0x003B3732, 0x000F0902, 0x002E2821, 0x00A4A09B, 0x00E9E5E0, 0x00EDE9E4, 0x007E7A75, 0x00231F1A,
        0x00BCB8B3, 0x00908C87, 0x000B0702, 0x00727167, 0x005F5D53, 0x00655F58, 0x00D8D2CB, 0x003D3934, 0x000A0A04, 0x00090D08, 0x000D140F, 0x000C100B, 0x000C100B, 0x000C100B, 0x000C100B, 0x000C100B, 0x000C100B, 0x000C100B, 0x000C100B, 0x00080C07,
        0x00161A15, 0x000A0E09, 0x00141813, 0x000F130E, 0x000C100B, 0x000A0E09, 0x00141813, 0x00141511, 0x000F100C, 0x000D0E0A, 0x000F130E, 0x000B0F0A, 0x00080E09, 0x00101611, 0x000C120D, 0x000B100E, 0x000B100E, 0x000E1512, 0x00252E2B, 0x00343F3C,
        0x002E3C38, 0x00273531, 0x001B2A26, 0x004B5B54, 0x00DCE5E2, 0x00B8BEBD, 0x00879895, 0x0090ADAA, 0x00A7C7C6, 0x00CEE5E7, 0x00DDE9ED, 0x00CFE5EA, 0x00C1DEE2, 0x00AECDCE, 0x0096AEAE, 0x00E0E8E8, 0x00F0F0F0, 0x00F4F6F6, 0x00CED7D4, 0x00B3BDB7,
        0x00E8F1EE, 0x00E2EDEB, 0x00E5F1F1, 0x00D0E2E3, 0x00AEC7CB, 0x00AACACF, 0x00B1D6DA, 0x00C6E7EA, 0x00C8E9EC, 0x00C3E4E7, 0x00B2D3D6, 0x00A0C1C4, 0x009FC0C3, 0x00B0D1D4, 0x00C2E3E6, 0x00C4E5E8, 0x00ADCED1, 0x0097B8BB, 0x0097B8BB, 0x00AACBCE,
        0x00BEDFE2, 0x00C5E6E9, 0x00C2E3E6, 0x00ABCCCF, 0x00A7C8CB, 0x00A4C5C8, 0x00AACBCE, 0x00B6D7DA, 0x00C4E5E8, 0x00CDEEF1, 0x00D1F2F5, 0x00BCDDE0, 0x00B2D3D6, 0x00A7C6C9, 0x00A3C2C5, 0x00AAC9CC, 0x00BBD8DC, 0x00CCE9ED, 0x00D7F4F8, 0x00CEE9ED,
        0x00CCE5E9, 0x00CBE0E2, 0x00C9DCDF, 0x00D1E0E2, 0xE2DEEAEC, 0xFFEDF6F9, 0xFFF7FFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFBFCFA, 0xFFF1F2F0, 0xF2E7E8E6, 0x8AB5B9B4, 0x4B979B96, 0x00676B66, 0x003A3E39, 0x001A1E19,
        0x000A0E09, 0x00050904, 0x00050904, 0x000E120D, 0x000B0F0A, 0x00080C07, 0x00080C07, 0x00090D08, 0x000B0F0A, 0x000B0F0A, 0x000A0E09, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0D07,
        0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06,
        0x00080C06, 0x00080C06, 0x00080C06, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x000C0D09,
        0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000E110F, 0x000A0B07, 0x000E0F0B, 0x00282723, 0x0073706B, 0x009E9A95, 0x00AEA8A1, 0x00958F88, 0x007D7772, 0x00514B46, 0x006B6560, 0x0096908B, 0x0036302B,
        0x0019130E, 0x00C9C3BE, 0x00635D58, 0x0069685E, 0x00656359, 0x005E5851, 0x00BAB4AD, 0x0038342F, 0x000E0E08, 0x000A0E09, 0x000C130E, 0x000C100B, 0x000C100B, 0x000C100B, 0x000C100B, 0x000C100B, 0x000C100B, 0x000C100B, 0x000C100B, 0x000B0F0A,
        0x000F130E, 0x00141813, 0x00040803, 0x00131712, 0x00050904, 0x00141813, 0x00060A05, 0x000F100C, 0x0010110D, 0x000C0D09, 0x000D110C, 0x000D110C, 0x000B110C, 0x00111712, 0x00060C07, 0x000B100E, 0x000B100E, 0x000E1512, 0x00252E2B, 0x00343F3C,
        0x002E3C38, 0x00263430, 0x001A2925, 0x0053635C, 0x00E7F0ED, 0x00ABB1B0, 0x00899A97, 0x00B3D0CD, 0x00C0E0DF, 0x00C6DDDF, 0x00D1DDE1, 0x00C2D8DD, 0x00C4E1E5, 0x00C0DFE0, 0x00ABC3C3, 0x00E9F1F1, 0x00EEEEEE, 0x00F3F5F5, 0x00D1DAD7, 0x00B9C3BD,
        0x00F1FAF7, 0x00E0EBE9, 0x00DCE8E8, 0x00D7E9EA, 0x00CDE6EA, 0x00C6E6EB, 0x00B4D9DD, 0x00ABCCCF, 0x00A9CACD, 0x00ACCDD0, 0x00B8D9DC, 0x00C2E3E6, 0x00BFE0E3, 0x00ADCED1, 0x009CBDC0, 0x009ABBBE, 0x00AECFD2, 0x00C0E1E4, 0x00BDDEE1, 0x00AACBCE,
        0x009ABBBE, 0x009ABBBE, 0x00A1C2C5, 0x00C1E2E5, 0x00C2E3E6, 0x00C0E1E4, 0x00B9DADD, 0x00AFD0D3, 0x00A6C7CA, 0x00A2C3C6, 0x00A1C2C5, 0x00B8D9DC, 0x00C3E4E7, 0x00CFEEF1, 0x00CDECEF, 0x00C1E0E3, 0x00B3D0D4, 0x00AAC7CB, 0x00A7C4C8, 0x00BED9DD,
        0x00C7E0E4, 0x00D5EAEC, 0x00E0F3F6, 0x00EAF9FB, 0xFFECF8FA, 0xFBE9F2F5, 0xF2E6EEEE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFCFCFC, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFFFFFF,
        0xFFFDFDFD, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFEFFFD, 0xFFFEFFFD, 0xFFFCFDFB, 0xFFFBFCFA, 0xFFFEFFFD, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFEFFFD, 0xFFFDFFFC, 0xFFFCFFFB, 0xFFF1F5F0, 0xD9DBDFDA, 0x8EB7BBB6,
        0x2E888C87, 0x005A5E59, 0x003C403B, 0x00161A15, 0x0010140F, 0x00090D08, 0x00060A05, 0x00070B06, 0x00080C07, 0x00080C07, 0x00060A05, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000B0D07,
        0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06, 0x00080C06,
        0x00080C06, 0x00080C06, 0x00080C06, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00090D07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x00080C07, 0x000C0D09,
        0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x00080B09, 0x0011120E, 0x00090A06, 0x000A0905, 0x000B0803, 0x00080400, 0x00201A13, 0x0049433C, 0x00756F6A, 0x009D9792, 0x009C9691, 0x008F8984, 0x00736D68,
        0x003B3530, 0x00342E29, 0x0027211C, 0x00717066, 0x00636157, 0x005D5750, 0x00AFA9A2, 0x002E2A25, 0x000E0E08, 0x00131712, 0x00030A05, 0x000C100B, 0x000C100B, 0x000C100B, 0x000C100B, 0x000C100B, 0x000C100B, 0x000C100B, 0x000C100B, 0x000F130E,
        0x0010140F, 0x00030702, 0x00141813, 0x00060A05, 0x00121611, 0x000A0E09, 0x000E120D, 0x000C0D09, 0x00131410, 0x000D0E0A, 0x000E120D, 0x000F130E, 0x00080E09, 0x000D130E, 0x000B110C, 0x000B100E, 0x000B100E, 0x000E1512, 0x00252E2B, 0x00343F3C,
        0x002E3C38, 0x00263430, 0x001A2925, 0x005E6E67, 0x00E8F1EE, 0x00A9AFAE, 0x0081928F, 0x0095B2AF, 0x00A8C8C7, 0x00C9E0E2, 0x00DFEBEF, 0x00D0E6EB, 0x00BFDCE0, 0x00A8C7C8, 0x0094ACAC, 0x00E3EBEB, 0x00F2F2F2, 0x00F3F5F5, 0x00C6CFCC, 0x00B6C0BA,
        0x00F1FAF7, 0x00E5F0EE, 0x00DFEBEB, 0x00C7D9DA, 0x00ACC5C9, 0x00B0D0D5, 0x00B4D9DD, 0x00C9EAED, 0x00C9EAED, 0x00C1E2E5, 0x00B0D1D4, 0x009FC0C3, 0x009EBFC2, 0x00ADCED1, 0x00BEDFE2, 0x00BEDFE2, 0x00A9CACD, 0x0097B8BB, 0x009CBDC0, 0x00B2D3D6,
        0x00C3E4E7, 0x00C1E2E5, 0x00B7D8DB, 0x00A3C4C7, 0x00A1C2C5, 0x00A2C3C6, 0x00AECFD2, 0x00BEDFE2, 0x00C9EAED, 0x00CAEBEE, 0x00C6E7EA, 0x00AFD0D3, 0x00A8C9CC, 0x00A4C3C6, 0x00A9C8CB, 0x00B7D6D9, 0x00C7E4E8, 0x00D0EDF1, 0x00D2EFF3, 0x00C5E0E4,
        0x00C4DDE1, 0x00C6DBDD, 0x00CADDE0, 0x00D6E5E7, 0xEEE3EFF1, 0xFFEEF7FA, 0xFFF5FDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFEFEFE, 0xFFEFEFEF, 0xE6DFDFDF, 0x86B2B3B1, 0x3B8E8F8D, 0x005D5E5C, 0x00353634, 0x001A1B19, 0x000B0C0A, 0x00060705, 0x00070806, 0x00090A06, 0x000B0C08, 0x000C0D09, 0x000B0C08, 0x000B0C08, 0x000D0E0A, 0x000D0E0A, 0x000B0C08, 0x00090B05,
        0x000C0E08, 0x000D0F09, 0x000B0D07, 0x00080A04, 0x00080A04, 0x000C0E08, 0x000F110B, 0x000D0F09, 0x000D0F09, 0x000B0D07, 0x00090B05, 0x000B0D07, 0x000F110B, 0x000E100A, 0x000A0C06, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07,
        0x000A0C06, 0x00090B05, 0x00080A04, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x000A0E09,
        0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0B07, 0x000B0C08, 0x000C0D09, 0x000E0F0B, 0x000E0F0B, 0x000C0D09, 0x000B0C08, 0x000A0B07, 0x00080703, 0x00090804, 0x001A1915, 0x00454440, 0x007A7975,
        0x00999894, 0x009A9995, 0x008E8D89, 0x00BFBEBA, 0x00454440, 0x00605F5B, 0x00DBDAD6, 0x00464541, 0x00030200, 0x0011100C, 0x000F0E0A, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000B110C,
        0x000B110C, 0x000B110C, 0x000B110C, 0x000B110C, 0x000B110C, 0x000B110C, 0x000B110C, 0x000F100C, 0x000F100C, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000F100C, 0x000F100C, 0x000D100E, 0x000B0E0C, 0x00111614, 0x0029302D, 0x00333C39,
        0x002D3835, 0x00263430, 0x00182622, 0x006F736E, 0x00EAF3F0, 0x009DAEAB, 0x008AA39F, 0x00BBD8D5, 0x00BED8D8, 0x00C1D4D7, 0x00D5E4E7, 0x00BEE0E0, 0x00C6E4E5, 0x00BCD1D2, 0x00B7C5C4, 0x00E2EAE9, 0x00EDF3F2, 0x00F1F8F5, 0x00C6CDC8, 0x00BCC5C2,
        0x00EDF8F6, 0x00E5F3F1, 0x00DAECEB, 0x00D3EBEB, 0x00CBE9EA, 0x00BFE0E3, 0x00BADDE0, 0x00A6C5C8, 0x00A7C6C9, 0x00AECDD0, 0x00BBDADD, 0x00C5E4E7, 0x00BFDEE1, 0x00ABCACD, 0x0099B8BB, 0x009BBCBF, 0x00B0D1D4, 0x00C2E3E6, 0x00BDDEE1, 0x00A7C8CB,
        0x0098B9BC, 0x009CBDC0, 0x00A8C9CC, 0x00BFE0E3, 0x00C4E5E8, 0x00C5E6E9, 0x00B9DADD, 0x00A8C9CC, 0x00A0C1C4, 0x00A5C6C9, 0x00AECFD2, 0x00BDE0E4, 0x00C5E8EC, 0x00CBEBF0, 0x00C3E3E8, 0x00B6D4D9, 0x00AAC8CD, 0x00A9C7CC, 0x00AECBD0, 0x00C4DDE1,
        0x00D1E7EC, 0x00E0F5F7, 0x00E6F7FA, 0xF2E6F3F5, 0xEEE4EDF0, 0xF7E8EFF2, 0xFFEDF2F3, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCFCFC, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFEFEFE, 0xFFF8F8F8, 0xFFFFFFFE, 0xFFFCFDFB, 0xFFEDEEEC, 0xCDD5D6D4, 0x86B2B3B1, 0x26848583, 0x00535452, 0x00333432, 0x001D1E1A, 0x000B0C08, 0x00010200, 0x00090A06, 0x000F100C, 0x000B0C08, 0x00070804, 0x000A0B07, 0x000F110B,
        0x000A0C06, 0x00070903, 0x000A0C06, 0x000F110B, 0x000E100A, 0x00080A04, 0x00030500, 0x00070903, 0x000C0E08, 0x000E100A, 0x000B0D07, 0x00080A04, 0x00090B05, 0x000A0C06, 0x000A0C06, 0x000B0D07, 0x000B0D07, 0x000C0E08, 0x000C0E08, 0x000B0D07,
        0x000A0C06, 0x000A0C06, 0x00090B05, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x000A0C06, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x000A0E09,
        0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0B07, 0x000B0C08, 0x000C0D09, 0x000D0E0A, 0x000D0E0A, 0x000C0D09, 0x000B0C08, 0x000A0B07, 0x000D0C08, 0x0012110D, 0x0011100C, 0x00070602, 0x00020100,
        0x000C0B07, 0x002C2B27, 0x00474642, 0x00585753, 0x001A1915, 0x00353430, 0x00989793, 0x003D3C38, 0x00100F0B, 0x0011100C, 0x000F0E0A, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000B110C,
        0x000B110C, 0x000B110C, 0x000B110C, 0x000B110C, 0x000B110C, 0x000B110C, 0x000B110C, 0x000F100C, 0x000F100C, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000F100C, 0x000F100C, 0x000D100E, 0x000B0E0C, 0x00101513, 0x002A312E, 0x00343D3A,
        0x002E3936, 0x00263430, 0x00172521, 0x007D817C, 0x00E5EEEB, 0x00A6B7B4, 0x007A938F, 0x0092AFAC, 0x00BBD5D5, 0x00CFE2E5, 0x00D3E2E5, 0x00B7D9D9, 0x00B7D5D6, 0x00A8BDBE, 0x00ADBBBA, 0x00E0E8E7, 0x00EDF3F2, 0x00EEF5F2, 0x00BFC6C1, 0x00C2C9C6,
        0x00F1F9F8, 0x00E4F2F0, 0x00D2E4E3, 0x00C0D8D8, 0x00B5D3D4, 0x00AFD0D3, 0x00B0D3D6, 0x00CEEDF0, 0x00CCEBEE, 0x00C2E1E4, 0x00AFCED1, 0x009EBDC0, 0x009FBEC1, 0x00B3D2D5, 0x00C6E5E8, 0x00BCDDE0, 0x00A8C9CC, 0x0097B8BB, 0x009CBDC0, 0x00B2D3D6,
        0x00C1E2E5, 0x00BDDEE1, 0x00B2D3D6, 0x009EBFC2, 0x009DBEC1, 0x00A3C4C7, 0x00B2D3D6, 0x00C3E4E7, 0x00C9EAED, 0x00C4E5E8, 0x00BBDCDF, 0x00A7CACE, 0x00A1C4C8, 0x00A1C1C6, 0x00ADCDD2, 0x00C2E0E5, 0x00D0EEF3, 0x00D1EFF4, 0x00CEEBF0, 0x00C3DCE0,
        0x00C2D8DD, 0x00C3D8DA, 0x00CEDFE2, 0xE6E0EDEF, 0xFFEEF7FA, 0xFFF5FCFF, 0xFFF7FCFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFDFDFD,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFBF9, 0xFFFEFFFD, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFEFFFD, 0xFFF9FAF8, 0xFBEAEBE9, 0xD9DADBD9, 0x60A2A39F, 0x08797A76, 0x004A4B47, 0x002A2B27, 0x00131410, 0x00030400, 0x00030400, 0x000C0D09, 0x000B0C08,
        0x000B0C08, 0x000D0E0A, 0x000F100C, 0x000C0D09, 0x00080905, 0x00090A06, 0x000E0F0B, 0x000B0D07, 0x000C0E08, 0x000B0D07, 0x000A0C06, 0x000B0D07, 0x000D0F09, 0x000E100A, 0x000D0F09, 0x000B0D07, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08,
        0x000B0D07, 0x000A0C06, 0x000A0C06, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x000A0E09,
        0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0B07, 0x000B0C08, 0x000C0D09, 0x000D0E0A, 0x000D0E0A, 0x000C0D09, 0x000B0C08, 0x000A0B07, 0x000D0C08, 0x000F0E0A, 0x0011100C, 0x0012110D, 0x00100F0B,
        0x000D0C08, 0x000A0905, 0x00080703, 0x00080703, 0x000F0E0A, 0x000A0905, 0x001A1915, 0x00020100, 0x000D0C08, 0x00161511, 0x000C0B07, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000A100B,
        0x000A100B, 0x000A100B, 0x000A100B, 0x000A100B, 0x000A100B, 0x000A100B, 0x000A100B, 0x000F100C, 0x000F100C, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000F100C, 0x000F100C, 0x000D100E, 0x000A0D0B, 0x00101513, 0x002A312E, 0x00353E3B,
        0x002F3A37, 0x00263430, 0x00162420, 0x007C807B, 0x00D8E1DE, 0x00859693, 0x0090A9A5, 0x00BBD8D5, 0x00B7D1D1, 0x00CADDE0, 0x00D3E2E5, 0x00C6E8E8, 0x00CBE9EA, 0x00BDD2D3, 0x00BFCDCC, 0x00E4ECEB, 0x00E8EEED, 0x00EBF2EF, 0x00C4CBC6, 0x00C8CFCC,
        0x00EEF6F5, 0x00DFECEA, 0x00D8EAE9, 0x00D4ECEC, 0x00CFEBEC, 0x00C1E0E3, 0x00B5D8DB, 0x00A7C6C9, 0x00A6C5C8, 0x00ACCBCE, 0x00BBDADD, 0x00C6E5E8, 0x00C0DFE2, 0x00A8C7CA, 0x0093B2B5, 0x00A3C4C7, 0x00B4D5D8, 0x00C1E2E5, 0x00B9DADD, 0x00A4C5C8,
        0x0099BABD, 0x00A1C2C5, 0x00AFD0D3, 0x00C0E1E4, 0x00C2E3E6, 0x00BEDFE2, 0x00B1D2D5, 0x00A2C3C6, 0x00A0C1C4, 0x00ACCDD0, 0x00BADBDE, 0x00C8EBEF, 0x00CAEDF1, 0x00C9E9EE, 0x00BADADF, 0x00ABC9CE, 0x00A5C3C8, 0x00ABC9CE, 0x00B6D3D8, 0x00D2EBEF,
        0x00D8EEF3, 0x00DEF3F5, 0x00E2F3F6, 0xEEE4F1F3, 0xF2E6EFF2, 0xFBEAF1F4, 0xFFEFF4F5, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE,
        0xFFFDFDFD, 0xFFFDFDFD, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFFFFFE, 0xFFFFFFFE, 0xFBEAEBE9, 0xB0C7C8C6, 0x5C9E9F9D, 0x00717270, 0x00424341, 0x0020211F, 0x00151612,
        0x00080905, 0x00000100, 0x00030400, 0x000A0B07, 0x000C0D09, 0x000C0D09, 0x000D0E0A, 0x000C0E08, 0x000D0F09, 0x000E100A, 0x000E100A, 0x000D0F09, 0x000C0E08, 0x000A0C06, 0x00080A04, 0x000B0D07, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08,
        0x000C0E08, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x000A0E09,
        0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000B0C08, 0x000B0C08, 0x000C0D09, 0x000D0E0A, 0x000D0E0A, 0x000C0D09, 0x000B0C08, 0x000B0C08, 0x0010110D, 0x000A0B07, 0x00050602, 0x00070804, 0x000E0F0B,
        0x0012130F, 0x000F100C, 0x000B0C08, 0x00070804, 0x00141511, 0x000A0B07, 0x000B0C08, 0x00131410, 0x000E0F0B, 0x000D0E0A, 0x0010110D, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000C100B,
        0x000C100B, 0x000C100B, 0x000C100B, 0x000C100B, 0x000C100B, 0x000C100B, 0x000C100B, 0x000F100C, 0x000E0F0B, 0x000E0F0B, 0x000D0E0A, 0x000D0E0A, 0x000E0F0B, 0x000E0F0B, 0x000F100C, 0x000C0F0D, 0x000A0D0B, 0x00101513, 0x002A312E, 0x00363F3C,
        0x00303B38, 0x0025332F, 0x0015231F, 0x00494D48, 0x00969F9C, 0x00879895, 0x0088A19D, 0x0094B1AE, 0x00B7D1D1, 0x00D1E4E7, 0x00D6E5E8, 0x00BCDEDE, 0x00B7D5D6, 0x009DB2B3, 0x00ADBBBA, 0x00E5EDEC, 0x00F4FAF9, 0x00EEF5F2, 0x00B7BEB9, 0x00CAD1CE,
        0x00F1F9F8, 0x00E3F0EE, 0x00D2E2E1, 0x00BCD1D2, 0x00B0CCCD, 0x00B0CFD2, 0x00B7D8DB, 0x00CBEAED, 0x00CBEAED, 0x00C3E2E5, 0x00AFCED1, 0x009DBCBF, 0x009DBCBF, 0x00B0CFD2, 0x00C4E3E6, 0x00AECFD2, 0x009FC0C3, 0x0095B6B9, 0x00A1C2C5, 0x00B8D9DC,
        0x00C4E5E8, 0x00BBDCDF, 0x00ACCDD0, 0x009ABBBE, 0x009EBFC2, 0x00A9CACD, 0x00BADBDE, 0x00C8E9EC, 0x00C8E9EC, 0x00BBDCDF, 0x00AFD0D3, 0x00A2C5C9, 0x00A3C6CA, 0x00ABCBD0, 0x00B9D9DE, 0x00CAE8ED, 0x00CEECF1, 0x00C7E5EA, 0x00BFDCE1, 0x00B7D0D4,
        0x00BED4D9, 0x00C9DEE0, 0x00D6E7EA, 0xEEE3F0F2, 0xFFEDF6F9, 0xFFF3FAFD, 0xFFF7FCFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFEFEFE, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFBFBFB, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFF8F9F7, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFEFFFD, 0xFFFFFFFE, 0xFFFEFFFD, 0xEEE4E5E3, 0xABC5C6C4, 0x328C8D89,
        0x006A6B67, 0x003E3F3B, 0x001F201C, 0x000F100C, 0x00080905, 0x00070804, 0x00090A06, 0x00040600, 0x00080A04, 0x000B0D07, 0x000C0E08, 0x000A0C06, 0x00070903, 0x00080A04, 0x00090B05, 0x000B0D07, 0x000B0D07, 0x000C0E08, 0x000C0E08, 0x000C0E08,
        0x000C0E08, 0x000C0E08, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x000A0E09,
        0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000B0C08, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000B0C08, 0x000A0B07, 0x000F100C, 0x00131410, 0x0012130F, 0x000D0E0A,
        0x00090A06, 0x000B0C08, 0x000E0F0B, 0x0012130F, 0x0011120E, 0x000A0B07, 0x00030400, 0x0011120E, 0x00070804, 0x000C0D09, 0x000F100C, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000C100B,
        0x000C100B, 0x000C100B, 0x000C100B, 0x000C100B, 0x000C100B, 0x000C100B, 0x000C100B, 0x000F100C, 0x000E0F0B, 0x000E0F0B, 0x000D0E0A, 0x000D0E0A, 0x000E0F0B, 0x000E0F0B, 0x000F100C, 0x000C0F0D, 0x000A0D0B, 0x00111614, 0x002B322F, 0x00363F3C,
        0x002F3A37, 0x0025332F, 0x0015231F, 0x00989C97, 0x00E4EDEA, 0x00829390, 0x0090A9A5, 0x00C0DDDA, 0x00BAD4D4, 0x00CDE0E3, 0x00D3E2E5, 0x00BFE1E1, 0x00CBE9EA, 0x00B5CACB, 0x00BFCDCC, 0x00E5EDEC, 0x00EFF5F4, 0x00F0F7F4, 0x00C0C7C2, 0x00D2D7D5,
        0x00EDF3F2, 0x00DDE8E6, 0x00DAEAE9, 0x00D6EBEC, 0x00CDE9EA, 0x00BEDDE0, 0x00B2D3D6, 0x00A7C6C9, 0x00A4C3C6, 0x00A8C7CA, 0x00B6D5D8, 0x00C3E2E5, 0x00BFDEE1, 0x00A9C8CB, 0x0094B3B6, 0x00A7C8CB, 0x00B7D8DB, 0x00C2E3E6, 0x00B8D9DC, 0x00A2C3C6,
        0x0098B9BC, 0x00A2C3C6, 0x00B2D3D6, 0x00C3E4E7, 0x00C0E1E4, 0x00B7D8DB, 0x00A9CACD, 0x009EBFC2, 0x00A1C2C5, 0x00B0D1D4, 0x00BEDFE2, 0x00C8EBEF, 0x00C5E8EC, 0x00BEDEE3, 0x00B0D0D5, 0x00A7C5CA, 0x00A8C6CB, 0x00B7D5DA, 0x00C6E3E8, 0x00DAF3F7,
        0x00D9EFF4, 0x00D7ECEE, 0xD5D7E8EB, 0xDEDCE9EB, 0xEEE3ECEF, 0xFFEBF2F5, 0xFFF1F6F7, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCFCFC, 0xFFFEFEFE, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFBFAFC, 0xFFFCFBFD, 0xFFFCFBFD, 0xFFFAF9FB, 0xFFFCFBFD, 0xFFFFFEFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFF8F8F8, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFFFFFE,
        0xFFF7F8F6, 0xDEDDDEDC, 0x92B8B9B7, 0x328A8B89, 0x005A5B59, 0x00313230, 0x00181917, 0x0011130D, 0x00090B05, 0x00040600, 0x00080A04, 0x000F110B, 0x0010120C, 0x000C0E08, 0x00080A04, 0x000A0C06, 0x000A0C06, 0x000B0D07, 0x000C0E08, 0x000C0E08,
        0x000C0E08, 0x000C0E08, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x000A0E09,
        0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x00090D08, 0x00090D08, 0x00090D08, 0x000A0E09, 0x000B0F0A,
        0x000B0F0A, 0x000A0E09, 0x00090D08, 0x00070B06, 0x000B0F0A, 0x00121611, 0x00050904, 0x000C100B, 0x000E120D, 0x00131712, 0x00000400, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000E0F0B,
        0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000E0F0B, 0x000E0F0B, 0x000B0E0C, 0x000A0D0B, 0x00121715, 0x002B322F, 0x00353E3B,
        0x002E3936, 0x0025332F, 0x00172521, 0x00BFC3BE, 0x00E6EFEC, 0x009DAEAB, 0x00819A96, 0x0091AEAB, 0x00B6D0D0, 0x00CFE2E5, 0x00D2E1E4, 0x00B9DBDB, 0x00B9D7D8, 0x0099AEAF, 0x00B2C0BF, 0x00E8F0EF, 0x00F9FFFE, 0x00F2F9F6, 0x00B7BEB9, 0x00D3D8D6,
        0x00F0F6F5, 0x00E0EBE9, 0x00D4E2E1, 0x00BDD1D2, 0x00AFC8CA, 0x00AECBCF, 0x00B4D3D6, 0x00C7E6E9, 0x00C5E4E7, 0x00BBDADD, 0x00A9C8CB, 0x009AB9BC, 0x009EBDC0, 0x00B3D2D5, 0x00C8E7EA, 0x00AACBCE, 0x009DBEC1, 0x0097B8BB, 0x00A4C5C8, 0x00BBDCDF,
        0x00C3E4E7, 0x00B7D8DB, 0x00A6C7CA, 0x009ABBBE, 0x00A1C2C5, 0x00AECFD2, 0x00BDDEE1, 0x00C6E7EA, 0x00C2E3E6, 0x00B5D6D9, 0x00A9CACD, 0x009CBFC3, 0x00A4C7CB, 0x00B5D5DA, 0x00C4E4E9, 0x00CFEDF2, 0x00CBE9EE, 0x00BFDDE2, 0x00B5D2D7, 0x00B4CDD1,
        0x00C1D7DC, 0x00D2E7E9, 0xEAE1F2F5, 0xFFEBF8FA, 0xFFF0F9FC, 0xFFF3FAFD, 0xFFF7FCFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFEFEFE, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFBFAFC, 0xFFFCFBFD, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFCFDFB,
        0xFFFEFFFD, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFF4F5F3, 0xC9D3D4D2, 0x8EB6B7B5, 0x117E807A, 0x005A5C56, 0x002D2F29, 0x0010120C, 0x00060802, 0x00070903, 0x000B0D07, 0x000E100A, 0x00090B05, 0x000A0C06, 0x000A0C06, 0x000B0D07, 0x000C0E08,
        0x000C0E08, 0x000B0D07, 0x000B0D07, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x000A0E09,
        0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000B0C08, 0x000B0C08, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000B0F0A, 0x000B0F0A, 0x000B0F0A, 0x000A0E09, 0x000B0F0A,
        0x000B0F0A, 0x000C100B, 0x000C100B, 0x00111510, 0x00010500, 0x00070B06, 0x000B0F0A, 0x000D110C, 0x00020601, 0x00080C07, 0x000C100B, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A,
        0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000E0F0B, 0x000E0F0B, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000E0F0B, 0x000E0F0B, 0x000B0E0C, 0x000B0E0C, 0x00131816, 0x002B322F, 0x00333C39,
        0x002C3734, 0x0025332F, 0x00192723, 0x00A8ACA7, 0x00D5DEDB, 0x007A8B88, 0x0094ADA9, 0x00C2DFDC, 0x00BCD6D6, 0x00CBDEE1, 0x00D2E1E4, 0x00C6E8E8, 0x00CAE8E9, 0x00ADC2C3, 0x00CAD8D7, 0x00F2FAF9, 0x00F6FCFB, 0x00F4FBF8, 0x00C9D0CB, 0x00DCDFDD,
        0x00EEF3F2, 0x00DDE5E4, 0x00DBE9E8, 0x00D1E5E6, 0x00C8E1E3, 0x00BFDCE0, 0x00B9D8DB, 0x00A8C7CA, 0x00A6C5C8, 0x00AAC9CC, 0x00B6D5D8, 0x00BFDEE1, 0x00B8D7DA, 0x00A0BFC2, 0x008BAAAD, 0x00ACCDD0, 0x00B8D9DC, 0x00BFE0E3, 0x00B3D4D7, 0x009FC0C3,
        0x009ABBBE, 0x00ABCCCF, 0x00BEDFE2, 0x00CCEDF0, 0x00BDDEE1, 0x00A9CACD, 0x009CBDC0, 0x009CBDC0, 0x00A8C9CC, 0x00B7D8DB, 0x00C0E1E4, 0x00CBEEF2, 0x00BFE2E6, 0x00B0D0D5, 0x00A5C5CA, 0x00A8C6CB, 0x00B3D1D6, 0x00C1DFE4, 0x00CCE9EE, 0x00DDF6FA,
        0x00D6ECF1, 0x00CFE4E6, 0xC9D1E2E5, 0xDEDCE9EB, 0xF7E7F0F3, 0xFFEDF4F7, 0xFFF0F5F6, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFDFDFD, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFCFBFD, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFEFFFD,
        0xFFFFFFFE, 0xFFFFFFFE, 0xFFFAFBF9, 0xFFFEFFFD, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFF9FAF8, 0xFFFFFFFB, 0xFFF0F2EC, 0xC9D6D8D2, 0x75ADAFA9, 0x04777973, 0x0042443E, 0x001D1F19, 0x000E100A, 0x00080A04, 0x00090B05, 0x000A0C06, 0x000B0D07, 0x000B0D07,
        0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x000C0E08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x00090D08, 0x000A0E09,
        0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000B0C08, 0x000B0C08, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000A0E09, 0x00080C07, 0x00070B06, 0x00080C07, 0x000B0F0A,
        0x000C100B, 0x000B0F0A, 0x00090D08, 0x000D110C, 0x00090D08, 0x000D110C, 0x00080C07, 0x000B0F0A, 0x00090D08, 0x000C100B, 0x000D110C, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A,
        0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000E0F0B, 0x000E0F0B, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000E0F0B, 0x000E0F0B, 0x000B0E0C, 0x000B0E0C, 0x00141917, 0x002B322F, 0x00323B38,
        0x002A3532, 0x0025332F, 0x001B2925, 0x00B3B7B2, 0x00DFE8E5, 0x0093A4A1, 0x0087A09C, 0x0096B3B0, 0x00B0CACA, 0x00D1E4E7, 0x00D0DFE2, 0x00B8DADA, 0x00B3D1D2, 0x0096ABAC, 0x00C3D1D0, 0x00F6FEFD, 0x00FAFFFF, 0x00F9FFFD, 0x00D1D8D3, 0x00E0E3E1,
        0x00F0F5F4, 0x00DCE4E3, 0x00D2E0DF, 0x00BED2D3, 0x00B2CBCD, 0x00AECBCF, 0x82B0CFD2, 0x00C0DFE2, 0x00BEDDE0, 0x00B5D4D7, 0x00A6C5C8, 0x009AB9BC, 0x009FBEC1, 0x00B4D3D6, 0x00C6E5E8, 0x00A2C3C6, 0x0098B9BC, 0x0096B7BA, 0x00A8C9CC, 0x00C0E1E4,
        0x00C6E7EA, 0x00B3D4D7, 0x009DBEC1, 0x0096B7BA, 0x00A7C8CB, 0x00BCDDE0, 0x00C8E9EC, 0x00C5E6E9, 0x00B7D8DB, 0x00A9CACD, 0x00A1C2C5, 0x009DC0C4, 0x00ADD0D4, 0x00C3E3E8, 0x00CDEDF2, 0x00CAE8ED, 0x00BEDCE1, 0x00B4D2D7, 0x00B0CDD2, 0x00B6CFD3,
        0x00C7DDE2, 0x00DAEFF1, 0x00E6F7FA, 0xFBEAF7F9, 0xFFECF5F8, 0xFFF2F9FC, 0xFFF8FDFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFDFDFD, 0xF7E7E7E7, 0x9BBCBCBC, 0x4F979797, 0x005E5F5B, 0x00343531, 0x00141511, 0x000C0D09, 0x00080905,
        0x00060703, 0x000A0B07, 0x000C0D09, 0x000D0F09, 0x000A0C06, 0x000B0D07, 0x000C0E08, 0x00090B05, 0x000C0E08, 0x000E100A, 0x000A0C06, 0x000E100A, 0x000B0D07, 0x000A0C06, 0x000D0F09, 0x000E100A, 0x000B0D07, 0x000B0D07, 0x000E100A, 0x00080C07,
        0x000A0E09, 0x000A0E09, 0x00080C07, 0x000A0E09, 0x000D110C, 0x000C100B, 0x00080C07, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09,
        0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000D0E0A,
        0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000D0E0A, 0x000D0E0A, 0x000C120D, 0x000B110C, 0x00101611, 0x00292F2A, 0x00343A35,
        0x002D332E, 0x002F3530, 0x00323833, 0x00AAB5B3, 0x00E4F0F0, 0x00ACBAB9, 0x0099A9A8, 0x00CBDFE0, 0x00D0E8E8, 0x00CDE6E8, 0x00CDE6E8, 0x00C6E3E0, 0x00D3EBE9, 0x00A1B6B4, 0x00CBD9D8, 0x00DFE7E7, 0x00F0F4F5, 0x00FFFCFE, 0x00E9E4E6, 0x00E7E7E7,
        0x00E9E9E9, 0x00EDEDED, 0x00FBFBFB, 0x00FFFFFF, 0xFFF7F7F7, 0xFFF0F0F0, 0xEEE3E3E3, 0xB4C7CFCF, 0xA3BFC9C9, 0x9BBCCAC9, 0x00C0D2D3, 0x00C0D5D6, 0x00B2CBCD, 0x00A0BCBD, 0x0093B1B2, 0x00ADD0D3, 0x00BCDDE0, 0x00BBDCDF, 0x00A6C6CB, 0x0096B4B9,
        0x009DBAC1, 0x00B4D0D7, 0x00C6E2E9, 0x00CFE9F0, 0x00BBD7DE, 0x00A6C2C9, 0x009CB9C0, 0x00A1C1C7, 0x00B2D2D8, 0x00BFE1E7, 0x00C7E9EF, 0x00C6E7EA, 0x00B6D7DA, 0x00A7C6C9, 0x00A1C0C3, 0x00AAC9CC, 0x00BCD9DD, 0x00CAE7EB, 0x00D0EDF1, 0x00D6EBED,
        0x00D4E7EA, 0x00D2E4E5, 0xD5D7E4E6, 0xE6E0E9EC, 0xFFECF1F2, 0xFFF4F8F9, 0xFFFAFCFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFF9F9F9, 0xFFFBFCF8, 0xCDD6D7D3, 0x69A7A8A4, 0x04777874, 0x00484945,
        0x00252622, 0x0011120E, 0x00050602, 0x00090B05, 0x00020400, 0x00040600, 0x000B0D07, 0x000B0D07, 0x000B0D07, 0x000C0E08, 0x000A0C06, 0x000C0E08, 0x000A0C06, 0x00090B05, 0x00080A04, 0x00090B05, 0x000B0D07, 0x000B0D07, 0x000C0E08, 0x000A0E09,
        0x000C100B, 0x000C100B, 0x00090D08, 0x00080C07, 0x000A0E09, 0x000B0F0A, 0x00090D08, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09,
        0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000D0E0A,
        0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000D0E0A, 0x000D0E0A, 0x000C120D, 0x000A100B, 0x00111712, 0x002A302B, 0x00373D38,
        0x00303631, 0x00313732, 0x00333934, 0x00C4CCCB, 0x00EBF3F2, 0x00C0CBC9, 0x006C7A79, 0x006B7B7A, 0x009FB3B4, 0x00BCD1D2, 0x00BACFD0, 0x00B0C6C4, 0x0094A9A7, 0x006E7E7D, 0x00BBC9C8, 0x00DFE9E9, 0x00D3D8D9, 0x00DDDFE0, 0x00E4E3E5, 0x00ECECEC,
        0x00F8F8F8, 0x00F9F9F9, 0x00FBFBFB, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFAFFFF, 0xFFF4F9FA, 0xDEDBE5E5, 0xABC3D0D2, 0x82B0C2C3, 0x00ADC0C3, 0x00B6CDCF, 0x00C2D9DB, 0x00A3C1C2, 0x009BB8BC, 0x009EBDC0, 0x00B3D2D5, 0x00C4E2E7,
        0x00BDDDE2, 0x00A8C8CE, 0x0097B7BD, 0x0099B9BE, 0x00AECED3, 0x00C5E5EA, 0x00CDEDF2, 0x00C3E3E8, 0x00B1D1D6, 0x00A3C3C8, 0x009CBCC1, 0x00A7C8CB, 0x00B7D8DB, 0x00C9E8EB, 0x00CCEBEE, 0x00C1E0E3, 0x00B5D2D6, 0x00AECBCF, 0x00AECBCF, 0x00C6DBDD,
        0x00D1E4E7, 0x00DFF1F2, 0xFBE9F6F8, 0xFFECF5F8, 0xFFEEF3F4, 0xFFF0F4F5, 0xFFF5F7F8, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFEFA, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFC, 0xFBEDEEEA,
        0xABC7C8C4, 0x3B90918D, 0x0061625E, 0x00353632, 0x001E1F1B, 0x000E0F0B, 0x000A0B07, 0x00060703, 0x00050602, 0x000A0B07, 0x000E0F0B, 0x00070804, 0x000A0B07, 0x000C0D09, 0x000E0F0B, 0x0011120E, 0x0011120E, 0x000C0D09, 0x00070804, 0x00050904,
        0x000A0E09, 0x000C100B, 0x000B0F0A, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x00090D08, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09,
        0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000D0E0A,
        0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000D0E0A, 0x000D0E0A, 0x000B110C, 0x000A100B, 0x00111712, 0x002D332E, 0x003A403B,
        0x00333934, 0x00343A35, 0x00353B36, 0x008C918F, 0x00C2C7C5, 0x00E8EEED, 0x00BEC6C5, 0x00768080, 0x005F6B6B, 0x007F8C8E, 0x00AAB9BB, 0x00BCC8C8, 0x00C7D3D3, 0x00B3BFBF, 0x00CBD5D5, 0x00DBE5E5, 0x00D9E1E1, 0x00DEE6E6, 0x00CBD3D3, 0x00DEDEDE,
        0x00FBFBFB, 0x00FFFFFF, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFAFA, 0xFFFDFFFF, 0xFFFBFFFF, 0xFFF7FFFF, 0xF7E7F0F3, 0xC4CFDCDE, 0x8AB4C3C6, 0x64A1B2B5, 0x00B9CED0, 0x00C2D9DB, 0x00BDD6D8, 0x00A4BFC3, 0x0093B2B5,
        0x009DBDC2, 0x00B3D6DA, 0x00C0E5E9, 0x00B7DDE1, 0x00AACFD3, 0x009BC0C4, 0x0099BCC0, 0x00A6C6CB, 0x00B8D8DD, 0x00C8E6EB, 0x00CFEDF2, 0x00BBDCDF, 0x00ADCED1, 0x00A2C1C4, 0x00A4C3C6, 0x00B3D2D5, 0x00C5E2E6, 0x00CEEBEF, 0x00CFECF0, 0x00CCE1E3,
        0x00C9DCDF, 0x00CADCDD, 0xD1D5E2E4, 0xEEE4EDF0, 0xFFF3F8F9, 0xFFF9FDFE, 0xFFFCFEFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFDFDFD, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFDFDFD, 0xFFFCFDFB, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFDFEFC, 0xFFFDFEFC,
        0xFFFFFFFE, 0xFFFFFFFE, 0xFFF9FAF8, 0xD5DBDCD8, 0x82B3B4B0, 0x1D838480, 0x00575854, 0x0032332F, 0x00191A16, 0x000B0C08, 0x00020300, 0x0010110D, 0x000B0C08, 0x00080905, 0x00090A06, 0x000C0D09, 0x000D0E0A, 0x000D0E0A, 0x000C0D09, 0x00070B06,
        0x000A0E09, 0x000D110C, 0x000C100B, 0x000A0E09, 0x000A0E09, 0x000C100B, 0x000E120D, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09,
        0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000D0E0A,
        0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000D0E0A, 0x000D0E0A, 0x000A100B, 0x00090F0A, 0x00121813, 0x002F3530, 0x003D433E,
        0x00373D38, 0x00373D38, 0x00373D38, 0x00191A16, 0x00393C3A, 0x00545755, 0x00898E8C, 0x00B6BBBA, 0x00C9CFCE, 0x00E7EFEF, 0x00F6FEFE, 0x00E7ECEB, 0x00F6FBFA, 0x00E9EFEE, 0x00DBE3E2, 0x00DEE6E5, 0x00D3DEDC, 0x00C6D3D1, 0x00A7B4B2, 0x00D5D5D5,
        0xFFF8F8F8, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFCFCFC, 0xFFFBFBFB, 0xFFFFFEFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFCFEFF, 0xFFFBFFFF, 0xFFFAFFFF, 0xFFF2F9FC, 0xF2E5ECEF, 0x9BBBC8CA, 0x75A9B8BA, 0x00AABCBD, 0x00C1D8DA, 0x00CAE6E7,
        0x00B6D5D8, 0x009EC1C4, 0x0096BCBE, 0x009EC7CA, 0x00B1D7DB, 0x00C3E8EC, 0x00C4E7EB, 0x00B6D6DB, 0x00A6C4C9, 0x009FBCC1, 0x009FBCC1, 0x00B0D1D4, 0x00C2E3E6, 0x00D1F0F3, 0x00C8E7EA, 0x00B1D0D3, 0x00A4C1C5, 0x00AAC7CB, 0x00B5D2D6, 0x00CEE3E5,
        0x00DBEEF1, 0x00E8FAFB, 0xFFEBF8FA, 0xF2E6EFF2, 0xF2E6EBEC, 0xFFEDF1F2, 0xFFF8FAFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFCFCFC, 0xFFFEFFFD, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFEFFFD,
        0xFFFDFEFC, 0xFFFBFCFA, 0xFFFAFBF9, 0xFFFFFFFC, 0xFFFEFFFB, 0xFFFCFDF9, 0xFFEFF0EC, 0xC0D1D2CE, 0x6DA8A9A5, 0x04777874, 0x004D4E4A, 0x00232420, 0x00141511, 0x00080905, 0x00080905, 0x00090A06, 0x00070804, 0x00090A06, 0x000D0E0A, 0x000A0E09,
        0x00090D08, 0x00090D08, 0x00080C07, 0x00070B06, 0x00070B06, 0x00090D08, 0x000C100B, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09,
        0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09,
        0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000D0E0A, 0x000D0E0A, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000D0E0A, 0x000D0E0A, 0x00090F0A, 0x00080E09, 0x00111712, 0x002F3530, 0x003F4540,
        0x00393F3A, 0x00393F3A, 0x00383E39, 0x001D1F19, 0x002D2E2A, 0x0020211D, 0x001E221D, 0x00353836, 0x00545755, 0x00878989, 0x00ADAFAF, 0x00DDDDDD, 0x00E3E3E3, 0x00E2E4E4, 0x00D8DDDC, 0x00DAE2E1, 0x00D7E2E0, 0x00D4E1DF, 0x00D3E0DE, 0xFBEAEAEA,
        0xFFFFFFFF, 0xFFFEFEFE, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFCFCFC, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFEFD, 0xFFFFFEFF, 0xFFFFFDFE, 0xFFFBF9F9, 0xFFF9F8FA, 0xFFFBFDFE, 0xFFFDFEFF, 0xFFFBFCFF, 0xFFF6FBFC, 0xF7E8F0F0, 0xB8C9D5D5, 0x75AAB9BB, 0x64A2B6B7,
        0x00B2C9CB, 0x00BEDADB, 0x00C0DEDF, 0x00B1D4D7, 0x00A1C4C7, 0x0097B8BB, 0x00A0C1C4, 0x00B8D7DA, 0x00CAE7EB, 0x00C9E6EA, 0x00C4DFE3, 0x00B0D1D4, 0x00A3C4C7, 0x009DBCBF, 0x00A8C7CA, 0x00C0DFE2, 0x00D1EEF2, 0x00CFECF0, 0x00C6E3E7, 0x00C3D8DA,
        0x00C4D7DA, 0x00CBDDDE, 0xDEDBE8EA, 0xFFECF5F8, 0xFFF8FDFE, 0xFFF9FDFE, 0xFFF8FAFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCFCFC, 0xFFFBFBFB, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFDFDFD, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFEFFFD, 0xFFFDFEFC, 0xFFFFFFFE, 0xFFFAFBF9, 0xF7E9EAE8, 0xA7C3C4C2, 0x589C9D9B, 0x00676866, 0x003D3E3C, 0x001F201E, 0x000F100E, 0x000A0B09, 0x000D0E0C, 0x000A0E09,
        0x00080C07, 0x00090D08, 0x000D110C, 0x000F130E, 0x000C100B, 0x00090D08, 0x00080C07, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09,
        0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09,
        0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000D0E0A, 0x000D0E0A, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000D0E0A, 0x000D0E0A, 0x00090F0A, 0x00080E09, 0x00101611, 0x002F3530, 0x003F4540,
        0x003A403B, 0x003A403B, 0x00393F3A, 0x00363A34, 0x001F231D, 0x002A2E28, 0x002F332E, 0x0041423E, 0x00484945, 0x002D2E2C, 0x00323331, 0x0060615F, 0x00858684, 0x00B1B4B2, 0x00C3C8C6, 0x00D9E0DD, 0x00F5FCF9, 0x00E8F1EE, 0x00E6EFEC, 0xFFFDFDFD,
        0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFEFAF9, 0xFFFFFFFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFDFF, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFFFFFF, 0xFFFBFDFD, 0xFFF8FCFD, 0xFFF7FCFD, 0xEAE1EBEB,
        0x9FBECACC, 0x79ABB8BA, 0x75AAB9BB, 0x00B9CFD4, 0x00C6DFE3, 0x00D0E9ED, 0x00C7E0E4, 0x00B0CBCF, 0x00A3BEC2, 0x00A5C2C6, 0x00AFCCD0, 0x00BCDDE0, 0x00C3E4E7, 0x00C6E5E8, 0x00BAD9DC, 0x00AAC9CC, 0x00A6C3C7, 0x00B0CDD1, 0x00BDDADE, 0x00D6EBED,
        0x00DDF0F3, 0x00E4F6F7, 0xEEE4F1F3, 0xE6E0E9EC, 0xF2E5EAEB, 0xFFF0F4F5, 0xFFFCFEFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFDFDFD, 0xFFFBFBFB, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFCFCFC, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFEFFFD, 0xFFFCFDFB, 0xFFFEFFFD, 0xFFFEFFFD, 0xFFFDFEFC, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFF9FAF8, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFF5F6F4, 0xE2DFE0DE, 0x9BBDBEBC, 0x3B8E8F8D, 0x00575856, 0x0030312F, 0x00191D18,
        0x000E120D, 0x00040803, 0x00030702, 0x00070B06, 0x000A0E09, 0x000A0E09, 0x000B0F0A, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09,
        0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09,
        0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000D0E0A, 0x000D0E0A, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000D0E0A, 0x000D0E0A, 0x00090F0A, 0x00070D08, 0x000F1510, 0x002D332E, 0x003F4540,
        0x003A403B, 0x00393F3A, 0x00393F3A, 0x001D261C, 0x00262E24, 0x00444C42, 0x00353C35, 0x00343832, 0x0040443F, 0x002A2B27, 0x0031322E, 0x004B504E, 0x003F4442, 0x00383D3B, 0x00444745, 0x007C7F7D, 0x00DDE0DE, 0x00F1F4F2, 0xFFFDFFFE, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFFFFFE, 0xFFFFFDFC, 0xFFFEFCFB, 0xFFFFFEFE, 0xFFFFFFFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFAF8F7, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFDFD, 0xFFFDFCFE,
        0xFFFFFEFF, 0xFFF9F8FC, 0xFBE9EAEE, 0x9FBEC9CD, 0x82AFBBBF, 0x6DA5B4B7, 0x00AFC2C5, 0x00C4DBDD, 0x00CDE9EA, 0x00C2E0E1, 0x00B3D2D3, 0x009FC0C3, 0x00A1C2C5, 0x00AAC9CC, 0x00B9D8DB, 0x00C7E6E9, 0x00CDEAEE, 0x00C6E3E7, 0x00BEDBDF, 0x00C1D6D8,
        0x00C5D8DB, 0x00D0E2E3, 0xEAE1EEF0, 0xFFF0F9FC, 0xFFFAFFFF, 0xFFF8FCFD, 0xFFF6F8F9, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFCFCFC, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFAFAFA, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFEFEFE, 0xFFFDFDFD, 0xFFFFFFFE, 0xFFFDFEFC, 0xFFFEFFFD, 0xFFFFFFFE, 0xFFFDFEFC, 0xFFFEFFFD, 0xFFFFFFFE, 0xFFFEFFFD, 0xFFFAFBF9, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFCFDFB, 0xFFFEFFFD, 0xFFFFFFFE, 0xFFEFF0EE, 0xD5D8D9D7, 0x64A2A6A1,
        0x157D817C, 0x004D514C, 0x00282C27, 0x00131712, 0x00090D08, 0x00060A05, 0x00070B06, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09,
        0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09,
        0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000D0E0A, 0x000D0E0A, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000D0E0A, 0x000D0E0A, 0x000A100B, 0x00070D08, 0x000E140F, 0x002C322D, 0x003E443F,
        0x00393F3A, 0x00393F3A, 0x00383E39, 0x00313D31, 0x003E473D, 0x00394238, 0x00343C32, 0x003E453E, 0x003B3F39, 0x002C302B, 0x00363733, 0x004A514E, 0x00505754, 0x00424745, 0x00363937, 0x006F7270, 0x00F9FAF8, 0xFFFFFFFE, 0xFFFFFDFC, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFC, 0xFFFEFFFD, 0xFFFDFEFC, 0xFFFFFFFE, 0xFFFFFFFF, 0xFFFCFCFC, 0xFFFDFCFE, 0xFFFFFEFF, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFDFE, 0xFFFFFDFE, 0xFFFFFEFF,
        0xFFFFFDFF, 0xFFFFFCFF, 0xFFFFF8FB, 0xFFFCFCFF, 0xFFF4F8FD, 0xEAE1EAEE, 0xABC4D3D6, 0x75A9BEC0, 0x609FB8BA, 0x6DA6C5C6, 0x00B2D4D4, 0x00C9EAED, 0x00C5E6E9, 0x00BCDBDE, 0x00ACCBCE, 0x00A0BFC2, 0x00A5C2C6, 0x00B7D4D8, 0x00C7E4E8, 0x00DAEFF1,
        0x00D9ECEF, 0x00D9EBEC, 0xDEDCE9EB, 0xE6E0E9EC, 0xFBEAEFF0, 0xFFF3F7F8, 0xFFFBFDFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFEFEFE, 0xFFEEEEEE, 0xB8CACACA, 0x5C9D9D9D, 0x006F6F6F, 0x00404040, 0x00202020, 0x000F100C, 0x00080905, 0x00070804, 0x000B0C08, 0x000B0C08, 0x00070804, 0x000B0C08, 0x00131410, 0x00070804, 0x000D0E0A, 0x000E0F0B, 0x000A0B07, 0x00080905,
        0x000A0B07, 0x000C0D09, 0x000A0B07, 0x000B0F0A, 0x00070B06, 0x00060A05, 0x00090D08, 0x000A0E09, 0x00080C07, 0x00090D08, 0x000C100B, 0x000D0E0A, 0x000C0D09, 0x000A0B07, 0x000B0C08, 0x000C0D09, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A,
        0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000D0E0A, 0x000D0E0A, 0x000D110C, 0x000A0E09, 0x0010140F, 0x002E322D, 0x003F433E,
        0x003A3E39, 0x003A3E39, 0x003B3F3A, 0x003B413C, 0x00373D38, 0x00363C37, 0x00393F3A, 0x00383E39, 0x00353B36, 0x00212722, 0x00373D38, 0x00464B49, 0x004C514F, 0x00434846, 0x003C3F3D, 0x00A3A6A4, 0xFFFCFDFB, 0xFFFDFEFC, 0xFFFFFFFE, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFEFEFEF, 0xD9DADADA, 0xB8CACACA, 0x79ABB7B9, 0x86B1BDBF, 0x00BDCACC, 0x00C8DADB, 0x00D1E5E6, 0x00CDE5E5, 0x00C1DBDB, 0x00B5D1D1, 0x00BED2D3,
        0x00C7DBDC, 0x00D7E9EA, 0xF7E8F5F7, 0xFFF2FBFE, 0xFFF6FDFF, 0xFFF5FAFD, 0xFFF3F6FA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCFCFC, 0xFFFDFDFD, 0xFFF7F7F7, 0xE6E0E0E0, 0xB8C9C9C9, 0x368F908C, 0x00646561, 0x0032332F, 0x00161713, 0x000F100C, 0x000D0E0A, 0x00090A06, 0x00070804, 0x000D0E0A, 0x000C0D09, 0x000C0D09, 0x000D0E0A, 0x000E0F0B,
        0x000C0D09, 0x000B0C08, 0x000B0C08, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x00080C07, 0x00080C07, 0x00090D08, 0x00080C07, 0x00070B06, 0x000C0D09, 0x000D0E0A, 0x000E0F0B, 0x000E0F0B, 0x000E0F0B, 0x000D0E0A, 0x000B0C08, 0x000A0B07, 0x000D0E0A,
        0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000D0E0A, 0x000D0E0A, 0x000D110C, 0x000A0E09, 0x0010140F, 0x002D312C, 0x003E423D,
        0x003A3E39, 0x003A3E39, 0x003B3F3A, 0x00373D38, 0x00333934, 0x003C423D, 0x003C423D, 0x00303631, 0x00393F3A, 0x002C322D, 0x002F3530, 0x004C514F, 0x004A4F4D, 0x002D3230, 0x005B5E5C, 0xD9D9DCDA, 0xFFFFFFFE, 0xFFF9FAF8, 0xFFFFFFFE, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFAFAFA, 0xFFF3FAFD, 0xE6DFE8EB, 0xB0C6D2D4, 0x8EB5C2C4, 0x8AB3C2C4, 0x00BACECF, 0x00C7DCDD, 0x00D1E6E7, 0x00DEF0F1,
        0x00DBEDEE, 0xD9D9E8EA, 0xDEDBE7E9, 0xE6E0E9EC, 0xFBEAF1F4, 0xFFF4F9FC, 0xFFFBFEFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCFCFC,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFF7F7F7, 0xFFFFFFFC, 0xFFF4F5F1, 0xD5DBDCD8, 0x86B4B5B1, 0x1D82837F, 0x0050514D, 0x00292A26, 0x00151612, 0x00090A06, 0x00070804, 0x000A0B07, 0x000F100C, 0x000E0F0B,
        0x00080905, 0x00070804, 0x000B0C08, 0x00070B06, 0x000C100B, 0x000D110C, 0x00090D08, 0x000A0E09, 0x000E120D, 0x000E120D, 0x000A0E09, 0x00090A06, 0x000A0B07, 0x000D0E0A, 0x000E0F0B, 0x000F100C, 0x000E0F0B, 0x000E0F0B, 0x000D0E0A, 0x000D0E0A,
        0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000D0E0A, 0x000D0E0A, 0x000C100B, 0x000A0E09, 0x0010140F, 0x002C302B, 0x003D413C,
        0x00393D38, 0x003A3E39, 0x003A3E39, 0x003B413C, 0x00353B36, 0x00313732, 0x00333934, 0x00373D38, 0x003B413C, 0x00252B26, 0x00303631, 0x00484D4B, 0x00303533, 0x004D5250, 0x86B2B5B3, 0xFFFDFFFE, 0xFFFFFFFE, 0xFFFEFFFD, 0xFFFEFFFD, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFCFCFC, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFBFEFF, 0xFFFBFEFF, 0xFFFAFFFF, 0xFFF4FBFE, 0xFBE9F2F5, 0xD5D8E4E6, 0xB0C6D3D5, 0x9BBBC8CA, 0xABC3D2D4,
        0x00CEDBDD, 0xE2DDE9EB, 0xFFECF5F8, 0xFFF5FCFF, 0xFFF7FCFF, 0xFFF3F6FA, 0xFFEFF2F6, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFF9F9F9,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFF9F9F9, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFE, 0xFFFAFBF9, 0xFFF7F8F6, 0xFFFCFDFB, 0xFFFFFFFE, 0xFFF2F3F1, 0xB8CBCCCA, 0x6DA7A8A6, 0x00727371, 0x00494A48, 0x001A1B19, 0x00060705, 0x00090A08,
        0x000F100E, 0x000D0E0C, 0x00080907, 0x00060A05, 0x00090D08, 0x00090D08, 0x00080C07, 0x00080C07, 0x000B0F0A, 0x000C100B, 0x000A0E09, 0x000A0B07, 0x000A0B07, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000C0D09, 0x000D0E0A, 0x000F100C, 0x000D0E0A,
        0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000D0E0A, 0x000D0E0A, 0x000C100B, 0x000A0E09, 0x0010140F, 0x002A2E29, 0x003B3F3A,
        0x00383C37, 0x00393D38, 0x00383C37, 0x00353B36, 0x00373D38, 0x00383E39, 0x00353B36, 0x00303631, 0x00343A35, 0x00262C27, 0x00383E39, 0x00353A38, 0x00474C4A, 0x86B1B6B4, 0xFFF9FCFA, 0xFFFAFDFB, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFDFEFC, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFDFDFD, 0xFFFDFCFE, 0xFFFEFDFF, 0xFFFFFEFF, 0xFFFDFFFF, 0xFFFBFFFF, 0xFFFAFEFF, 0xFFF8FDFE, 0xFFF7FCFD, 0xEEE3EDED,
        0xEAE1EBEB, 0xEAE2EAEA, 0xEAE2EAEA, 0xFBE9EEEF, 0xFFF1F5F6, 0xFFF8FCFD, 0xFFFBFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCFCFC, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFCFA, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFDFEFC, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFF8F9F7, 0xF2E7E8E6, 0xA7C2C3C1, 0x3B8E8F8D, 0x005A5B59,
        0x00323331, 0x00151614, 0x00060705, 0x00070B06, 0x00040803, 0x00050904, 0x000A0E09, 0x000B0F0A, 0x00090D08, 0x00070B06, 0x00070B06, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000B0C08, 0x000B0C08, 0x000A0B07, 0x00090A06, 0x00090A06, 0x000D0E0A,
        0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000D0E0A, 0x000D0E0A, 0x000B0F0A, 0x000B0F0A, 0x0010140F, 0x00292D28, 0x00393D38,
        0x00383C37, 0x00393D38, 0x00373B36, 0x00393F3A, 0x00333934, 0x003A403B, 0x00373D38, 0x002C322D, 0x00383E39, 0x002C322D, 0x00292F2A, 0x00525755, 0x7DADB2B0, 0xFFFBFFFE, 0xFFFDFFFE, 0xFFF8FBF9, 0xFFFFFFFE, 0xFFFDFEFC, 0xFFFEFFFD, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFDFF, 0xFFFEFDFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFAFFFF,
        0xFFFBFFFF, 0xFFFAFEFF, 0xFFF6FAFB, 0xFFF5F9FA, 0xFFF4F8F9, 0xFFF7F9FA, 0xFFF8FAFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFEFEFE, 0xFFFDFDFD, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCFCFC, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFF0F0F0,
        0xC9D2D2D2, 0x64A2A2A2, 0x11797979, 0x003E423D, 0x002A2E29, 0x00141813, 0x00080C07, 0x00040803, 0x00030702, 0x00090D08, 0x0010140F, 0x00090A06, 0x00090A06, 0x000A0B07, 0x000C0D09, 0x000E0F0B, 0x000E0F0B, 0x000C0D09, 0x000A0B07, 0x000D0E0A,
        0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000D0E0A, 0x000D0E0A, 0x000B0F0A, 0x000B0F0A, 0x000F130E, 0x00272B26, 0x00373B36,
        0x00373B36, 0x00393D38, 0x00363A35, 0x00383E39, 0x00383E39, 0x002F3530, 0x00323833, 0x003A403B, 0x002E342F, 0x00191F1A, 0x00474D48, 0x8EB5BAB8, 0xFFFBFFFE, 0xFFFBFFFE, 0xFFFBFEFC, 0xFFFDFFFE, 0xFFFDFEFC, 0xFFFDFEFC, 0xFFFFFFFE, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFDFDFD, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFBFBFB, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFFFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFE, 0xFFFFFDFD, 0xFFFEFCFC, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFFFF, 0xFFFDFFFF, 0xFFFDFFFF, 0xFFFCFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFDFDFD, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFBFBFB, 0xFFF7F7F7, 0xDEDCE0DB, 0x96BBBFBA, 0x2E898D88, 0x005B5F5A, 0x00373B36, 0x001D211C, 0x000C100B, 0x00020601, 0x0011120E, 0x000D0E0A, 0x000A0B07, 0x000A0B07, 0x000E0F0B, 0x0010110D, 0x000F100C, 0x000D0E0A, 0x000D0E0A,
        0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000D0E0A, 0x000D0E0A, 0x000B0F0A, 0x000B0F0A, 0x000F130E, 0x00262A25, 0x00363A35,
        0x00363A35, 0x00383C37, 0x00353934, 0x002B312C, 0x003C423D, 0x00363C37, 0x00333934, 0x00363C37, 0x002D332E, 0x00454B46, 0x8AB3B9B4, 0xFFFBFFFE, 0xFFFBFFFE, 0xFFF0F5F3, 0xFFFDFFFE, 0xFFFDFFFE, 0xFFF7F8F6, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF,
        0xFFFFFDFE, 0xFFFFFDFD, 0xFFFFFDFD, 0xFFFDFDFD, 0xFFFEFEFE, 0xFFFDFFFF, 0xFFFDFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFEFEFE, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFFFC, 0xFFFDFFFC, 0xFFFCFFFB, 0xFFEDF1EC, 0xC9D2D6D1, 0x71A9ADA8, 0x04747873, 0x004C504B, 0x00242521, 0x001A1B17, 0x000E0F0B, 0x00070804, 0x00080905, 0x000B0C08, 0x000B0C08, 0x000B0C08, 0x000D0E0A,
        0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000D0E0A, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000C0D09, 0x000D0E0A, 0x000D0E0A, 0x000B0F0A, 0x000B0F0A, 0x000F130E, 0x00252924, 0x00353934,
        0x00363A35, 0x00383C37, 0x00343833, 0x00353B36, 0x002F3530, 0x00363C37, 0x002F3530, 0x00252B26, 0x00616762, 0x8AB4BAB5, 0xFFFBFFFC, 0xFFF6FBF9, 0xFFF9FEFC, 0xFFFBFFFE, 0xFFFDFFFE, 0xFFF7FAF8, 0xFFFFFFFE, 0xFFFEFFFD, 0xFFFEFFFD, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFFFF, 0xFFFDFFFF, 0xFFFDFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFF, 0xFFFFFCFD, 0xFFFFFEFF,
        0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFF7F7F7, 0xFFF0F0F0, 0x9FC1C2BE, 0x4B999A96, 0x00656662, 0x003B3C38, 0x0021221E, 0x0011120E, 0x000B0C08, 0x000C0D09, 0x000C0D09,
        0x00070804, 0x00090A06, 0x0011120E, 0x0011120E, 0x000A0B07, 0x000A0B07, 0x000F100C, 0x00090B05, 0x000D0F09, 0x000F110B, 0x000B0D07, 0x000B0D07, 0x000E100A, 0x000E100A, 0x000B0D07, 0x00080C07, 0x000A0E09, 0x000F130E, 0x00222621, 0x00353934,
        0x00333732, 0x0030342F, 0x00383C37, 0x00343533, 0x003B3C3A, 0x002D2E2C, 0x002D2E2C, 0x04747573, 0xDEDCDDDB, 0xFFFFFFFE, 0xFFFBFCFA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFCFCFC, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFF9F9F9, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFF2F3EF, 0xD9DCDDD9, 0x8EB9BAB6, 0x2E8A8B87, 0x00565753, 0x00343531, 0x001A1B17,
        0x000D0E0A, 0x00040501, 0x00080905, 0x000F100C, 0x0010110D, 0x000E0F0B, 0x000C0D09, 0x0011130D, 0x000D0F09, 0x00070903, 0x00060802, 0x000B0D07, 0x000F110B, 0x000E100A, 0x000A0C06, 0x000E120D, 0x00010500, 0x000D110C, 0x00272B26, 0x00313530,
        0x00343833, 0x00373B36, 0x00353934, 0x00313230, 0x00292A28, 0x0040413F, 0x4B969795, 0xFFF1F2F0, 0xFFFFFFFE, 0xFFFAFBF9, 0xFFFFFFFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFDFDFD, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFBF7, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFFFFFFC, 0xFFF8F9F5, 0xEEE6E7E3, 0xC9D5D6D2, 0x589FA09C,
        0x157F807C, 0x004F504C, 0x00262723, 0x000F100C, 0x00080905, 0x000A0B07, 0x000C0D09, 0x00070804, 0x000C0D09, 0x0011120E, 0x0012130F, 0x000D0E0A, 0x000A0B07, 0x000E0F0B, 0x00141511, 0x000D110C, 0x000B0F0A, 0x00191D18, 0x00282C27, 0x002E322D,
        0x00323631, 0x00353934, 0x002F332E, 0x00272826, 0x00595A58, 0x8AB5B6B4, 0xFFFBFCFA, 0xFFFFFFFE, 0xFFFDFEFC, 0xFFFDFEFC, 0xFFFDFEFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFFFD, 0xFFFFFFFE, 0xFFFDFEFC, 0xFFFBFCFA, 0xFFFDFEFC, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFEFFFD,
        0xFFF6F7F5, 0xE6E1E2E0, 0xA3C0C1BF, 0x4F989997, 0x006C6D6B, 0x003E3F3D, 0x001F201E, 0x0011120E, 0x00090A06, 0x00050602, 0x000A0B07, 0x000F100C, 0x000E0F0B, 0x000B0C08, 0x000A0B07, 0x00111510, 0x000B0F0A, 0x00070B06, 0x001B1F1A, 0x00363A35,
        0x00323631, 0x00252924, 0x002C302B, 0x04747474, 0xD1D5D5D5, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFAFAFA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFDFDFD, 0xFFFEFEFE, 0xFFFFFFFE, 0xFFFEFFFD, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFEFFFD, 0xFFFFFFFE, 0xFFFFFFFE,
        0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFF3F4F2, 0xD1D6D7D5, 0x96BBBCBA, 0x21858682, 0x0061625E, 0x00353632, 0x00181915, 0x000C0D09, 0x00090A06, 0x000A0B07, 0x000C0D09, 0x00090D08, 0x000C100B, 0x00151914, 0x00272B26, 0x002B2F2A,
        0x0020241F, 0x00464A45, 0x3F90948F, 0xFFF5F5F5, 0xFFF6F6F6, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFF8F8F8, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFCFCFC, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFCFCFC, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCFCFC, 0xFFFFFFFE, 0xFFEDEEEC, 0xC0CFD0CE, 0x75ABACAA, 0x21828381, 0x00545553, 0x002B2C2A, 0x00141513, 0x00080C07, 0x00070B06, 0x000C100B, 0x00141813, 0x00242823,
        0x00555954, 0x82B0B4AF, 0xFFFDFFFC, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFF9F8FA, 0xFFFAF9FB, 0xFFFFFEFF, 0xFFFBFAFC, 0xFFF1F0F2, 0xFFFFFEFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFCFCFC, 0xFFF7F7F7,
        0xFFFCFCFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFCFCFC, 0xFFFDFDFD, 0xFFFEFEFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFCFDFB, 0xF2E7E8E6, 0xA7C2C3C1, 0x69A4A5A3, 0x006A6E69, 0x00454944, 0x001E221D, 0x002B2F2A, 0x0D787C77,
        0xC4D0D4CF, 0xFFFDFFFC, 0xFFFDFFFC, 0xFFFAF9FB, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFDFCFE, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFAF9FB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFCFA, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFEFFFD, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFFFFFE, 0xFFFBFCFA, 0xFFFAFEF9, 0xEAE2E6E1, 0x96BBBFBA, 0x9FBFC3BE, 0xFFEFF3EE,
        0xFFFDFFFC, 0xFFFBFFFA, 0xFFFCFFFB, 0xFFFDFCFE, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFF9F8FA, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFDFCFE, 0xFFFFFEFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF
};

static GUI_CONST_STORAGE GUI_BITMAP _bmJLink_300x132 = {
  300,                                // XSize
  132,                                // YSize
  1200,                               // BytesPerLine
  32,                                 // BitsPerPixel
  (unsigned char *)_acJLink_300x132,  // Pointer to picture data
  NULL,                               // Pointer to palette
  GUI_DRAW_BMP8888
};

static GUI_CONST_STORAGE unsigned long _acJTrace_300x164[] = {
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00838571, 0x00A5A793, 0x00A6A894, 0x009FA18D, 0x009C9E8A, 0x00959783, 0x009C9E8A, 0x009A9C88, 0x00898D70, 0x008A8E71, 0x008C9073, 0x008F9376, 0x00929679,
        0x00929679, 0x00909477, 0x008D9174, 0x0083886B, 0x00858A6D, 0x00868B6E, 0x0084896C, 0x00818669, 0x00808568, 0x0082876A, 0x00858A6D, 0x00858A6B, 0x00838869, 0x00868B6C, 0x00828768, 0x007F8465, 0x007F8465, 0x00797E5F, 0x007B8061, 0x006F7457,
        0x00707558, 0x006D7255, 0x006C7154, 0x0072775A, 0x00767B5E, 0x00757A5D, 0x0074795C, 0x00737863, 0x00747964, 0x00696E59, 0x006A6C58, 0x00686A56, 0x00666854, 0x00696A56, 0x005B5C48, 0x005E5E52, 0x005F5F53, 0x00626256, 0x00646458, 0x00626256,
        0x005F5F53, 0x00616155, 0x00656559, 0x006B6C5C, 0x006A6B5B, 0x00646555, 0x005C5C4E, 0x005F5F51, 0x00646456, 0x005C5C50, 0x00515145, 0x0070755A, 0x006D7257, 0x00676C51, 0x006E7358, 0x0070755A, 0x00666B50, 0x0061664B, 0x005C6146, 0x00585D42,
        0x00585D42, 0x00575C41, 0x00555A3F, 0x0054593E, 0x00565B40, 0x00575C41, 0x00565B40, 0x004B5035, 0x0050553A, 0x00555A3F, 0x0053583D, 0x004C5136, 0x00474C31, 0x00484D32, 0x004A4F34, 0x00494A3A, 0x00474838, 0x00474838, 0x004B4C3C, 0x004E4F3F,
        0x004E4F3F, 0x004D4E3E, 0x004C4D3D, 0x004E5338, 0x0052573C, 0x0053583D, 0x00555A3F, 0x00585D42, 0x0054593E, 0x004F5439, 0x0050553A, 0x004F513D, 0x004F513D, 0x004F513D, 0x004D4F3B, 0x00494B37, 0x00454733, 0x00424430, 0x0041432F, 0x00464835,
        0x00444633, 0x00424431, 0x00414330, 0x00424431, 0x00434532, 0x00444633, 0x00444633, 0x0040422E, 0x003E402C, 0x003D3F2B, 0x003E402C, 0x003E402C, 0x003B3D29, 0x00393B27, 0x003A3C28, 0x003F412E, 0x003A3C29, 0x00363825, 0x00373926, 0x00383A27,
        0x00373926, 0x00353724, 0x00343623, 0x003D3F2B, 0x003A3C28, 0x00353723, 0x00333521, 0x00323420, 0x0031331F, 0x002F311D, 0x002D2F1B, 0x00292A21, 0x00292A21, 0x00292A21, 0x002A2B22, 0x002A2B22, 0x002A2B22, 0x002A2B22, 0x002B2C23, 0x0032332A,
        0x00292A21, 0x0024251C, 0x0027281F, 0x00292A21, 0x0026271E, 0x0023241B, 0x0023241B, 0x0028291F, 0x0027281E, 0x0026271D, 0x0025261C, 0x0026271D, 0x0025261C, 0x0024251B, 0x00222319, 0x001F2017, 0x001E1F16, 0x001D1E15, 0x001E1F16, 0x00202118,
        0x00212219, 0x0022231A, 0x0022231A, 0x002A2B22, 0x00282920, 0x0026271E, 0x0023241B, 0x0022231A, 0x0022231A, 0x0023241B, 0x0023241B, 0x0022231A, 0x0022231A, 0x0022231A, 0x0022231A, 0x0022231A, 0x0023241B, 0x0023241B, 0x0023241B, 0x0022231A,
        0x0023241B, 0x0024251C, 0x0025261D, 0x0026271E, 0x0027281F, 0x0027281F, 0x0027281F, 0x00282A24, 0x00272923, 0x00242620, 0x0022241E, 0x0022241E, 0x0022241E, 0x0023251F, 0x00242620, 0x002A2B22, 0x00292A21, 0x00292A21, 0x00282920, 0x00282920,
        0x00292A21, 0x00292A21, 0x002A2B22, 0x002E2F25, 0x002F3026, 0x00303127, 0x00323329, 0x0034352B, 0x0036372D, 0x0037382E, 0x0038392F, 0x00414036, 0x003A392F, 0x00414135, 0x004C4C40, 0x00474739, 0x003D3D2F, 0x003B3B2D, 0x003E3F2F, 0x003A382D,
        0x003A382D, 0x0039372C, 0x003A382D, 0x003B392E, 0x003C3A2F, 0x003C3A2F, 0x003B392E, 0x00434333, 0x003D3C2E, 0x003F3E30, 0x00403F31, 0x00454338, 0x003E3C31, 0x002F2D23, 0x003E3C32, 0x002B2E1F, 0x002A2D1E, 0x00292C1D, 0x002A2D1E, 0x002B2E1F,
        0x002C2F20, 0x002C2F20, 0x002C2F20, 0x00272A1B, 0x00282B1C, 0x00292C1D, 0x002B2E1F, 0x002D3021, 0x002D3021, 0x002C2F20, 0x002B2E1F, 0x002F3027, 0x002E2F26, 0x002C2D24, 0x002B2C23, 0x002B2C23, 0x002D2E25, 0x002F3027, 0x00313229, 0x0038362E,
        0x003A3830, 0x0039372F, 0x0034322A, 0x00323028, 0x0035332B, 0x0038362E, 0x0039372F, 0x003C3D33, 0x003E3F35, 0x003E3F35, 0x003A3B31, 0x003A3B31, 0x00404137, 0x00424339, 0x00424339, 0x00595D51, 0x00A2A69B, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFDFEFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x007B7D77, 0x006E705C, 0x00727460, 0x00525440, 0x00323420, 0x00333521, 0x003A3C28, 0x003B3D29, 0x00383A26, 0x00454234, 0x00444133, 0x00434032, 0x00444133, 0x00454234,
        0x00444133, 0x00403D2F, 0x003C392B, 0x00434335, 0x00454537, 0x00464638, 0x00444436, 0x00404032, 0x003E3E30, 0x00404032, 0x00434335, 0x00484838, 0x00434333, 0x00484838, 0x004A4A3A, 0x00515141, 0x00575747, 0x00515141, 0x004F4F3F, 0x004B4B3D,
        0x004A4A3C, 0x0049493B, 0x004B4B3D, 0x00515143, 0x00565648, 0x00575749, 0x00565648, 0x005B5C52, 0x00595A50, 0x0053544A, 0x0075746A, 0x0085847A, 0x00747369, 0x00727066, 0x0069675D, 0x006F6F61, 0x00717163, 0x00767668, 0x007A7A6C, 0x007A7A6C,
        0x0078786A, 0x007C7C6E, 0x00818173, 0x00858773, 0x007F816D, 0x007A7C68, 0x00757764, 0x007B7D6A, 0x00787969, 0x00606151, 0x00505141, 0x00605F55, 0x005E5D53, 0x00515046, 0x00504F45, 0x00535248, 0x004F4E44, 0x00504F45, 0x004E4D43, 0x004F4E44,
        0x004E4D43, 0x004D4C42, 0x004B4A40, 0x004B4A40, 0x004C4B41, 0x004E4D43, 0x004E4D43, 0x0045443A, 0x0048473D, 0x004A493F, 0x0049483E, 0x0046453B, 0x00444339, 0x0045443A, 0x0048473D, 0x00484541, 0x0043403C, 0x00403D39, 0x00413E3A, 0x0044413D,
        0x0045423E, 0x0045423E, 0x0044413D, 0x00444339, 0x00424137, 0x00403F35, 0x00424137, 0x00434238, 0x00403F35, 0x003C3B31, 0x003C3B31, 0x003D3E2E, 0x003D3E2E, 0x003E3F2F, 0x003E3F2F, 0x003D3E2E, 0x003C3D2D, 0x003B3C2C, 0x003A3B2B, 0x00343426,
        0x00323224, 0x00303022, 0x00303022, 0x00323224, 0x00343426, 0x00353527, 0x00353527, 0x00373926, 0x00363825, 0x00353724, 0x00363825, 0x00363825, 0x00353724, 0x00333522, 0x00323421, 0x00353527, 0x00313123, 0x002D2D1F, 0x002B2B1D, 0x002B2B1D,
        0x002B2B1D, 0x002B2B1D, 0x002C2C1E, 0x002A2C19, 0x00282A17, 0x00262815, 0x00272916, 0x00292B18, 0x002A2C19, 0x00282A17, 0x00252714, 0x0023241B, 0x0023241B, 0x0024251C, 0x0024251C, 0x0024251C, 0x0024251C, 0x0024251C, 0x0024251C, 0x0024251C,
        0x001C1D14, 0x00191A11, 0x001E1F16, 0x00202118, 0x001C1D14, 0x001C1D14, 0x00212219, 0x00252819, 0x00232617, 0x00222516, 0x00222516, 0x00232617, 0x00232617, 0x00212415, 0x00202314, 0x0024251C, 0x0024251C, 0x0022231A, 0x0022231A, 0x0022231A,
        0x0022231A, 0x0022231A, 0x0022231A, 0x0022231A, 0x00202118, 0x001E1F16, 0x001C1D14, 0x001B1C13, 0x001B1C13, 0x001B1C13, 0x001B1C13, 0x001A1B12, 0x001A1B12, 0x001B1C13, 0x001B1C13, 0x001B1C13, 0x001B1C13, 0x001B1C13, 0x001C1D14, 0x001A1B12,
        0x001A1B12, 0x001B1C13, 0x001C1D14, 0x001D1E15, 0x001E1F16, 0x001F2017, 0x001F2017, 0x0020221C, 0x001F211B, 0x001D1F19, 0x001C1E18, 0x001B1D17, 0x001B1D17, 0x001C1E18, 0x001D1F19, 0x00202118, 0x00202118, 0x001F2017, 0x001F2017, 0x001F2017,
        0x00202118, 0x00202118, 0x00212219, 0x0024251B, 0x0024251B, 0x0025261C, 0x0026271D, 0x0027281E, 0x0028291F, 0x0028291F, 0x0028291F, 0x001E1D0F, 0x0039382A, 0x00656456, 0x00848474, 0x00888878, 0x00848472, 0x00828270, 0x0080806E, 0x00807D6E,
        0x00807D6E, 0x00817E6F, 0x00827F70, 0x00848172, 0x00858273, 0x00868374, 0x00868374, 0x0082806E, 0x0083816F, 0x008C8A78, 0x00888576, 0x00858273, 0x00605D4F, 0x00242113, 0x001D1A0C, 0x0022201F, 0x00211F1E, 0x001F1D1C, 0x001E1C1B, 0x001E1C1B,
        0x001F1D1C, 0x001F1D1C, 0x001F1D1C, 0x00191716, 0x00171514, 0x00151312, 0x00161413, 0x00181615, 0x001B1918, 0x001C1A19, 0x001C1A19, 0x001B1C13, 0x00191A11, 0x0017180F, 0x0015160D, 0x0015160D, 0x0016170E, 0x00181910, 0x001A1B12, 0x00191A11,
        0x001D1E15, 0x001C1D14, 0x0016170E, 0x00111209, 0x000F1007, 0x000F1007, 0x000E0F06, 0x000A0B01, 0x00121309, 0x0013140A, 0x00121309, 0x0013140A, 0x0018190F, 0x00202117, 0x00212218, 0x002E3423, 0x003B3F33, 0x00B9BDB2, 0xFFFFFFFB,
  0xFFFFFFFF, 0xFFFCFCFC, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x0041453A, 0x0075746A, 0x0016150B, 0x00040300, 0x00141309, 0x00232218, 0x003C3B31, 0x00444339, 0x00434238, 0x00433D38, 0x00423C37, 0x00403A35, 0x003F3934, 0x003E3833,
        0x003D3732, 0x003A342F, 0x0038322D, 0x002F2C27, 0x00312E29, 0x00322F2A, 0x00302D28, 0x002C2924, 0x00292621, 0x002A2722, 0x002B2823, 0x002B2820, 0x0025221A, 0x0026231B, 0x0025221A, 0x0027241C, 0x0028251D, 0x001F1C14, 0x001D1A12, 0x00201D18,
        0x001C1914, 0x001A1712, 0x001B1813, 0x001D1A15, 0x001E1B16, 0x001E1B16, 0x001C1914, 0x0013140A, 0x0013140A, 0x0017180E, 0x00504F45, 0x007B7A70, 0x0078776D, 0x007B796F, 0x007C7A70, 0x00767567, 0x00767567, 0x00777668, 0x00787769, 0x00747365,
        0x00706F61, 0x00706F61, 0x00747365, 0x00737660, 0x00727460, 0x00777965, 0x00787A66, 0x00797B68, 0x00696B58, 0x004C4D3D, 0x00464737, 0x00050100, 0x00181413, 0x00171312, 0x00130F0E, 0x00120E0D, 0x00100C0B, 0x0014100F, 0x00151110, 0x00161211,
        0x00151110, 0x00130F0E, 0x00130F0E, 0x0014100F, 0x00151110, 0x00161211, 0x00181413, 0x00161211, 0x00151110, 0x00130F0E, 0x00130F0E, 0x0014100F, 0x00161211, 0x00161211, 0x00171312, 0x00191611, 0x0017140F, 0x0014110C, 0x0014110C, 0x0016130E,
        0x0017140F, 0x0015120D, 0x00120F0A, 0x000E0A09, 0x00110D0C, 0x00161211, 0x00181413, 0x00151110, 0x00130F0E, 0x00130F0E, 0x00130F0E, 0x00131109, 0x00131109, 0x00121008, 0x00121008, 0x00131109, 0x00131109, 0x0014120A, 0x0014120A, 0x0016130E,
        0x0013100B, 0x00110E09, 0x00100D08, 0x00120F0A, 0x0013100B, 0x0013100B, 0x00120F0A, 0x000E0D03, 0x000D0C02, 0x000D0C02, 0x000D0C02, 0x000F0E04, 0x00100F05, 0x000E0D03, 0x000C0B01, 0x000F0C07, 0x0013100B, 0x0016130E, 0x0016130E, 0x0014110C,
        0x0013100B, 0x0016130E, 0x00181510, 0x00141309, 0x00111006, 0x000D0C02, 0x000D0C02, 0x000F0E04, 0x00111006, 0x00100F05, 0x000F0E04, 0x000E0F05, 0x000E0F05, 0x000E0F05, 0x000E0F05, 0x000E0F05, 0x000E0F05, 0x000E0F05, 0x000E0F05, 0x000F1006,
        0x000A0B01, 0x000B0C02, 0x000F1006, 0x000E0F05, 0x00090A00, 0x000C0D03, 0x0015160C, 0x000F1202, 0x000E1101, 0x000D1000, 0x000D1000, 0x000F1202, 0x000F1202, 0x000E1101, 0x000D1000, 0x000D0E04, 0x000D0E04, 0x000C0D03, 0x000B0C02, 0x000A0B01,
        0x000A0B01, 0x000A0B01, 0x000A0B01, 0x000D0E04, 0x000D0E04, 0x000C0D03, 0x000C0D03, 0x000B0C02, 0x000A0B01, 0x000A0B01, 0x00090A00, 0x000A0B01, 0x000A0B01, 0x000A0B01, 0x000A0B01, 0x000B0C02, 0x000B0C02, 0x000B0C02, 0x000B0C02, 0x000C0D03,
        0x000C0D03, 0x000C0D03, 0x000C0D03, 0x000C0D03, 0x000D0E04, 0x000D0E04, 0x000E0F05, 0x00090C03, 0x000A0D04, 0x000A0D04, 0x000A0D04, 0x000A0D04, 0x000A0D04, 0x000A0D04, 0x000A0D04, 0x000B0C02, 0x000B0C02, 0x000A0B01, 0x000A0B01, 0x000B0C02,
        0x000B0C02, 0x000C0D03, 0x000D0E04, 0x00080900, 0x00080900, 0x000A0B01, 0x000B0C02, 0x000B0C02, 0x000B0C02, 0x000B0C02, 0x000B0C02, 0x0019180A, 0x00282719, 0x00434333, 0x00585848, 0x005B5B49, 0x005A5A48, 0x005B5C48, 0x005A5B47, 0x00605D4E,
        0x00605D4E, 0x00605D4E, 0x005F5C4D, 0x005F5C4D, 0x005E5B4C, 0x005E5B4C, 0x005E5B4C, 0x0061604C, 0x005E5D49, 0x005E5C4A, 0x005B5947, 0x00666354, 0x00535041, 0x001D1A0C, 0x00151204, 0x00100E0D, 0x00100E0D, 0x00100E0D, 0x00100E0D, 0x00100E0D,
        0x00110F0E, 0x0012100F, 0x00131110, 0x00171514, 0x00151312, 0x00131110, 0x00141211, 0x00161413, 0x00191716, 0x001A1817, 0x001A1817, 0x001E1F15, 0x001E1F15, 0x001E1F15, 0x001E1F15, 0x001E1F15, 0x001F2016, 0x00212218, 0x00212218, 0x001B1C12,
        0x0023241A, 0x002A2B21, 0x002C2D23, 0x002D2E24, 0x00313228, 0x0033342A, 0x0033342A, 0x0037382E, 0x003B3C32, 0x00393A30, 0x0037382E, 0x002F3026, 0x00222319, 0x00191A10, 0x000F1006, 0x002C3221, 0x00323728, 0x006A6E63, 0xFFFFFFF9,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFDFF, 0xFFFFFEFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00414637, 0x0042413D, 0x000B0A06, 0x002A2925, 0x0051504C, 0x00676662, 0x00868581, 0x00898884, 0x008B8A86, 0x008E8E82, 0x008E8E82, 0x008E8E82, 0x008E8E82, 0x008E8E82,
        0x008E8E82, 0x008E8E82, 0x008F8F83, 0x008A8D7E, 0x008B8E7F, 0x008C8F80, 0x008B8E7F, 0x00898C7D, 0x00878A7B, 0x0086897A, 0x0086897A, 0x00898979, 0x00898979, 0x008F8F7F, 0x008A8A7A, 0x00868676, 0x00868676, 0x00828272, 0x00868676, 0x0088887A,
        0x00818173, 0x007E7E70, 0x007E7E70, 0x007B7B6D, 0x00777769, 0x00757567, 0x00707062, 0x00727861, 0x006E745D, 0x005C624B, 0x006E715B, 0x00868973, 0x0081846E, 0x007B7D67, 0x00787A64, 0x007E7E6E, 0x007C7C6C, 0x007B7B6B, 0x00797969, 0x00757565,
        0x006E6E5E, 0x006C6C5C, 0x006D6D5D, 0x00757763, 0x006F715D, 0x00737562, 0x00737562, 0x00737464, 0x005D5E4E, 0x00373828, 0x00333325, 0x003D3D31, 0x0067675B, 0x007C7C70, 0x007E7E72, 0x0079796D, 0x00717165, 0x00727266, 0x00737367, 0x00717165,
        0x006F6F63, 0x006E6E62, 0x006F6F63, 0x00707064, 0x006F6F63, 0x00707064, 0x00727266, 0x00747468, 0x00707064, 0x006C6C60, 0x006C6C60, 0x006E6E62, 0x00707064, 0x006F6F63, 0x006D6D61, 0x0071745E, 0x0071745E, 0x0070735D, 0x006E715B, 0x006C6F59,
        0x00686B55, 0x0061644E, 0x005A5D47, 0x0058584C, 0x00636357, 0x006E6E62, 0x006A6A5E, 0x005D5D51, 0x0057574B, 0x0057574B, 0x00555549, 0x00524F4A, 0x00504D48, 0x004D4A45, 0x004B4843, 0x004B4843, 0x004B4843, 0x004B4843, 0x004A4742, 0x00484541,
        0x0046433F, 0x0044413D, 0x00423F3B, 0x00403D39, 0x003E3B37, 0x003D3A36, 0x003B3834, 0x00312E29, 0x00312E29, 0x00302D28, 0x00302D28, 0x0033302B, 0x0036332E, 0x0034312C, 0x00302D28, 0x00312E2A, 0x003C3935, 0x0046433F, 0x00494642, 0x00474440,
        0x0046433F, 0x00474440, 0x00484541, 0x003F3C37, 0x00393631, 0x00322F2A, 0x002D2A25, 0x002C2924, 0x002D2A25, 0x002F2C27, 0x002F2C27, 0x002C2D23, 0x002C2D23, 0x002C2D23, 0x002B2C22, 0x002B2C22, 0x002B2C22, 0x002B2C22, 0x002B2C22, 0x002D2E24,
        0x002C2D23, 0x002E2F25, 0x00303127, 0x002C2D23, 0x0027281E, 0x002B2C22, 0x0033342A, 0x00292C1D, 0x00282B1C, 0x00272A1B, 0x00282B1C, 0x00292C1D, 0x002A2D1E, 0x00292C1D, 0x00282B1C, 0x002C2D23, 0x002C2D23, 0x002D2E24, 0x002C2D23, 0x002B2C22,
        0x002C2D23, 0x002D2E24, 0x002E2F25, 0x002D2E24, 0x002D2E24, 0x002D2E24, 0x002E2F25, 0x002D2E24, 0x002D2E24, 0x002C2D23, 0x002C2D23, 0x002D2E24, 0x002D2E24, 0x002D2E24, 0x002D2E24, 0x002D2E24, 0x002E2F25, 0x002E2F25, 0x002E2F25, 0x00323329,
        0x00313228, 0x00313228, 0x00303127, 0x00303127, 0x00303127, 0x00313228, 0x00313228, 0x002E3128, 0x002E3128, 0x002F3229, 0x0030332A, 0x0030332A, 0x0030332A, 0x002F3229, 0x002F3229, 0x0036372D, 0x0036372D, 0x0036372D, 0x0036372D, 0x0037382E,
        0x0037382E, 0x0038392F, 0x00393A30, 0x00393B2F, 0x003A3C30, 0x003D3F33, 0x003F4135, 0x00404236, 0x00414337, 0x00414337, 0x00404236, 0x003F3F33, 0x00363628, 0x003F3F31, 0x00565648, 0x00626353, 0x00626353, 0x005F614E, 0x005C5E4B, 0x00626252,
        0x00626252, 0x00636353, 0x00636353, 0x00626252, 0x00616151, 0x00626252, 0x00636353, 0x00676755, 0x006D6D5B, 0x00707060, 0x006C6C5C, 0x00757466, 0x006B6A5C, 0x004F4E40, 0x00555348, 0x00515444, 0x00525545, 0x00545747, 0x00555848, 0x00575A4A,
        0x00595C4C, 0x005B5E4E, 0x005D6050, 0x005C5F4F, 0x005D6050, 0x005F6252, 0x00616454, 0x00626555, 0x00626555, 0x00616454, 0x00606353, 0x00606157, 0x00616258, 0x00626359, 0x0065665C, 0x0067685E, 0x0068695F, 0x00696A60, 0x006A6B61, 0x0065695E,
        0x006B6F64, 0x00707469, 0x0071756A, 0x0071756A, 0x0072766B, 0x0072766B, 0x0071756A, 0x00727369, 0x006F7066, 0x006E6F65, 0x006B6C62, 0x0065665C, 0x00525349, 0x00313228, 0x00191A10, 0x0014190A, 0x003F4337, 0x00484B42, 0xFFEDEFE9,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFDFF, 0xFFFFFEFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00545A49, 0x003A3B32, 0x00414239, 0x0057584F, 0x004F5047, 0x004F5047, 0x0066675E, 0x0067685F, 0x00686960, 0x00676D5C, 0x006A705F, 0x006F7564, 0x00717766, 0x00727867,
        0x00737968, 0x00757B6A, 0x00787E6D, 0x00747865, 0x00757966, 0x00777B68, 0x007A7E6B, 0x007E826F, 0x00808471, 0x00818572, 0x00818572, 0x007C7D69, 0x007E7F6B, 0x00868773, 0x00838470, 0x0080816D, 0x0082836F, 0x0082836F, 0x00898A76, 0x008B8D7A,
        0x00848673, 0x00868875, 0x008C8E7B, 0x008B8D7A, 0x008A8C79, 0x008A8C79, 0x00868875, 0x00848974, 0x00868B76, 0x00707560, 0x00676955, 0x00767864, 0x007C7E6A, 0x00797A66, 0x007C7D69, 0x00817F6D, 0x007F7D6B, 0x00807E6C, 0x00848270, 0x00868472,
        0x00858371, 0x00858371, 0x00868472, 0x00818272, 0x007B7C6C, 0x007D7E6E, 0x00777769, 0x00777769, 0x00606054, 0x00313125, 0x0027271B, 0x0051533F, 0x00757763, 0x00838571, 0x00868874, 0x00878975, 0x00828470, 0x00858773, 0x008A8C78, 0x008A8C78,
        0x00878975, 0x00868874, 0x00888A76, 0x00878975, 0x00848672, 0x00848672, 0x00868874, 0x00767864, 0x00757763, 0x00737561, 0x00737561, 0x00727460, 0x00727460, 0x0071735F, 0x0070725E, 0x0071745E, 0x00747761, 0x00767963, 0x00757862, 0x00757862,
        0x00767963, 0x00737660, 0x006E715B, 0x00747662, 0x00797B67, 0x007A7C68, 0x006F715D, 0x00626450, 0x00666854, 0x006B6D59, 0x00666854, 0x006E6E62, 0x006C6C60, 0x006A6A5E, 0x0069695D, 0x0069695D, 0x0069695D, 0x0067675B, 0x0066665A, 0x00646359,
        0x00646359, 0x00646359, 0x00626157, 0x005E5D53, 0x005B5A50, 0x0059584E, 0x0059584E, 0x0056554B, 0x0056554B, 0x0055544A, 0x00545349, 0x0057564C, 0x005A594F, 0x0058574D, 0x00535248, 0x004A493F, 0x00535248, 0x0059584E, 0x005A594F, 0x0059584E,
        0x005A594F, 0x005A594F, 0x0059584E, 0x005A594F, 0x0057564C, 0x00545349, 0x00525147, 0x00525147, 0x00545349, 0x0057564C, 0x0059584E, 0x00525349, 0x00525349, 0x00525349, 0x00515248, 0x00515248, 0x00515248, 0x00505147, 0x00505147, 0x004B4C42,
        0x004C4D43, 0x004D4E44, 0x004C4D43, 0x004A4B41, 0x0048493F, 0x004A4B41, 0x004C4D43, 0x004D4E44, 0x004B4C42, 0x004A4B41, 0x004B4C42, 0x004C4D43, 0x004C4D43, 0x004B4C42, 0x004A4B41, 0x00494A40, 0x004A4B41, 0x004B4C42, 0x004A4B41, 0x00494A40,
        0x00494A40, 0x004B4C42, 0x004C4D43, 0x004C4D43, 0x004C4D43, 0x004B4C42, 0x004B4C42, 0x004B4C42, 0x004B4C42, 0x004B4C42, 0x004B4C42, 0x004B4C42, 0x004B4C42, 0x004B4C42, 0x004B4C42, 0x004C4D43, 0x004C4D43, 0x004C4D43, 0x004C4D43, 0x004F5046,
        0x004F5046, 0x004E4F45, 0x004D4E44, 0x004D4E44, 0x004E4F45, 0x004F5046, 0x004F5046, 0x004B4F44, 0x004A4E43, 0x004A4E43, 0x00494D42, 0x00494D42, 0x00494D42, 0x004A4E43, 0x004A4E43, 0x004D4E44, 0x004D4E44, 0x004D4E44, 0x004D4E44, 0x004E4F45,
        0x004F5046, 0x00505147, 0x00515248, 0x00535549, 0x00535549, 0x0054564A, 0x00535549, 0x00525448, 0x004F5145, 0x004D4F43, 0x004B4D41, 0x003F4338, 0x00303429, 0x002D3125, 0x00373B2F, 0x003E4334, 0x0044493A, 0x00494E3F, 0x00494E3F, 0x004B4D41,
        0x004D4F43, 0x004F5145, 0x004F5145, 0x004E5044, 0x004E5044, 0x00505246, 0x00515347, 0x00505344, 0x00545748, 0x00515445, 0x004D5041, 0x004D4F43, 0x00414337, 0x003D3E34, 0x00515248, 0x00525643, 0x00535744, 0x00545845, 0x00535744, 0x00515542,
        0x004F5340, 0x004F5340, 0x00505441, 0x00505441, 0x00515542, 0x00515542, 0x00505441, 0x004E523F, 0x004B4F3C, 0x00484C39, 0x00474B38, 0x00494A40, 0x0048493F, 0x0048493F, 0x0046473D, 0x0045463C, 0x0044453B, 0x0043443A, 0x0043443A, 0x003D4136,
        0x003F4338, 0x003D4136, 0x00393D32, 0x00373B30, 0x00393D32, 0x00393D32, 0x00373B30, 0x0034352B, 0x002E2F25, 0x00313228, 0x002E2F25, 0x003B3C32, 0x0047483E, 0x0033342A, 0x0023241A, 0x00262A1E, 0x00383C31, 0x00343630, 0xFFD9DAD6,
  0xFFFFFFFF, 0xFFFDFCFE, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x005B6150, 0x002A2D1E, 0x002F3223, 0x004E5142, 0x004A4D3E, 0x001A1D0E, 0x00070A00, 0x000F1203, 0x000F1203, 0x00030B01, 0x00091107, 0x0010180E, 0x00141C12, 0x00151D13,
        0x00161E14, 0x00192117, 0x001C241A, 0x00222319, 0x00212218, 0x00222319, 0x0025261C, 0x0028291F, 0x002A2B21, 0x00292A20, 0x0027281E, 0x002B291E, 0x0029271C, 0x002E2C21, 0x002C2A1F, 0x002D2B20, 0x00302E23, 0x002E2C21, 0x00323025, 0x0037362C,
        0x00302F25, 0x0035342A, 0x003D3C32, 0x003D3C32, 0x003E3D33, 0x003F3E34, 0x003B3A30, 0x003A3935, 0x0041403C, 0x0031302C, 0x0024211D, 0x00302D29, 0x00383531, 0x00383330, 0x0046413E, 0x004C4A38, 0x00494735, 0x00494735, 0x004D4B39, 0x00504E3C,
        0x00504E3C, 0x004F4D3B, 0x004F4D3B, 0x00474739, 0x0048483A, 0x004B4B3D, 0x003D3D31, 0x003D3D31, 0x0036352B, 0x001B1A10, 0x00201F15, 0x001D1E0E, 0x00323323, 0x00353626, 0x003C3D2D, 0x00464737, 0x00424333, 0x003F4030, 0x00424333, 0x00414232,
        0x003E3F2F, 0x003D3E2E, 0x003F4030, 0x003D3E2E, 0x00393A2A, 0x00373828, 0x00393A2A, 0x00343525, 0x00373828, 0x003A3B2B, 0x00393A2A, 0x00373828, 0x00343525, 0x00343525, 0x00353626, 0x0035342A, 0x0037362C, 0x0035342A, 0x00302F25, 0x002F2E24,
        0x00333228, 0x00343329, 0x00333228, 0x00313222, 0x00323323, 0x00333424, 0x002E2F1F, 0x00303121, 0x003D3E2E, 0x003F4030, 0x00303121, 0x002F321C, 0x002E311B, 0x002F321C, 0x0031341E, 0x00333620, 0x00343721, 0x0032351F, 0x0030331D, 0x002B2D19,
        0x002D2F1B, 0x002F311D, 0x002E301C, 0x002B2D19, 0x00292B17, 0x00282A16, 0x00282A16, 0x00252616, 0x00252616, 0x00242515, 0x00222313, 0x00252616, 0x00282919, 0x00252616, 0x001F2010, 0x00252713, 0x00262814, 0x00242612, 0x001F210D, 0x001E200C,
        0x0021230F, 0x00232511, 0x0021230F, 0x00202111, 0x00212212, 0x00222313, 0x00222313, 0x00222313, 0x00202111, 0x001F2010, 0x001F2010, 0x001B1D11, 0x001A1C10, 0x001A1C10, 0x001A1C10, 0x00191B0F, 0x00191B0F, 0x00181A0E, 0x00181A0E, 0x0016180C,
        0x0016180C, 0x0016180C, 0x0016180C, 0x0017190D, 0x00181A0E, 0x00181A0E, 0x0016180C, 0x0015160D, 0x0014150C, 0x0012130A, 0x0012130A, 0x0013140B, 0x0012130A, 0x00111209, 0x00101108, 0x0014160A, 0x0015170B, 0x0014160A, 0x00121408, 0x00101206,
        0x000F1105, 0x00101206, 0x00111307, 0x0015170B, 0x0014160A, 0x00121408, 0x00101206, 0x000F1105, 0x00101206, 0x00111307, 0x00121408, 0x00111307, 0x00111307, 0x00111307, 0x00111307, 0x00111307, 0x00121408, 0x00121408, 0x00121408, 0x00111307,
        0x00111307, 0x00101206, 0x00101206, 0x00101206, 0x00111307, 0x00121408, 0x00131509, 0x0012160B, 0x00101409, 0x000E1207, 0x000C1005, 0x000C1005, 0x000C1005, 0x000D1106, 0x000E1207, 0x000D0F03, 0x000D0F03, 0x000D0F03, 0x000D0F03, 0x000E1004,
        0x000F1105, 0x00101206, 0x00111307, 0x000D0F03, 0x000E1004, 0x000F1105, 0x000F1105, 0x000F1105, 0x000D0F03, 0x000B0D01, 0x000A0C00, 0x00050A01, 0x0010150C, 0x001D2318, 0x001D2318, 0x00181E13, 0x001B2215, 0x001F2619, 0x001A2114, 0x001E2217,
        0x00202419, 0x00202419, 0x001F2318, 0x001C2015, 0x001A1E13, 0x001B1F14, 0x001C2015, 0x001E2216, 0x001D2115, 0x001C2014, 0x002A2E23, 0x002E3227, 0x0015190E, 0x00050800, 0x00090C03, 0x00060501, 0x00090804, 0x000B0A06, 0x000B0A06, 0x00090804,
        0x00080703, 0x00080703, 0x00090804, 0x00070602, 0x00070602, 0x00070602, 0x00060501, 0x00040300, 0x00050400, 0x00070602, 0x000A0905, 0x00080A00, 0x00070900, 0x00060800, 0x00050700, 0x00040600, 0x00040600, 0x00040600, 0x00040600, 0x00040800,
        0x00040800, 0x00010500, 0x00000400, 0x00020600, 0x000A0E02, 0x00101408, 0x00111509, 0x00040500, 0x00030400, 0x000C0D03, 0x00050600, 0x0017180E, 0x0034352B, 0x002A2B21, 0x001F2016, 0x0024281D, 0x003C3E38, 0x00343531, 0xFFD6D6D6,
  0xFFFFFFFF, 0xFFFDFFFF, 0xFFFCFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00747767, 0x00393431, 0x00333028, 0x003B392F, 0x00646257, 0x0019190D, 0x0020231A, 0x00181E19, 0x00080F0C, 0x001C2015, 0x00000500, 0x00080C06, 0x00181915, 0x00020100,
        0x0010100A, 0x000A0D04, 0x00050B00, 0x00191611, 0x000D0A05, 0x00020200, 0x000E0E08, 0x00020200, 0x0012120C, 0x00181510, 0x00050200, 0x00060B02, 0x00060900, 0x00040200, 0x00100E06, 0x00040200, 0x00070500, 0x00070100, 0x000B0300, 0x00070800,
        0x00060300, 0x00090000, 0x000B0000, 0x00150909, 0x00090000, 0x00040100, 0x00050600, 0x00070505, 0x00040000, 0x00050303, 0x00050505, 0x00020706, 0x00070F0E, 0x0003110F, 0x00031613, 0x000A110E, 0x000B100E, 0x000C0F0D, 0x000D100E, 0x000C110F,
        0x0008110E, 0x0002110D, 0x0000100C, 0x00020A0A, 0x000E1714, 0x00040B06, 0x000D150B, 0x00060E04, 0x00283127, 0x00323F37, 0x00000D07, 0x00090700, 0x00020100, 0x0007090A, 0x00000003, 0x00000506, 0x00060D08, 0x00000400, 0x000A1201, 0x000D0B0B,
        0x00060403, 0x00040100, 0x000E0B06, 0x000B0702, 0x000C0502, 0x001E1113, 0x0036292B, 0x0017251F, 0x001C1F1D, 0x00080808, 0x00000101, 0x00000304, 0x00020000, 0x00070504, 0x00000200, 0x00000006, 0x0001050A, 0x00000003, 0x00000003, 0x0004080D,
        0x00000006, 0x00020208, 0x00020003, 0x00090000, 0x00040B06, 0x00000600, 0x00070100, 0x001E0A05, 0x00160802, 0x00040300, 0x00070C0B, 0x00001004, 0x00081E12, 0x0009100B, 0x00070000, 0x000A0807, 0x00071710, 0x00000900, 0x00190F08, 0x0003110B,
        0x00060D06, 0x0011110B, 0x00020500, 0x00000400, 0x0009140A, 0x00040200, 0x00130500, 0x00000605, 0x00000100, 0x00110D0C, 0x00070000, 0x00090000, 0x000D0609, 0x00020004, 0x00010007, 0x00020202, 0x00090001, 0x000A0005, 0x000B060F, 0x00020007,
        0x00090006, 0x000E0109, 0x00000003, 0x00000503, 0x00050000, 0x000B0001, 0x00040208, 0x00000006, 0x000A0007, 0x00090000, 0x00000200, 0x00000003, 0x00000004, 0x0000070B, 0x00081114, 0x00040908, 0x00111210, 0x00262828, 0x00161C1B, 0x00010900,
        0x00050C05, 0x00161A15, 0x00222523, 0x00393A36, 0x001E1E18, 0x00020400, 0x000C0C00, 0x000C0D04, 0x0012130A, 0x00191A11, 0x000F1209, 0x001D2017, 0x00282D24, 0x00191E15, 0x0020251C, 0x001B1E1C, 0x00060907, 0x00121513, 0x00090C0A, 0x000A0D0B,
        0x00191C1A, 0x000A0D0B, 0x000C0F0D, 0x00180D10, 0x000C0607, 0x000D0B0B, 0x00161917, 0x00151A18, 0x00080E09, 0x00040B04, 0x000D140D, 0x001B1313, 0x00040000, 0x00121311, 0x000B0D0D, 0x00000100, 0x000C0E0E, 0x000A090B, 0x00020001, 0x000E0C0B,
        0x00020000, 0x000E0C0B, 0x000C0A09, 0x00090706, 0x0012100F, 0x00090706, 0x00060403, 0x000D0B0A, 0x00020000, 0x00020000, 0x000A0807, 0x00100E0D, 0x00090706, 0x00060403, 0x00090706, 0x000F170C, 0x0010180E, 0x00121A10, 0x000A0F06, 0x001B1F19,
        0x0031332D, 0x00262723, 0x002C2B27, 0x0032352C, 0x00282B22, 0x00222A20, 0x00141D13, 0x00041207, 0x0019291E, 0x00314237, 0x00283C30, 0x0007130D, 0x000C1812, 0x0015211B, 0x000C1812, 0x0005110B, 0x0008110E, 0x00030C09, 0x0007100D, 0x000B0D0D,
        0x000A0C0C, 0x00090B0B, 0x00080A0A, 0x00080A0A, 0x00080A0A, 0x00080A0A, 0x00080A0A, 0x000D1211, 0x00050D0C, 0x000A1512, 0x00182821, 0x001C2D24, 0x00112116, 0x000A160A, 0x000C1609, 0x00111516, 0x00121817, 0x0006100A, 0x00000D05, 0x00192820,
        0x00020E08, 0x00131C19, 0x00151A1B, 0x000B1505, 0x0011190F, 0x00191C1A, 0x0009080C, 0x00373436, 0x001C1C16, 0x000D1001, 0x00222811, 0x00140E0F, 0x00191514, 0x00191A16, 0x000F130D, 0x00151914, 0x00121212, 0x00181419, 0x00160E18, 0x0015150F,
        0x00121A10, 0x00161A0F, 0x002A281D, 0x00141C11, 0x0001170B, 0x00212C24, 0x00655654, 0x00252622, 0x00060703, 0x000C0E08, 0x000D1007, 0x00292D22, 0x00565A4E, 0x002A2E22, 0x00191E0F, 0x001C2112, 0x003B3F33, 0x003B3E35, 0xFFDBDDD7,
  0xFFFFFFFF, 0xFFFDFFFF, 0xFFFAFCFC, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00676A5A, 0x0036332E, 0x002E2B23, 0x00454037, 0x00615F54, 0x00212519, 0x005F6D62, 0x007F968E, 0x0084A29D, 0x00B7CCC3, 0x006E837B, 0x009EAFAB, 0x009AA9A5, 0x006F7E7A,
        0x00A3B4B0, 0x00899E96, 0x00798E85, 0x00AECAC4, 0x0053726B, 0x004F7069, 0x007EA099, 0x00577972, 0x00779891, 0x008DACA5, 0x004F6B65, 0x0073988E, 0x005E8177, 0x004C6F65, 0x007A9C92, 0x00405F56, 0x002F4C43, 0x005C776E, 0x0029443B, 0x0018372E,
        0x004A6660, 0x002E4540, 0x005B706D, 0x00546966, 0x001B322D, 0x003E5A54, 0x0037564D, 0x001A3833, 0x00405B57, 0x002B4440, 0x00243B37, 0x003D524F, 0x002D423F, 0x000B201D, 0x00000E0B, 0x00061311, 0x00010C0A, 0x000A100F, 0x00090E0D, 0x00010605,
        0x00000807, 0x00000D0B, 0x00000D0B, 0x000D1312, 0x00000100, 0x000C1310, 0x00030D07, 0x0009150F, 0x000D1D16, 0x00091D18, 0x00213633, 0x0029443B, 0x00405752, 0x003D514C, 0x003D4B49, 0x0045504D, 0x004F5651, 0x006D756B, 0x005C6459, 0x0065766D,
        0x0055685F, 0x0053675B, 0x0061776B, 0x004E665A, 0x00496558, 0x005A786D, 0x0065857A, 0x008AA699, 0x0099ADA1, 0x00687970, 0x0060756D, 0x006F817A, 0x0068776F, 0x00849489, 0x0060766A, 0x00516B5B, 0x00607768, 0x00576E5F, 0x005B7061, 0x0074897A,
        0x006B8071, 0x006F8273, 0x00748778, 0x00667970, 0x006D8F84, 0x00628B7C, 0x00688576, 0x007B8C7E, 0x006C7D70, 0x00617A6C, 0x008AA699, 0x006C7D72, 0x0081948B, 0x0087918B, 0x007B7A76, 0x00818B85, 0x006C8E84, 0x005D7D72, 0x00808B81, 0x00788A83,
        0x00929D95, 0x00838C82, 0x006B7B70, 0x006C887B, 0x00638476, 0x004B645A, 0x0076867F, 0x005B7F69, 0x00466752, 0x00819E87, 0x00526E57, 0x004B6652, 0x00708C79, 0x00395646, 0x004D6D5C, 0x005C7864, 0x00586E5B, 0x00718473, 0x005E7566, 0x0052695B,
        0x0067796C, 0x005A6F60, 0x004E6959, 0x00638B72, 0x005B715E, 0x005C6F60, 0x00618071, 0x005B7A6B, 0x00667769, 0x005E715E, 0x0055775F, 0x00637E6E, 0x00759080, 0x007A9683, 0x007A9482, 0x00708975, 0x006E8773, 0x00849E87, 0x0092AC95, 0x00779988,
        0x007E9F90, 0x008DADA2, 0x0096B3AA, 0x00ACCABF, 0x009AB7A8, 0x00809E8B, 0x00809F8A, 0x006E8B7C, 0x007F9C8D, 0x0093B0A1, 0x0092B1A2, 0x00A1C0B1, 0x00ACCBBC, 0x009EBFB0, 0x00A7C8B9, 0x008DB19B, 0x007CA08A, 0x0084A892, 0x007DA18B, 0x007DA18B,
        0x0089AD97, 0x007FA38D, 0x0081A58F, 0x007FA28E, 0x006B8F79, 0x00779E88, 0x0088B29B, 0x007AA48B, 0x00729C83, 0x007BA68B, 0x007AA58A, 0x007B9783, 0x00668772, 0x00719682, 0x006A917C, 0x00628A78, 0x00739987, 0x00698D7C, 0x005D7E6F, 0x0089AC98,
        0x00567965, 0x007EA18D, 0x0089AC98, 0x00597C68, 0x006E917D, 0x0081A490, 0x00577A66, 0x006F927E, 0x00628571, 0x005D806C, 0x006A8D79, 0x00779A86, 0x00789B87, 0x00729581, 0x0070937F, 0x0092AEA1, 0x007E9A8D, 0x0087A598, 0x008DAB9E, 0x008EAFA0,
        0x0094B5A6, 0x0086AA9A, 0x0082A696, 0x00A3B4A9, 0x009EAFA4, 0x009CB0A4, 0x0091A599, 0x007F9589, 0x0083998D, 0x00859D91, 0x00778F83, 0x006E8580, 0x004C635E, 0x002B413C, 0x000E241F, 0x00041813, 0x00021611, 0x0000110C, 0x00031410, 0x0006110F,
        0x0006110F, 0x0005100E, 0x0005100E, 0x0005100E, 0x0006110F, 0x00071210, 0x00081311, 0x00000F0E, 0x00031816, 0x0019322E, 0x00385750, 0x004E7066, 0x0059796E, 0x005F7D72, 0x00678376, 0x00718C88, 0x0075948D, 0x00799B90, 0x00779B8D, 0x0082A99A,
        0x00759B8F, 0x0084A79D, 0x0088AAA4, 0x00789F97, 0x0081A4A0, 0x0088A7AA, 0x0089A3AA, 0x00A2BCC3, 0x007F9B9C, 0x0083A49D, 0x0094B6AB, 0x00789992, 0x00779A90, 0x00779D91, 0x0072998A, 0x007DA397, 0x007EA399, 0x0085A7A1, 0x007F9E9D, 0x007B9D97,
        0x00769F97, 0x007DA298, 0x008EADA4, 0x007BA59A, 0x006DA598, 0x0079A69D, 0x009BAEAB, 0x00232422, 0x00070806, 0x000B0C08, 0x000C0E08, 0x0025281F, 0x004F5348, 0x002D3126, 0x001D2115, 0x00282D1E, 0x002F3327, 0x00373A31, 0xFFE2E4DE,
  0xFFFFFFFF, 0xFFFDFFFF, 0xFFF9FBFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00666959, 0x0033332D, 0x00211E16, 0x00413A31, 0x0059554A, 0x00171F14, 0x00678278, 0x007CAEA4, 0x006CABA2, 0x005AA39B, 0x005DA19A, 0x00599791, 0x005F9D97, 0x005C9C96,
        0x005BA19A, 0x00559E96, 0x00519A92, 0x00599791, 0x005C9C96, 0x004D918A, 0x0058A199, 0x005AA39B, 0x00579B94, 0x00579791, 0x006AA8A2, 0x00579D96, 0x005AA39B, 0x00489189, 0x005FA59E, 0x0065A59F, 0x005D9B95, 0x0065A39D, 0x005D9D97, 0x0061A097,
        0x0067A69D, 0x00528E86, 0x0064A098, 0x005C9890, 0x0058948C, 0x004D8C83, 0x00428178, 0x004D8C83, 0x00427E76, 0x003D766E, 0x0051847D, 0x00507974, 0x00345753, 0x001F3E3B, 0x00062320, 0x00031917, 0x00071C1A, 0x0002100F, 0x00071111, 0x00121A1A,
        0x00060E0E, 0x00061010, 0x00081414, 0x000C1211, 0x000B1312, 0x000E1917, 0x00051514, 0x00001210, 0x00082020, 0x001B3737, 0x003B5757, 0x00589287, 0x0087BDB0, 0x0097CABC, 0x0090BEB1, 0x0083B4A6, 0x0062988B, 0x0059978B, 0x0060A297, 0x0075A397,
        0x00669488, 0x00609183, 0x00699E90, 0x005D9889, 0x00509181, 0x00519985, 0x004A9782, 0x00569182, 0x005B9485, 0x005A8F81, 0x00649587, 0x006E9C8F, 0x005F9082, 0x0063988A, 0x00659C8D, 0x0063977F, 0x00659D86, 0x005C9782, 0x005A937E, 0x006B9F87,
        0x00669880, 0x00619780, 0x00609984, 0x00558D82, 0x00569385, 0x004B927E, 0x004F9783, 0x0060A28F, 0x005A9482, 0x00578C78, 0x0087BDA6, 0x00E2EEE8, 0x00EDFDF6, 0x00F3FDF7, 0x00EDF1EB, 0x00E0F5EC, 0x0081AFA3, 0x0072A296, 0x00CFECE3, 0x00ECFDF9,
        0x00F6FFFC, 0x00F0FEF3, 0x00DBF5E7, 0x009CCBBB, 0x0066A193, 0x004F8B81, 0x00649793, 0x0052937A, 0x005A9B82, 0x005E9F86, 0x00579980, 0x00599B82, 0x005B9D84, 0x005D9F86, 0x0056987F, 0x0057A185, 0x004D9479, 0x0060A388, 0x005D9B83, 0x0056947C,
        0x00599A84, 0x0050967F, 0x0059A18A, 0x0058A082, 0x005A9B82, 0x005C9E8B, 0x00519D8B, 0x00519983, 0x006BA38C, 0x00619D85, 0x0047967B, 0x005C9C86, 0x005F9981, 0x005C937A, 0x005E977E, 0x005B9981, 0x0052927C, 0x0054927A, 0x005D977B, 0x00498C77,
        0x004A8C79, 0x004F8D7F, 0x00468478, 0x00549286, 0x00519080, 0x004A8B76, 0x004F907A, 0x004F8D7D, 0x00549282, 0x00569585, 0x00498878, 0x00498A7A, 0x004F9080, 0x00478878, 0x004D9180, 0x0051957E, 0x00478B74, 0x00488C75, 0x00458972, 0x00448871,
        0x004B8F78, 0x00488C75, 0x00498D76, 0x0039876F, 0x0048967E, 0x003E8C74, 0x0036846C, 0x0048947C, 0x0047937B, 0x003C8870, 0x00438F77, 0x00387F6B, 0x003B8271, 0x003F8B79, 0x00358673, 0x00338372, 0x00398978, 0x00388375, 0x00388073, 0x003D8878,
        0x00378272, 0x00428D7D, 0x00418C7C, 0x003F8A7A, 0x00459080, 0x00408B7B, 0x00418C7C, 0x00479282, 0x00418C7C, 0x003E8979, 0x00418C7C, 0x00428D7D, 0x00408B7B, 0x003E8979, 0x003E8979, 0x00528E88, 0x00417D77, 0x0048877E, 0x0048887C, 0x003F8273,
        0x003E8571, 0x003A826C, 0x003D856E, 0x00397E71, 0x003A7C70, 0x003C7E72, 0x003B7B6F, 0x00347266, 0x00306C61, 0x0029655A, 0x001F594E, 0x002C514F, 0x00274C4A, 0x00204241, 0x000B2C28, 0x00001B18, 0x00001A17, 0x00001815, 0x00001915, 0x00011411,
        0x00011411, 0x00001310, 0x0000120F, 0x00001310, 0x00011411, 0x00021512, 0x00031613, 0x00001718, 0x00001F20, 0x000B3230, 0x001B4845, 0x0023564F, 0x00255952, 0x00265B52, 0x00285B53, 0x00256058, 0x00246056, 0x002E6C5E, 0x002E6F5F, 0x00347566,
        0x00337569, 0x0030736A, 0x00357871, 0x001E8385, 0x0045A8AC, 0x0057B5BB, 0x0057B2BB, 0x0060B9C3, 0x0046A4AA, 0x003C9DA0, 0x00066C6B, 0x002A776F, 0x00267469, 0x002D7A6C, 0x00267463, 0x002D7B6A, 0x00307A6E, 0x00337C74, 0x002B736D, 0x002D7372,
        0x00277471, 0x0027736F, 0x00347674, 0x0026746D, 0x0028867B, 0x0034877E, 0x0048827D, 0x00101010, 0x00000000, 0x00090A08, 0x00090A08, 0x000D0E0A, 0x00262822, 0x00181B12, 0x0014170E, 0x0022261A, 0xFF4D5146, 0xFF9D9F99, 0xFFF3F4F0,
  0xFFFFFFFF, 0xFFFDFFFF, 0xFFF9FBFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x006A6D5D, 0x00353A31, 0x001E1C12, 0x00423930, 0x00655F54, 0x00162117, 0x004C766B, 0x004B9288, 0x001C786D, 0x00177574, 0x002F8381, 0x00529D9B, 0x005FABA7, 0x004B9F9A,
        0x00237F7A, 0x0014726E, 0x001B7575, 0x00317776, 0x004D9896, 0x00388986, 0x001D726E, 0x00196E6A, 0x00227370, 0x00337E7C, 0x004A908F, 0x003D8C89, 0x00176B67, 0x002B827E, 0x001A6E6A, 0x0025706E, 0x00569A99, 0x00438C8A, 0x002B7A77, 0x00206B69,
        0x0027716D, 0x002F7771, 0x004B948C, 0x003B847C, 0x001D655F, 0x0019635F, 0x00135E5C, 0x00145651, 0x00448681, 0x003B7B76, 0x0018534F, 0x0019504D, 0x00184745, 0x000E3635, 0x00214545, 0x00072928, 0x00001918, 0x00092121, 0x00011314, 0x00000D0F,
        0x00071315, 0x00091618, 0x00031012, 0x00060E0D, 0x000A1616, 0x00021316, 0x000F252A, 0x0000171B, 0x00163538, 0x002F4E4F, 0x004B6B6A, 0x006F9288, 0x00A0C2B7, 0x00C0E4D3, 0x00C0EED8, 0x00B6F1DC, 0x0087D6C3, 0x003A9B8D, 0x00006B5F, 0x00236963,
        0x00236865, 0x001F6461, 0x001F6663, 0x00236D69, 0x0016635B, 0x00136559, 0x00116455, 0x0011665E, 0x00116A60, 0x001B6F63, 0x00155A4F, 0x001A5E53, 0x001D6C61, 0x000E645A, 0x0016645D, 0x001C5F56, 0x0013605D, 0x00116767, 0x00106361, 0x00155B54,
        0x0023665D, 0x00307D76, 0x00287E7E, 0x003C8281, 0x00377A75, 0x002A766B, 0x00137166, 0x00086862, 0x00196964, 0x002B6D62, 0x0053927E, 0x00F7FEFB, 0x00F6FFFE, 0x00F9FFF9, 0x00FFFFFB, 0x00F1FFF9, 0x005D887B, 0x00608B82, 0x00DBF5EF, 0x00FAFFFE,
        0x00F8FCF7, 0x00FBFFF9, 0x00ECFFF8, 0x0079AF9E, 0x00226A5E, 0x001B6864, 0x00145E60, 0x0020676A, 0x00196365, 0x001C696C, 0x001C6D70, 0x00207071, 0x0015625F, 0x0019635D, 0x001F655E, 0x000A6760, 0x00177770, 0x00146F66, 0x0019685F, 0x0017655E,
        0x000E6862, 0x0013726E, 0x000C6666, 0x00146358, 0x00186764, 0x00146F74, 0x000C7173, 0x000B6461, 0x00195F59, 0x00186561, 0x00107671, 0x00146B68, 0x0017645D, 0x0023685E, 0x001E6862, 0x000A6562, 0x00066666, 0x000D6663, 0x0014635A, 0x0017665B,
        0x0017665D, 0x001C6C67, 0x00115F5E, 0x00186665, 0x00166562, 0x00176760, 0x00196C63, 0x001B6865, 0x00196865, 0x001A6966, 0x0012615E, 0x00176865, 0x001D6E6B, 0x00126662, 0x00146864, 0x001B6A6D, 0x0019686B, 0x00176669, 0x00176669, 0x00166568,
        0x00166568, 0x0019686B, 0x0018676A, 0x00116B6C, 0x00136A6C, 0x0014686D, 0x0015666B, 0x0017656B, 0x0018696E, 0x0016676C, 0x00106168, 0x0028828D, 0x00298592, 0x00268693, 0x00238793, 0x00218492, 0x001F8290, 0x00248393, 0x00298596, 0x00218290,
        0x00258694, 0x00298A98, 0x00258694, 0x002C8D9B, 0x002D8E9C, 0x00258694, 0x002E8F9D, 0x002D8E9C, 0x002E8F9D, 0x002E8F9D, 0x002B8C9A, 0x00288997, 0x00288997, 0x002A8B99, 0x002B8C9A, 0x00308C99, 0x002F8994, 0x00217A84, 0x00086165, 0x000C6262,
        0x00166B67, 0x0011665E, 0x00176A61, 0x00096560, 0x0008625D, 0x00065D59, 0x00075B57, 0x00095855, 0x0008514F, 0x00034948, 0x00004443, 0x0007333A, 0x00083539, 0x000F373C, 0x000C3135, 0x0004272A, 0x00042326, 0x00011D1E, 0x00001415, 0x00021415,
        0x00011314, 0x00001112, 0x00001011, 0x00001011, 0x00001213, 0x00011314, 0x00021415, 0x00001A21, 0x00002228, 0x00032E31, 0x0005383A, 0x00074041, 0x00094545, 0x00094747, 0x000A4947, 0x00054F51, 0x00014B4B, 0x000D5654, 0x000D5955, 0x000D5A57,
        0x000F5F60, 0x0007595E, 0x001B6E76, 0x0046A2B5, 0x004097AB, 0x002D7E93, 0x00267588, 0x00328196, 0x004396AB, 0x004BA4B9, 0x00217E93, 0x00045F66, 0x00005B5F, 0x00106868, 0x000C6360, 0x000F6361, 0x000F6263, 0x0013686A, 0x000E6267, 0x000D5E65,
        0x0009636A, 0x000D626A, 0x0014646B, 0x00096266, 0x000A7370, 0x00197972, 0x00408882, 0x00121113, 0x00000001, 0x00080808, 0x000C0D0B, 0x00020300, 0x00040600, 0x00030500, 0x00080B02, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFDFFFF, 0xFFFAFCFC, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x006A6D5D, 0x00323A30, 0x001B1A10, 0x00393026, 0x00696259, 0x000F1D12, 0x00315E55, 0x003D8E85, 0x00157C74, 0x00296974, 0x006D9EA8, 0x00D2F6FE, 0x00B9DEE2, 0x00BFF2F4,
        0x0094D4D8, 0x002E6D75, 0x0037717D, 0x0094C8CE, 0x00A6E0E5, 0x009BDEE1, 0x0058A2A4, 0x00196365, 0x002E7174, 0x0085BFC4, 0x00B6EAF0, 0x00A2DEE4, 0x0050979B, 0x0018676A, 0x00388185, 0x008CC6CC, 0x00ADE1E8, 0x00A2DCE2, 0x0052969B, 0x00286D76,
        0x0036787D, 0x0083BEC0, 0x00A3DCDB, 0x00AEE7E6, 0x00609B9D, 0x001F6166, 0x001F646D, 0x0090BCBD, 0x00A5D5D6, 0x009ACECE, 0x005A9392, 0x000D4645, 0x001F5353, 0x006F9D9E, 0x0078A4A5, 0x0034605F, 0x000E3635, 0x00001B1B, 0x00001617, 0x0021383A,
        0x00203739, 0x000F2628, 0x00092224, 0x00001112, 0x00091E20, 0x00051F25, 0x00000E15, 0x00204046, 0x00557477, 0x003B5855, 0x00405A54, 0x008A7E74, 0x00D5CABC, 0x00F1E7D6, 0x00F4F3DF, 0x00D4E2D0, 0x00C4E5D7, 0x00BAEDE5, 0x0063A39E, 0x001B6B72,
        0x00186772, 0x001E6977, 0x00155D6E, 0x00175A69, 0x00205D67, 0x004C8388, 0x005D8F8F, 0x0019616B, 0x00106469, 0x001D6A6C, 0x00598F90, 0x0055888A, 0x00145E60, 0x000D5E63, 0x002E707B, 0x0059888C, 0x00387A85, 0x00116374, 0x00135E6C, 0x003F777C,
        0x0074A5A7, 0x0080C1C9, 0x0065BACA, 0x006EB0BB, 0x00A2D2D8, 0x009BD3D4, 0x004FA8AC, 0x00096F7C, 0x000F5C6F, 0x00235E67, 0x0047817C, 0x00F3F7F8, 0x00FAFFFF, 0x00F6F8F2, 0x00FFFEF7, 0x00EFF7ED, 0x007C9A8F, 0x008EA7A3, 0x00D2D7D8, 0x00FFFAFB,
        0x00FFFEFB, 0x00FDF8EF, 0x00EFFFF3, 0x0080AEA1, 0x001B5F58, 0x00156265, 0x001A6974, 0x00246378, 0x000C5067, 0x0019657C, 0x000B5970, 0x000D5A6D, 0x001C626F, 0x003B767F, 0x0063989B, 0x00276D7A, 0x000B5F65, 0x00136063, 0x0054888E, 0x005B8F96,
        0x001D6870, 0x00085A65, 0x001D6273, 0x00619193, 0x004F8693, 0x00145F75, 0x00005365, 0x0031747D, 0x00608C93, 0x004A818A, 0x00075D69, 0x000E5F6E, 0x0043828A, 0x005E9193, 0x00316F75, 0x00055C6C, 0x0006677B, 0x00116675, 0x0023676E, 0x001D676D,
        0x000E5961, 0x00165F6D, 0x00125C6E, 0x001A6476, 0x00156173, 0x00146370, 0x0013636E, 0x00155F71, 0x00176173, 0x00196375, 0x00156173, 0x001B6779, 0x001C6A7B, 0x00136172, 0x00115F70, 0x00105C73, 0x00156178, 0x00125E75, 0x00146077, 0x00135F76,
        0x00105C73, 0x00125E75, 0x00125E75, 0x0015637A, 0x000B556D, 0x00145A72, 0x00256682, 0x001C5C7A, 0x000A4C69, 0x00185E7C, 0x003B84A2, 0x0059B9DD, 0x0045A6CC, 0x00369BC1, 0x003AA4C9, 0x003AA3CA, 0x00389FC6, 0x003DA1CB, 0x00399BC5, 0x003EA4CE,
        0x00379DC7, 0x0042A8D2, 0x0042A8D2, 0x00389EC8, 0x003BA1CB, 0x003EA4CE, 0x00399FC9, 0x003DA3CD, 0x003BA1CB, 0x00389EC8, 0x00389EC8, 0x003CA2CC, 0x0040A6D0, 0x003FA5CF, 0x003BA1CB, 0x0033A2C8, 0x0046B1D6, 0x003FA6C7, 0x00187896, 0x00035D76,
        0x0003566C, 0x00065366, 0x0010596D, 0x00155E6C, 0x00125967, 0x000D505F, 0x000F4B5B, 0x0011495A, 0x00104254, 0x000A3A4C, 0x000A384A, 0x000C4051, 0x00003244, 0x00002D3E, 0x0007303F, 0x00042937, 0x0001212C, 0x00021E29, 0x00001923, 0x0004161D,
        0x0003151C, 0x0002141B, 0x0001131A, 0x0002141B, 0x0004161D, 0x0006181F, 0x00081A21, 0x0005232E, 0x00092C36, 0x000A3440, 0x00083B45, 0x00074049, 0x000A454E, 0x000D4851, 0x000D4852, 0x0001465A, 0x00074B5E, 0x00125466, 0x00135567, 0x000B5063,
        0x00075268, 0x000E5D78, 0x00388BAA, 0x004484A3, 0x002C6683, 0x003B6E88, 0x0057889E, 0x00487A91, 0x00316785, 0x00347395, 0x005EA2C7, 0x00156884, 0x0003526D, 0x00115B73, 0x0012576B, 0x00115568, 0x00115469, 0x00145A71, 0x00105870, 0x00115669,
        0x000F5C6F, 0x000E576D, 0x0014576C, 0x000E5B6B, 0x0007656A, 0x001B726F, 0x0065A5A0, 0x00302F31, 0x00050505, 0x00070707, 0x00171816, 0x00131410, 0x000C0E08, 0x000E1108, 0x0014170E, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFDFFFF, 0xFFFCFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00737666, 0x0031392E, 0x0015170B, 0x00282217, 0x005D584F, 0x0009160E, 0x00254F48, 0x0037817B, 0x001A7873, 0x00175363, 0x007FA9B6, 0x00A7BDC8, 0x00051F25, 0x00618E91,
        0x0092D1D5, 0x00114E58, 0x005A8E9F, 0x009DC1C9, 0x00002B32, 0x004C8388, 0x0087C6CA, 0x001F5E62, 0x00548B90, 0x00A2CED5, 0x00001D25, 0x004F7985, 0x009CD5DE, 0x001F636A, 0x004C8790, 0x0096BECA, 0x00022431, 0x00426C78, 0x009DD6DF, 0x00115667,
        0x0046828E, 0x00ACDAE2, 0x0004292D, 0x00375C60, 0x00B0DEE6, 0x004C8894, 0x00296E7F, 0x00AFC4CC, 0x0006232A, 0x00396166, 0x009ACACE, 0x00104548, 0x002A5F62, 0x009FCFD3, 0x0000171B, 0x0006393B, 0x00649597, 0x00002225, 0x0012383C, 0x006D9296,
        0x00001216, 0x00001E22, 0x006A9396, 0x00123336, 0x00012428, 0x0001262E, 0x00355963, 0x0095B5BB, 0x005D7573, 0x005D6D62, 0x00A9B4A4, 0x00D1CEB2, 0x00F1EDD1, 0x00FFF5DD, 0x00FFFEE8, 0x00FEF6E5, 0x00EAE8DE, 0x00DEE4DF, 0x00E2EDEB, 0x003A8391,
        0x00085264, 0x000F5971, 0x00145974, 0x00205972, 0x00598194, 0x00CCE2EE, 0x00E8F1FA, 0x005F889F, 0x001F5A69, 0x005D909A, 0x00E9FAFF, 0x00D8E7F0, 0x0046747F, 0x001D5463, 0x008CAEC6, 0x00F4FFFF, 0x00A3CAD2, 0x00215D6D, 0x00316571, 0x00B8D2D2,
        0x00F1FFFE, 0x0093BABC, 0x0010515F, 0x00427A85, 0x00C8DFE7, 0x00DAF2F8, 0x0078BECB, 0x001F7B98, 0x00145A7F, 0x0024566D, 0x004D8187, 0x00F4F2F8, 0x00FBFFFF, 0x00FFFFFB, 0x00FFFFF8, 0x00F4F8ED, 0x00A6BFB5, 0x00B5CBC9, 0x00D4D7DC, 0x00FFFEFF,
        0x00FFFEFC, 0x00F8EDE5, 0x00EDF6E9, 0x0084AA9E, 0x001E5A59, 0x00165C69, 0x00196074, 0x00215B6E, 0x00286A7D, 0x00145D73, 0x00145F75, 0x00195F70, 0x00386F78, 0x00B7DFDE, 0x00E0FBF7, 0x0095B8C5, 0x00245D5F, 0x00518280, 0x00DBE9E8, 0x00E9F6F8,
        0x00659597, 0x0021585F, 0x007799A9, 0x00FAFCF6, 0x00D6E9F0, 0x00518193, 0x00225C68, 0x0098B7B8, 0x00F9FEFC, 0x00C4D9DB, 0x002C656E, 0x002C6672, 0x00BADBDE, 0x00F1FFFE, 0x008EADAE, 0x00367785, 0x001C6E80, 0x00296876, 0x00648D90, 0x003D7E8C,
        0x0019596B, 0x00115169, 0x000E4F6B, 0x00155774, 0x00155976, 0x00175E79, 0x00145C74, 0x00185A77, 0x001A5C79, 0x00195B78, 0x00125673, 0x00105471, 0x000F5572, 0x00115774, 0x00155B78, 0x000F586E, 0x00145D73, 0x00145D73, 0x00155E74, 0x00165F75,
        0x00125B71, 0x00115A70, 0x00125B71, 0x0010576B, 0x001C5F74, 0x001A566E, 0x0018506B, 0x001B5572, 0x00145472, 0x00337B99, 0x0072BFDF, 0x0054B6DE, 0x00389FC6, 0x002E98C1, 0x00339FC8, 0x002C9BC3, 0x002C98C2, 0x00349DC8, 0x003199C4, 0x002B96C2,
        0x00329DC9, 0x00319CC8, 0x002E99C5, 0x00329DC9, 0x00309BC7, 0x002B96C2, 0x00339ECA, 0x00339ECA, 0x00339ECA, 0x00319CC8, 0x002F9AC6, 0x002E99C5, 0x002E99C5, 0x002D98C4, 0x002C97C3, 0x00239CCE, 0x0034A9DC, 0x0047B4E7, 0x003AA0D0, 0x001A76A5,
        0x00106592, 0x00196893, 0x001E6A94, 0x00196D90, 0x00196B8E, 0x0019678B, 0x001C668A, 0x001D6388, 0x001A5B81, 0x00125177, 0x000D4B71, 0x00003E5B, 0x0000415E, 0x0003425E, 0x0009415A, 0x000A3B51, 0x00113C51, 0x0012374B, 0x00002234, 0x0007232E,
        0x0006222D, 0x0006222D, 0x0006222D, 0x0008242F, 0x000C2833, 0x000F2B36, 0x00122E39, 0x000E3242, 0x00103948, 0x00134152, 0x00134757, 0x00124A5B, 0x00104B5B, 0x0011495C, 0x0011495C, 0x000A4A68, 0x00114D6A, 0x00144F69, 0x0018506D, 0x00134F6D,
        0x000A4C6F, 0x00216C93, 0x004193BD, 0x002B5F7D, 0x005C8CA4, 0x00AED9EA, 0x00DAFFFF, 0x00B9E0EE, 0x0078A7BD, 0x002D6384, 0x004582AA, 0x003A84AE, 0x0010557D, 0x00155175, 0x00174C6D, 0x001A4D6D, 0x00194F6E, 0x001A5373, 0x00135072, 0x001D5570,
        0x00155672, 0x000E4969, 0x00154B6A, 0x0014546C, 0x00095C64, 0x001E6A69, 0x0079AFAA, 0x00393A38, 0x00020301, 0x00080905, 0x001F211B, 0x0020231A, 0x001A1E13, 0x0023271C, 0x002F3327, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFDFFFF, 0xFFFDFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00797C6C, 0x00343E31, 0x0017190D, 0x0029251A, 0x005C5A50, 0x001C271F, 0x00436460, 0x00417B7A, 0x00216C6E, 0x001A6878, 0x006499A6, 0x00B9DBE1, 0x001C4242, 0x00579490,
        0x0087D7D6, 0x000B5A63, 0x00428798, 0x00ADCED7, 0x001B474E, 0x005F979C, 0x007EBEC2, 0x000F4F53, 0x00467E83, 0x00B1DDE4, 0x002C4D56, 0x005C8692, 0x0081BCC5, 0x00165E65, 0x0047868E, 0x00AED6E2, 0x00335360, 0x005E8B96, 0x00ACEAF2, 0x000D6377,
        0x00377C8D, 0x00A4D5DF, 0x003F6167, 0x00517379, 0x009FD0DA, 0x00559AAB, 0x00449AAE, 0x00BDD1DC, 0x003F5C65, 0x005E858D, 0x0088BAC0, 0x000E454A, 0x0032666C, 0x00A4D2D9, 0x00305A61, 0x00296264, 0x007CB3B6, 0x00003134, 0x00205054, 0x0094C4C8,
        0x0024575A, 0x002E6568, 0x0080B9BB, 0x00002F33, 0x0014464C, 0x0023515C, 0x0081AAB3, 0x0084A3A6, 0x0042534A, 0x008C8E7A, 0x00E3DCC1, 0x00B6C193, 0x00BEC69D, 0x00EAEFCF, 0x00FFFFEC, 0x00FFFFF2, 0x00DDDCCE, 0x00A3A397, 0x00E2E1D7, 0x0096D1DB,
        0x00256976, 0x000E586A, 0x000E576D, 0x00155064, 0x00567786, 0x00E2E8EF, 0x00FFF6F8, 0x0082A0B3, 0x00174E57, 0x00608B8E, 0x00EEF2F3, 0x00E8EAEB, 0x005F888B, 0x001D505A, 0x00A7BFD3, 0x00FFFFF6, 0x00C4E2E3, 0x002E6671, 0x002F5E62, 0x00BBCAC2,
        0x00FBFFF1, 0x009BBBB6, 0x0018575F, 0x00467B78, 0x00EAF0EB, 0x00F5F9F4, 0x0089C3C9, 0x00237C97, 0x0011547B, 0x001E4F69, 0x0040797B, 0x00FBF3FD, 0x00FEFDFF, 0x00FFFEF9, 0x00FFFEF3, 0x00E3F0E2, 0x0082A89C, 0x006A928D, 0x00C0D4D9, 0x00FDFFFF,
        0x00FDF8F5, 0x00F8F3EA, 0x00F4FEF1, 0x007FA298, 0x001F585A, 0x001B6071, 0x000C506D, 0x00195261, 0x001E5F6E, 0x00155D6F, 0x00115B6D, 0x00135260, 0x003D676C, 0x00CCE2DD, 0x00FCFFF7, 0x009AB6BD, 0x001F5653, 0x005B887F, 0x00E7ECE3, 0x00EEF2EC,
        0x0069958E, 0x00225859, 0x0087A1AD, 0x00FFFFF0, 0x00E1EEEC, 0x0045747C, 0x00235A5D, 0x00A7C1B4, 0x00F3EFDD, 0x00C2D0C5, 0x00346A6A, 0x0035666E, 0x00C4D9D6, 0x00FFFFF7, 0x00B1C5C0, 0x007AB7C1, 0x0067B5C6, 0x00639EA7, 0x00A5C4C1, 0x0043808A,
        0x001C5965, 0x00185668, 0x0015536B, 0x0014566F, 0x00145770, 0x00165C74, 0x000C556B, 0x00155672, 0x00175874, 0x00195A76, 0x00175A75, 0x00145772, 0x00115671, 0x00135873, 0x00155A75, 0x0011586C, 0x00155C70, 0x00165D71, 0x00145B6F, 0x00175E72,
        0x00155C70, 0x0011586C, 0x00155C70, 0x000F5A6A, 0x000F5467, 0x0018596E, 0x00135169, 0x000D506B, 0x0036839E, 0x005EB7D2, 0x005CBDD7, 0x0042ABD4, 0x0036A0C9, 0x0033A4CC, 0x0031A3CC, 0x00279BC4, 0x002C9DC8, 0x0035A2CE, 0x0037A2CE, 0x0030A0CE,
        0x002D9DCB, 0x0030A0CE, 0x0032A2D0, 0x002C9CCA, 0x002C9CCA, 0x0030A0CE, 0x002B9BC9, 0x002D9DCB, 0x0030A0CE, 0x0033A3D1, 0x0033A3D1, 0x0030A0CE, 0x002D9DCB, 0x0030A0CE, 0x0035A5D3, 0x002DA6D8, 0x002AA0D3, 0x0034A9DC, 0x0045B4E6, 0x0045B0E3,
        0x0046ACE0, 0x0045ABDC, 0x003DA0D2, 0x0033A9D8, 0x0035A9D8, 0x0038AAD9, 0x0039A8D8, 0x0035A3D3, 0x00349DCE, 0x002E95C6, 0x00258CBD, 0x002483AA, 0x002782A7, 0x0022789C, 0x001D6C8D, 0x00145C7A, 0x00195A76, 0x00215C76, 0x000D455E, 0x000A3849,
        0x00093748, 0x00083647, 0x00073546, 0x00093748, 0x000C3A4B, 0x000F3D4E, 0x00113F50, 0x000A3E4F, 0x000A4253, 0x000E495C, 0x00125165, 0x00135469, 0x0015536B, 0x0017536B, 0x0019516C, 0x0012566D, 0x00115169, 0x00144E64, 0x00185069, 0x0015516E,
        0x00074C6D, 0x002E7EA3, 0x002B82AA, 0x004E6D86, 0x00ADC7D8, 0x00E6F9FF, 0x00EDFDFC, 0x00E9FCFF, 0x00D1ECFA, 0x00567B97, 0x003A6489, 0x003F91BA, 0x00085379, 0x000C4C6E, 0x00144E6B, 0x001B526D, 0x001B536E, 0x00195874, 0x00155873, 0x00175371,
        0x00155675, 0x00135175, 0x001B5174, 0x00145770, 0x00075E68, 0x00126360, 0x00619D93, 0x0032342E, 0x00000200, 0x0010130A, 0x00282C21, 0x002B2F23, 0x00282D1E, 0x00313627, 0x003B4130, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFDFFFF, 0xFFFBFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00707363, 0x00303A2D, 0x0014180C, 0x002C2A1F, 0x00555349, 0x00212823, 0x0056716E, 0x00477779, 0x002B686C, 0x00165C6D, 0x005A8795, 0x00C8DDE5, 0x00CBE4E6, 0x00B8EDEA,
        0x004E9898, 0x001A616B, 0x00134E61, 0x008BB5BA, 0x00AADDE0, 0x007EBFC0, 0x001D6767, 0x00105A5A, 0x00256667, 0x0075A8AB, 0x00B5DFE4, 0x0088B9C1, 0x0024686D, 0x000C5F61, 0x000C5559, 0x007FB0B8, 0x00B1D8E1, 0x008BC1C8, 0x004A9397, 0x0045ACBF,
        0x000E6071, 0x0068A0AB, 0x00BBE0E8, 0x00B6DBE3, 0x0084BCC7, 0x00398B9C, 0x003097AA, 0x0099B6BF, 0x00BFE3EB, 0x009DCDD3, 0x00387075, 0x000B454A, 0x001D5157, 0x005A868D, 0x00C2E7EF, 0x0091CCCE, 0x002A6365, 0x00195053, 0x00144B4E, 0x00467F81,
        0x0092CFD1, 0x008FD0D1, 0x00296F6F, 0x000E484D, 0x00144D56, 0x00376B77, 0x00ADD8E1, 0x00547273, 0x007C867A, 0x00CFC8AF, 0x00FFECC9, 0x00D1BC89, 0x00B6A376, 0x00C3B291, 0x00DED2BA, 0x00EBE3D2, 0x00F7EFE2, 0x00C6C1B2, 0x009E9A88, 0x00BFEFF3,
        0x003B777D, 0x00115C65, 0x000B5A67, 0x00145661, 0x004A7074, 0x00D9E0DD, 0x00FFFAF3, 0x00759EA7, 0x00135855, 0x004B857A, 0x00F2FFF5, 0x00E6F1E7, 0x003F776C, 0x00125351, 0x009DC0CA, 0x00FEFFF5, 0x00BDE2E6, 0x00216270, 0x00255C63, 0x00B2C7BF,
        0x00FAFFF7, 0x009CC4BF, 0x00024D56, 0x004F8774, 0x00F2F2E0, 0x00FFFCED, 0x009BD0CD, 0x00278095, 0x000E5577, 0x0021566B, 0x00337570, 0x00F8ECF8, 0x00FFFCFF, 0x00F0F0EA, 0x00E5E7DB, 0x00D7F1E1, 0x0062998A, 0x001F5954, 0x00B7E0E3, 0x00F3FFFF,
        0x00F9FFFA, 0x00F8FAEE, 0x00EEFDEF, 0x0079A196, 0x001A5557, 0x00185B70, 0x00105576, 0x001F596C, 0x0018596E, 0x000F576F, 0x00175F77, 0x001A5568, 0x003F626C, 0x00D4DFDD, 0x00FFFDF4, 0x0080ABB4, 0x00105754, 0x00427F75, 0x00DAEBE2, 0x00DEEFE6,
        0x005A968E, 0x003D8383, 0x00B1DBE8, 0x00F2F1DC, 0x00D0EBE7, 0x002F6E76, 0x000E5858, 0x009CC3B4, 0x00E2EBD6, 0x00B3CFC2, 0x00226966, 0x002E6973, 0x00B4CFCC, 0x00FBFFF6, 0x00A4BFBB, 0x00428895, 0x000B667B, 0x00165C69, 0x007DA3A3, 0x00317171,
        0x00145458, 0x001A5B64, 0x00155867, 0x00115667, 0x0010586A, 0x00186373, 0x00105B69, 0x00175A6F, 0x0014576C, 0x0011566A, 0x0013586C, 0x0012596D, 0x0011586C, 0x0011586C, 0x000B5468, 0x000E536E, 0x000F546F, 0x00125772, 0x000D526D, 0x00115671,
        0x00125772, 0x000B506B, 0x00135873, 0x0003566B, 0x000C5B70, 0x000B526D, 0x000F5572, 0x003380A0, 0x005CB7D6, 0x0057C1E0, 0x0035A9C8, 0x0040ACDC, 0x003AA8D8, 0x0039ABDA, 0x002DA3D4, 0x002CA2D3, 0x0036A9DC, 0x0034A4D8, 0x0032A0D4, 0x002CA0D5,
        0x0033A7DC, 0x002FA3D8, 0x002EA2D7, 0x0035A9DE, 0x0032A6DB, 0x0031A5DA, 0x0035A9DE, 0x0032A6DB, 0x002DA1D6, 0x002CA0D5, 0x0032A6DB, 0x0035A9DE, 0x0034A8DD, 0x0031A5DA, 0x0031A5DA, 0x0033AAD7, 0x003AB1DE, 0x0034ACDA, 0x0031A9D7, 0x0032ACDA,
        0x002DA6D7, 0x002AA6D6, 0x0031ADDD, 0x0031A7E2, 0x0030A6E1, 0x0032A8E3, 0x0034A8E3, 0x0032A4E0, 0x0036A8E4, 0x0038A8E4, 0x0030A0DC, 0x00299DC6, 0x002090BA, 0x00218CB2, 0x002485A9, 0x00005A7C, 0x0000405F, 0x00186481, 0x004089A5, 0x000B4A5E,
        0x0009485C, 0x00064559, 0x00044357, 0x00044357, 0x00054458, 0x0007465A, 0x0009485C, 0x000B4D5F, 0x00084D5E, 0x00085062, 0x000B5468, 0x000B566C, 0x000D536B, 0x000F526D, 0x00155371, 0x000E5765, 0x00105663, 0x00195866, 0x001D5969, 0x00115366,
        0x00004C63, 0x003990AB, 0x001F7C9D, 0x0037737F, 0x00ACE3E6, 0x00D6FFFF, 0x00D5FFF2, 0x00D7FFFA, 0x00C0F9F8, 0x00448594, 0x002B758F, 0x00399BB9, 0x00005974, 0x0007556C, 0x0013586C, 0x00145668, 0x000D5263, 0x00095464, 0x00065667, 0x000D516E,
        0x00095474, 0x000D5378, 0x000F4F72, 0x0004516B, 0x0003656D, 0x0017716B, 0x005FA497, 0x00383B32, 0x00000400, 0x001A1E13, 0x0034382C, 0x003F4435, 0x00414736, 0x003D4330, 0x00393F2C, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFCFCFC, 0xFFFEFDFF, 0xFFFDFCFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00606655, 0x00384137, 0x0014180D, 0x00282419, 0x005B564D, 0x001A2218, 0x0033544D, 0x003F7A72, 0x001E6B64, 0x00205C72, 0x001D596F, 0x00246076, 0x0028647A, 0x00215D73,
        0x001C586E, 0x001D596F, 0x001B576D, 0x0016535D, 0x001C5761, 0x001D5461, 0x001E5360, 0x00255A67, 0x00235A69, 0x001F5867, 0x00205B6A, 0x00155161, 0x001A5666, 0x001D5969, 0x001C5868, 0x001B5767, 0x001C5868, 0x001B5767, 0x00185464, 0x003283A6,
        0x0056A7CC, 0x00045578, 0x00145E76, 0x000D525C, 0x007BC4CC, 0x004198A8, 0x00005770, 0x004A97B7, 0x00298199, 0x00005465, 0x00014758, 0x00235365, 0x001C4D63, 0x00004F64, 0x002B98AD, 0x00075972, 0x00085062, 0x0019545E, 0x002C5B5F, 0x00204A4F,
        0x0015424D, 0x001C4A5B, 0x00124458, 0x00184D61, 0x001D5064, 0x006291A6, 0x00B1D5E5, 0x00596F74, 0x009CA598, 0x00FCF7D8, 0x00E2D4AA, 0x00B09E6F, 0x00E9DAA2, 0x00ECE1A3, 0x00BCB27C, 0x00B1A680, 0x00FFF7DC, 0x00D3CEB5, 0x00979478, 0x00BFE4DC,
        0x005E9FA0, 0x0002505D, 0x00295C6C, 0x004B6167, 0x00858F89, 0x00D3D4CA, 0x00E7DED5, 0x00979E89, 0x00616D61, 0x00899B94, 0x00D7E7DC, 0x00CDD6C2, 0x00868B76, 0x005F6A5A, 0x00ABBCB3, 0x00DCE8D6, 0x00BCC8B6, 0x00616D5B, 0x0065715F, 0x00B3BFAD,
        0x00D4E0CE, 0x00A0AC9A, 0x0064705E, 0x007E887C, 0x00CEDBCD, 0x00C1D0BB, 0x0097B09C, 0x00417477, 0x00095671, 0x00024B5F, 0x00447B78, 0x00DFEFE8, 0x00FFFCFF, 0x00F0F1ED, 0x00C6CDB8, 0x00E0E7D8, 0x00567F81, 0x0017535F, 0x00AAC8D3, 0x00F1FDFF,
        0x00FBFEFF, 0x00F5F3F2, 0x00F6FFFC, 0x00789D99, 0x001B575D, 0x001A6175, 0x0009516F, 0x00055D6E, 0x00105467, 0x002D4C6D, 0x00165373, 0x001F5762, 0x00747865, 0x00BEBEA0, 0x00EBE2CE, 0x00929E92, 0x004C6855, 0x00698169, 0x00D8D8C0, 0x00DDDDC5,
        0x00869E86, 0x00839F8C, 0x00939F93, 0x00E0DBCC, 0x00BBCFBC, 0x005C836D, 0x004A6652, 0x00AAAB9B, 0x00F2E9DB, 0x00B7C1B0, 0x006D917B, 0x00557654, 0x00B2C9B3, 0x00E0DCCA, 0x00A59A7E, 0x003F5F40, 0x00398776, 0x0095D1CB, 0x008A918C, 0x0025606F,
        0x00215C6B, 0x001C5766, 0x001B5665, 0x001B5866, 0x001E5B69, 0x001E5D6B, 0x00205F6D, 0x00165B6C, 0x00155A6B, 0x0014596A, 0x0014596A, 0x00155A6B, 0x00155A6B, 0x00135869, 0x00115667, 0x00125768, 0x00135869, 0x00155A6B, 0x00175C6D, 0x00165B6C,
        0x00155A6B, 0x00125768, 0x00105566, 0x001C5C6E, 0x00105467, 0x00064E66, 0x003685A0, 0x0060B5D5, 0x0054AFD4, 0x004CACD4, 0x0048A9D5, 0x0054ABD7, 0x004BB2DF, 0x00289ECD, 0x00229ACE, 0x0038A9E2, 0x00329ED8, 0x002599D2, 0x0023A1D8, 0x0027A0D1,
        0x002DA3D6, 0x0038ACE1, 0x002B9CD4, 0x002FA1D6, 0x002EA3D6, 0x002CA4D2, 0x002AA6CF, 0x002B9DCC, 0x003FAAE4, 0x002A92D5, 0x0034A2E2, 0x002EA7D9, 0x0031AAD6, 0x0036A1D4, 0x0042A3DD, 0x002DB0DC, 0x0032AFDC, 0x003FB4E1, 0x002796C4, 0x001E89B5,
        0x00218EBA, 0x001F8FBA, 0x001B8EB9, 0x002695BB, 0x002390B6, 0x002996BC, 0x00218CB2, 0x00278EB5, 0x00268BB2, 0x003496BE, 0x002C8EB6, 0x002B93C2, 0x00238CB8, 0x00117AA3, 0x00268AAD, 0x003C99B8, 0x001F748E, 0x00004259, 0x00246A81, 0x003A9CB4,
        0x00085570, 0x000C4260, 0x00184766, 0x000A4761, 0x000C5269, 0x000B5064, 0x000C485E, 0x00134F65, 0x00115169, 0x00084F6A, 0x000E5B76, 0x00004A67, 0x000A5875, 0x000F607B, 0x00085C76, 0x00005F69, 0x00035B69, 0x000D536A, 0x0016506D, 0x00215C7C,
        0x00034A6B, 0x002A809E, 0x002B8EAA, 0x003B6C76, 0x0087B4B8, 0x00DFFFFF, 0x00E3FFFF, 0x00E2FFFF, 0x00A8CDD5, 0x00426D80, 0x00477691, 0x004394AF, 0x000D5A74, 0x00075066, 0x000F5468, 0x000F5065, 0x0014546C, 0x00104F6B, 0x0011516F, 0x000C4E67,
        0x00085167, 0x0013576E, 0x00124E6B, 0x000A506E, 0x00005569, 0x001C706E, 0x0074B5A5, 0x003B3B3B, 0x00050602, 0x001D2116, 0x00434636, 0x00434734, 0x0050523F, 0x004E4F3F, 0x00424333, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFDFDFD, 0xFFFFFEFF, 0xFFFDFCFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00696F5E, 0x00424B41, 0x00161A0F, 0x00252116, 0x00555047, 0x00161E14, 0x0032534C, 0x003B766E, 0x0018655E, 0x00266076, 0x001F596F, 0x001E586E, 0x001F596F, 0x001C566C,
        0x001C566C, 0x001E586E, 0x001B556B, 0x00205B6A, 0x001D5867, 0x001D5665, 0x00245A6B, 0x002A6071, 0x00225A6D, 0x001C5669, 0x00225C6F, 0x001C576A, 0x00215C6F, 0x00235E71, 0x00205B6E, 0x001E596C, 0x001F5A6D, 0x001F5A6D, 0x001D586B, 0x00005463,
        0x00348DA2, 0x0056A9BF, 0x00185C6F, 0x00295F6A, 0x007CB0BC, 0x00306A80, 0x00054869, 0x003B8BA4, 0x0066C1D6, 0x00258194, 0x00004C5F, 0x002D5F75, 0x002B576E, 0x000E4D62, 0x003A90A4, 0x003E90B3, 0x000F536A, 0x002C636C, 0x0032636B, 0x00184D5A,
        0x001E5669, 0x001B5162, 0x001B4F5B, 0x001F5768, 0x00215768, 0x0072A2B4, 0x009CC1CF, 0x0051686A, 0x0091988B, 0x00C7BFA2, 0x00CBBA93, 0x00DAC598, 0x00FFFBC3, 0x00FEF0B5, 0x00BAAE78, 0x00CDC09A, 0x00F3E7CF, 0x00B2AD94, 0x0089866A, 0x00A3CAC2,
        0x006AABAC, 0x000B535D, 0x002E5968, 0x00677377, 0x005C6158, 0x00616357, 0x006F695E, 0x00897F6D, 0x00777368, 0x0062625C, 0x0065635B, 0x007C7463, 0x008B806C, 0x006C6556, 0x0064645E, 0x0067604F, 0x00817A69, 0x00867F6E, 0x006D6655, 0x00625B4A,
        0x00625B4A, 0x008E8776, 0x00948D7C, 0x006B665D, 0x00555348, 0x00656351, 0x007E8471, 0x00234348, 0x00154F6C, 0x00376E83, 0x00507571, 0x00FDFFF8, 0x00FFFDFE, 0x00F0EAE3, 0x00CECDB8, 0x00EEEEDC, 0x00698B8A, 0x002B6168, 0x00B2CCD2, 0x00FAFFFF,
        0x00FCF8F7, 0x00F5EFE8, 0x00D2DACF, 0x0084A59E, 0x00245D5F, 0x00064B5A, 0x001A6078, 0x000A5361, 0x002C6D7C, 0x0036607D, 0x000C5575, 0x00225D6C, 0x005F6259, 0x00575C47, 0x0045463D, 0x00595D51, 0x00646355, 0x00696350, 0x0069654D, 0x00656149,
        0x00605A47, 0x00717062, 0x00575B4F, 0x005B5445, 0x00565646, 0x00646757, 0x00666757, 0x00585344, 0x005C5345, 0x00535041, 0x00676A5A, 0x0070735D, 0x005F695D, 0x00525147, 0x005C5240, 0x005B6E5F, 0x004E9192, 0x0060ABB4, 0x003B6A72, 0x00125F7A,
        0x00115E79, 0x00105D78, 0x000F5E79, 0x0012617C, 0x0013647F, 0x00146580, 0x00146580, 0x000F6281, 0x000E6180, 0x000E6180, 0x000E6180, 0x000F6281, 0x000E6180, 0x000D607F, 0x000C5F7E, 0x000D607F, 0x000E6180, 0x000F6281, 0x00106382, 0x00106382,
        0x000E6180, 0x000D607F, 0x000B5E7D, 0x00095B74, 0x000C607A, 0x00277E99, 0x0055B0CF, 0x005BBCDE, 0x0049AED4, 0x0049B2D9, 0x0046B0D9, 0x0056B0D9, 0x003CA2CC, 0x0033A5CE, 0x0032A2D0, 0x0042ACDB, 0x0042A8D8, 0x0041ABDA, 0x0030A3D0, 0x00319CD6,
        0x0037A2DF, 0x002692D2, 0x00329FE3, 0x0038A7EB, 0x002F9FE1, 0x0031A2E1, 0x002A9BD9, 0x0028A8D9, 0x0024A1DB, 0x00229DDB, 0x002DA5E0, 0x0028A0CE, 0x002CA5D1, 0x002EA9DB, 0x0031ADE9, 0x0028A7DE, 0x002EA9E1, 0x0032A9E0, 0x0035A9E0, 0x002F9FD4,
        0x002A9ACF, 0x0030A0D5, 0x0037A7DB, 0x00279ECF, 0x002CA3D4, 0x0030A6D7, 0x0034A7D9, 0x0032A3D5, 0x0035A4D6, 0x0038A5D8, 0x002E9BCE, 0x002690BF, 0x002490BF, 0x002793BD, 0x00147FA5, 0x002D93B6, 0x003392B3, 0x00247B9B, 0x00004867, 0x00136882,
        0x004C9EB7, 0x0019637B, 0x0007475F, 0x00134C62, 0x001B5267, 0x00094457, 0x00145766, 0x001B516A, 0x000E4F64, 0x00095666, 0x00085D65, 0x0059AAAF, 0x0071B4B7, 0x0095C5C9, 0x009FC3C9, 0x0082B9C0, 0x005D95A0, 0x00336E7E, 0x000E4D62, 0x000E546C,
        0x0007516D, 0x00126281, 0x004FA1C0, 0x002D7286, 0x003F778A, 0x008AB1BF, 0x00B7D1DF, 0x0094AEBE, 0x004E758B, 0x002D6483, 0x00498DB0, 0x00297893, 0x0007546E, 0x000B546A, 0x00105368, 0x00105166, 0x0016566E, 0x00104F6B, 0x000D4D6B, 0x0012546D,
        0x00075066, 0x000F536A, 0x00124E6B, 0x000E5472, 0x0000576B, 0x00126664, 0x00599A8A, 0x00282828, 0x00000100, 0x0021251A, 0x00494C3C, 0x00464A37, 0x004E503D, 0x004E4F3F, 0x00444535, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFDFDFD, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00727867, 0x003C453B, 0x00101409, 0x00221E13, 0x00575249, 0x001E261C, 0x003B5C55, 0x003E7971, 0x0017645D, 0x00215B71, 0x001D576D, 0x001D576D, 0x001E586E, 0x001E586E,
        0x00225C72, 0x00255F75, 0x00225C72, 0x001F596C, 0x00225C6F, 0x001F586D, 0x001E576C, 0x00225B70, 0x00215A70, 0x001B546A, 0x00175066, 0x001B556B, 0x00215B71, 0x00255F75, 0x00215B71, 0x001C566C, 0x001C566C, 0x001F596F, 0x00215B71, 0x00358180,
        0x00529DA5, 0x005397A4, 0x0072A7B4, 0x0094BEC5, 0x0085A9B3, 0x00275164, 0x00598BA9, 0x005DA4B8, 0x0023798D, 0x003B98AD, 0x003989A0, 0x000F4661, 0x002D566F, 0x002A5B71, 0x00185366, 0x004395BF, 0x00377F9D, 0x001E5C6E, 0x00195565, 0x001A5B70,
        0x0013536B, 0x00195467, 0x00265B65, 0x001A5564, 0x0017505F, 0x006DA1AE, 0x00B1D8E1, 0x004C6464, 0x00979E91, 0x00C3BA9F, 0x00B6A380, 0x00BBA57C, 0x00F3E0AD, 0x00E6D59C, 0x00D7C695, 0x00EFDEBD, 0x00BEB29A, 0x00848068, 0x00535538, 0x00739C94,
        0x00549494, 0x00094A53, 0x002A4A55, 0x005F6161, 0x0019170C, 0x00080900, 0x00323222, 0x007B6C59, 0x005E5649, 0x00130F0A, 0x000B0400, 0x00544836, 0x008E806A, 0x00594E40, 0x000D0700, 0x001B1100, 0x00615746, 0x008E8473, 0x00433928, 0x00130900,
        0x00211706, 0x007E7463, 0x00877D6C, 0x002F2720, 0x00090200, 0x003F3726, 0x0070705E, 0x00233E42, 0x005386A0, 0x0082B6C7, 0x0063857E, 0x00E5EFDE, 0x00FFFFFB, 0x00E1EADD, 0x00B5C3A7, 0x00E5F2DA, 0x0074A198, 0x00397A78, 0x00B8E1DA, 0x00FCFDF9,
        0x00FFFFF9, 0x00F5E9DD, 0x00D7DACA, 0x0099B5A8, 0x00205651, 0x001D5E67, 0x000C5063, 0x003D7685, 0x006DB0BF, 0x007AB4D1, 0x0049A2C4, 0x004D8CA0, 0x00514F4F, 0x00121A10, 0x00000505, 0x0032392A, 0x00857467, 0x006F5B4A, 0x000F1100, 0x000C0E00,
        0x00554130, 0x007A695C, 0x003A4132, 0x000E0F00, 0x00180F01, 0x0068574A, 0x007D7062, 0x00322F20, 0x00080900, 0x001B1607, 0x00706053, 0x00775D4F, 0x00292621, 0x000A0905, 0x003B2F25, 0x00596160, 0x002F6E82, 0x002B88A7, 0x003390AA, 0x003193BD,
        0x003094BE, 0x003397C1, 0x00369AC4, 0x00379DC7, 0x00389EC8, 0x00359EC7, 0x00339CC5, 0x00339AC7, 0x00349BC8, 0x00359CC9, 0x00349BC8, 0x00349BC8, 0x00339AC7, 0x003299C6, 0x00339AC7, 0x002E95C2, 0x002F96C3, 0x002F96C3, 0x003097C4, 0x002F96C3,
        0x002F96C3, 0x002E95C2, 0x002D94C1, 0x003096B9, 0x002C92B5, 0x0043ABCE, 0x0052BCE1, 0x003EA9CE, 0x003AA7CD, 0x0048B7DD, 0x0040B2D7, 0x0044A7D3, 0x0039A2CB, 0x004AB7DD, 0x0043ABD0, 0x003595B9, 0x002A86A9, 0x003495B6, 0x003196B6, 0x0051AABF,
        0x0049A6BF, 0x0048ABC9, 0x0036A1C2, 0x001987AB, 0x002B99BD, 0x002692B4, 0x002E96B9, 0x002F96AF, 0x00208DA9, 0x00349FBB, 0x0047A4BB, 0x005AA8B8, 0x005FB0BF, 0x0046AAC2, 0x001D94B4, 0x0033AAE8, 0x003EB5F3, 0x002AA4E0, 0x002AA2DE, 0x002DA3DE,
        0x0032A4E0, 0x003AA8E2, 0x00339FD9, 0x002AA8DE, 0x002DA9DF, 0x00239FD5, 0x0030AAE0, 0x002EA8DE, 0x002FA6DD, 0x00259CD3, 0x001388BF, 0x000F7CA8, 0x001885B1, 0x002B9BC6, 0x001C8CB6, 0x001583AD, 0x00208AB3, 0x003397C1, 0x000F719B, 0x00004464,
        0x001B748F, 0x003595AC, 0x0014677D, 0x000E485E, 0x001F4C61, 0x00255B6C, 0x000C525F, 0x000F556D, 0x000A4C5E, 0x004D8D91, 0x0098D4CA, 0x0099CBB9, 0x00B9D9C6, 0x00EAF8E6, 0x00F7F8E8, 0x00FAFCFD, 0x00E8F7FA, 0x00B9DEE2, 0x00629BA4, 0x0014596A,
        0x00004A62, 0x00074F6D, 0x003E83A4, 0x00449EBD, 0x002C7492, 0x00326180, 0x00476582, 0x00395877, 0x0038688C, 0x00468EB6, 0x003692BD, 0x000E5B76, 0x00044F69, 0x000F556C, 0x000E5166, 0x000F5065, 0x0016566E, 0x000E4F6B, 0x000C4E6B, 0x0014566F,
        0x00075066, 0x000C5067, 0x00114D6A, 0x00105674, 0x00035A6E, 0x00106462, 0x004B8C7C, 0x001C1C1C, 0x00000100, 0x0021251A, 0x004B4E3E, 0x00484C39, 0x004E503D, 0x004E4F3F, 0x00434434, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFDFDFD, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00727867, 0x00394238, 0x000C1005, 0x00221E13, 0x0058534A, 0x0021291F, 0x0041625B, 0x00427D75, 0x001C6962, 0x001E586E, 0x001F596F, 0x001F596F, 0x001D576D, 0x001B556B,
        0x001D576D, 0x001F596F, 0x001E586E, 0x00255B72, 0x00225B71, 0x001D566F, 0x001A566E, 0x001E5973, 0x00235B76, 0x00235A75, 0x00235775, 0x00215A73, 0x001F5871, 0x001D566F, 0x001E5770, 0x00225B74, 0x00235C75, 0x00205972, 0x001C556E, 0x00A3D3D4,
        0x00AFE0E8, 0x008DBECC, 0x007BA3AF, 0x00618285, 0x00638382, 0x0087AFB4, 0x007CADBB, 0x001C5467, 0x00054A5E, 0x000D6076, 0x0055A4BF, 0x0061A0BC, 0x006392AD, 0x0075A3B5, 0x00689CA9, 0x004798B9, 0x006AC0E4, 0x003088AD, 0x00045576, 0x0013576E,
        0x001B5666, 0x00275D6E, 0x00265B70, 0x002A6574, 0x001D5763, 0x004C808C, 0x00C8F4FB, 0x0043605D, 0x007D877B, 0x00D2CBB7, 0x00B3A287, 0x00D4C1A0, 0x00CBBA8F, 0x00E2D1A0, 0x00E2D1A6, 0x00E2D2B5, 0x00BFB5A3, 0x006C6D59, 0x00424B31, 0x0066928B,
        0x00337171, 0x00114A53, 0x003D525A, 0x00675E5B, 0x00201807, 0x00111200, 0x003A3B2B, 0x0087836B, 0x00545446, 0x000B1007, 0x00101408, 0x0056533E, 0x007F7962, 0x004A4836, 0x000F150A, 0x00201E0C, 0x00747260, 0x00989684, 0x00464432, 0x00181604,
        0x002C2A18, 0x00767462, 0x007D7B69, 0x002B2E25, 0x000F1308, 0x00383A27, 0x00646D59, 0x00214447, 0x002B6B83, 0x003A7D8C, 0x003D7167, 0x00FDFFEE, 0x00F5EFE8, 0x00BAC4B8, 0x00A5B499, 0x00E9F1DA, 0x0061867C, 0x00215D57, 0x00C4E8DC, 0x00FDFFFB,
        0x00F5F0E7, 0x00E7DED0, 0x00E3E7D4, 0x00A0BDAE, 0x00235952, 0x00185961, 0x002E7082, 0x008CC3DE, 0x0085D1E8, 0x0069B6D7, 0x003DA5CA, 0x004E91A8, 0x00595152, 0x001E1F15, 0x0004110F, 0x00343D29, 0x00797563, 0x005D5744, 0x00080F00, 0x000D1400,
        0x004D4734, 0x006F6B59, 0x003C4531, 0x000D1504, 0x00181808, 0x004D4839, 0x005F5C4D, 0x002C3221, 0x000C1403, 0x00181B0B, 0x00625D4E, 0x00806D58, 0x0028261C, 0x000F0700, 0x003E2A1F, 0x00565E5E, 0x001E667E, 0x000D79A2, 0x002993BC, 0x002897C7,
        0x002C9BCB, 0x002D9FCE, 0x002EA0CF, 0x002DA1D0, 0x002DA1D0, 0x002A9ECD, 0x00249AC9, 0x002B9CCE, 0x002C9DCF, 0x002E9FD1, 0x002E9FD1, 0x002C9DCF, 0x002B9CCE, 0x002C9DCF, 0x002D9ED0, 0x002E9FD1, 0x002E9FD1, 0x002D9ED0, 0x002D9ED0, 0x002D9ED0,
        0x002C9DCF, 0x002C9DCF, 0x002C9DCF, 0x00309FCD, 0x002998C6, 0x0035A2CE, 0x0038A6D0, 0x0036A2CC, 0x0042AED7, 0x0045B2D8, 0x0038A3C9, 0x0032A1D3, 0x0048B4E3, 0x0044AAD4, 0x001B799C, 0x00004D6B, 0x00025771, 0x003087A1, 0x003A97AE, 0x0092B7AF,
        0x0078A6A0, 0x007EB7B8, 0x0063A7AC, 0x0019606A, 0x00155B68, 0x000D4C5A, 0x00114D59, 0x00034B5C, 0x00237384, 0x004A9CA8, 0x00659FA4, 0x0088AAA9, 0x0086ACAC, 0x0059A0AA, 0x001C8396, 0x001B85BA, 0x0039A7DB, 0x003AAFE2, 0x002CA3D4, 0x002DA4D5,
        0x002C9ECD, 0x003AA3D4, 0x003CA2D3, 0x002DA0CD, 0x0034A7D4, 0x0033A6D3, 0x0032A5D2, 0x002C9FCC, 0x001585B3, 0x002191BF, 0x001A8AB8, 0x00258AB1, 0x001982A9, 0x001985AE, 0x002D9CC4, 0x001F8FB9, 0x001D8AB6, 0x001C87B3, 0x00329AC9, 0x001F7599,
        0x00004667, 0x00086A88, 0x0046A1BC, 0x00105A74, 0x00125068, 0x00145368, 0x0014586B, 0x00004554, 0x005B9CA5, 0x00BCDBDA, 0x007F8679, 0x007A7964, 0x00D5D3BB, 0x00FDFCE7, 0x00FFFFF1, 0x00FDE6DE, 0x00FBEDE7, 0x00F7FDF8, 0x00DEFAFB, 0x0078A7AF,
        0x00195769, 0x000B526D, 0x00115A7A, 0x00338FB2, 0x0050A1C2, 0x005B9CBB, 0x00578EAD, 0x00518AAA, 0x005195B8, 0x00388BB1, 0x00005B83, 0x00054F6B, 0x00074E69, 0x0010546B, 0x000D4E63, 0x00115065, 0x0015556D, 0x000E4F6B, 0x000F516E, 0x0010526B,
        0x00075066, 0x000E5269, 0x00134F6C, 0x000D5371, 0x00045B6F, 0x001A6E6C, 0x00519282, 0x001E1E1E, 0x00000100, 0x001F2318, 0x00474A3A, 0x00474B38, 0x004E503D, 0x004E4F3F, 0x00404131, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFCFCFC, 0xFFFEFDFF, 0xFFFDFCFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x006C7261, 0x00424B41, 0x0011150A, 0x00242015, 0x00534E45, 0x00182016, 0x003A5B54, 0x003E7971, 0x001E6B64, 0x00245D73, 0x00235C72, 0x001F586E, 0x001D566C, 0x001F586E,
        0x00215A70, 0x00225B71, 0x00235C72, 0x001F556E, 0x00164F68, 0x0015526C, 0x001C5E77, 0x001C5D79, 0x00195572, 0x001A526F, 0x00205373, 0x001E5770, 0x001F5871, 0x00205972, 0x00205972, 0x001E5770, 0x001C556E, 0x001B546D, 0x001B546D, 0x00396D74,
        0x00295D6D, 0x0033667A, 0x00729CA9, 0x005C7B7A, 0x0096ADA5, 0x0099B4AB, 0x00668783, 0x003B6578, 0x0021586D, 0x00003E57, 0x00125974, 0x005091AD, 0x007EB8CE, 0x0076AEBF, 0x006CA8B4, 0x0057A4B4, 0x0053B2D9, 0x004BBAF2, 0x001579A9, 0x00004860,
        0x00255862, 0x002A586A, 0x00174B6F, 0x001D5566, 0x001F5867, 0x002B616C, 0x00BDEDF3, 0x008DAFAE, 0x00596B64, 0x008A8D7E, 0x008E8776, 0x00E3D7BF, 0x00D6CAA8, 0x00C9BD95, 0x00C9BB97, 0x007F745E, 0x00626153, 0x004B5848, 0x0029402A, 0x00588281,
        0x000B484C, 0x00013841, 0x0033464B, 0x007A6E68, 0x007C7260, 0x006E6F5B, 0x006A6D5D, 0x0088836A, 0x00787868, 0x0065695E, 0x005F6253, 0x00736F57, 0x00908970, 0x00797562, 0x00696D61, 0x006D6956, 0x0084806D, 0x008D8976, 0x008A8673, 0x007E7A67,
        0x00807C69, 0x008C8875, 0x00938F7C, 0x0083877C, 0x0076786C, 0x00737361, 0x00737968, 0x002D5157, 0x00276B88, 0x00216D80, 0x00326F6B, 0x00F5F3E8, 0x00B6AEAF, 0x008D9896, 0x00AFBCAC, 0x00FAFAEE, 0x006B8081, 0x002D5958, 0x00D6EEE6, 0x00DBF0ED,
        0x00C9D5CF, 0x00BBC1B6, 0x00E1F2E4, 0x0088B0A4, 0x00114D4C, 0x002D717E, 0x007EC4DB, 0x0086CCF4, 0x006AC3E5, 0x004CA2CC, 0x001F8BB4, 0x0033738B, 0x006C605C, 0x00645E4B, 0x00515347, 0x00655C48, 0x006C715C, 0x005A5F4A, 0x00504938, 0x00554E3D,
        0x004E533E, 0x00606550, 0x0059503C, 0x00463F30, 0x004C4D3D, 0x005B6150, 0x00676A5A, 0x00555041, 0x004A4334, 0x00484838, 0x00626857, 0x00666B4B, 0x00404530, 0x00504230, 0x00674F3B, 0x005B6B64, 0x0023768B, 0x001482AC, 0x002D8BB9, 0x002E9ECC,
        0x0033A3D1, 0x0033A6D3, 0x0032A5D2, 0x002FA4D1, 0x002FA4D1, 0x002DA2CF, 0x00269DCA, 0x002FA2CF, 0x0030A3D0, 0x0032A5D2, 0x0032A5D2, 0x0031A4D1, 0x0030A3D0, 0x0030A3D0, 0x0031A4D1, 0x002FA2CF, 0x002EA1CE, 0x002DA0CD, 0x002DA0CD, 0x002C9FCC,
        0x002DA0CD, 0x002DA0CD, 0x002DA0CD, 0x00309DD1, 0x00309DD0, 0x00339ED1, 0x003BA4D5, 0x004AB1DE, 0x004DB3DE, 0x0044A8D2, 0x0044A6D0, 0x0039AFE3, 0x003FABDB, 0x001E7AA3, 0x00004F70, 0x00004A64, 0x00247086, 0x004897AC, 0x0019687D, 0x00254B4F,
        0x0017474D, 0x00195561, 0x00468C9D, 0x002A758B, 0x0000475F, 0x0014566F, 0x0015536B, 0x000D5773, 0x00378BA7, 0x00237790, 0x000E4C5E, 0x00153B47, 0x001F4654, 0x001F687E, 0x002A93B4, 0x00025C7A, 0x001D7B98, 0x003498B4, 0x00339DB5, 0x0038A2BA,
        0x001F839B, 0x00036079, 0x0009637C, 0x000B647F, 0x000C6580, 0x00136C87, 0x00126B86, 0x002B849F, 0x0007627D, 0x0027829D, 0x001F7A95, 0x003488A4, 0x00207792, 0x0024809D, 0x001D7F9D, 0x003496B8, 0x002A8BAF, 0x001C7DA3, 0x002C8BB2, 0x003B99BC,
        0x001B7294, 0x00005174, 0x00146586, 0x004098B6, 0x00025974, 0x00115B77, 0x00104E6C, 0x00347F88, 0x00B7E4E8, 0x00848987, 0x00A6938B, 0x00EFDCCD, 0x00FDF2E4, 0x00F2EBE2, 0x00BBB2AE, 0x00F2DFD0, 0x00E5D2C3, 0x00D7C7BB, 0x00EEE8E3, 0x00E1F0F3,
        0x005A8693, 0x00084E65, 0x00005873, 0x00004C69, 0x001F6E89, 0x00388AA3, 0x003B91A7, 0x00368CA4, 0x001D728C, 0x0000536F, 0x00004C6B, 0x000A506D, 0x000B506B, 0x0010536A, 0x00125166, 0x00155469, 0x0014546C, 0x000C4F6A, 0x000E526F, 0x000F516A,
        0x00095268, 0x0010546B, 0x0014506D, 0x000A506E, 0x00045B6F, 0x001E7270, 0x004E8F7F, 0x001B1B1B, 0x00030400, 0x0021251A, 0x00464939, 0x00464A37, 0x004C4E3B, 0x004F5040, 0x00404131, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFCFCFC, 0xFFFEFDFF, 0xFFFDFCFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00666C5B, 0x00414A40, 0x000E1207, 0x00242015, 0x00514C43, 0x00171F15, 0x003A5B54, 0x003A756D, 0x001A6760, 0x00235C72, 0x00215A70, 0x001D566C, 0x0020596F, 0x00255E74,
        0x00235C72, 0x00215A70, 0x00245D73, 0x00235670, 0x00215A73, 0x001D5D75, 0x00125870, 0x000D536B, 0x00175672, 0x00235B78, 0x00255775, 0x00235D73, 0x00205A70, 0x001E586E, 0x001F596F, 0x00205A70, 0x001D576D, 0x001A546A, 0x001A546A, 0x000D5A63,
        0x000E5A6C, 0x00084E66, 0x001D5162, 0x0094B3B6, 0x006E7E77, 0x00707B71, 0x00BCCAC4, 0x006291A7, 0x00184A60, 0x00276076, 0x00104C64, 0x00266278, 0x008FCCE0, 0x0070B3C2, 0x005197A4, 0x005CA0A7, 0x003993B2, 0x004DBDF2, 0x0057C4F8, 0x00388BAA,
        0x00286474, 0x0024596E, 0x0023597C, 0x0021566B, 0x00265E71, 0x00134A57, 0x006CA2A9, 0x00D1FCFF, 0x005D7C79, 0x0034433F, 0x00616962, 0x00706F61, 0x006E6C54, 0x00A9A386, 0x00B6AF96, 0x00595648, 0x00424C46, 0x00254037, 0x00446B5B, 0x00325961,
        0x00033E47, 0x00043C47, 0x002F4348, 0x007E746D, 0x00ABA18F, 0x00A2A290, 0x009B9B8D, 0x0095846A, 0x00988B7B, 0x00978E84, 0x008F8476, 0x009D8C77, 0x00C5B198, 0x00AE9F8C, 0x00978F82, 0x00A29281, 0x008F7F6E, 0x00958574, 0x00BCAC9B, 0x00B7A796,
        0x00B6A695, 0x00B4A493, 0x00B6A695, 0x00999083, 0x009B9285, 0x00978878, 0x00787267, 0x002C4755, 0x004D8BB3, 0x004893B3, 0x001B5C64, 0x00668F8A, 0x00628C93, 0x0079B7BD, 0x005A968E, 0x006D9290, 0x00356B72, 0x00105A60, 0x00528A85, 0x0083B6B9,
        0x0080A7A9, 0x00698885, 0x008CB0AA, 0x003C7272, 0x00256C76, 0x0077C3DA, 0x0085D2F3, 0x0060B9E5, 0x0050AFD6, 0x0053A4D1, 0x00349AC4, 0x0038798E, 0x00726960, 0x00837C63, 0x00827B6A, 0x008C6E5B, 0x007B7661, 0x00706E5C, 0x00856D61, 0x00866E62,
        0x005E5C4A, 0x006E6954, 0x007C5E4B, 0x007D675B, 0x0074695B, 0x00807D6E, 0x009A9384, 0x008B786B, 0x00836B5F, 0x007A6A5D, 0x00736E5F, 0x005F6B47, 0x00626D53, 0x008C816B, 0x008B755C, 0x0055695C, 0x0014687A, 0x00157BA6, 0x003687BA, 0x002997C1,
        0x002F9DC7, 0x00319FC9, 0x002C9CC6, 0x002C9CC6, 0x002D9FC8, 0x002C9EC7, 0x00289AC3, 0x002C9DC8, 0x002D9EC9, 0x002E9FCA, 0x002FA0CB, 0x002E9FCA, 0x002E9FCA, 0x002E9FCA, 0x002E9FCA, 0x0032A3CE, 0x0031A2CD, 0x0031A2CD, 0x0030A1CC, 0x0030A1CC,
        0x0030A1CC, 0x0030A1CC, 0x0030A1CC, 0x00329FD2, 0x0037A2D5, 0x00329BCE, 0x00379ECF, 0x003EA4D4, 0x003799C7, 0x003A9AC8, 0x0050B0DE, 0x003FAFDA, 0x00207DA4, 0x00256D8B, 0x00245D72, 0x00407A86, 0x00417E88, 0x006EABB7, 0x002B6876, 0x0041787B,
        0x002C686E, 0x00337882, 0x00408B9B, 0x004F9DAE, 0x001B6779, 0x00256F81, 0x002F7586, 0x00296E78, 0x0058A1AF, 0x003C8391, 0x00427D86, 0x00436F70, 0x004C7B79, 0x0033747C, 0x005EB4C6, 0x00286C73, 0x00397F86, 0x00287175, 0x00368084, 0x003E888C,
        0x0056A1A3, 0x002D7477, 0x003C8386, 0x00397379, 0x00336D73, 0x002B676D, 0x00347076, 0x00609EA4, 0x00458389, 0x005C9CA1, 0x00408085, 0x005C97A6, 0x003E7B89, 0x0064A7B6, 0x00236C7A, 0x0059A4B4, 0x00388294, 0x0059A1B3, 0x003C8397, 0x0051A3B5,
        0x005FA2B9, 0x00487E97, 0x0027647E, 0x004C9EB7, 0x003491A8, 0x00065A74, 0x000C506D, 0x009BC4C7, 0x00C3D5D6, 0x00B6B1B0, 0x00FEF4ED, 0x00FFFFF7, 0x00FDFFF9, 0x00AEA9A6, 0x00887578, 0x00BEC0AD, 0x00FFFAE8, 0x00E9D4C5, 0x00A48D85, 0x00D4CFCE,
        0x00AECBD4, 0x00155A6B, 0x0000586F, 0x001C5A72, 0x00074D64, 0x00004F64, 0x00004E5F, 0x00005262, 0x00005163, 0x00014D60, 0x001A5D72, 0x000E526F, 0x000F506C, 0x0012526A, 0x0017566B, 0x0019586D, 0x0014546C, 0x000C4F6A, 0x000A4E6B, 0x0011536C,
        0x00095268, 0x000F536A, 0x0014506D, 0x00094F6D, 0x00045B6F, 0x001A6E6C, 0x003A7B6B, 0x000F0F0F, 0x00030400, 0x0024281D, 0x00494C3C, 0x00464A37, 0x004A4C39, 0x00505141, 0x00434434, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFDFDFD, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00686E5D, 0x003C453B, 0x00080C01, 0x00221E13, 0x00544F46, 0x001F271D, 0x0044655E, 0x003E7971, 0x0019665F, 0x00245A71, 0x00235970, 0x0020566D, 0x0021576E, 0x0022586F,
        0x0020566D, 0x00295F76, 0x003D738A, 0x006397AE, 0x005C96AC, 0x004A8DA2, 0x002A758B, 0x00125D73, 0x00175972, 0x00245C77, 0x00265874, 0x001F5A6D, 0x00256073, 0x002B6679, 0x00296477, 0x00205B6E, 0x001C576A, 0x00256073, 0x00326D80, 0x001B646C,
        0x000F5B6D, 0x00115B75, 0x0018546A, 0x002D5B63, 0x006C8C8B, 0x0086A5A2, 0x004D6C6D, 0x000D5168, 0x00135267, 0x001A5166, 0x001E5062, 0x00265A6B, 0x002B6676, 0x00064B5C, 0x00044E60, 0x00154B5C, 0x001F6279, 0x00398EAE, 0x0058BCE6, 0x0049B0DD,
        0x001C79A0, 0x00135C78, 0x00245E71, 0x00285773, 0x00295D74, 0x001A5263, 0x00316974, 0x00A7DBE1, 0x008FBABD, 0x00436265, 0x00395052, 0x0048514E, 0x0041483B, 0x00545642, 0x00777868, 0x00454C47, 0x0024393A, 0x002D5553, 0x00356D62, 0x00123543,
        0x00053E4D, 0x00104958, 0x004A646A, 0x006D6A62, 0x005A5342, 0x00464636, 0x00636157, 0x0096876D, 0x00786E5C, 0x00433D30, 0x003F3829, 0x00756750, 0x00A7967B, 0x007E715B, 0x00423C2F, 0x004B3D2A, 0x00766855, 0x00A0927F, 0x00827461, 0x004F412E,
        0x005B4D3A, 0x00918370, 0x00A89A87, 0x005F5648, 0x00494032, 0x00605343, 0x0077756D, 0x0025465A, 0x002672A2, 0x002C85B1, 0x0002556A, 0x00004345, 0x00287D8D, 0x0071D9E8, 0x00107377, 0x000B4E57, 0x004794A7, 0x004DAEBC, 0x003F8E91, 0x004492A2,
        0x001C5E69, 0x00235A61, 0x001A5158, 0x001E656F, 0x006CBFD5, 0x007FD4FA, 0x005FB1E1, 0x005FC6E6, 0x00419CBB, 0x004282AB, 0x003C93BB, 0x0046889B, 0x005B5C53, 0x00484530, 0x003F3629, 0x0069553C, 0x00867963, 0x006E6655, 0x004A3F31, 0x004D4234,
        0x005C5443, 0x007B6E58, 0x0069553C, 0x00494233, 0x00483D2F, 0x0078675A, 0x00968679, 0x00686152, 0x004D4839, 0x004F4638, 0x006E5E51, 0x007D7159, 0x004A503F, 0x00474936, 0x005C4F39, 0x0058655D, 0x002A6C85, 0x001B77AA, 0x002A81B9, 0x002995C5,
        0x00319DCD, 0x0034A0D0, 0x002E9CCC, 0x002E9CCC, 0x00309FCF, 0x00309FCF, 0x002B9ACA, 0x002C9FCC, 0x002C9FCC, 0x002C9FCC, 0x002DA0CD, 0x002EA1CE, 0x002FA2CF, 0x002EA1CE, 0x002DA0CD, 0x002C9FCC, 0x002C9FCC, 0x002C9FCC, 0x002C9FCC, 0x002C9FCC,
        0x002C9FCC, 0x002B9ECB, 0x002B9ECB, 0x00289BC8, 0x0030A3D0, 0x002F9FCD, 0x0035A5D3, 0x0037A6D4, 0x0039A5D4, 0x0046B0DF, 0x0042ACDB, 0x001B7990, 0x001B6375, 0x0096C1CA, 0x007F9E9D, 0x00A9CAC3, 0x0060877F, 0x00A0C9C4, 0x00729A99, 0x00B1C5B9,
        0x00849990, 0x00B0C6C1, 0x007E9492, 0x00A1B9B7, 0x0088A39F, 0x008CA8A2, 0x0093B0A7, 0x0082AC9B, 0x0097BEB6, 0x00779C98, 0x0096B8B1, 0x0082A591, 0x00A4C8B2, 0x006B9080, 0x00A6CAC4, 0x00608984, 0x009CC5C0, 0x0069918C, 0x0094BAB4, 0x00628B84,
        0x00A0CBC2, 0x00629188, 0x0085B7AD, 0x007A9B97, 0x0092B3AF, 0x007EA19D, 0x0081A6A2, 0x0086AEA9, 0x00739C97, 0x0081ADA7, 0x0069958F, 0x00A1C3C3, 0x006C9090, 0x0097C1C0, 0x004C7B79, 0x0090C2BE, 0x00548380, 0x0098C5C2, 0x00588380, 0x009BC6C3,
        0x005A817F, 0x009EC4C6, 0x005E888F, 0x0085BCC5, 0x004A8E9B, 0x00085764, 0x00217483, 0x00CEF4EE, 0x00ADBBB7, 0x00EEE5E2, 0x00FFFAF3, 0x00EEF8EC, 0x00BCCFC0, 0x00A8B3A3, 0x009F998C, 0x00718170, 0x00D5D8C8, 0x00E0D3C3, 0x00827164, 0x00928E89,
        0x00E2FBFF, 0x00467F8E, 0x00024E64, 0x00175069, 0x00114E68, 0x0013566F, 0x0008526A, 0x00044E66, 0x00115A70, 0x0014576C, 0x000F4E62, 0x000F4F6D, 0x0011506C, 0x0015536B, 0x0018546A, 0x00145368, 0x00115169, 0x000C516C, 0x00074D6A, 0x0011536C,
        0x00085167, 0x000D5168, 0x00134F6C, 0x00084E6C, 0x00045B6F, 0x001A6E6C, 0x00317262, 0x000A0A0A, 0x00020300, 0x0022261B, 0x00474A3A, 0x00454936, 0x00494B38, 0x00505141, 0x00424333, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x006B7160, 0x00454E44, 0x000B0F04, 0x00211D12, 0x00534E45, 0x00222A20, 0x004B6C65, 0x00447F77, 0x001E6B64, 0x00245A71, 0x00265C73, 0x00245A71, 0x00235970, 0x00235970,
        0x002E647B, 0x00558BA2, 0x0084BAD1, 0x0073A8BD, 0x00619CB0, 0x0063A8BB, 0x0068B4C7, 0x004A96A9, 0x0021657C, 0x001B546D, 0x00295C76, 0x00266272, 0x0065A1B1, 0x0097D3E3, 0x007FBBCB, 0x003C7888, 0x00246070, 0x005D99A9, 0x00A7E3F3, 0x00ACDBDF,
        0x004D8493, 0x0013506A, 0x0013506A, 0x00215C6B, 0x005C969B, 0x0049898D, 0x00226A71, 0x00439BB3, 0x0019647A, 0x00205A6D, 0x0043707E, 0x002B5866, 0x001B4F5F, 0x00145367, 0x00165C73, 0x00275574, 0x005D8A98, 0x0092CBD4, 0x005BB5D3, 0x003BB3EE,
        0x0044BDFB, 0x00227D9C, 0x00236161, 0x002A5675, 0x0022536D, 0x0020586B, 0x00084450, 0x00255E67, 0x00B2E4EA, 0x00AAD1D9, 0x004E7076, 0x003B4A4C, 0x002C3B33, 0x003A4434, 0x0040483D, 0x00323E3E, 0x00274449, 0x002E6060, 0x00074741, 0x00204053,
        0x000C4457, 0x00134F5F, 0x007A979E, 0x007F7F79, 0x001D1A0B, 0x00050400, 0x003C3833, 0x008C8C6E, 0x00616651, 0x00000B00, 0x00000800, 0x00505235, 0x00848264, 0x0050543B, 0x00000600, 0x000C0F00, 0x0060634D, 0x0091947E, 0x0032351F, 0x00040700,
        0x001E210B, 0x006E715B, 0x007B7E68, 0x001F2611, 0x00000600, 0x002C301D, 0x0078877F, 0x00295E73, 0x000A6A9F, 0x001E90BF, 0x002492AC, 0x00115665, 0x00135977, 0x0054AECC, 0x00106274, 0x0019475F, 0x005388A9, 0x005399B6, 0x00487C8C, 0x0005687E,
        0x00005264, 0x000E5563, 0x00226776, 0x0074C3D6, 0x0078D2F1, 0x0058B3E0, 0x0063BAF3, 0x0043AEC3, 0x00479DB3, 0x006090B4, 0x0059A4CB, 0x005092A5, 0x003D4741, 0x00101605, 0x000E0803, 0x003A3F22, 0x00918670, 0x00686150, 0x00000700, 0x00000F00,
        0x005A5342, 0x00857A64, 0x0044492C, 0x00000900, 0x00161606, 0x006E5B4E, 0x00797062, 0x00223522, 0x00000E00, 0x00101A09, 0x0079695C, 0x0091685F, 0x0027241F, 0x00000800, 0x002D2917, 0x005C5E5E, 0x00366688, 0x001C75AE, 0x002B8ECC, 0x002E9AD0,
        0x0036A2D8, 0x0039A5DB, 0x0034A1D7, 0x00329FD5, 0x0033A3D8, 0x0032A2D7, 0x002D9DD2, 0x002AA0D3, 0x00299FD2, 0x00299FD2, 0x002BA1D4, 0x002DA3D6, 0x002DA3D6, 0x002CA2D5, 0x002AA0D3, 0x002BA1D4, 0x002BA1D4, 0x002CA2D5, 0x002CA2D5, 0x002CA2D5,
        0x002BA1D4, 0x002AA0D3, 0x002AA0D3, 0x002CA6CE, 0x0032ACD4, 0x002DA6D0, 0x002DA5CF, 0x00289FCC, 0x0037ADDC, 0x0038AEDD, 0x000174A6, 0x0004555A, 0x001D5354, 0x00C1D8D0, 0x00697362, 0x00C1CFB7, 0x006B836B, 0x00AAC4B2, 0x00688173, 0x009DC1B0,
        0x00628374, 0x009AB8AB, 0x006E897F, 0x0098B3A9, 0x00759485, 0x0090B39F, 0x00739A81, 0x0080998B, 0x008FA29F, 0x007F8F96, 0x009AAFB1, 0x005F7E75, 0x009FBEAF, 0x00667970, 0x00B6BCBB, 0x005F7973, 0x00ADC3BE, 0x005F6F68, 0x00B6C4BE, 0x00606F67,
        0x00A8BDB4, 0x005D7B6E, 0x009ABDAF, 0x006A807B, 0x0099AFAA, 0x007B928D, 0x00859F99, 0x00738F89, 0x0076958E, 0x007E9F98, 0x006A8B84, 0x0094A59C, 0x006B8077, 0x0093ADA0, 0x00607C6F, 0x0098B7A8, 0x00506D5D, 0x00A0BAAA, 0x005D7563, 0x00AEB5A0,
        0x00657863, 0x0095B2A2, 0x005D7B70, 0x009CB7B4, 0x00618A8C, 0x0011585B, 0x00359797, 0x00AAE8DA, 0x00778F87, 0x00F1E2DF, 0x00F7E1DC, 0x00A3A294, 0x0095AB93, 0x00B3D2B1, 0x00ADC6A4, 0x008DA194, 0x00778272, 0x008E8E7C, 0x00959283, 0x00747970,
        0x00E3FAFC, 0x006996A3, 0x00175468, 0x00175370, 0x00154E6D, 0x00184D6E, 0x00215173, 0x001A4D6D, 0x00134B68, 0x0014546C, 0x00105569, 0x000C4C6A, 0x0011506C, 0x0014526A, 0x00145066, 0x000C4B60, 0x000E4E66, 0x00105570, 0x00094F6C, 0x000E5069,
        0x00075066, 0x000C5067, 0x00124E6B, 0x00064C6A, 0x00055C70, 0x00207472, 0x00387969, 0x000F0F0F, 0x00030400, 0x001C2015, 0x00404333, 0x00434734, 0x004A4C39, 0x00505141, 0x003E3F2F, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFE, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x006F7367, 0x004B5342, 0x000A0B02, 0x001F1717, 0x004D4A45, 0x001A291B, 0x00365C4A, 0x003C776F, 0x00296E71, 0x001F5871, 0x0024596D, 0x00295D6E, 0x001A546A, 0x00135675,
        0x003B86A6, 0x0068B0C8, 0x00357986, 0x0029677F, 0x00557991, 0x00347185, 0x00427190, 0x0062A0C6, 0x00459FC2, 0x00155470, 0x000D5D68, 0x00538494, 0x00DFF1F2, 0x00FFFFF6, 0x00F6FFFE, 0x0088B9C3, 0x00417C8C, 0x00D2EFF6, 0x00FFFFF8, 0x00F1FFF7,
        0x00C2DFE3, 0x0023546E, 0x00084E6C, 0x00578FAA, 0x00C5EDFF, 0x007AB2C3, 0x003997A4, 0x002C88A1, 0x0046A4BB, 0x006DC3D7, 0x00A4DFF2, 0x00527285, 0x003F5967, 0x00234E57, 0x00216165, 0x0049707E, 0x00DAE1F5, 0x00FFF7FF, 0x00DFE2F0, 0x0065AFC9,
        0x0034B3E6, 0x0043B9F4, 0x002D7CAF, 0x00064763, 0x00165974, 0x00165871, 0x000E445B, 0x00224B61, 0x001D4754, 0x0068A0A5, 0x008FD5D4, 0x00649AA5, 0x0034616C, 0x001A4449, 0x001A4C4C, 0x001C5E5D, 0x0010595D, 0x00054550, 0x0016495D, 0x000C475B,
        0x00143A5A, 0x001F5573, 0x004A7E8B, 0x005D6260, 0x002D2F1C, 0x000C1E07, 0x004E493A, 0x0084846C, 0x00666551, 0x00242113, 0x001F1A11, 0x00555047, 0x007E7B6D, 0x00575642, 0x001F1F07, 0x002B2E15, 0x006A634F, 0x00918474, 0x00534E3F, 0x000F1504,
        0x0029321E, 0x007B7863, 0x007B6D57, 0x002B2C28, 0x00302118, 0x004E3931, 0x00747C7C, 0x00215C6C, 0x00177B9D, 0x001D91BA, 0x0030A1CC, 0x0023656A, 0x000E515A, 0x00064C59, 0x00094F60, 0x000C5466, 0x000D5265, 0x00084D60, 0x00115568, 0x001F6277,
        0x0018555F, 0x003C7479, 0x007EC3D2, 0x0078D0F4, 0x0053B8E5, 0x0057BCE3, 0x0050ACC9, 0x00519AB0, 0x0054A5CA, 0x0050A5D7, 0x005EA9D7, 0x00487A91, 0x00425758, 0x001E2216, 0x00161402, 0x00434129, 0x006D6E5A, 0x0054594A, 0x001A2015, 0x00161C11,
        0x00444738, 0x00716F5D, 0x004B4430, 0x001B2623, 0x00282520, 0x0063574B, 0x00736C59, 0x00343622, 0x0019220E, 0x0027251A, 0x00625650, 0x0074624B, 0x002A2E15, 0x00222B16, 0x002A291F, 0x00546568, 0x00327080, 0x00237997, 0x003782AE, 0x002D95B8,
        0x0035A0C6, 0x002F9BC5, 0x002D9CCA, 0x002D9DD1, 0x002CA0D5, 0x0033A7DE, 0x00279BD4, 0x002CA1D4, 0x002CA1D4, 0x002CA1D4, 0x002CA1D4, 0x002BA0D3, 0x002BA0D3, 0x002BA0D3, 0x002BA0D3, 0x002AA0D3, 0x002BA1D4, 0x002CA2D5, 0x002BA1D4, 0x002AA0D3,
        0x00299FD2, 0x002AA0D3, 0x002CA2D5, 0x002CA2D5, 0x002E9FD7, 0x00319EDC, 0x002B9CDA, 0x0031A7DB, 0x002C9EC7, 0x00137391, 0x0007576E, 0x00124859, 0x0059605B, 0x0076765E, 0x0063725D, 0x006D7467, 0x0067705C, 0x0064705E, 0x006B605C, 0x006D7362,
        0x006D7362, 0x006C7261, 0x006B7160, 0x00696F5E, 0x00666C5B, 0x00656B5A, 0x00646A59, 0x00696E5F, 0x00636859, 0x00686D5E, 0x00666B5C, 0x00666B5C, 0x006A6F60, 0x006A6F60, 0x00757A6B, 0x00696F5E, 0x006B7160, 0x00676D5C, 0x006D7060, 0x00656858,
        0x006C6D5D, 0x006B6C5C, 0x00707161, 0x00676858, 0x00727363, 0x00727363, 0x006A6D5D, 0x006D7060, 0x006F7564, 0x006C7261, 0x00696F5E, 0x006A705F, 0x006B7160, 0x00707363, 0x006A6D5D, 0x00707363, 0x006D6E5E, 0x006F7060, 0x00676858, 0x007F7563,
        0x00676759, 0x006E766B, 0x006E6E60, 0x00817B68, 0x005B6051, 0x001C413F, 0x0066A5AD, 0x0096DCCF, 0x003E6157, 0x00D6D4CA, 0x00D7CBBF, 0x00A9AA9A, 0x00C1CEBE, 0x00E8F1E4, 0x00F3F1E7, 0x00B5C4A9, 0x00969C85, 0x00A8A491, 0x00ACA69B, 0x00686D6B,
        0x00E2FFFF, 0x006AA2AD, 0x000D5664, 0x00005170, 0x00085673, 0x0007506C, 0x000E546C, 0x00135971, 0x00044C64, 0x0006516B, 0x0005526D, 0x00135064, 0x0013536C, 0x00125372, 0x000F5273, 0x00094E6F, 0x000A506E, 0x000A5270, 0x00024E6B, 0x000F526D,
        0x0009536B, 0x000B5168, 0x0014506E, 0x000C4F70, 0x0003586E, 0x001D6F70, 0x00397668, 0x000C0D09, 0x00030500, 0x001F2317, 0x00434636, 0x00464A37, 0x004A4B3B, 0x004F4F41, 0x00444438, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFE, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x0074786C, 0x00464E3D, 0x000C0D04, 0x001F1717, 0x004A4742, 0x001F2E20, 0x00426856, 0x00417C74, 0x00256A6D, 0x00286079, 0x00285D71, 0x00275D6E, 0x00215D73, 0x001E6482,
        0x00559CBD, 0x003D7D96, 0x00437C8B, 0x008CB8C9, 0x00A8C7D6, 0x0097C4CF, 0x00628FA4, 0x003F7A9A, 0x004997BB, 0x00307694, 0x000E5A6D, 0x006690A3, 0x00EEFCFF, 0x00FFFCF9, 0x00F6FFFF, 0x0094BFCE, 0x004C8196, 0x00DFF7FF, 0x00FFFEFE, 0x00F0FCF6,
        0x00B8F0F5, 0x0053A7B9, 0x00044B66, 0x005F94A8, 0x00A2D8DF, 0x00437679, 0x008AB2B7, 0x0062A7B6, 0x003D7A88, 0x0041717D, 0x00859FAB, 0x008A949E, 0x00818A8E, 0x005E7273, 0x00587774, 0x00C5DBE0, 0x00EDF2FF, 0x00FFF3FF, 0x00FFFFFB, 0x00B9E5DF,
        0x005DBBD2, 0x0048B5E8, 0x0047A7E3, 0x002D748F, 0x0000435B, 0x00054B62, 0x001E576C, 0x00245061, 0x001F4955, 0x001A5154, 0x000D4F4D, 0x0031707E, 0x002C616E, 0x002F5D68, 0x0023555B, 0x000D4B51, 0x000B4E57, 0x00114D5D, 0x0011465B, 0x000E485B,
        0x00113955, 0x001D5572, 0x00538798, 0x005A6569, 0x007E8276, 0x007F8B77, 0x008F8678, 0x00948D7C, 0x00867F70, 0x00888073, 0x008E857B, 0x0080776D, 0x008B8376, 0x00867F70, 0x00807968, 0x007B775E, 0x00968B75, 0x009F917F, 0x009C9483, 0x009B9B89,
        0x008A8C78, 0x00918B74, 0x00907E67, 0x00918E86, 0x008B8879, 0x00898A7A, 0x005D6E6A, 0x000A384A, 0x0029779C, 0x00228AB9, 0x0031A7D8, 0x0020626D, 0x00115562, 0x000E5362, 0x000F5465, 0x00125669, 0x00115568, 0x000E5062, 0x00155769, 0x000E4A56,
        0x00347584, 0x0072BBD1, 0x006EC4E8, 0x0052B4E2, 0x0053B8E5, 0x004CAACD, 0x00489EB6, 0x005CAFCB, 0x0054ACD1, 0x0050A6D4, 0x004F97BF, 0x00325F74, 0x00485D5B, 0x00686C60, 0x00767364, 0x007C6B58, 0x00807161, 0x00665A50, 0x00584D45, 0x005D524A,
        0x005E4F46, 0x00786556, 0x006A5442, 0x00515248, 0x00696154, 0x006E604E, 0x007B705A, 0x005F5E44, 0x0063654F, 0x005A5342, 0x00756559, 0x006D5C53, 0x00606354, 0x00505546, 0x006A625B, 0x00596161, 0x00002A35, 0x00024358, 0x00053E5E, 0x00004E67,
        0x00005471, 0x00086A8C, 0x002C95BC, 0x0042AFDB, 0x0037A6D6, 0x002E9FD1, 0x002FA2D4, 0x0030A2D1, 0x0030A2D1, 0x0030A2D1, 0x0030A2D1, 0x002FA1D0, 0x002FA1D0, 0x002FA1D0, 0x002FA1D0, 0x002A9ECD, 0x002B9FCE, 0x002CA0CF, 0x002B9FCE, 0x002A9ECD,
        0x00299DCC, 0x002B9FCE, 0x002CA0CF, 0x0029A0CD, 0x0031A0D2, 0x0036A2D8, 0x002E9DD5, 0x002BA1D2, 0x002698BD, 0x000A6B87, 0x0000475D, 0x00023A4B, 0x00414843, 0x005E5E46, 0x004B5A45, 0x004F5649, 0x004A533F, 0x00525E4C, 0x00635854, 0x00535948,
        0x00525847, 0x00525847, 0x00525847, 0x00525847, 0x00515746, 0x00505645, 0x004E5443, 0x004F5445, 0x004B5041, 0x00505546, 0x00505546, 0x00515647, 0x00535849, 0x00505546, 0x00575C4D, 0x00545A49, 0x00565C4B, 0x00515746, 0x00575A4A, 0x00515444,
        0x00585949, 0x00565747, 0x00595A4A, 0x00515242, 0x00595A4A, 0x00595A4A, 0x00525545, 0x00545747, 0x00545A49, 0x00515746, 0x00515746, 0x00525847, 0x00525847, 0x00545A49, 0x00505343, 0x00565949, 0x00565747, 0x005B5C4C, 0x00575848, 0x00625846,
        0x004C4C3E, 0x004F574C, 0x00525244, 0x0067614E, 0x00494E3F, 0x00123735, 0x004E8D95, 0x0099DBD0, 0x0047665D, 0x009F9A91, 0x00DDCCBF, 0x00E0DCCA, 0x00E9F5DF, 0x00F0FBE7, 0x00D7D9C6, 0x009BA48A, 0x00CDCFB9, 0x009A9481, 0x00756F64, 0x00676C6A,
        0x00D3F2F5, 0x007FB8C1, 0x00024C58, 0x000B546A, 0x000D536A, 0x000E5166, 0x00125166, 0x00115065, 0x0014526A, 0x0012526B, 0x000C4D69, 0x00145068, 0x0016526A, 0x0015526C, 0x0015526C, 0x0016536D, 0x0014546D, 0x0010526B, 0x000A4C65, 0x000F526D,
        0x0008526A, 0x000A5067, 0x0014506E, 0x000C4F70, 0x0004596F, 0x001C6E6F, 0x00357264, 0x000C0D09, 0x00040600, 0x00212519, 0x00444737, 0x00474B38, 0x004A4B3B, 0x004C4C3E, 0x003F3F33, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFE, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x006F7367, 0x00404837, 0x000F1007, 0x001F1717, 0x0045423D, 0x00253426, 0x004D7361, 0x00437E76, 0x00216669, 0x00285B75, 0x00285B6F, 0x00225A6B, 0x001D5E73, 0x00387E9C,
        0x005B9EBF, 0x00336883, 0x008AB2C4, 0x00EBFDFF, 0x00E8FFFF, 0x00EFFFFF, 0x00ADD5DA, 0x00458094, 0x004C8BAD, 0x004695B6, 0x000B4E6F, 0x002E6279, 0x00ABC9D4, 0x00F1FDFF, 0x00C8E2E9, 0x004C8195, 0x0016546C, 0x008EB5C4, 0x00E9F3FA, 0x00CCE9EE,
        0x003F8690, 0x002B8A9D, 0x004097AB, 0x001F6572, 0x001D5658, 0x007CA3A1, 0x00AEBBB9, 0x004D8487, 0x00365C60, 0x004D5E61, 0x00888C8D, 0x00B9BCBA, 0x00B4BBB4, 0x009BA399, 0x009DA398, 0x00F9FBF5, 0x00FAFEFF, 0x00FFFDFD, 0x00FFFFEE, 0x00F8FFEB,
        0x0091CED0, 0x0044A6D0, 0x0034A3E1, 0x0037748E, 0x001D5D75, 0x003B768A, 0x00739FB0, 0x007A95A3, 0x00788F97, 0x008AABAE, 0x0072A19F, 0x002F7C8F, 0x00115366, 0x000B4152, 0x001C4F5F, 0x001A5160, 0x00104B5B, 0x00154E63, 0x00134962, 0x00104754,
        0x0018465E, 0x00094360, 0x00427891, 0x00263D4C, 0x002B3634, 0x002F382B, 0x0044392B, 0x0034322A, 0x0028271D, 0x002F2F23, 0x0039392B, 0x002C2C1E, 0x002F2F23, 0x002A291F, 0x0036342C, 0x00323323, 0x002E2B1D, 0x00352E25, 0x003E3C34, 0x003A3F36,
        0x00252B20, 0x00302F21, 0x0042392B, 0x00352E25, 0x003D412E, 0x001D2F18, 0x0019342B, 0x0003283C, 0x002D6A96, 0x003D9DD3, 0x00249DD5, 0x00195D70, 0x000A4E61, 0x00105265, 0x00125467, 0x00135365, 0x001A5A6C, 0x0018586A, 0x00114F61, 0x00326E74,
        0x0073BDD5, 0x0068C6F3, 0x004AB3EC, 0x004FB8EB, 0x0044A4CC, 0x00439CB7, 0x0057ADC3, 0x0057B6DD, 0x0051B0D8, 0x004197C1, 0x00246786, 0x0008323F, 0x00203231, 0x00454A41, 0x00313125, 0x00333627, 0x00262A1E, 0x002A3025, 0x002B3329, 0x0031362D,
        0x0027291D, 0x002C2C1C, 0x00322E1C, 0x002D2F29, 0x0039372D, 0x003A3225, 0x002F2A1B, 0x00404131, 0x002E3122, 0x00353329, 0x00382E27, 0x00342C2D, 0x00363A35, 0x0032342E, 0x00372E2A, 0x00222424, 0x0015353A, 0x00002F3B, 0x0018455A, 0x00327D8D,
        0x00358799, 0x004AA3BE, 0x0050B2D4, 0x0040ABD1, 0x0032A2CC, 0x002EA1CC, 0x0031A4CF, 0x0030A2D1, 0x0030A2D1, 0x0030A2D1, 0x0030A2D1, 0x0030A2D1, 0x002FA1D0, 0x002FA1D0, 0x002FA1D0, 0x0031A4D1, 0x0032A5D2, 0x0031A4D1, 0x0030A3D0, 0x002FA2CF,
        0x0030A3D0, 0x0031A4D1, 0x0033A6D3, 0x002BA1CA, 0x0031A0CE, 0x0035A0D3, 0x002C9CD0, 0x002EA4D3, 0x003AAFD6, 0x00349BBB, 0x0029829D, 0x001D5A6E, 0x00424D4A, 0x00585A44, 0x004F5B47, 0x00565A4E, 0x00515A46, 0x0057634F, 0x00625A53, 0x00575D4C,
        0x00565C4B, 0x00555B4A, 0x00555B4A, 0x00565C4B, 0x00565C4B, 0x00545A49, 0x00525847, 0x00515647, 0x004E5344, 0x0054594A, 0x00565B4C, 0x00575C4D, 0x00575C4D, 0x00525748, 0x0054594A, 0x00555B4A, 0x00555B4A, 0x00515746, 0x00565949, 0x00535646,
        0x00595A4A, 0x00565747, 0x00575848, 0x00585949, 0x005D5E4E, 0x005C5D4D, 0x00585B4B, 0x005A5D4D, 0x00565C4B, 0x00545A49, 0x00575D4C, 0x00555D4C, 0x00565C4B, 0x00595F4E, 0x00505645, 0x00565949, 0x00545747, 0x00595A4A, 0x00565747, 0x00615745,
        0x00515143, 0x004E564B, 0x00515143, 0x00625C49, 0x00464B3C, 0x00133836, 0x0033727A, 0x009CDCD6, 0x005A7A75, 0x0077746C, 0x00817063, 0x00A59C88, 0x00FBFFE5, 0x00D2D9BE, 0x009C9F85, 0x00C4C6B0, 0x00DBD7C4, 0x0077705F, 0x00464237, 0x00A5B0AD,
        0x00E1FFFF, 0x00518A93, 0x00135B67, 0x001D5B6B, 0x00074555, 0x00145466, 0x001E5D72, 0x0007475F, 0x00094A66, 0x000D4D6B, 0x001A5C79, 0x00286F90, 0x001F6380, 0x0014546C, 0x000E4D62, 0x000D4D65, 0x000C4F66, 0x0010536A, 0x001C5D72, 0x00155873,
        0x000B556D, 0x000A5067, 0x00124E6C, 0x000A4D6E, 0x00055A70, 0x001E7071, 0x00347163, 0x000B0C08, 0x00040600, 0x0022261A, 0x00464939, 0x00484C39, 0x004B4C3C, 0x004A4A3C, 0x003B3B2F, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFE, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x0064685C, 0x003D4534, 0x00101108, 0x001D1515, 0x0043403B, 0x00273628, 0x004D7361, 0x00407B73, 0x00216669, 0x002D5E78, 0x002E6175, 0x00245F6F, 0x0014576C, 0x004991AF,
        0x004483A5, 0x0046728F, 0x00C9E4F8, 0x00FBFDFE, 0x00EBFFF7, 0x00FFFFF7, 0x00DFFFFF, 0x00619AA9, 0x00437899, 0x004A9EC2, 0x0016527C, 0x000C566E, 0x00286373, 0x004F7D88, 0x00326C78, 0x00055469, 0x0002566F, 0x00206275, 0x00487580, 0x0024646F,
        0x00195769, 0x000B5970, 0x003398AE, 0x00338FA2, 0x001C5564, 0x00789FA8, 0x00568688, 0x00124B48, 0x00597B7B, 0x00D1DBDB, 0x00FBFFFF, 0x00E4F4ED, 0x00D8F0E6, 0x00D6E6DB, 0x00CFD5CA, 0x00F0E7DD, 0x00E3E7E2, 0x00CFD5CA, 0x00C5C8AF, 0x00B4C7B8,
        0x0082BACB, 0x004AA6CF, 0x0030A0CB, 0x00327A92, 0x002E778B, 0x0073B6C5, 0x004C7F89, 0x0067898F, 0x00496369, 0x00587B7E, 0x00548381, 0x00368EA6, 0x0028788F, 0x0010526B, 0x00134B64, 0x001C526B, 0x001B516A, 0x00174F68, 0x000E4560, 0x00124853,
        0x000B4054, 0x00245E7B, 0x00376E8D, 0x0001273F, 0x001A2F37, 0x00232D27, 0x00181205, 0x00000B0A, 0x00000E0A, 0x0005160B, 0x00172A1B, 0x00041708, 0x00000C01, 0x0001100C, 0x00071514, 0x000E1B19, 0x00000C0E, 0x00030F13, 0x00000A12, 0x00071920,
        0x00132427, 0x00010D0F, 0x00000504, 0x0017160C, 0x00222817, 0x00263624, 0x00163631, 0x0003344A, 0x00236B9A, 0x00288BC5, 0x002EA2DD, 0x00195C77, 0x0013556E, 0x00115267, 0x00175468, 0x001B596B, 0x00114F61, 0x000E4D61, 0x002C6D82, 0x0074BED0,
        0x006AC5EC, 0x0047B2EC, 0x0048B6F0, 0x0045A8D4, 0x003B96B5, 0x0054AFCE, 0x0053B3D7, 0x004EB5E2, 0x003D9DC5, 0x001A6C8F, 0x00003E53, 0x00022B34, 0x00112627, 0x0037413B, 0x00292D27, 0x00082018, 0x00000D05, 0x00011712, 0x00000E06, 0x0000110A,
        0x00011207, 0x00021004, 0x00101C10, 0x00141C1C, 0x00020A09, 0x00000B09, 0x00000907, 0x0011221F, 0x00000C0B, 0x00071315, 0x00030A0D, 0x00000909, 0x0015201E, 0x000D1711, 0x00212722, 0x00182624, 0x00173A3E, 0x00063844, 0x0053899A, 0x0074BACB,
        0x00438FA5, 0x00459CBC, 0x0051B6DD, 0x0041AEDA, 0x0031A6D3, 0x002AA1CE, 0x002AA2CC, 0x002DA2D5, 0x002CA1D4, 0x002CA1D4, 0x002CA1D4, 0x002CA1D4, 0x002BA0D3, 0x002BA0D3, 0x002BA0D3, 0x002BA0D3, 0x002BA0D3, 0x002A9FD2, 0x00299ED1, 0x00299ED1,
        0x00299ED1, 0x002BA0D3, 0x002CA1D4, 0x002CA5D1, 0x0031A3D2, 0x0033A1D5, 0x002B9FD4, 0x0027A4D6, 0x0031AEDB, 0x0037A9D2, 0x00349BC2, 0x0027687D, 0x003A4847, 0x0052533F, 0x00515B4A, 0x005A5C50, 0x00535946, 0x00515D49, 0x0057514A, 0x00565E4D,
        0x00535B4A, 0x00515948, 0x00515948, 0x00525A49, 0x00515948, 0x004E5645, 0x004A5241, 0x004D5445, 0x004C5344, 0x004E5546, 0x00505748, 0x00535A4B, 0x00545B4C, 0x00515849, 0x00505748, 0x005A604F, 0x00575D4C, 0x00545A49, 0x00575A4A, 0x00585B4B,
        0x005C5D4D, 0x005A5B4B, 0x00585949, 0x00585949, 0x005B5C4C, 0x005A5B4B, 0x00585B4B, 0x005A5D4D, 0x00535948, 0x00535948, 0x005A604F, 0x00525A49, 0x00525A49, 0x005C6251, 0x00525847, 0x00565C4B, 0x00545747, 0x00525545, 0x004F5242, 0x00655B49,
        0x005B5B4D, 0x00555D52, 0x005A5A4C, 0x00645E4B, 0x00454A3B, 0x000F3432, 0x00115058, 0x0084CFCD, 0x007CABA8, 0x003E4842, 0x003E3528, 0x006C634F, 0x00AAA68D, 0x00A6A589, 0x00BFBB9F, 0x00A29F90, 0x00656253, 0x00515042, 0x005F645B, 0x00C8DBD8,
        0x00C7EDF1, 0x002E6973, 0x00115764, 0x00185061, 0x00114E62, 0x00064E66, 0x00004966, 0x000C6385, 0x003692B5, 0x003B97BA, 0x0056B1D6, 0x005EBFEB, 0x0062BCDF, 0x005AAFC9, 0x003B91A9, 0x0017708B, 0x00015878, 0x000B5E7A, 0x00307D97, 0x001C5F7A,
        0x000E5870, 0x000A5067, 0x00114D6B, 0x00084B6C, 0x00065B71, 0x00227475, 0x00367365, 0x000A0B07, 0x00040600, 0x00212519, 0x00454838, 0x00484C39, 0x004C4D3D, 0x004C4C3E, 0x003B3B2F, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFE, 0xFFFEFDFF, 0xFFFFFEFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x0064685C, 0x003F4736, 0x00101108, 0x001C1414, 0x0043403B, 0x00253426, 0x00456B59, 0x003A756D, 0x0024696C, 0x002C5D77, 0x002C5F73, 0x00256070, 0x0013566B, 0x00448CAA,
        0x004988AA, 0x004D7996, 0x00B5D0E4, 0x00FBFAFC, 0x00EFFFFB, 0x00FFFFF6, 0x00C9ECE8, 0x005891A0, 0x0046799A, 0x003E8FB4, 0x001B5781, 0x000F5A74, 0x0014576C, 0x00144F62, 0x00115568, 0x0005586E, 0x00065A74, 0x00145A71, 0x00164E61, 0x000A5A6B,
        0x001F5D75, 0x0015516E, 0x00035372, 0x003F93B6, 0x004C93B4, 0x00266B86, 0x00388A9C, 0x005F8C8F, 0x00D6EFF3, 0x00FAFDFF, 0x00F1F5FA, 0x00E4F6F5, 0x00D0EBE7, 0x00A8BCB7, 0x00D1D8D5, 0x00EBE7E2, 0x00A8AEA3, 0x0086907F, 0x00788A7D, 0x00538193,
        0x0051A2D5, 0x004DADDB, 0x003F9EB2, 0x00268098, 0x0046A2B5, 0x000B646E, 0x00115A5E, 0x000A4243, 0x00124243, 0x00154B4B, 0x00084848, 0x001B7892, 0x0028819C, 0x00095976, 0x00004261, 0x0017506F, 0x001A506E, 0x00154C67, 0x00154E67, 0x00164C57,
        0x00003747, 0x0016526A, 0x00427998, 0x00023856, 0x00193E52, 0x00A3B6BB, 0x00828F87, 0x00152732, 0x00000D14, 0x002B4041, 0x00AAC1BD, 0x007C938F, 0x00001516, 0x00061920, 0x003A4C57, 0x0097A7A6, 0x00475C5D, 0x00001519, 0x00001117, 0x0070888E,
        0x00B0C4C9, 0x0045595A, 0x00011614, 0x000D1E1B, 0x00929994, 0x00ACB8B2, 0x0040666B, 0x0008536D, 0x002B93BE, 0x003BA8DB, 0x00379DD1, 0x000C4F6E, 0x00175874, 0x0014526A, 0x00135064, 0x001C5A6C, 0x000C4F64, 0x00236981, 0x0073BCD8, 0x0069C9F1,
        0x004AB1E2, 0x0045B2E8, 0x0040A7D4, 0x00439DBB, 0x0054ABC5, 0x004FB1D9, 0x0047B4EA, 0x004DB0DC, 0x001A7398, 0x0000415B, 0x00003545, 0x000F3C47, 0x001D3D42, 0x00738889, 0x00A9BAB7, 0x00193038, 0x0003191F, 0x000D2023, 0x005E6D6F, 0x007F8B8B,
        0x001F2A28, 0x00000705, 0x00272F2E, 0x00737F79, 0x00556662, 0x00001915, 0x00001310, 0x00152F2F, 0x006D8585, 0x003D5152, 0x00011516, 0x00042521, 0x002B4642, 0x00829A92, 0x0053746D, 0x00052D2B, 0x00002D34, 0x00317385, 0x005AAAC1, 0x00347F99,
        0x002B7E9E, 0x003B9AC5, 0x0040ABDE, 0x0035A9DE, 0x0030A8DC, 0x002BA3D1, 0x002DA5CF, 0x002EA3DA, 0x002DA2D9, 0x002DA2D9, 0x002DA2D9, 0x002DA2D9, 0x002CA1D8, 0x002CA1D8, 0x002CA1D8, 0x002CA2D6, 0x002CA2D6, 0x002BA1D5, 0x002AA0D4, 0x002BA1D5,
        0x002BA1D5, 0x002CA2D6, 0x002CA2D6, 0x0029A5D5, 0x002EA1D4, 0x002F9FD4, 0x002DA1DA, 0x0024A3DA, 0x001DA1D7, 0x00229DD5, 0x00299AD2, 0x00206880, 0x00364849, 0x00575946, 0x00576151, 0x005E5C51, 0x00545845, 0x0054614B, 0x00615C53, 0x00596150,
        0x00565E4D, 0x00545C4B, 0x00545C4B, 0x00555D4C, 0x00555D4C, 0x00515948, 0x004E5645, 0x00535A4B, 0x0052594A, 0x00505748, 0x00515849, 0x00545B4C, 0x00575E4F, 0x005A6152, 0x00596051, 0x00595F4E, 0x00555B4A, 0x00525847, 0x00535646, 0x00565949,
        0x00585949, 0x00585949, 0x00555646, 0x00595A4A, 0x005B5C4C, 0x005A5B4B, 0x005A5D4D, 0x005C5F4F, 0x00555B4A, 0x00565C4B, 0x00616756, 0x00575F4E, 0x00555D4C, 0x00606857, 0x00585E4D, 0x005E6453, 0x005D6352, 0x005C5F4F, 0x00595C4C, 0x005E5442,
        0x0058584A, 0x0050584D, 0x0058584A, 0x00625C49, 0x0044493A, 0x000F3432, 0x00024149, 0x00308789, 0x008CCCCD, 0x00537470, 0x002F3A30, 0x00555547, 0x007A7965, 0x00615C47, 0x00847B67, 0x003D4037, 0x002E332A, 0x005A655D, 0x00ADC1BC, 0x00E3FFFF,
        0x0070A0A6, 0x000B4753, 0x00115667, 0x000F4762, 0x00377A99, 0x0022789C, 0x00006089, 0x00299FC9, 0x0054D1FD, 0x0030AED7, 0x0025A4CB, 0x0038AEE2, 0x003AAAD4, 0x0038A5C5, 0x0036A7C8, 0x0048C0EA, 0x004FC3F2, 0x0039A2CB, 0x003491B2, 0x00185B76,
        0x000B556D, 0x000A5067, 0x00114D6B, 0x00084B6C, 0x00065B71, 0x00207273, 0x00306D5F, 0x00090A06, 0x00030500, 0x001F2317, 0x00424535, 0x00474B38, 0x004E4F3F, 0x004F4F41, 0x003E3E32, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFE, 0xFFFCFBFD, 0xFFFDFCFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x006D7165, 0x00434B3A, 0x000F1007, 0x001B1313, 0x0044413C, 0x00223123, 0x003E6452, 0x00367169, 0x00256A6D, 0x00265973, 0x0026596D, 0x00225A6B, 0x001B5C71, 0x002D7391,
        0x0062A5C6, 0x00427792, 0x006A92A4, 0x00E0F1FA, 0x00E9FFFF, 0x00E0F0EF, 0x0082A8AD, 0x00467F94, 0x00609DBF, 0x00347EA0, 0x00105072, 0x00215976, 0x001E536E, 0x0020566F, 0x001F5871, 0x00175672, 0x001D5C78, 0x001B526D, 0x0023526D, 0x00115671,
        0x000D556D, 0x00245F79, 0x001B496B, 0x00114E76, 0x003089AE, 0x00439DBC, 0x0069ACC7, 0x00DFEFF6, 0x00F8FDFF, 0x00F7F4FD, 0x00FFFCFF, 0x00F5F8FD, 0x00F8FFFF, 0x00EEF3F4, 0x00E6E8E9, 0x00F4FCFB, 0x00C9D1C7, 0x007F8776, 0x004D6662, 0x002A6B92,
        0x0043AAEF, 0x00369ED3, 0x00308595, 0x0065A8C9, 0x00569CB4, 0x005C9FAE, 0x0051878E, 0x007BA1A5, 0x00749499, 0x007FA7AC, 0x006EA0A6, 0x004199B7, 0x00449FBE, 0x001D7897, 0x00015376, 0x00115475, 0x00164F6E, 0x00114964, 0x0016556A, 0x00144C5D,
        0x00034857, 0x0000394D, 0x00366C8A, 0x002F7593, 0x00104863, 0x009FC0CF, 0x00D0F6F6, 0x00425A6C, 0x001D3646, 0x0037515F, 0x00D9F3FF, 0x00BED8E4, 0x0017313F, 0x00173040, 0x006E8698, 0x00D8EFEA, 0x00678782, 0x00133A38, 0x00244A4A, 0x00A3C2C3,
        0x00DFF9F9, 0x0062807B, 0x00062821, 0x00264A54, 0x00C3DEE8, 0x00CEE9F7, 0x006FA8C1, 0x0049ADD0, 0x003FB8E2, 0x003DA9D2, 0x00166E92, 0x000A4C69, 0x00094B64, 0x0017566B, 0x000F4D5F, 0x0005495C, 0x002E7890, 0x0060B1D2, 0x007AD0F4, 0x0044B2E6,
        0x0048B5E8, 0x0038A0CB, 0x003694B7, 0x004FAAC5, 0x005AB7D8, 0x004AB2E1, 0x003CAEEA, 0x002E83A9, 0x00024E6B, 0x00003B4E, 0x000A4352, 0x000A3D4D, 0x000C3946, 0x00597E86, 0x008FAEAF, 0x000E4155, 0x002B5C6C, 0x001F4C57, 0x007CA3AB, 0x00A6CBCF,
        0x0023464A, 0x00022529, 0x0021454B, 0x00AEBFB2, 0x00728E81, 0x00042D25, 0x0007332D, 0x00517876, 0x00A8C8C7, 0x005E7F7B, 0x001E423C, 0x00195555, 0x0054807F, 0x00B3DBD9, 0x004A827D, 0x004D8D8D, 0x0055969F, 0x0068B5C8, 0x002C90A8, 0x000F6484,
        0x0047A4CB, 0x0059C0F1, 0x003DAEE6, 0x0037ABE4, 0x003BAEE1, 0x0035A5CF, 0x003CA7CC, 0x0033A2D0, 0x0033A2D0, 0x0033A2D0, 0x0033A2D0, 0x0033A2D0, 0x0032A1CF, 0x0032A1CF, 0x0032A1CF, 0x0034A4CF, 0x0034A4CF, 0x0033A3CE, 0x0034A4CF, 0x0035A5D0,
        0x0035A5D0, 0x0034A4CF, 0x0033A3CE, 0x0035A9D2, 0x003BA6D2, 0x00399FCF, 0x003AA7DA, 0x0035ADE1, 0x0022A1D8, 0x001E99D3, 0x002596D4, 0x001F6A84, 0x0034494B, 0x00565747, 0x00545B4C, 0x005C574E, 0x00575945, 0x00515E48, 0x005C5A4F, 0x00515B4A,
        0x00505A49, 0x004F5948, 0x00505A49, 0x00525C4B, 0x00525C4B, 0x00515B4A, 0x004F5948, 0x00505A4A, 0x00525C4C, 0x004C5646, 0x004C5646, 0x004F5949, 0x00535D4D, 0x005A6454, 0x00596353, 0x005D6352, 0x00585E4D, 0x00565C4B, 0x00545747, 0x00595C4C,
        0x005A5B4B, 0x005B5C4C, 0x00595A4A, 0x00545545, 0x00575848, 0x00565747, 0x00555848, 0x00565949, 0x00515746, 0x00545A49, 0x005E6453, 0x00586251, 0x00515B4A, 0x005C6453, 0x004E5645, 0x00565C4B, 0x00595F4E, 0x00555B4A, 0x00565949, 0x00635947,
        0x005A5A4C, 0x004F574C, 0x00575749, 0x00635D4A, 0x00484D3E, 0x00173C3A, 0x000A4951, 0x0000454F, 0x00509AA0, 0x0074ABAE, 0x003F6462, 0x00243B36, 0x0044534B, 0x00222922, 0x001B1D17, 0x00152726, 0x00445A58, 0x00ACCBC8, 0x00D6FEFD, 0x0084B4B8,
        0x001A525D, 0x00155567, 0x00084B62, 0x00195272, 0x00246A8F, 0x003B9AC2, 0x003FB2DF, 0x0049CBFA, 0x003AC1ED, 0x0039BDE5, 0x0036B8DD, 0x003DB3E2, 0x004BBDE2, 0x0044B8D7, 0x0032AED6, 0x0042C9FF, 0x0047C9FF, 0x001B89B9, 0x00005C7D, 0x000E516C,
        0x00054F67, 0x00094F66, 0x0014506E, 0x00094C6D, 0x00055A70, 0x001C6E6F, 0x00266355, 0x00080905, 0x00030500, 0x001E2216, 0x00404333, 0x00474B38, 0x00515242, 0x00535345, 0x00414135, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFE, 0xFFFCFBFD, 0xFFFDFCFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x006D7165, 0x00464E3D, 0x000F1007, 0x001B1313, 0x0043403B, 0x00202F21, 0x003F6553, 0x0037726A, 0x0022676A, 0x00275F78, 0x00295E72, 0x00255B6C, 0x00235F75, 0x00155B79,
        0x004E95B6, 0x004D8DA6, 0x00467F8E, 0x0061899B, 0x007892A2, 0x00658D99, 0x00466F85, 0x00477D9E, 0x00519BBF, 0x00266685, 0x000F566A, 0x0024536F, 0x00194B67, 0x00205674, 0x001C546F, 0x00174E69, 0x00245974, 0x00154763, 0x00265574, 0x000F4F71,
        0x001C5E77, 0x00184F64, 0x00335F77, 0x00215877, 0x0007516D, 0x0077B0C5, 0x00D4E8F9, 0x00FFFCFF, 0x00FFFEFF, 0x00FAFCFD, 0x00FEFEFE, 0x00FFFAFB, 0x00FFFBFC, 0x00FCFFFD, 0x00D7E0DD, 0x00B2C6C1, 0x00C7D4CC, 0x00818579, 0x00495B54, 0x0027647E,
        0x0054BBF4, 0x0040ACE2, 0x0048A2C4, 0x006FA1CB, 0x004F84A5, 0x00497E92, 0x00507A86, 0x0059767D, 0x0039535A, 0x00587B85, 0x00467380, 0x002D7D9A, 0x00419CBB, 0x003EA3C3, 0x00137194, 0x00004A6B, 0x000B4D6A, 0x0014526A, 0x000C4E60, 0x00124C62,
        0x00085363, 0x001B5463, 0x000C4259, 0x00277A96, 0x00327E9B, 0x0034667C, 0x005D9CA4, 0x0072A6B7, 0x006B9EB2, 0x0043758B, 0x005D8FA6, 0x003E7087, 0x0017495F, 0x00477A8E, 0x006498A9, 0x00305F67, 0x0048818A, 0x006CB1BB, 0x0079BAC8, 0x005E95A4,
        0x004B7C8A, 0x00326972, 0x002C6A70, 0x005389A0, 0x00528CA2, 0x005FA5C2, 0x004FACD3, 0x0052C0F0, 0x002998C6, 0x00046180, 0x00045263, 0x00145772, 0x000E4F64, 0x0019596B, 0x00175867, 0x0022697D, 0x005AADC9, 0x006DCAF1, 0x0048ADDA, 0x0045B3E3,
        0x003BA4CD, 0x003193B5, 0x0049ABCD, 0x0045ABD5, 0x0043ADDC, 0x0050B8E7, 0x00187FAC, 0x000C516C, 0x000A475B, 0x00154C59, 0x00185160, 0x0009465A, 0x00013D53, 0x00154A57, 0x00224F53, 0x000E627E, 0x004C9CB3, 0x00277282, 0x00044953, 0x0013545C,
        0x0003424A, 0x00094A53, 0x0001434E, 0x00224C4B, 0x00235C5D, 0x002B757B, 0x003B8793, 0x003E8394, 0x00155161, 0x00205D6B, 0x004E919A, 0x00146574, 0x004C8594, 0x002C5F69, 0x000D5053, 0x0097DEE1, 0x00A6E3ED, 0x005AA2B3, 0x000E7080, 0x005DB8D7,
        0x005ABBE1, 0x0042ACDB, 0x0040ADE3, 0x0046B3E7, 0x002C95BE, 0x00177592, 0x001C7288, 0x0012718B, 0x0012718B, 0x0012718B, 0x0012718B, 0x0011708A, 0x0011708A, 0x0011708A, 0x0011708A, 0x00106D86, 0x00106D86, 0x00106D86, 0x00126F88, 0x00137089,
        0x00137089, 0x00106D86, 0x000E6B84, 0x0003647E, 0x00126C8A, 0x00186D8D, 0x002C88AB, 0x0040A9D0, 0x003AABD6, 0x0033A2D4, 0x00379ED5, 0x001D6E89, 0x00394F54, 0x00595C4D, 0x00565A4E, 0x00625B52, 0x005E604C, 0x00506048, 0x0058584C, 0x00525C4B,
        0x00525C4B, 0x00535D4C, 0x00535D4C, 0x00545E4D, 0x00545E4D, 0x00535D4C, 0x00525C4B, 0x00515B4B, 0x00566050, 0x00505A4A, 0x00505A4A, 0x00515B4B, 0x00535D4D, 0x005C6656, 0x00596353, 0x005C6251, 0x00565C4B, 0x00555B4A, 0x00505343, 0x00565949,
        0x00555646, 0x005A5B4B, 0x00585949, 0x00585949, 0x005C5D4D, 0x005B5C4C, 0x00575A4A, 0x00575A4A, 0x00545A49, 0x00585E4D, 0x00616756, 0x005E6857, 0x00545E4D, 0x005C6655, 0x004F5746, 0x00565E4D, 0x005B6150, 0x00535948, 0x00515746, 0x00665C4A,
        0x005A5A4C, 0x004D554A, 0x00535345, 0x00605A47, 0x00464B3C, 0x00143937, 0x000E4D55, 0x00003C4F, 0x000B505F, 0x00478A93, 0x0070AFB3, 0x004C8283, 0x001C474A, 0x00274A4E, 0x002C4950, 0x0055787C, 0x00A7D0D3, 0x00CDFDFF, 0x007AB4B9, 0x00205E68,
        0x00084A5C, 0x0010526B, 0x0010506E, 0x00144A68, 0x00003D5E, 0x001D759D, 0x0044B0DA, 0x0040B4DD, 0x00005E83, 0x00006383, 0x000A6983, 0x000C6786, 0x000B657D, 0x0001647A, 0x00007199, 0x0029A9E4, 0x003BB3F4, 0x00106E9C, 0x0000415C, 0x000C4F6A,
        0x00034D65, 0x000B5168, 0x00165270, 0x00094C6D, 0x00055A70, 0x001D6F70, 0x00256254, 0x00080905, 0x00030500, 0x001F2317, 0x00404333, 0x00484C39, 0x00535444, 0x00555547, 0x00414135, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFE, 0xFFFEFDFF, 0xFFFFFEFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x0064685C, 0x0048503F, 0x000F1007, 0x001A1212, 0x0043403B, 0x00202F21, 0x00426856, 0x003A756D, 0x001E6366, 0x00205972, 0x00295E72, 0x0025596A, 0x001F596F, 0x000E5170,
        0x00257090, 0x0075BDD5, 0x0063A7B4, 0x00528AA3, 0x0066859E, 0x00467D92, 0x0076A2C1, 0x0078AFD6, 0x00277B9F, 0x000C4663, 0x00115D69, 0x001B506B, 0x001F5A74, 0x00044762, 0x00175A75, 0x00175770, 0x00134F67, 0x001C5771, 0x0017516E, 0x00095579,
        0x001E4D69, 0x003B6375, 0x00175762, 0x0011596A, 0x005C8699, 0x00E8ECF7, 0x00FFFEFE, 0x00FFFBF7, 0x00F6FDF6, 0x00F1FFFB, 0x00EBF8F0, 0x00FFFFF9, 0x00FCF9F1, 0x00F4FDF3, 0x0098B2A5, 0x004F675F, 0x00768480, 0x007B7C73, 0x00879181, 0x00427375,
        0x0052B0D3, 0x0040ADE3, 0x0049ADE3, 0x00307FA8, 0x00004463, 0x00004656, 0x00045056, 0x000D4E4F, 0x0007464A, 0x00054D55, 0x00004E59, 0x00004664, 0x00025C7B, 0x0036A0BF, 0x0041AACB, 0x001C7393, 0x00135976, 0x001B5C71, 0x00195C6B, 0x00114B68,
        0x000A5767, 0x001A515E, 0x00194C60, 0x00004B64, 0x002A7F9F, 0x004C8CA5, 0x00004956, 0x0000505E, 0x00035A6E, 0x00287D97, 0x004DA0BF, 0x00196C8B, 0x002B809A, 0x004DA4B8, 0x00004A58, 0x00287191, 0x004DA4C4, 0x0051B2D4, 0x0067C5E9, 0x0072C5EB,
        0x0076C1E7, 0x0076C9E9, 0x0075D1EE, 0x0076B7D6, 0x004DA3C1, 0x0041AFD3, 0x003CB3E4, 0x00319FD9, 0x00217DAE, 0x003986A0, 0x0010595D, 0x000B4E65, 0x001B5D70, 0x00125060, 0x00256877, 0x006FBBCE, 0x0077CEEE, 0x0045ABD6, 0x0046B3E7, 0x003AA4C9,
        0x003597B5, 0x0046A7C3, 0x004AB3DC, 0x0040B3EC, 0x003EB1EE, 0x002188B5, 0x00004F6D, 0x000F485D, 0x00215562, 0x0020535D, 0x0017505F, 0x000F526B, 0x000E536E, 0x000E4C5C, 0x0022595E, 0x003D8BB0, 0x003E87A7, 0x004688A1, 0x00145060, 0x000B424F,
        0x001A515E, 0x00124A5B, 0x00114B5E, 0x000D536A, 0x00378EA8, 0x0036A0BF, 0x00319CC2, 0x002688B2, 0x002F88B4, 0x003794BB, 0x0016789A, 0x00348FAE, 0x00236381, 0x00164D62, 0x00095159, 0x00246B6F, 0x00A8DEE5, 0x0075B2BC, 0x005AB3BD, 0x0067C4DE,
        0x0058B9DB, 0x0049B1DC, 0x004BB5E4, 0x003096C1, 0x00096483, 0x00065667, 0x000C545C, 0x00055860, 0x00055860, 0x00055860, 0x0004575F, 0x0004575F, 0x0004575F, 0x0004575F, 0x0003565E, 0x0005565D, 0x0005565D, 0x0006575E, 0x00085960, 0x00095A61,
        0x00095A61, 0x0006575E, 0x0003545B, 0x00015561, 0x000C5767, 0x00004356, 0x00075369, 0x00217C97, 0x002286A8, 0x001C81A8, 0x001E7AA9, 0x00075A76, 0x0031494F, 0x005D6051, 0x00565A4E, 0x005E574E, 0x00595B47, 0x004D5D45, 0x005B5B4F, 0x00505A49,
        0x00505A49, 0x00505A49, 0x00505A49, 0x004E5847, 0x004D5746, 0x004C5645, 0x004C5645, 0x004A5444, 0x00515B4B, 0x004D5747, 0x004D5747, 0x004C5646, 0x004C5646, 0x00545E4E, 0x00505A4A, 0x005A604F, 0x00545A49, 0x00535948, 0x004C4F3F, 0x00535646,
        0x00515242, 0x00575848, 0x00565747, 0x00575848, 0x005D5E4E, 0x005B5C4C, 0x00555848, 0x00555848, 0x00535948, 0x00565C4B, 0x005E6453, 0x005A6453, 0x00505A49, 0x005C6655, 0x00525A49, 0x005B6352, 0x005F6756, 0x00565C4B, 0x00525847, 0x00635947,
        0x00565648, 0x004B5348, 0x00525244, 0x00605A47, 0x0044493A, 0x00103533, 0x000F4E56, 0x001A5067, 0x00003B4F, 0x00074F5B, 0x00135E66, 0x0069B3B9, 0x0095D6DF, 0x0093CAD7, 0x00A2D5E5, 0x00B8E6EE, 0x0090C4CB, 0x003C7A80, 0x000D535A, 0x00044C58,
        0x000D5468, 0x000C4E6B, 0x000C4B6D, 0x001B4D63, 0x0015556E, 0x00004768, 0x00016185, 0x0051B2D4, 0x000F6583, 0x000A5165, 0x00144F5F, 0x00084A5C, 0x00054752, 0x00085663, 0x00167A9C, 0x003EB2ED, 0x0040AAE9, 0x001A6690, 0x00205062, 0x0011546F,
        0x00075169, 0x000D536A, 0x00165270, 0x00084B6C, 0x00075C72, 0x00217374, 0x002B685A, 0x00080905, 0x00040600, 0x00202418, 0x00414434, 0x00494D3A, 0x00545545, 0x00555547, 0x00404034, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFE, 0xFFFEFDFF, 0xFFFFFEFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x005A5E52, 0x00404A3A, 0x000B0D07, 0x0015100F, 0x0045423E, 0x00253224, 0x00335747, 0x003C756D, 0x00216368, 0x00265A71, 0x00275B72, 0x0022586F, 0x00255E74, 0x00245E74,
        0x00175369, 0x0029687D, 0x005798AD, 0x0071B4CD, 0x0079BCD5, 0x0074B6CF, 0x005294AD, 0x00296982, 0x00105069, 0x00105069, 0x001B5872, 0x0013516F, 0x00124E6B, 0x001C546F, 0x001F5770, 0x001A4F6A, 0x00205674, 0x00154B6A, 0x001E5475, 0x000B516E,
        0x00165974, 0x0029627B, 0x002A576C, 0x006A8998, 0x00D9E9F0, 0x00FBFFFF, 0x00FFFDF9, 0x00F8FFF4, 0x00FDFFF9, 0x00FCFFFA, 0x00FDFFFE, 0x00F1F7F6, 0x00F4FFFF, 0x00E3F7F2, 0x00657D75, 0x00283331, 0x00576155, 0x00716D62, 0x00584D55, 0x00344D6F,
        0x003B90C0, 0x00219BC9, 0x0039B7E0, 0x00146677, 0x004C8097, 0x006F94A8, 0x006B9C9A, 0x0084B29B, 0x0084A089, 0x0090B1AD, 0x005F98A7, 0x00589BB0, 0x004195B8, 0x001075A2, 0x003292C0, 0x0061AFD4, 0x007FC3E0, 0x0077C2E2, 0x005CB4D8, 0x001A6788,
        0x00125875, 0x00105166, 0x00155161, 0x000E4C5E, 0x000B5168, 0x00297996, 0x0052A9CB, 0x00216074, 0x00054355, 0x00165F7D, 0x0044A0D3, 0x0043A0D1, 0x003F8AA4, 0x000E4F58, 0x003D7E87, 0x0074BACB, 0x005EB3D3, 0x004BAFDF, 0x004DB5EA, 0x0055B8EA,
        0x005CB8E9, 0x005DB7F0, 0x0059B5F6, 0x006BC0F2, 0x005BB9EE, 0x0052BBEE, 0x0044ABD2, 0x000F6981, 0x00529FAF, 0x0078BECF, 0x0011556C, 0x00045066, 0x00104B54, 0x00326A6F, 0x006ABFD5, 0x0055C5FA, 0x0034A7EA, 0x0050B9EC, 0x0041A4C0, 0x004F9BBF,
        0x003C98C1, 0x0045B4E6, 0x0041B3E8, 0x004FB6E7, 0x002986A7, 0x00025B69, 0x00005757, 0x001C506E, 0x00134962, 0x00155063, 0x00105461, 0x00034D59, 0x000C5765, 0x000A5263, 0x0023697A, 0x003C7C9A, 0x00215F6F, 0x00AFB8C5, 0x004E787F, 0x0000515B,
        0x001C5269, 0x00255A6F, 0x0018616F, 0x0069A1BA, 0x00549CB4, 0x00338CA7, 0x003E9EBC, 0x00308FB0, 0x001F7E9F, 0x00298FAC, 0x001F8EA8, 0x0029869F, 0x00247687, 0x00084C51, 0x0026615D, 0x0087C3C3, 0x0082CFD8, 0x0056B6CE, 0x0051BDDF, 0x0034A8E1,
        0x003CACE1, 0x0046B0DF, 0x0045AED7, 0x00329BC2, 0x001C88B1, 0x002591C0, 0x002491C4, 0x001D8CB4, 0x002793BC, 0x002790B7, 0x00228AAF, 0x00258CB3, 0x00248DB6, 0x00218AB6, 0x00218BBA, 0x00238BC0, 0x002288BC, 0x00278ABC, 0x002A8AB8, 0x002F8BB6,
        0x00368EB6, 0x001F7599, 0x0000486B, 0x000B5470, 0x0014506D, 0x001C4E6A, 0x00144964, 0x00064960, 0x00054E62, 0x00054D5F, 0x00004255, 0x000F363F, 0x0046473D, 0x00585C43, 0x004A5A49, 0x005A5850, 0x00535542, 0x004D5D45, 0x00515948, 0x00555547,
        0x00545446, 0x00545446, 0x00535345, 0x00545446, 0x00545446, 0x00555547, 0x00555547, 0x00505344, 0x004D5041, 0x004D5041, 0x00515445, 0x00535647, 0x00515445, 0x00505344, 0x00515445, 0x004D5544, 0x004E5645, 0x004E5645, 0x004D5544, 0x004B5342,
        0x004B5342, 0x004D5544, 0x004F5746, 0x00565949, 0x00565949, 0x00575A4A, 0x00565C4B, 0x00565C4B, 0x00535B4A, 0x00505847, 0x004E5645, 0x00555A4B, 0x0054594A, 0x00565B4C, 0x00565B4C, 0x0054594A, 0x00535849, 0x00535849, 0x00515647, 0x00505847,
        0x0050574A, 0x00515347, 0x00585546, 0x00555642, 0x00334437, 0x000F393E, 0x000A465C, 0x0012495E, 0x000F485D, 0x000C4659, 0x000B4656, 0x00114E5C, 0x001E5C66, 0x00296A73, 0x002E6F77, 0x00145367, 0x000C4B5F, 0x0006475C, 0x000A4B60, 0x000E5168,
        0x000F5269, 0x000E5168, 0x000E516A, 0x00094968, 0x0005556C, 0x000F536A, 0x00004263, 0x0048ADD4, 0x0041A4D0, 0x00106389, 0x001E7D97, 0x004EAECC, 0x00449CC1, 0x0041A1C9, 0x002C9EC7, 0x003BAAD2, 0x0022789C, 0x00175F7D, 0x000A566D, 0x00134F6D,
        0x000D536A, 0x000C5165, 0x00114E68, 0x00064C69, 0x0002596D, 0x00196D72, 0x002B6C63, 0x000D0C0E, 0x00040503, 0x001E2118, 0x00414435, 0x00494C3C, 0x00545545, 0x0058584A, 0x0049493B, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFE, 0xFFFEFDFF, 0xFFFFFEFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x005A5E52, 0x00444E3E, 0x000D0F09, 0x0015100F, 0x0043403C, 0x00243123, 0x00345848, 0x003D766E, 0x0023656A, 0x002E6279, 0x002F637A, 0x00255B72, 0x00215A70, 0x00245E74,
        0x001E5A70, 0x0016556A, 0x001A596E, 0x0013536C, 0x0016566F, 0x0015556E, 0x0014516B, 0x0013506A, 0x0018536D, 0x001A556F, 0x001A556F, 0x001A5674, 0x001E5875, 0x001C546F, 0x001B536E, 0x0019516C, 0x00114964, 0x00296380, 0x000F4867, 0x001E607D,
        0x001B5872, 0x00215369, 0x005E8292, 0x00CFE5F0, 0x00F3FFFF, 0x00ECEFF3, 0x00FFFFFF, 0x00F4FCF5, 0x00F9FFF9, 0x00FDFFFC, 0x00F2F5F3, 0x00FBFFFE, 0x00F2FBF8, 0x00A8B6B0, 0x0031443B, 0x0028342E, 0x00555758, 0x0038444E, 0x00184354, 0x00387891,
        0x000E5980, 0x003498CE, 0x002CB2EC, 0x003E91B1, 0x004494B1, 0x003A8699, 0x004C888E, 0x005D7979, 0x004A5357, 0x006A7D8C, 0x00507E96, 0x004E8C86, 0x0035858C, 0x003794AD, 0x003B93B7, 0x0074BBE1, 0x007BB7E1, 0x0071B6E8, 0x0056A6E1, 0x0068C1E6,
        0x0061B7DB, 0x00297696, 0x00054F69, 0x000E546C, 0x00004159, 0x00105772, 0x006BB5D1, 0x00215F71, 0x000E4C5C, 0x00095270, 0x0051AFE4, 0x003393C8, 0x00126483, 0x00327A8C, 0x0071BDD0, 0x0067BCDC, 0x0047A8D4, 0x003BABE0, 0x003CADE5, 0x0049B4E7,
        0x0058BDEA, 0x0053B6E8, 0x0053B8EF, 0x004BB1DC, 0x005BC5F4, 0x0036A2D1, 0x000E7399, 0x0032889E, 0x00448F9F, 0x000E5569, 0x00034C68, 0x00055168, 0x00216578, 0x0070BACC, 0x0061C0E1, 0x003AACE1, 0x0045B4F2, 0x00369CCC, 0x00409DBE, 0x00409BC2,
        0x0053BCE5, 0x0041B4E1, 0x0048B6E6, 0x001D7AA7, 0x00004E6F, 0x00024C5E, 0x000E575F, 0x003E6A7B, 0x005D8E9C, 0x00477F8A, 0x004A8892, 0x0060A5AE, 0x00357F8B, 0x00034D5F, 0x001E6A7D, 0x003C8DAE, 0x00388697, 0x00495E66, 0x00396A6C, 0x00268386,
        0x00488A9D, 0x00377C90, 0x004299A9, 0x0042A1B5, 0x002D95AC, 0x002091AB, 0x001E8BA7, 0x0046A3C2, 0x000A5C7B, 0x0030819C, 0x002E849C, 0x004196AC, 0x0061AEBE, 0x0011525A, 0x00205D5F, 0x0067A8B0, 0x004FA1B3, 0x0050B5D5, 0x0034A6CF, 0x0036AADF,
        0x003CAFE2, 0x0039A8DA, 0x003CABD9, 0x003CABD9, 0x003AA9D7, 0x0039A8D8, 0x0031A0D2, 0x002EA2D7, 0x002EA3D6, 0x0032A3D5, 0x0036A5D5, 0x0039A8D6, 0x0037A3D2, 0x0035A1D1, 0x003AA6D6, 0x0030A3D5, 0x0030A1D3, 0x0035A4D4, 0x0037A3D2, 0x0037A2CE,
        0x003EA6D1, 0x003399C3, 0x00147BA2, 0x00044F65, 0x000E4D62, 0x001D5168, 0x0020556A, 0x000F4F61, 0x00064B5A, 0x00084957, 0x000B4655, 0x0009333F, 0x0044473E, 0x005B5E45, 0x00485545, 0x00535149, 0x004E503D, 0x00495941, 0x004B5243, 0x00515445,
        0x00515445, 0x00505344, 0x00505344, 0x00515445, 0x00515445, 0x00525546, 0x00535647, 0x004F5445, 0x004C5142, 0x004C5142, 0x00505546, 0x00525748, 0x00505546, 0x004F5445, 0x00505546, 0x00505847, 0x00515948, 0x00525A49, 0x00525A49, 0x00515948,
        0x00515948, 0x00525A49, 0x00545C4B, 0x00575A4A, 0x00545747, 0x00515444, 0x004E5443, 0x00505645, 0x00505847, 0x00515948, 0x00515948, 0x00505546, 0x00525748, 0x00525748, 0x00525748, 0x00535849, 0x00525748, 0x004F5445, 0x004F5445, 0x00505847,
        0x004F5649, 0x00505246, 0x00575445, 0x00545541, 0x00334437, 0x00103A3F, 0x000B475D, 0x00104A60, 0x00114B61, 0x00104B5F, 0x000A485A, 0x00094757, 0x00094A58, 0x000A4B59, 0x00084A55, 0x00115064, 0x000A4C5F, 0x0008495E, 0x000D4E63, 0x000F5269,
        0x000F5269, 0x000C4F68, 0x000C4F68, 0x00125271, 0x00025067, 0x000B4B63, 0x000A4A6C, 0x002385AD, 0x002487B3, 0x003F97BC, 0x003BA0B9, 0x0042A5CB, 0x006EC6EE, 0x0050ACD5, 0x00016A91, 0x002A8EB1, 0x00085778, 0x00014562, 0x000F5B71, 0x0015516F,
        0x0010566D, 0x000F5468, 0x0015526C, 0x00094F6C, 0x00045B6F, 0x001A6E73, 0x002D6E65, 0x000C0B0D, 0x00030402, 0x001D2017, 0x003F4233, 0x00454838, 0x004D4E3E, 0x004F4F41, 0x003F3F31, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFE, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00666A5E, 0x00475141, 0x000F110B, 0x00161110, 0x00403D39, 0x00222F21, 0x00355949, 0x003D766E, 0x0024666B, 0x00295F76, 0x002C6279, 0x002A6077, 0x00225B71, 0x00225C72,
        0x00255F75, 0x001E5A70, 0x00145066, 0x001D5872, 0x001E5973, 0x001D5872, 0x001C546F, 0x001D5570, 0x001F5671, 0x001D546F, 0x0019506B, 0x00174F6C, 0x001C5471, 0x0018536D, 0x0016516B, 0x00195670, 0x00205D77, 0x0073B1C9, 0x00387890, 0x001E5574,
        0x001A4C63, 0x006A8E9E, 0x00D1E8F0, 0x00F3FFFF, 0x00FAFFFF, 0x00FDFEFF, 0x00F7F7FD, 0x00F4FCFB, 0x00F8FEFD, 0x00F6F9F7, 0x00FBFCFA, 0x00FFFFFC, 0x00CAD1CA, 0x00454D46, 0x00212E26, 0x002F3737, 0x00283648, 0x00103C59, 0x002A788F, 0x00035769,
        0x00246E88, 0x004DA2D0, 0x002899D8, 0x004195C5, 0x00137293, 0x00004B5A, 0x00165E6A, 0x004F8B9B, 0x00589EB5, 0x0052A4BD, 0x004DA1BA, 0x006BA9C1, 0x0052A2C1, 0x005FBFE7, 0x006BCEFA, 0x0070C9F5, 0x0079D0FC, 0x0056BAEA, 0x0040B1E3, 0x004CB9E5,
        0x0052BDE9, 0x0041A7D2, 0x0016729B, 0x00004B70, 0x00014765, 0x000F4D65, 0x0010475C, 0x00114F61, 0x001D5969, 0x00075370, 0x0044A4DA, 0x002C93CC, 0x002F8BB4, 0x005EB4D2, 0x0055AFD2, 0x003FA8D9, 0x0043B4EC, 0x0034AAE5, 0x0030A5DC, 0x0045B2DE,
        0x0047ABCE, 0x003F9BBE, 0x0046A1C6, 0x0049B1CE, 0x0039A2C3, 0x0040A2C4, 0x00469AB6, 0x003C8293, 0x00135462, 0x0003485C, 0x00004865, 0x00135C7A, 0x0062B5D5, 0x005FBFE7, 0x0042AEDE, 0x003EB0E5, 0x0034A1D4, 0x003495C1, 0x003D95B9, 0x0044B0DA,
        0x0041B3DC, 0x0033A5CE, 0x00238AB1, 0x00004D72, 0x00114F6D, 0x00124C62, 0x00155161, 0x008CB0B0, 0x0083ACAE, 0x006C9D9F, 0x0082BBBD, 0x00A8E8EC, 0x005DA4AE, 0x0000495C, 0x0014667F, 0x003499BF, 0x002F8B9E, 0x0053767A, 0x00346A63, 0x0061BAB7,
        0x00327D8B, 0x00005065, 0x0021839B, 0x004F99B5, 0x0081D5F1, 0x00318FAC, 0x00146E8C, 0x0052A0BD, 0x00468EA6, 0x002B778A, 0x00004B5A, 0x0014596D, 0x000B4D5F, 0x0013505E, 0x00064651, 0x00226E80, 0x004DA9C6, 0x0040B0DA, 0x002CA7D9, 0x002FA2D4,
        0x003AB0E3, 0x002FA7DB, 0x002FA7DB, 0x0030A4D9, 0x0036A6DA, 0x0034A3D3, 0x0032A5D2, 0x002AA1D9, 0x002CA3DB, 0x002FA4DB, 0x002DA1D8, 0x00289CD1, 0x002B9DD2, 0x0030A0D4, 0x002E9ED2, 0x00229FCC, 0x00219ECB, 0x0027A4D1, 0x0028A5D2, 0x0028A1D2,
        0x0030A9DA, 0x0033ACDE, 0x0028A1D3, 0x001E7488, 0x0010596D, 0x00104A60, 0x00155064, 0x00125466, 0x000D5261, 0x000F505E, 0x00154E5D, 0x00003242, 0x003C423D, 0x00585A44, 0x00455040, 0x004D4C42, 0x004A4E3B, 0x00495942, 0x004F5145, 0x004B5243,
        0x004B5243, 0x004B5243, 0x004B5243, 0x004C5344, 0x004D5445, 0x004E5546, 0x004F5647, 0x004E5848, 0x004B5545, 0x004A5444, 0x004E5848, 0x004F5949, 0x004D5747, 0x004B5545, 0x004C5646, 0x00515948, 0x00525A49, 0x00545C4B, 0x00555D4C, 0x00555D4C,
        0x00555D4C, 0x00565E4D, 0x00575F4E, 0x005B5E4E, 0x00565949, 0x00525545, 0x00505645, 0x00545A49, 0x00575F4E, 0x0058604F, 0x0058604F, 0x00535849, 0x00595E4F, 0x00575C4D, 0x00565B4C, 0x005B6051, 0x00575C4D, 0x00515647, 0x0054594A, 0x004E5645,
        0x004E5548, 0x004E5044, 0x00565344, 0x00535440, 0x00334437, 0x00113B40, 0x000D495F, 0x000A4761, 0x000E4B65, 0x00114F67, 0x000F5065, 0x000F5065, 0x000D5164, 0x000B4F62, 0x00064B5C, 0x000C4D62, 0x000B4C61, 0x000C4D62, 0x000D5067, 0x0010536A,
        0x000D5069, 0x000C4F68, 0x000B4E67, 0x000F4C6C, 0x00024C64, 0x0018546C, 0x000E4B6D, 0x002584AC, 0x001578A4, 0x000B668B, 0x002D9BB3, 0x001682AC, 0x002782AF, 0x00004A74, 0x001A759A, 0x002E82A5, 0x00014463, 0x0010526B, 0x00055469, 0x00124E6C,
        0x000E546B, 0x000E5367, 0x0016536D, 0x000C526F, 0x00065D71, 0x001D7176, 0x0032736A, 0x000E0D0F, 0x00050604, 0x001F2219, 0x00414435, 0x00464939, 0x004D4E3E, 0x004E4E40, 0x003D3D2F, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFE, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00696D61, 0x00475141, 0x000F110B, 0x0015100F, 0x003D3A36, 0x00222F21, 0x00375B4B, 0x003B746C, 0x0023656A, 0x002E647B, 0x002B6178, 0x002D637A, 0x002B647A, 0x00235C72,
        0x00215A70, 0x00265F75, 0x00265F75, 0x001C546F, 0x00225974, 0x00245B76, 0x00205772, 0x001E536E, 0x001E536E, 0x0021536F, 0x0020526E, 0x001F5671, 0x001C546F, 0x0018526F, 0x0013526E, 0x000F4F68, 0x00216179, 0x0067A6BA, 0x002C6A7C, 0x001F4A65,
        0x007093A7, 0x00CCE2ED, 0x00F6FFFF, 0x00FFFFFE, 0x00F7F5F5, 0x00FCFCFF, 0x00F6F7FF, 0x00F8FEFF, 0x00F6FBFE, 0x00FDFFFF, 0x00FFFFFC, 0x00D3D5CF, 0x004B4F49, 0x00252C25, 0x002A322B, 0x00273649, 0x00103F54, 0x002C6F86, 0x00498497, 0x006EABB5,
        0x004D98A1, 0x00156174, 0x005491B3, 0x004295C2, 0x0016667F, 0x0029646D, 0x0073A4AE, 0x005AA6BC, 0x002FA4BF, 0x0043B1C9, 0x0074BAD1, 0x007CB8D5, 0x0062AECB, 0x003F9AB9, 0x0043A6C6, 0x003C9DBE, 0x0041A5C7, 0x002DA1C0, 0x0037BADB, 0x004EC7F9,
        0x0032ACE0, 0x0042B9F0, 0x0043B3E8, 0x000F6F9D, 0x00004C70, 0x0018516A, 0x001A4859, 0x00104E60, 0x00104C5C, 0x000E5979, 0x0047ABE2, 0x0033A0DE, 0x0040A6D7, 0x0050B4DE, 0x0039A5D5, 0x0034AAE5, 0x0040B4ED, 0x0043B3E7, 0x002D95C0, 0x00005171,
        0x000C556B, 0x005893A3, 0x00528693, 0x002B767F, 0x0029707E, 0x00518FA1, 0x005A8C98, 0x005F898E, 0x00336367, 0x00195A69, 0x000B5B74, 0x0065B0D6, 0x0064C6F4, 0x0036AAE1, 0x0042B3EC, 0x0038A3D6, 0x00218AB3, 0x0047A7CB, 0x004594BB, 0x003099CA,
        0x001585B0, 0x002D98BE, 0x00137091, 0x00074D6B, 0x00164D68, 0x00184E65, 0x000C485E, 0x0092B3A5, 0x004B716B, 0x0050817F, 0x00447A7B, 0x00447D7E, 0x00387981, 0x00024F62, 0x000C6280, 0x00309DC9, 0x001C7A91, 0x00688E90, 0x003E6E62, 0x0090D6D0,
        0x002B737F, 0x00167C93, 0x002F8EAF, 0x005DA8C2, 0x007BD1E9, 0x0027839C, 0x003890A8, 0x0054A0B6, 0x00438B9C, 0x00297881, 0x00025B5F, 0x00134B5E, 0x000D475A, 0x000E4D61, 0x001D667C, 0x00499FBD, 0x004DB6DF, 0x002FA5D9, 0x002EAEE9, 0x003CACDA,
        0x003AB3E4, 0x0028A8DD, 0x002BA9E0, 0x0033A7DE, 0x0038A3D6, 0x00309BC7, 0x0037A6CC, 0x003DA6CF, 0x00339CC7, 0x002F9DCD, 0x0033A3D7, 0x002DA1D6, 0x002A9FD6, 0x002A9FD6, 0x00269BD2, 0x0029A2CE, 0x00249FCB, 0x0025A2CF, 0x0024A1D3, 0x001E9CD2,
        0x0021A0D7, 0x0026A7E0, 0x0024A6E1, 0x003BA2BD, 0x001B7593, 0x00085471, 0x0008516D, 0x00085871, 0x00085A73, 0x000B556D, 0x000C4E67, 0x00074458, 0x003A4543, 0x00545541, 0x00444E3E, 0x004D4C42, 0x00484E3B, 0x00475740, 0x00515046, 0x00495343,
        0x00495343, 0x00495343, 0x004A5444, 0x004B5545, 0x004C5646, 0x004D5747, 0x004E5848, 0x004E5949, 0x004B5646, 0x004B5646, 0x004E5949, 0x004F5A4A, 0x004C5747, 0x004B5646, 0x004B5646, 0x00505847, 0x00515948, 0x00525A49, 0x00545C4B, 0x00545C4B,
        0x00545C4B, 0x00535B4A, 0x00535B4A, 0x00545747, 0x00525545, 0x00505343, 0x00515746, 0x00575D4C, 0x0058604F, 0x00565E4D, 0x00535B4A, 0x00515647, 0x005A5F50, 0x00565B4C, 0x0054594A, 0x005A5F50, 0x00555A4B, 0x004C5142, 0x00515647, 0x004D5544,
        0x004C5346, 0x004C4E42, 0x00545142, 0x0052533F, 0x00324336, 0x00123C41, 0x000E4A60, 0x00084965, 0x000B4C68, 0x000C4D69, 0x000A4D66, 0x000A4D66, 0x000C4F68, 0x000A5068, 0x00074D65, 0x000B4C61, 0x000C4D62, 0x000C4F66, 0x000E5168, 0x000D5069,
        0x000C4F68, 0x000B4E67, 0x00094F67, 0x000E4B6B, 0x000F576F, 0x001A526B, 0x00094164, 0x002D89B2, 0x000F729E, 0x00004064, 0x002999B0, 0x004FBEEC, 0x000B6594, 0x00004974, 0x0018698E, 0x00438EAE, 0x000C4865, 0x00135169, 0x00045164, 0x00104C6A,
        0x000D536A, 0x000D5266, 0x0015526C, 0x000C526F, 0x00045B6F, 0x00196D72, 0x0032736A, 0x000D0C0E, 0x00050604, 0x001E2118, 0x00404334, 0x00474A3A, 0x004F5040, 0x00525244, 0x00424234, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFE, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x005D6155, 0x00444E3E, 0x000D0F09, 0x0015100F, 0x003B3834, 0x00233022, 0x003A5E4E, 0x0039726A, 0x00216368, 0x002C657B, 0x00215A70, 0x00245D73, 0x002E647B, 0x00295F76,
        0x00255B72, 0x00265C73, 0x0022586F, 0x001E5570, 0x001E5570, 0x001C536E, 0x001C516C, 0x001F546F, 0x00245672, 0x00235571, 0x001E506C, 0x001F556C, 0x001A526D, 0x0014506D, 0x00185674, 0x0012526B, 0x001B556B, 0x00215A69, 0x001C525D, 0x00728FA4,
        0x00D4E9F8, 0x00F3FFFF, 0x00F4F5F1, 0x00FFFFFB, 0x00FFFFFE, 0x00FBFCFF, 0x00F7F9FF, 0x00F2F8FF, 0x00F3F8FB, 0x00FBFFFE, 0x00E0E2DC, 0x00545950, 0x00232A23, 0x001D2623, 0x00384341, 0x00023052, 0x00255D6E, 0x00548387, 0x0093AFB0, 0x009DBCBF,
        0x00538585, 0x001B483F, 0x002C4335, 0x00265973, 0x005D8C94, 0x00809995, 0x00B8C1C4, 0x0090AEBF, 0x004D8DA6, 0x006595AD, 0x00A8AFC3, 0x007AADA6, 0x004C8882, 0x000B524F, 0x00085258, 0x004990A4, 0x00418CAC, 0x0049A1C6, 0x004DAFD7, 0x003AB3E5,
        0x0038B3EB, 0x0029A9E4, 0x0035B1ED, 0x0044B1E7, 0x00167099, 0x00003F5C, 0x0021566B, 0x00175468, 0x00094759, 0x000A5777, 0x0040A5DC, 0x002D9EDD, 0x0039A6DA, 0x003BAADC, 0x0038AEE9, 0x0037AEE6, 0x0038A7D9, 0x002A8BB1, 0x00095873, 0x00064252,
        0x005E838B, 0x00BBCDCE, 0x00C6CCC7, 0x00B5D1CB, 0x008EA9A6, 0x00BDD1D2, 0x00B6C4C2, 0x00D4E4DD, 0x007FA29E, 0x001E5B67, 0x006ABED7, 0x0064B9E9, 0x0041B0E2, 0x0043BAF1, 0x00288EC3, 0x00207DAA, 0x00369DBE, 0x002281A2, 0x001B668C, 0x002E8DBF,
        0x002588B4, 0x00298AAE, 0x00176D8B, 0x00054861, 0x0019556D, 0x004B8A9F, 0x004D94A8, 0x00749B8C, 0x00568380, 0x0052868C, 0x00376E71, 0x00609696, 0x00468385, 0x00004355, 0x000C6685, 0x00309CCC, 0x00247B95, 0x00AFD0D3, 0x0085A79C, 0x0091BEBB,
        0x005796A4, 0x002087A0, 0x004C9DC3, 0x0021909A, 0x001E919B, 0x0032A0AC, 0x0022828F, 0x003B8591, 0x00438189, 0x008FCFD0, 0x001B625F, 0x00215566, 0x000F485D, 0x00084E66, 0x004598B8, 0x005ABCE4, 0x0036A5D7, 0x002CA5DD, 0x0025A4E1, 0x0046B2E1,
        0x0031AADB, 0x0025A6D7, 0x002FAADC, 0x0038A1D2, 0x002583AE, 0x000B6889, 0x00046783, 0x001A6C7D, 0x000C647C, 0x00177899, 0x00319AC5, 0x0035A6D8, 0x002BA1D5, 0x00289FD6, 0x002BA2D9, 0x0035A6D1, 0x002EA1CE, 0x002EA1D3, 0x002FA3D8, 0x002AA1D9,
        0x0027A1DD, 0x0029A4E2, 0x002BA6E6, 0x003CB5DF, 0x00319ECA, 0x002E8CB9, 0x002D88B5, 0x002688B2, 0x00258AB1, 0x002C89B0, 0x003085AD, 0x001C637E, 0x003E4D50, 0x00555543, 0x00495140, 0x00515145, 0x00464F3B, 0x0041503B, 0x00514B44, 0x004A5444,
        0x004A5444, 0x004A5444, 0x004A5444, 0x004B5545, 0x004D5747, 0x004E5848, 0x004F5949, 0x004E5949, 0x004B5646, 0x004A5545, 0x004D5848, 0x004E5949, 0x004C5747, 0x004B5646, 0x004B5646, 0x00505847, 0x00505847, 0x00515948, 0x00525A49, 0x00525A49,
        0x00525A49, 0x00505847, 0x004F5746, 0x00535646, 0x00515444, 0x00515444, 0x00535948, 0x00595F4E, 0x0058604F, 0x00555D4C, 0x00515948, 0x00535849, 0x005C6152, 0x00575C4D, 0x0054594A, 0x005A5F50, 0x00535849, 0x004A4F40, 0x004F5445, 0x004B5342,
        0x004A5144, 0x004B4D41, 0x00535041, 0x0051523E, 0x00324336, 0x00123C41, 0x000E4A60, 0x000A4B67, 0x000B4C68, 0x00094C67, 0x00064964, 0x00054863, 0x00064A67, 0x00074B68, 0x00054966, 0x00094C63, 0x000B4E65, 0x000C4F66, 0x000B4E67, 0x000A4D66,
        0x00094F67, 0x00094E69, 0x00094E69, 0x000D4868, 0x00125A72, 0x000F4861, 0x000B4568, 0x001A79A1, 0x001C7FAB, 0x00217A9F, 0x002A94AC, 0x000F78A1, 0x004499C6, 0x00075580, 0x001D6E94, 0x002C799A, 0x00185472, 0x00125068, 0x000C586A, 0x0014506E,
        0x0011576E, 0x000F5468, 0x0015526C, 0x000D5370, 0x0002596D, 0x00166A6F, 0x0032736A, 0x000C0B0D, 0x00020301, 0x001A1D14, 0x003B3E2F, 0x00424535, 0x004C4D3D, 0x00505042, 0x00414133, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFE, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x005C6054, 0x00434D3D, 0x000C0E08, 0x00161110, 0x003A3733, 0x00253224, 0x003E6252, 0x00387169, 0x00206267, 0x00255E74, 0x0020596F, 0x00235C72, 0x00285E75, 0x00285C73,
        0x002A5E75, 0x002D5F76, 0x0026586F, 0x001F5772, 0x001E5671, 0x001C536E, 0x0019506B, 0x001D526D, 0x00205570, 0x001E536E, 0x001C4E6A, 0x00124B60, 0x001A536C, 0x0015516E, 0x00175573, 0x001D5572, 0x001D4F65, 0x0025515E, 0x0079A0A8, 0x00DAE9F2,
        0x00F0FCFF, 0x00F8FEFD, 0x00FDFCF8, 0x00FEFBF6, 0x00FFFDFC, 0x00FDFFFF, 0x00F1F5FA, 0x00FAFEFF, 0x00F7FDFC, 0x00D8DFD8, 0x00565E53, 0x001F281E, 0x00202E2A, 0x001F3033, 0x0023363D, 0x0000344F, 0x004F727C, 0x00A3AEA6, 0x008EA093, 0x00A1B6AE,
        0x007E8580, 0x005A5B47, 0x005D6842, 0x004D4A4C, 0x00829189, 0x00A0B7A9, 0x0096A39B, 0x0096A1A5, 0x0099B1BD, 0x006D909D, 0x006F969F, 0x005B90B1, 0x00447F99, 0x004B8DA0, 0x0070B2CB, 0x0085C7EA, 0x007BC2EE, 0x005CAFDC, 0x00237FAA, 0x000F79A8,
        0x0040B0E4, 0x0039B4EC, 0x001F9FDA, 0x0039B2EA, 0x0048B1E2, 0x00237BA0, 0x00004868, 0x000A4A62, 0x00115064, 0x00085575, 0x003399CE, 0x002899D7, 0x003FAFE3, 0x0044B7EA, 0x0027A4E1, 0x002FA0D9, 0x00359BC6, 0x00176A86, 0x00004052, 0x006996A3,
        0x00CAE4EA, 0x00BDC2C0, 0x00C6BDB3, 0x00D9E0D3, 0x00C1C6BD, 0x00E5E9E4, 0x00B2B6B0, 0x00A0ADA5, 0x007CA0A0, 0x00478C9F, 0x0065C3E6, 0x0044A8E2, 0x0040B7E8, 0x002A99C1, 0x00227095, 0x00357FA3, 0x002E91B1, 0x00117492, 0x000B5273, 0x003286B6,
        0x00308CB7, 0x002A88AC, 0x00196F8D, 0x00105870, 0x0063A4B9, 0x00458D9F, 0x001C6D7C, 0x00245956, 0x0045838B, 0x00357789, 0x002B6773, 0x0078AEAF, 0x005F9798, 0x001D6674, 0x000A6482, 0x00339BCA, 0x00267A94, 0x00426267, 0x0036534A, 0x004E6C6D,
        0x003E7989, 0x00319BB3, 0x0033769D, 0x008AC1C4, 0x00599398, 0x0088C2C8, 0x0068979F, 0x0081A2AB, 0x00617F84, 0x00ADD4D2, 0x002A5D56, 0x00144C5D, 0x0006475C, 0x003B8BA8, 0x004FAED5, 0x002B97C6, 0x0032A6DB, 0x0034ABE3, 0x002BA1DC, 0x003DA6D9,
        0x002AA0CF, 0x0034B1DD, 0x0030A1C9, 0x002C83A5, 0x00115572, 0x00044E60, 0x0000515D, 0x00044C56, 0x001F6F80, 0x003995B2, 0x003BA4CB, 0x00309FCF, 0x002A9FD2, 0x002AA0D3, 0x00279ECF, 0x00309CCB, 0x002B99C9, 0x002B9ACC, 0x0030A0D5, 0x0032A3DB,
        0x0031A3DF, 0x0031A4E1, 0x0031A3E2, 0x001DA1D6, 0x00269DD4, 0x00349ED4, 0x00359FD4, 0x002E9FD1, 0x002EA2D1, 0x0035A4D4, 0x0038A0CF, 0x00227493, 0x003B4E55, 0x00555243, 0x004C5241, 0x00525546, 0x0047533D, 0x0042513C, 0x00564D49, 0x004C5344,
        0x004C5344, 0x004C5344, 0x004C5344, 0x004D5445, 0x004E5546, 0x004F5647, 0x00505748, 0x004D5747, 0x004A5444, 0x004A5444, 0x004D5747, 0x004E5848, 0x004C5646, 0x004B5545, 0x004B5545, 0x00525A49, 0x00515948, 0x00505847, 0x00515948, 0x00515948,
        0x00515948, 0x00505847, 0x004F5746, 0x00595C4C, 0x00555848, 0x00535646, 0x00525847, 0x00565C4B, 0x00565E4D, 0x00555D4C, 0x00535B4A, 0x00565B4C, 0x005B6051, 0x00585D4E, 0x00565B4C, 0x00595E4F, 0x00535849, 0x004C5142, 0x004F5445, 0x00495140,
        0x00495043, 0x004A4C40, 0x00535041, 0x0051523E, 0x00324336, 0x00113B40, 0x000D495F, 0x000B4B63, 0x000D4D65, 0x000C4E67, 0x000A4B67, 0x000A4D68, 0x000C4E6B, 0x000C4E6B, 0x00084B6A, 0x000A4D64, 0x000B4E65, 0x000A4D66, 0x00084B64, 0x00064C64,
        0x00084D68, 0x00094E69, 0x00074E69, 0x000F4868, 0x00034D65, 0x000C4C64, 0x00014465, 0x000D6F97, 0x0041A2CE, 0x003786AD, 0x0005607B, 0x00004865, 0x00247296, 0x004F9EC7, 0x00318DB6, 0x0020779F, 0x00064A6D, 0x000C4963, 0x00064E60, 0x00124E6C,
        0x0010566D, 0x000E5367, 0x0016536D, 0x00105673, 0x00065D71, 0x001C7075, 0x003C7D74, 0x00111012, 0x00060705, 0x001D2017, 0x003C3F30, 0x00414434, 0x004B4C3C, 0x004F4F41, 0x00404032, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFE, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00616559, 0x00434D3D, 0x000D0F09, 0x00161110, 0x00393632, 0x00273426, 0x00436757, 0x003A736B, 0x0023656A, 0x00266076, 0x00276177, 0x00286177, 0x00265C73, 0x0022566D,
        0x0025576E, 0x00285870, 0x0026566E, 0x001C5771, 0x00205B75, 0x00205B75, 0x001D5570, 0x0019516C, 0x001A516C, 0x001B526D, 0x001A516C, 0x00195366, 0x0019556D, 0x00175370, 0x00104B6B, 0x00184C6A, 0x00285167, 0x006E8C97, 0x00CFE5EA, 0x00F8FDFC,
        0x00FBFFFE, 0x00F8FBF9, 0x00FAFDFB, 0x00FDFFFE, 0x00F5F8F6, 0x00F2F7F6, 0x00FBFFFF, 0x00F7FCFB, 0x00DFE5E0, 0x00565E53, 0x001D2A1C, 0x0018291E, 0x001C3230, 0x00112C36, 0x00173344, 0x00588289, 0x00A3B6B9, 0x0086908A, 0x00A3B5A8, 0x00707D6F,
        0x00564D43, 0x0065584A, 0x00676553, 0x0077644F, 0x00585142, 0x0088988D, 0x008FAFA4, 0x0078968B, 0x0091AFAA, 0x0080B8B9, 0x005DB5BB, 0x0068B4FC, 0x0065B5EC, 0x007BCBF4, 0x005CADD0, 0x002D7EA4, 0x0057ADD7, 0x003798BA, 0x002A91AA, 0x000D638D,
        0x00197AA6, 0x003FB0E2, 0x0042C0F6, 0x0029ABE0, 0x003DB7EB, 0x003FAEDE, 0x0007709C, 0x000E516C, 0x0008495E, 0x000C5979, 0x0043A8DC, 0x0030A1DA, 0x0039A8DA, 0x003BB1E2, 0x002EAEE9, 0x003FA9E8, 0x002B8BB9, 0x00156681, 0x000A4F60, 0x00458090,
        0x008DBAC7, 0x008DABB0, 0x00859692, 0x0097A9A2, 0x00879C99, 0x007C9192, 0x00627778, 0x00648384, 0x00588F9C, 0x00489EC2, 0x003CA8DE, 0x0040B1F4, 0x0029A3CB, 0x00288699, 0x0085B5C7, 0x0077ADCB, 0x001F82A2, 0x002088A5, 0x000A516C, 0x003B90BD,
        0x002685AD, 0x002F90B4, 0x000E6988, 0x001D6783, 0x0084C7DC, 0x002B7280, 0x0000434F, 0x0008505C, 0x004895AF, 0x0063B2D3, 0x00468AA1, 0x005D9499, 0x006FA4A1, 0x006AB1BB, 0x00126983, 0x00319ECA, 0x003189A1, 0x00517B80, 0x0030524C, 0x00587278,
        0x004B8B9D, 0x00279BB2, 0x00306F95, 0x00837E7B, 0x00676A68, 0x007D8585, 0x00686F72, 0x007E8386, 0x005A6666, 0x006C8C87, 0x0026564A, 0x000A4B5A, 0x004590A6, 0x004DA7C9, 0x00339CC7, 0x002295C7, 0x0030A4D9, 0x0036A6DA, 0x003CA9DD, 0x003DA4DD,
        0x002397C6, 0x0038B0D4, 0x002687A1, 0x002C6C7E, 0x0025535E, 0x0033686B, 0x00195E5B, 0x00166A83, 0x00449EBD, 0x0055B9E3, 0x003AA9DB, 0x00269ACF, 0x002CA2D5, 0x0033A8D5, 0x0031A3CC, 0x002FA1D0, 0x002D9FCE, 0x002B9ED0, 0x002FA2D5, 0x0032A4D9,
        0x002FA3DA, 0x002EA2D9, 0x002DA1D8, 0x0020A2D7, 0x00269BD2, 0x00309AD0, 0x002E9BCF, 0x00259BCC, 0x00219ECB, 0x00259DCB, 0x002598C5, 0x00187094, 0x00334954, 0x00535042, 0x004C4F3F, 0x00515445, 0x0048553F, 0x00455341, 0x005A4E4C, 0x004F5243,
        0x004F5243, 0x004E5142, 0x004E5142, 0x004F5243, 0x00505344, 0x00505344, 0x00515445, 0x004E5344, 0x004B5041, 0x004B5041, 0x004F5445, 0x00505546, 0x004F5445, 0x004E5344, 0x004F5445, 0x00505847, 0x004F5746, 0x004D5544, 0x004E5645, 0x004F5746,
        0x00505847, 0x00505847, 0x004F5746, 0x00545747, 0x00515444, 0x004E5141, 0x004B5140, 0x004C5241, 0x004B5342, 0x004B5342, 0x004A5241, 0x004F5445, 0x00505546, 0x00505546, 0x004F5445, 0x004F5445, 0x004C5142, 0x00494E3F, 0x00484D3E, 0x0048503F,
        0x00484F42, 0x004A4C40, 0x00535041, 0x0051523E, 0x00314235, 0x00103A3F, 0x000B475D, 0x000C4B5F, 0x000F4E63, 0x00104F64, 0x000C4C64, 0x000B4B64, 0x000A4B67, 0x00084866, 0x00044462, 0x00094C63, 0x000A4D66, 0x00094C65, 0x00064962, 0x00054A65,
        0x00084D68, 0x00064C69, 0x00044A67, 0x00164F6F, 0x00004B62, 0x00084E65, 0x00004969, 0x001A83AA, 0x0048A6D3, 0x0010557D, 0x0000415F, 0x00004D5A, 0x00064D68, 0x0016698F, 0x004DB6E2, 0x0009709D, 0x00003C63, 0x00175874, 0x000C5162, 0x000F4B69,
        0x000E546B, 0x000B5064, 0x0014516B, 0x00105673, 0x00075E72, 0x001E7277, 0x00418279, 0x00121113, 0x00080907, 0x001F2219, 0x003E4132, 0x00424535, 0x004B4C3C, 0x004E4E40, 0x003F3F31, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFE, 0xFFFDFCFE, 0xFFFFFEFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x005C6054, 0x00454F3F, 0x000E100A, 0x00171211, 0x00393632, 0x00283527, 0x00456959, 0x003C756D, 0x0026686D, 0x00245E74, 0x00205A70, 0x001F586E, 0x00245A71, 0x00265A71,
        0x0023556C, 0x00215169, 0x0024526A, 0x0015526C, 0x0017546E, 0x0016536D, 0x0016516B, 0x0016516B, 0x0019516C, 0x0018506B, 0x00154D68, 0x001B5669, 0x000B475D, 0x00104E6C, 0x000F4868, 0x00235271, 0x00496B82, 0x00BED2DD, 0x00E2EEF2, 0x00FFFEF6,
        0x00FEFEF8, 0x00FAFEF9, 0x00F5FAF9, 0x00F5FBFA, 0x00FAFFFE, 0x00FBFFFC, 0x00FDFFFC, 0x00E7EBE6, 0x0050554C, 0x00222B1E, 0x001E2E1D, 0x00243A2E, 0x00223E3E, 0x0001212E, 0x0041637A, 0x00CFC6BC, 0x007A8F8C, 0x0094B6B6, 0x00717E7C, 0x00565547,
        0x005F5F4F, 0x005C5756, 0x00635061, 0x00696F4C, 0x006F6252, 0x00544A4A, 0x007D918C, 0x0096B3A4, 0x008B9B90, 0x00ADC0C7, 0x0081AEC3, 0x0029889C, 0x004CAAB0, 0x006EC8C3, 0x000A5E5C, 0x002F7E8B, 0x0058A8BF, 0x0000546A, 0x000A6272, 0x00549BC1,
        0x0010658D, 0x001179A4, 0x003AB3E4, 0x0032B6EB, 0x0022A8DE, 0x0032B1E8, 0x0039B4EC, 0x00286C89, 0x0004475E, 0x000F5C7C, 0x003EA1D3, 0x002C9BD3, 0x0043B3E1, 0x003AAEDD, 0x0030B1EA, 0x00369EE3, 0x003291C3, 0x000F6180, 0x00075369, 0x00004C62,
        0x0000465A, 0x0014505C, 0x00013437, 0x00001E1D, 0x00002124, 0x0000272E, 0x0000262E, 0x002D616D, 0x00569DB8, 0x003C9FD3, 0x00259DE5, 0x002FABF2, 0x00229EC0, 0x0055A6A9, 0x00759398, 0x005D879E, 0x002E90B2, 0x00087591, 0x0012586F, 0x003794BB,
        0x002689AF, 0x003098BB, 0x00076687, 0x00004E6B, 0x001F6277, 0x00084957, 0x000F545D, 0x00156982, 0x0058B1D6, 0x0051A9D7, 0x00236C8A, 0x005C9299, 0x00417470, 0x00195D64, 0x00146A82, 0x0033A5CD, 0x0044A2B9, 0x0052868C, 0x003B6361, 0x005D7C85,
        0x00539BAD, 0x00209DB1, 0x002D6D8F, 0x005C7C69, 0x00406453, 0x004A6E62, 0x003B5751, 0x005D706D, 0x00475D58, 0x004A6F65, 0x001E5143, 0x00428899, 0x0063B6CC, 0x0041A3C5, 0x002596C1, 0x00269CCF, 0x0032A7DA, 0x0039A5D5, 0x0042A8D8, 0x003CA2DD,
        0x001688B7, 0x0038A9C9, 0x003991A2, 0x0072A6AD, 0x008AA9AA, 0x0086AFA8, 0x00356F64, 0x0046A8D2, 0x004CB3E4, 0x003FAEE6, 0x0028A0DC, 0x00229DD7, 0x00289ED1, 0x002D9FC8, 0x0034A2C6, 0x00239CCD, 0x00259ECF, 0x00269FD0, 0x0028A1D2, 0x002EA4D7,
        0x002FA5D8, 0x002FA5D8, 0x0030A6D9, 0x002AA6D6, 0x002E9DCF, 0x00369DCE, 0x0036A0CF, 0x00289EC8, 0x00229EC7, 0x0027A1C9, 0x002DA2C9, 0x00106E92, 0x00304A56, 0x00565345, 0x004A4D3D, 0x004C4F40, 0x0046533D, 0x0042503E, 0x00564947, 0x00505042,
        0x00505042, 0x004F4F41, 0x004F4F41, 0x004F4F41, 0x004F4F41, 0x00505042, 0x00505042, 0x004E5142, 0x004B4E3F, 0x004C4F40, 0x004F5243, 0x00515445, 0x00505344, 0x004F5243, 0x00505344, 0x004C5443, 0x004B5342, 0x00495140, 0x004A5241, 0x004C5443,
        0x004E5645, 0x004E5645, 0x004E5645, 0x00535646, 0x00525545, 0x00505343, 0x004D5342, 0x004C5241, 0x00495140, 0x0048503F, 0x00464E3D, 0x004E5344, 0x004D5243, 0x004E5344, 0x004F5445, 0x004D5243, 0x004C5142, 0x004C5142, 0x004A4F40, 0x00474F3E,
        0x00484F42, 0x004A4C40, 0x00535041, 0x0052533F, 0x00314235, 0x000F393E, 0x000A465C, 0x000D4B5D, 0x00104E60, 0x00104D61, 0x000D4C61, 0x000E4B65, 0x000E4D69, 0x000F4E6A, 0x000D4B69, 0x00074A63, 0x00094C65, 0x00084B64, 0x00044A62, 0x00054A65,
        0x00064D68, 0x00064C69, 0x00024865, 0x00114768, 0x00035168, 0x0000485E, 0x00207291, 0x003BA8CE, 0x002C8AB7, 0x0006446D, 0x00124F6F, 0x000F5358, 0x0005495C, 0x00005075, 0x002FA1D0, 0x002C9DCF, 0x00005380, 0x00084A67, 0x000F5163, 0x00134F6D,
        0x0011576E, 0x000C5165, 0x00124F69, 0x000C526F, 0x0000576B, 0x00166A6F, 0x003A7B72, 0x000C0B0D, 0x00020301, 0x001A1D14, 0x003B3E2F, 0x003F4232, 0x00474838, 0x004A4A3C, 0x003A3A2C, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFE, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x0062665A, 0x00485545, 0x00090B05, 0x001B1313, 0x003C3734, 0x00273124, 0x00345949, 0x00357169, 0x001D676B, 0x00235C72, 0x00225B71, 0x00215A70, 0x0020596F, 0x0020596F,
        0x001E576D, 0x001C556B, 0x001A5369, 0x00245075, 0x001B5172, 0x000E516C, 0x0011546B, 0x00144D66, 0x001F546F, 0x00164D6C, 0x00115170, 0x00194C7E, 0x0049799B, 0x006795A6, 0x0073A2AA, 0x00608992, 0x006F8590, 0x00E6E2E8, 0x00FFFCFC, 0x00EEFCF8,
        0x00EBF9F7, 0x00EEFCFA, 0x00EBFBFA, 0x00F2FFFE, 0x00F2FFFA, 0x00F8FFFB, 0x00D9E2D8, 0x005E5E46, 0x00192A1D, 0x00132C30, 0x00193147, 0x00083148, 0x00215A69, 0x00638F96, 0x00A7B3B5, 0x00829189, 0x00A5B2AA, 0x00737C72, 0x00474D42, 0x00606054,
        0x00625C51, 0x005A5144, 0x006E6355, 0x005E5C4A, 0x00696455, 0x006B6356, 0x00585247, 0x0087887F, 0x00A7B2AA, 0x008BA098, 0x00A7C3BD, 0x0059958A, 0x007BA7A8, 0x0072A3B3, 0x00247289, 0x003897B1, 0x00004D66, 0x00084658, 0x00174E5B, 0x0007577C,
        0x004C99B9, 0x001D6D8A, 0x00137097, 0x003FADE1, 0x0033ADE9, 0x002EABE5, 0x0036B0E4, 0x001E8DB5, 0x000B4562, 0x00155770, 0x003DABD5, 0x00279BD4, 0x0039ADE2, 0x0035B0E2, 0x0037ABE6, 0x0031A7D8, 0x002A9DC8, 0x00165881, 0x00224B6C, 0x0007485D,
        0x001A5568, 0x00164154, 0x000B4C5B, 0x0014475B, 0x000F485D, 0x00004058, 0x00034D69, 0x003990B0, 0x0042A3C7, 0x00319AC1, 0x00309FC7, 0x002C99C5, 0x00389BC1, 0x004194B3, 0x00458DA5, 0x004C8FA8, 0x00468FAD, 0x0020769A, 0x0000557D, 0x00308DB4,
        0x002D88AD, 0x00348AAE, 0x001B6C8F, 0x00024D6D, 0x00034665, 0x000C4D69, 0x002D6986, 0x005FB3D7, 0x004BA1BF, 0x0010677B, 0x00005261, 0x00388B9A, 0x0018647A, 0x001E6586, 0x004285AC, 0x002D91A9, 0x0051AEC7, 0x00277B97, 0x005BADCC, 0x000F6282,
        0x000C688B, 0x0038A1C2, 0x001B8CAD, 0x0070A3A6, 0x004C7E84, 0x00619399, 0x00508288, 0x0064959D, 0x00396A72, 0x006798A2, 0x004A7B85, 0x003EA7E0, 0x002C95CE, 0x002790C9, 0x00329DD6, 0x003AA5DE, 0x00319ED6, 0x002895CD, 0x002794CC, 0x00329FD2,
        0x00228AB9, 0x003E9BC8, 0x00368BB3, 0x00115F83, 0x0014627F, 0x002E8099, 0x004B9EB4, 0x0036A1DA, 0x0035A0D9, 0x002590C9, 0x00228DC6, 0x001782BB, 0x00137EB7, 0x002994CD, 0x002994CD, 0x0037A5CF, 0x0032A2D0, 0x002BA2D3, 0x0026A3D6, 0x0027A3D9,
        0x002FA7DB, 0x0033A6D9, 0x00319ED1, 0x0024A1CE, 0x002497C9, 0x002B97CD, 0x002C9CD1, 0x00219ACB, 0x001D9EC5, 0x002AA7C6, 0x0035AAC5, 0x002C7185, 0x003C4C4B, 0x004F513D, 0x004A5642, 0x00505344, 0x00465039, 0x00465940, 0x004F4E40, 0x004B5041,
        0x004B5041, 0x004C5142, 0x004D5243, 0x004E5344, 0x004E5344, 0x004B5041, 0x00494E3F, 0x00474E3F, 0x00484F40, 0x00495041, 0x004A5142, 0x004B5243, 0x004B5243, 0x004A5142, 0x004A5142, 0x00505645, 0x004E5443, 0x004B5140, 0x004A503F, 0x004C5241,
        0x004E5443, 0x00505645, 0x00515746, 0x00525242, 0x00515141, 0x00505040, 0x00505040, 0x00505040, 0x00505040, 0x00515141, 0x00525242, 0x00474E3F, 0x00495041, 0x004A5142, 0x004D5243, 0x004B5041, 0x004C4F40, 0x004C4F40, 0x004C4F40, 0x00514C3D,
        0x00484C40, 0x00444E41, 0x00494C3C, 0x00524C39, 0x003D4136, 0x0017373D, 0x000D475D, 0x00094962, 0x000A4A63, 0x000B4B64, 0x000B4D66, 0x000B4D66, 0x000B4D66, 0x00094C65, 0x00094C65, 0x00074A65, 0x00084B66, 0x00094C67, 0x000A4D68, 0x000A4D68,
        0x000A4D68, 0x000A4D68, 0x00094C67, 0x00005069, 0x00004661, 0x002A789D, 0x00498EB9, 0x001D6C97, 0x002D8DB1, 0x00004868, 0x000B4666, 0x00004658, 0x0003627C, 0x003AB0D9, 0x003DBCEF, 0x003DAEE6, 0x004099CB, 0x00085177, 0x000A4D68, 0x000F4F6D,
        0x00095268, 0x000E5367, 0x0013506A, 0x000A506D, 0x0002596D, 0x0016686D, 0x0037766D, 0x000F0E10, 0x00020301, 0x001D2017, 0x003A3D2E, 0x003E4131, 0x00494A3A, 0x00474739, 0x003A3A2C, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFE, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00606458, 0x00455242, 0x000C0E08, 0x001E1616, 0x003C3734, 0x00252F22, 0x00315646, 0x00306C64, 0x00176165, 0x00245D73, 0x00235C72, 0x00215A70, 0x0020596F, 0x0020596F,
        0x001E576D, 0x001B546A, 0x00195268, 0x00224F71, 0x001D5473, 0x0011546D, 0x0014576E, 0x00175069, 0x001C516C, 0x00104968, 0x00175877, 0x004A94C4, 0x0073C3E0, 0x0079C3CF, 0x006B9FA5, 0x00687C87, 0x009598A6, 0x00EFFAFE, 0x00E5FDF5, 0x00F5FFF9,
        0x00ECF7F4, 0x00F6FFFE, 0x00F4FFFC, 0x00F1FCF9, 0x00F8FFFC, 0x00D0D7D0, 0x004A5248, 0x000F2512, 0x00232721, 0x00313A43, 0x000A3140, 0x00235768, 0x00587B89, 0x00A5BBC0, 0x007F9692, 0x009AA79F, 0x00758076, 0x0050594F, 0x004B5146, 0x00505246,
        0x005B5A4C, 0x006A6556, 0x005F5A4B, 0x00676553, 0x005A5846, 0x00635E4F, 0x006B655A, 0x005A594F, 0x00788076, 0x00A7B6AE, 0x0090A59D, 0x00B4C1BF, 0x0080B9B6, 0x0043979D, 0x004D92A5, 0x000B4A66, 0x00014E68, 0x0004556A, 0x000A495E, 0x00014C6C,
        0x001F6884, 0x004491AB, 0x00197396, 0x00147FB2, 0x0037AFEB, 0x002BA6E0, 0x003AB4EA, 0x001F8EB6, 0x000B4562, 0x00165871, 0x003EACD6, 0x00279BD4, 0x0039ADE2, 0x0035B0E2, 0x0037ABE6, 0x002CA0D5, 0x002796C4, 0x0013698D, 0x0000435B, 0x00004E5D,
        0x00004E59, 0x00125060, 0x00114E62, 0x00196064, 0x002F797F, 0x002D7B82, 0x00297B86, 0x004CA4B2, 0x004EAABB, 0x0048A7BA, 0x004BACC0, 0x004BA7C0, 0x0053A9BD, 0x0059A3AF, 0x005C9DA5, 0x0062A2A7, 0x0060A2AD, 0x004690A2, 0x0029778E, 0x004EACBF,
        0x004CA8B9, 0x0052AABA, 0x003C8F9E, 0x00277782, 0x002B7881, 0x003D868E, 0x005FA7AE, 0x004EA6B7, 0x00439CA7, 0x00267F83, 0x00227B78, 0x0058ACAA, 0x00409196, 0x0046919F, 0x004E97AB, 0x001C7179, 0x004798A0, 0x004C96A2, 0x007BC1CE, 0x00357C8A,
        0x002B7C8B, 0x0052ADBC, 0x0054B7C5, 0x0065B9B4, 0x0051A5A0, 0x0055A9A5, 0x004B9F9B, 0x00489B99, 0x00358886, 0x005EB1AF, 0x0058AAAB, 0x0058B0BE, 0x0054ADBB, 0x0054ADBB, 0x0057B0BE, 0x0055B1BE, 0x0050ACB9, 0x004CAAB7, 0x004EACB9, 0x003DA7BF,
        0x003298AF, 0x0052AFC6, 0x0059AFC3, 0x00489AAB, 0x004C9EAA, 0x0052A7AF, 0x005BB3BA, 0x0050ACB9, 0x0050ACB9, 0x0047A3B0, 0x004CA8B5, 0x004BA7B4, 0x004AA6B3, 0x0055B1BE, 0x004AA6B3, 0x0027829D, 0x00167798, 0x002B96BC, 0x003DB1E0, 0x0028A2D6,
        0x00209BD3, 0x002DA5E0, 0x002DA3DE, 0x002698C7, 0x00339CCF, 0x003B9BD1, 0x003798D0, 0x00329BCE, 0x002B92BF, 0x001C78A1, 0x000F6085, 0x000C4E61, 0x00364440, 0x0053523D, 0x0048513D, 0x004F4F41, 0x00454E39, 0x0042543D, 0x004E4D43, 0x004F5445,
        0x004E5344, 0x004E5344, 0x004F5445, 0x00505546, 0x00505546, 0x004E5344, 0x004D5243, 0x004C5344, 0x004C5344, 0x004D5445, 0x004D5445, 0x004E5546, 0x004E5546, 0x004D5445, 0x004D5445, 0x004D5342, 0x004B5140, 0x004A503F, 0x004B5140, 0x004C5241,
        0x004E5443, 0x004E5443, 0x004E5443, 0x00525343, 0x00515242, 0x00515242, 0x00515242, 0x00515242, 0x00515242, 0x00515242, 0x00525343, 0x004A5142, 0x004B5243, 0x004C5344, 0x004D5243, 0x004C5142, 0x004D5041, 0x004D5041, 0x004E5142, 0x00534E3F,
        0x004A4E42, 0x00465043, 0x004B4E3E, 0x00554F3C, 0x003F4338, 0x0018383E, 0x000E485E, 0x00094962, 0x000A4A63, 0x000B4B64, 0x000B4D66, 0x000B4D66, 0x000B4D66, 0x00094C65, 0x00094C65, 0x00094C67, 0x00094C67, 0x000A4D68, 0x000B4E69, 0x000B4E69,
        0x000B4E69, 0x000A4D68, 0x000A4D68, 0x00074A65, 0x00206C89, 0x003B87AB, 0x00156289, 0x0000446B, 0x0032A7C6, 0x00279AB5, 0x002E8BA5, 0x002E89A8, 0x0038A8CC, 0x0031B5E4, 0x00048DC5, 0x0035B0EA, 0x00147CB1, 0x0041A0C8, 0x00025D7C, 0x000D4D6B,
        0x00085167, 0x000D5266, 0x00124F69, 0x00084E6B, 0x00035A6E, 0x001C6E73, 0x00407F76, 0x000F0E10, 0x00010200, 0x001A1D14, 0x00353829, 0x003A3D2D, 0x00474838, 0x0048483A, 0x003C3C2E, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFE, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x005C6054, 0x00485545, 0x000C0E08, 0x00191111, 0x00393431, 0x002E382B, 0x00426757, 0x003A766E, 0x00155F63, 0x00225B74, 0x00215A73, 0x001F5871, 0x001F5871, 0x001F5871,
        0x001E5770, 0x001B546D, 0x0019526B, 0x001F4D6F, 0x001E5673, 0x0012546D, 0x0015556D, 0x0019516A, 0x00194D6B, 0x000F4A6A, 0x00296E8F, 0x004BB3DE, 0x003F9BB8, 0x00488A95, 0x005D7980, 0x0055535F, 0x008C8592, 0x00F0FFFF, 0x00DFFFFC, 0x00F1F8F1,
        0x00FBFFFB, 0x00F1F8F1, 0x00F4F8F2, 0x00FDFFFB, 0x00C0C4BE, 0x00575B55, 0x001B1F19, 0x000E2E23, 0x00222C2C, 0x0027313B, 0x002F525F, 0x00497782, 0x00A1BEC3, 0x00879593, 0x0095A59A, 0x007E867C, 0x004C5449, 0x003E4439, 0x00555C4F, 0x00535849,
        0x00484B3B, 0x00545643, 0x005A5C49, 0x00535440, 0x00656450, 0x00686654, 0x005A5749, 0x0057554A, 0x005F6056, 0x007B8379, 0x00AEB9B1, 0x008E9997, 0x009AB9B8, 0x006BA4A6, 0x00156068, 0x00206A7C, 0x005093AE, 0x004992B0, 0x00388DAD, 0x000C516C,
        0x00004458, 0x001D667C, 0x003287A7, 0x003198C9, 0x0037AAE7, 0x003BB3EF, 0x0031A8E0, 0x00208FB7, 0x000C4663, 0x00165871, 0x003EACD6, 0x00289CD5, 0x003AAEE3, 0x0035B0E2, 0x0037ABE6, 0x0029A6E0, 0x003192C4, 0x00126384, 0x00176272, 0x0052939B,
        0x00378088, 0x000C5A67, 0x000E4D62, 0x00788E8C, 0x00A5BABB, 0x00ABBFC0, 0x00A5B9BA, 0x00B6C9CC, 0x00B7C8CB, 0x00BCCCD2, 0x00BFCFD5, 0x00AAD1D9, 0x00ABD0D4, 0x00ADCECA, 0x00ADCCC3, 0x00B2D0C5, 0x00B5D1CB, 0x00A9C7C8, 0x009DBBC0, 0x00B7CDD2,
        0x00B8CDCF, 0x00BFD4D6, 0x00B2C6C7, 0x00A7BAB7, 0x00ABBCB8, 0x00B5C4C0, 0x00CBDBD4, 0x00ABC1C7, 0x00ADC4C6, 0x00AFC6C1, 0x00A8C0B6, 0x00B7CCC3, 0x00A5B6B2, 0x00B8C4C8, 0x00B8C1CA, 0x00AFC0BC, 0x00ABB8B6, 0x00B3B9B8, 0x00D2D6D7, 0x00BABFC0,
        0x00B7C3C5, 0x00B4C9CA, 0x00B1CDCE, 0x00B5C8C5, 0x00BBCECB, 0x00BACCCB, 0x00C6D8D7, 0x00B3C5C6, 0x00AFC1C2, 0x00BBCCCF, 0x00BBCCCF, 0x00BCC7BF, 0x00C4CFC7, 0x00C5D2CA, 0x00BFCCC4, 0x00B9C8C0, 0x00BBCAC2, 0x00BDCCC4, 0x00BBCCC3, 0x00AFCDD2,
        0x00A5C2C7, 0x00B8CED3, 0x00BCCFD4, 0x00B7C8CB, 0x00BACBCE, 0x00B3C7C8, 0x00B3C8C9, 0x00C0CDC5, 0x00C4D1C9, 0x00BFCCC4, 0x00C5D2CA, 0x00C6D3CB, 0x00C5D2CA, 0x00C7D4CC, 0x00B5C2BA, 0x00034851, 0x00004C5C, 0x000C6881, 0x002A94B9, 0x003AADDF,
        0x002EA6E1, 0x00209BD9, 0x00209ADC, 0x00269BC8, 0x00309CCC, 0x00369BCF, 0x003298CD, 0x00359ED1, 0x003C9DCF, 0x002776A7, 0x00014171, 0x00003141, 0x003A403B, 0x00645E47, 0x004C523F, 0x004E4C41, 0x00484E3D, 0x00415140, 0x004B4A46, 0x004A4F40,
        0x00494E3F, 0x00484D3E, 0x00494E3F, 0x004A4F40, 0x004A4F40, 0x00484D3E, 0x00474C3D, 0x00484F40, 0x00484F40, 0x00484F40, 0x00484F40, 0x00484F40, 0x00484F40, 0x00495041, 0x00495041, 0x00494F3E, 0x00494F3E, 0x00494F3E, 0x004B5140, 0x004D5342,
        0x004D5342, 0x004B5140, 0x004A503F, 0x004B5140, 0x004C5241, 0x004C5241, 0x004C5241, 0x004C5241, 0x004C5241, 0x004C5241, 0x004B5140, 0x004B5243, 0x004C5344, 0x004C5344, 0x004C5142, 0x004A4F40, 0x004B4E3F, 0x004C4F40, 0x004D5041, 0x00514C3D,
        0x00484C40, 0x00454F42, 0x004B4E3E, 0x00544E3B, 0x003E4237, 0x0016363C, 0x000A445A, 0x00094962, 0x000A4A63, 0x000C4C65, 0x000B4D66, 0x000B4D66, 0x000B4D66, 0x00094C65, 0x00094C65, 0x000B4E69, 0x000B4E69, 0x000C4F6A, 0x000C4F6A, 0x000C4F6A,
        0x000B4E69, 0x000A4D68, 0x000A4D68, 0x000A425F, 0x00115774, 0x000D5676, 0x00003C61, 0x00004D6F, 0x004CBCDA, 0x0041B0CA, 0x001F7C96, 0x001C7695, 0x003095BB, 0x004AC0EA, 0x0043B9EA, 0x00349DD0, 0x0000517C, 0x0025809F, 0x003895AE, 0x000D4D6B,
        0x00075066, 0x000A4F63, 0x00104D67, 0x00084E6B, 0x00035A6E, 0x001B6D72, 0x003E7D74, 0x000D0C0E, 0x00000100, 0x00191C13, 0x00343728, 0x00393C2C, 0x00464737, 0x00474739, 0x003B3B2D, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFE, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00595D51, 0x00475444, 0x000D0F09, 0x00170F0F, 0x0035302D, 0x00313B2E, 0x004A6F5F, 0x003E7A72, 0x00155F63, 0x001F5871, 0x001E5770, 0x001E5770, 0x001E5770, 0x001F5871,
        0x001F5871, 0x001D566F, 0x001B546D, 0x001B4C6C, 0x001B5572, 0x0010536A, 0x00125068, 0x00174F68, 0x00154B69, 0x000F4E70, 0x003E88AA, 0x0035ADD7, 0x00055272, 0x00314B5B, 0x0074717A, 0x00555059, 0x006B6D77, 0x00E1E4E9, 0x00FFFFFF, 0x00FAFEF8,
        0x00FCFEF8, 0x00FFFFF9, 0x00FFFFF8, 0x00CACBC1, 0x0055584F, 0x00181C17, 0x00272C2A, 0x001B3234, 0x00032427, 0x000C282F, 0x0052616A, 0x00A6BCC1, 0x006D918B, 0x0096ACA0, 0x00898174, 0x0043473B, 0x00515549, 0x00575C4D, 0x00525847, 0x004E5441,
        0x004F5542, 0x00525944, 0x004F5641, 0x00595941, 0x005D5C47, 0x00605F4B, 0x00615F4D, 0x00696658, 0x0059574C, 0x0058574D, 0x008B8C83, 0x009BB2AE, 0x00959A99, 0x00B4C1C3, 0x005E9697, 0x0056AAB0, 0x0054A3B8, 0x0086CEF0, 0x004393BC, 0x0077BBD2,
        0x00276B7E, 0x0003485B, 0x001F7291, 0x0046ACDD, 0x003AACE8, 0x002FA4E1, 0x0038ABE4, 0x002190B8, 0x000D4764, 0x00175972, 0x003FADD7, 0x00289CD5, 0x003AAEE3, 0x0035B0E2, 0x0037ABE6, 0x001DA9E4, 0x004093C7, 0x001F5576, 0x007EA5B4, 0x00EFFEFF,
        0x00B3DFE6, 0x0014646F, 0x000A4F62, 0x00578078, 0x0082A9A1, 0x0082A79F, 0x007FA298, 0x0089ABA0, 0x0086A69B, 0x0090AEA1, 0x0090AEA1, 0x008DAFA8, 0x008BAEA4, 0x0088AD9D, 0x0088AF9A, 0x008AB09A, 0x008DAF9E, 0x008FADA0, 0x0090ABA1, 0x008BAEA0,
        0x0088AB9D, 0x008DB0A2, 0x0089AD9D, 0x0084AA98, 0x0083A997, 0x007BA28D, 0x007EA590, 0x007EA39B, 0x00799E94, 0x007AA191, 0x00799F8D, 0x007EA291, 0x00749888, 0x0084A39A, 0x007A9992, 0x0085AF9D, 0x00709886, 0x00759988, 0x007EA08F, 0x007DA191,
        0x007AA191, 0x006E9B8A, 0x006D9F8D, 0x007C9A8D, 0x0086A499, 0x007F9D92, 0x008CAA9F, 0x0083A097, 0x0086A39A, 0x00839F99, 0x00809C96, 0x007EA193, 0x0082A597, 0x0081A496, 0x007B9F91, 0x007CA092, 0x0080A798, 0x0080A798, 0x007BA293, 0x0085AA9A,
        0x0082A696, 0x0085A89A, 0x0080A395, 0x007FA196, 0x0084A79D, 0x0080A59B, 0x0085AAA0, 0x0086AA9C, 0x008BAFA1, 0x0089AD9F, 0x0089AD9F, 0x0085A99B, 0x0085A99B, 0x0087AB9D, 0x00769A8C, 0x00174D4E, 0x0014525A, 0x00004E5F, 0x0005607F, 0x002C95BE,
        0x0040AFE1, 0x0032A3DB, 0x00289BD4, 0x0024A3CA, 0x00239BC5, 0x002A9FCC, 0x0026A0CE, 0x00209ECE, 0x0032ABDC, 0x00379DD1, 0x001870A6, 0x00013847, 0x003F433D, 0x00645C45, 0x003B3F2C, 0x00323026, 0x003B4031, 0x00405143, 0x004D4B4A, 0x004B5041,
        0x004A4F40, 0x004A4F40, 0x004B5041, 0x004B5041, 0x004B5041, 0x00484D3E, 0x00474C3D, 0x00495041, 0x00495041, 0x00484F40, 0x00484F40, 0x00495041, 0x004A5142, 0x004C5344, 0x004D5445, 0x004E5443, 0x004E5443, 0x004F5544, 0x00505645, 0x00525847,
        0x00525847, 0x00515746, 0x004F5544, 0x004A5444, 0x004B5545, 0x004C5646, 0x004D5747, 0x004D5747, 0x004C5646, 0x004B5545, 0x004A5444, 0x004C5344, 0x004C5344, 0x004B5243, 0x004B5041, 0x00494E3F, 0x004A4D3E, 0x004B4E3F, 0x004C4F40, 0x00534E3F,
        0x004A4E42, 0x00475144, 0x004E5141, 0x0058523F, 0x0041453A, 0x0018383E, 0x000B455B, 0x00094962, 0x000A4A63, 0x000C4C65, 0x000B4D66, 0x000C4E67, 0x000B4D66, 0x000A4D66, 0x00094C65, 0x000B4E69, 0x000B4E69, 0x000B4E69, 0x000B4E69, 0x000B4E69,
        0x000A4D68, 0x000A4D68, 0x00094C67, 0x0019516E, 0x00064C69, 0x00004662, 0x00054564, 0x000B4E6F, 0x002D7D9C, 0x001D6888, 0x00074060, 0x00004058, 0x00004A64, 0x0020738F, 0x003383A2, 0x00145776, 0x000C4C64, 0x00004455, 0x00226F78, 0x0010506E,
        0x00075066, 0x00094E62, 0x000F4C66, 0x00094F6C, 0x00035A6E, 0x0016686D, 0x0035746B, 0x000B0A0C, 0x00000100, 0x001B1E15, 0x00383B2C, 0x003D4030, 0x00464737, 0x00444436, 0x00363628, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFE, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00575B4F, 0x00404D3D, 0x000F110B, 0x001D1515, 0x00342F2C, 0x00273124, 0x003B6050, 0x00357169, 0x00155F63, 0x001F5772, 0x001E5671, 0x001D5570, 0x001D5570, 0x001E5671,
        0x001D5570, 0x001B536E, 0x0019516C, 0x001A4C68, 0x001A556F, 0x0012526A, 0x00134F67, 0x001A4F6A, 0x00144A69, 0x000C4E71, 0x004596B9, 0x0035A4D2, 0x000A5172, 0x001A3442, 0x00414649, 0x002D3639, 0x003B454C, 0x00A2A0A6, 0x00FFF7FB, 0x00FAFFFE,
        0x00F2F6F0, 0x00ECF0E5, 0x00B0B2A6, 0x0046473D, 0x00171E17, 0x00232B2A, 0x00243032, 0x0012313A, 0x000B2F35, 0x003C565C, 0x00ABB4B7, 0x007E8C88, 0x0091ADA0, 0x00808F81, 0x00584D3F, 0x005F5F51, 0x00535345, 0x004B4C3C, 0x004B4D3A, 0x004E503C,
        0x004F523C, 0x0060644B, 0x007D8168, 0x009C977E, 0x00918C73, 0x00615D45, 0x00635F4C, 0x00696755, 0x005D5A4C, 0x00696358, 0x00554F44, 0x008E8A89, 0x009BA7A1, 0x0090A29B, 0x00B8CDCB, 0x0071A4A7, 0x004CA5B0, 0x0055A9C5, 0x003A759D, 0x005AA5BF,
        0x00367F93, 0x0000485B, 0x00065D7D, 0x0046ADDE, 0x003EB0EC, 0x0034A7E4, 0x0036AAE1, 0x002190B8, 0x000D4764, 0x00175972, 0x003FADD7, 0x00289CD5, 0x0039ADE2, 0x0035B0E2, 0x0037ABE6, 0x001BA3DE, 0x004191C6, 0x0023597A, 0x007CA3B1, 0x00E9F7FD,
        0x00ADD6D9, 0x00125C62, 0x00094454, 0x00B8BABA, 0x00D3D5D5, 0x00CACDCB, 0x00CCD0CB, 0x00D0D4CE, 0x00C9CEC5, 0x00CCD4C9, 0x00CAD3C6, 0x00D6D3CF, 0x00D0D2CC, 0x00CED4C9, 0x00CCD5C8, 0x00CBD4C7, 0x00CED2C6, 0x00D3D2C8, 0x00D8D5CD, 0x00CDD1C6,
        0x00CACEC3, 0x00CCD0C5, 0x00CAD0C5, 0x00CCD5C8, 0x00D0D9CC, 0x00CAD4C7, 0x00C9D3C6, 0x00C7CDC8, 0x00C3CAC3, 0x00C5CDC3, 0x00CAD0C5, 0x00CDD3C8, 0x00C4C9C0, 0x00C7CBC5, 0x00C2C6C1, 0x00BFC9BD, 0x00C1C9BE, 0x00D0D6CB, 0x00CBCFC4, 0x00C9D0C3,
        0x00BDC6B9, 0x00C2CCBF, 0x00C8D5C7, 0x00C3D3C2, 0x00C5D4C6, 0x00BFCEC0, 0x00BCCBBD, 0x00C5D3C7, 0x00C3D1C5, 0x00C4D2C7, 0x00C0CEC3, 0x00C4CAC9, 0x00C1C7C6, 0x00BCC4C3, 0x00BBC3C2, 0x00BDC8C6, 0x00C1CCCA, 0x00C0CBC9, 0x00BAC7C5, 0x00C5C5B7,
        0x00C8CBBC, 0x00C9CDC1, 0x00C3C9BE, 0x00C4CBC4, 0x00C6CCC7, 0x00C2C8C3, 0x00C7CCCA, 0x00C1C9C8, 0x00C5CDCC, 0x00C4CCCB, 0x00C3CBCA, 0x00C1C9C8, 0x00C5CDCC, 0x00C7CFCE, 0x00B9C1C0, 0x00214E52, 0x00154A54, 0x00064958, 0x00004960, 0x00045F7E,
        0x003293B5, 0x0049ADD0, 0x003A9DC3, 0x0030A4C7, 0x0031A1C5, 0x0033A5CA, 0x002BA6CC, 0x001CA5CC, 0x0021ABD9, 0x002AA9DC, 0x002599D0, 0x00185265, 0x003E4341, 0x00554E3A, 0x00242717, 0x00141208, 0x002D3223, 0x00445443, 0x00534F4E, 0x004B5041,
        0x004B5041, 0x004C5142, 0x004D5243, 0x004D5243, 0x004C5142, 0x00494E3F, 0x00464B3C, 0x00495041, 0x00495041, 0x00495041, 0x00495041, 0x004B5243, 0x004C5344, 0x004E5546, 0x004F5647, 0x004E5443, 0x004D5342, 0x004C5241, 0x004D5342, 0x004E5443,
        0x00505645, 0x004F5544, 0x004F5544, 0x00485242, 0x00495343, 0x004A5444, 0x004B5545, 0x004B5545, 0x004A5444, 0x00495343, 0x00485242, 0x004D5445, 0x004D5445, 0x004C5344, 0x004C5142, 0x004A4F40, 0x004B4E3F, 0x004C4F40, 0x004E5142, 0x00514C3D,
        0x00474B3F, 0x00444E41, 0x004C4F3F, 0x0057513E, 0x00404439, 0x0016363C, 0x00084258, 0x000A4A63, 0x000B4B64, 0x000C4C65, 0x000B4D66, 0x000C4E67, 0x000C4E67, 0x000A4D66, 0x00094C65, 0x000B4E69, 0x000A4D68, 0x000A4D68, 0x00094C67, 0x00094C67,
        0x00094C67, 0x00094C67, 0x00094C67, 0x000A405E, 0x0000455F, 0x0006566D, 0x0010566E, 0x00004560, 0x00004E69, 0x00045471, 0x00105170, 0x00185B70, 0x00044F65, 0x00025368, 0x00004A5D, 0x0015566B, 0x0018576B, 0x001F6674, 0x00004A56, 0x000D4D6B,
        0x00075066, 0x000B5064, 0x00104D67, 0x00074D6A, 0x0001586C, 0x001A6C71, 0x003E7D74, 0x000E0D0F, 0x00020301, 0x001E2118, 0x003B3E2F, 0x003E4131, 0x00464737, 0x00434335, 0x00343426, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFE, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00575B4F, 0x00404D3D, 0x000E100A, 0x001A1212, 0x00332E2B, 0x00293326, 0x003E6353, 0x0036726A, 0x00176165, 0x001F5A74, 0x001E5973, 0x001C5771, 0x001B5670, 0x001A556F,
        0x0018536D, 0x0016516B, 0x00134E68, 0x00194F68, 0x001A566E, 0x0017566B, 0x00195369, 0x001F516D, 0x00144A6B, 0x00044A6F, 0x003E94B8, 0x003C9DCF, 0x000D5F7E, 0x00003339, 0x00234642, 0x00657875, 0x00636E72, 0x003C4549, 0x00697275, 0x0098A6A5,
        0x009DA8A5, 0x007B8379, 0x00383E33, 0x00131B11, 0x00202B29, 0x001F3237, 0x001B313C, 0x0022535B, 0x00647981, 0x00B0B7BA, 0x0081938C, 0x00A1B8AA, 0x00838A7D, 0x004B473C, 0x0056584C, 0x00555545, 0x007E7C6A, 0x00706E5C, 0x0054503D, 0x00807B66,
        0x00B8B29B, 0x00C9C4AB, 0x00DCD5BC, 0x00D6C5AB, 0x00DDD0B6, 0x009D967D, 0x00625E46, 0x00585743, 0x00615F4D, 0x006B6657, 0x00655D50, 0x00584842, 0x00878C83, 0x009DB3A7, 0x007E968E, 0x009EB8B8, 0x008FB7C3, 0x006FACC0, 0x004F99B3, 0x00439CBE,
        0x004B9FBB, 0x0020758F, 0x00106E91, 0x0035A2D5, 0x0031A7E2, 0x003AB0EB, 0x0036A8DD, 0x002190B8, 0x000D4764, 0x00175972, 0x003FADD7, 0x00289CD5, 0x0039ADE2, 0x0034AFE1, 0x0036AAE5, 0x002FA6DE, 0x003391BF, 0x0010637F, 0x000B5861, 0x003D7B7B,
        0x00316D6C, 0x0020575A, 0x002E515B, 0x00737472, 0x00838482, 0x007C807B, 0x00828883, 0x00828A83, 0x007B867C, 0x0079877C, 0x007B897D, 0x007A8A83, 0x00778A81, 0x00758A81, 0x00748C82, 0x00728A7E, 0x0071877B, 0x0074887B, 0x00788C7F, 0x00808A7E,
        0x00818B7F, 0x00818B7F, 0x007D877B, 0x007A8379, 0x0079847A, 0x00788379, 0x00788379, 0x00757D76, 0x00777F78, 0x00777F78, 0x0079817A, 0x00757D76, 0x006B766E, 0x006A756D, 0x00727D75, 0x007B7873, 0x00807D78, 0x00838179, 0x007A7870, 0x00838278,
        0x007B7A70, 0x00828075, 0x007E7C71, 0x00757D6C, 0x00767E6D, 0x00798071, 0x00707768, 0x007C8374, 0x0072796C, 0x00757C6F, 0x0072796C, 0x007B7F79, 0x00797D77, 0x00767D76, 0x00777E77, 0x00777F78, 0x00767E77, 0x00777F78, 0x0077827A, 0x00797D72,
        0x007B8176, 0x00788276, 0x00738176, 0x0077847C, 0x0076807A, 0x00717873, 0x00747775, 0x007C837C, 0x007A817A, 0x007A817A, 0x007C837C, 0x007D847D, 0x00828982, 0x007F867F, 0x00727972, 0x002C4F53, 0x00285259, 0x0019505D, 0x00044A5B, 0x00004E63,
        0x0012677D, 0x00257B91, 0x00277D91, 0x00197391, 0x00267998, 0x00217494, 0x001B7C9E, 0x00299CC1, 0x002AA9D6, 0x00209ED4, 0x002199D4, 0x001D5F78, 0x00354244, 0x00555543, 0x00374131, 0x002E2D23, 0x003E4431, 0x00495843, 0x00504D45, 0x004B5041,
        0x004B5041, 0x004B5041, 0x004C5142, 0x004C5142, 0x004B5041, 0x00484D3E, 0x00454A3B, 0x00464D3E, 0x00474E3F, 0x00474E3F, 0x00484F40, 0x00495041, 0x004B5243, 0x004C5344, 0x004D5445, 0x004C5241, 0x004A503F, 0x00484E3D, 0x00484E3D, 0x004A503F,
        0x004C5241, 0x004D5342, 0x004D5342, 0x00485144, 0x00485144, 0x00485144, 0x00495245, 0x00495245, 0x00485144, 0x00485144, 0x00485144, 0x004C5344, 0x004D5445, 0x004D5445, 0x004D5243, 0x004B5041, 0x004C4F40, 0x004D5041, 0x004E5142, 0x00504B3C,
        0x00464A3E, 0x00434D40, 0x004C4F3F, 0x0057513E, 0x0041453A, 0x0017373D, 0x00094359, 0x000A4A63, 0x000B4B64, 0x000C4C65, 0x000C4E67, 0x000C4E67, 0x000C4E67, 0x000A4D66, 0x000A4D66, 0x000A4D68, 0x000A4D68, 0x00094C67, 0x00084B66, 0x00084B66,
        0x00084B66, 0x00094C67, 0x00094C67, 0x001B4968, 0x000C566E, 0x00409CAF, 0x0062BCCD, 0x005AB9C9, 0x0044B4C6, 0x0040B9CD, 0x0047B9D0, 0x0054B5CF, 0x0049B3CA, 0x0050C0D4, 0x0046B1C6, 0x0061C1D8, 0x0051AEC8, 0x0053B9D6, 0x0010809E, 0x00074765,
        0x00064F65, 0x000E5367, 0x00114E68, 0x00044A67, 0x0001586C, 0x0023757A, 0x00519087, 0x00131214, 0x00050604, 0x001E2118, 0x00393C2D, 0x003B3E2E, 0x00454636, 0x00444436, 0x00363628, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFE, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00585C50, 0x00455242, 0x000D0F09, 0x00150D0D, 0x00332E2B, 0x00323C2F, 0x00476C5C, 0x003A766E, 0x00166064, 0x001C5673, 0x001B5572, 0x001A5471, 0x00195370, 0x00195370,
        0x0018526F, 0x0016506D, 0x00144E6B, 0x00185167, 0x0018546A, 0x0017566B, 0x001A5369, 0x001F516D, 0x00164C6D, 0x00014B6F, 0x003891B6, 0x003398CC, 0x00055574, 0x002D5D63, 0x00839994, 0x00D6E1DE, 0x00CFDCDE, 0x00506366, 0x002B4041, 0x003E5459,
        0x00405251, 0x003B4943, 0x00364137, 0x0026342E, 0x001F3334, 0x000C2731, 0x00123343, 0x0053848C, 0x00A0B4B9, 0x008A8D8B, 0x00A8B6AA, 0x00687A69, 0x00494C3D, 0x005E5950, 0x004E5148, 0x00565644, 0x00888773, 0x00928C79, 0x0088816D, 0x00B5A892,
        0x00D2C4AD, 0x00D0BFA5, 0x00E3CFB6, 0x00DEC3A9, 0x00DDC8AD, 0x00DCCFB5, 0x009A957C, 0x005D5C47, 0x005F5E4A, 0x0062604E, 0x006B6657, 0x005A5D4E, 0x00584F45, 0x0086877D, 0x0093ACA2, 0x00738A86, 0x00AEB8BF, 0x0090B0BB, 0x0062ADB5, 0x00349DC6,
        0x002185A8, 0x003596B7, 0x001B84AB, 0x0031A4D7, 0x0036B1EB, 0x0029A0D7, 0x003AADDF, 0x002190B8, 0x000D4764, 0x00175972, 0x003EACD6, 0x00279BD4, 0x0038ACE1, 0x0033AEE0, 0x0035A9E4, 0x003FA9DE, 0x002891BC, 0x00116A85, 0x00004C59, 0x00004F4D,
        0x00104D49, 0x00425E5F, 0x00556669, 0x003C4639, 0x00454F42, 0x00434D40, 0x004A5447, 0x00485245, 0x004A5447, 0x00475144, 0x004B5548, 0x00535248, 0x00525048, 0x00525048, 0x00535149, 0x00525048, 0x004E4F45, 0x004C5044, 0x004E5344, 0x003F4F3E,
        0x00445443, 0x00455544, 0x00455244, 0x00444E41, 0x00444E42, 0x00464E43, 0x00434B40, 0x00495444, 0x00434D40, 0x003A4438, 0x00404A3E, 0x00404C40, 0x00465246, 0x003E4D3F, 0x0040503F, 0x0042453C, 0x0045483F, 0x00484C41, 0x003E4439, 0x00484C40,
        0x00474A3B, 0x004F5040, 0x004F4F3F, 0x00514C3D, 0x00504B3C, 0x00504B3C, 0x004D473A, 0x004E483B, 0x004B453A, 0x004C463B, 0x00514B40, 0x00464B3C, 0x00454C3D, 0x00464D3E, 0x00454C3D, 0x00414B3B, 0x00414B3B, 0x00424D3D, 0x00434E3E, 0x00444E42,
        0x00434F43, 0x003E4F42, 0x003C5043, 0x00415346, 0x00425044, 0x00464E43, 0x004D5146, 0x00475141, 0x00434D3D, 0x00465040, 0x00485242, 0x00465040, 0x00485242, 0x00465040, 0x003F4939, 0x00415653, 0x00385657, 0x00235054, 0x00114E58, 0x000B5260,
        0x00004A5B, 0x00004455, 0x00004A5B, 0x00004A61, 0x00064C64, 0x0004445D, 0x00004765, 0x00136F92, 0x002C99C5, 0x002EA2D7, 0x002598D5, 0x00166181, 0x002A3F47, 0x00535A4D, 0x004D5A4C, 0x004F5046, 0x004E563F, 0x0046553A, 0x00514C3D, 0x004F5445,
        0x004D5243, 0x004B5041, 0x004A4F40, 0x004B5041, 0x004A4F40, 0x00494E3F, 0x00484D3E, 0x00474E3F, 0x00484F40, 0x00495041, 0x00495041, 0x004A5142, 0x004A5142, 0x004A5142, 0x004A5142, 0x004D5342, 0x004C5241, 0x004A503F, 0x004A503F, 0x004C5241,
        0x004E5443, 0x004E5443, 0x004E5443, 0x004E5246, 0x004D5145, 0x004D5145, 0x004D5145, 0x004D5145, 0x004D5145, 0x004D5145, 0x004E5246, 0x00464D3E, 0x00474E3F, 0x00484F40, 0x00494E3F, 0x00484D3E, 0x00494C3D, 0x00494C3D, 0x004A4D3E, 0x00544F40,
        0x004A4E42, 0x00465043, 0x004F5242, 0x005B5542, 0x00464A3F, 0x001D3D43, 0x000F495F, 0x000A4A63, 0x000B4B64, 0x000D4D66, 0x000C4E67, 0x000C4E67, 0x000C4E67, 0x000A4D66, 0x000A4D66, 0x000A4D68, 0x000A4D68, 0x00094C67, 0x00094C67, 0x00094C67,
        0x000A4D68, 0x000B4E69, 0x000B4E69, 0x00154765, 0x00015469, 0x0060C8D5, 0x0098FEFF, 0x0096FFFF, 0x006DE7F3, 0x0056DAEB, 0x005ADAEF, 0x0076DEF5, 0x0075E9FA, 0x0075F1FC, 0x006EE6F2, 0x007DEBFD, 0x0094FDFF, 0x0067D5F9, 0x000177A0, 0x00064664,
        0x00044D63, 0x000C5165, 0x00114E68, 0x00064C69, 0x0002596D, 0x00227479, 0x004D8C83, 0x00121113, 0x00040503, 0x001E2118, 0x00393C2D, 0x003C3F2F, 0x00454636, 0x00444436, 0x00363628, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFE, 0xFFFEFDFF, 0xFFFDFCFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00595D51, 0x00435040, 0x000E100A, 0x00181010, 0x0035302D, 0x00303A2D, 0x003F6454, 0x00316D65, 0x00125C60, 0x0017516E, 0x0017516E, 0x0017516E, 0x0018526F, 0x00195370,
        0x001A5471, 0x00195370, 0x0018526F, 0x001A5369, 0x00165268, 0x00165367, 0x00164F65, 0x001E4E6A, 0x00174D6E, 0x00044D73, 0x003994BB, 0x002EA4D5, 0x003D7C9E, 0x00D8D9E7, 0x00FFFDFC, 0x00D1D0CC, 0x00ACC0C1, 0x005A6D70, 0x00373B40, 0x002D4A4F,
        0x00405759, 0x0040514D, 0x0035463D, 0x00263733, 0x00152E32, 0x001C3D4C, 0x0060879D, 0x008EAFB8, 0x00759797, 0x00A0B0A9, 0x00857F72, 0x004E4C3A, 0x00465847, 0x003D493D, 0x00534745, 0x004C4D39, 0x00555440, 0x007A7560, 0x008E836D, 0x009C8C75,
        0x00C5AF96, 0x00DDC3AB, 0x00DEC3A9, 0x00E3C2A8, 0x00E0C5AB, 0x00DAC9AF, 0x00CBC6AD, 0x0094947C, 0x005E5F4B, 0x00605E4C, 0x00656351, 0x005B6352, 0x00575D4C, 0x005E584D, 0x00938781, 0x00ACB3B0, 0x00729A95, 0x008CB8B7, 0x0099B6BA, 0x002A9CCB,
        0x00228EB8, 0x00238DB2, 0x002D9BC5, 0x003FB7EB, 0x002BA8E2, 0x0038B2E8, 0x0036AAD9, 0x002190B8, 0x000D4764, 0x00175972, 0x003EACD6, 0x00279BD4, 0x0038ACE1, 0x0033AEE0, 0x0035A9E4, 0x003FA8D9, 0x002796BE, 0x00296E8F, 0x005C899E, 0x00448086,
        0x00476E70, 0x00434849, 0x003C4A48, 0x00525D43, 0x00555D46, 0x00515740, 0x00545642, 0x00545240, 0x005F5B49, 0x00595243, 0x005D5446, 0x004F5544, 0x00505344, 0x00525246, 0x00535146, 0x00525246, 0x004E5443, 0x004B5642, 0x00485841, 0x00505944,
        0x00525B46, 0x00505643, 0x00515542, 0x00545545, 0x005A5749, 0x005D574A, 0x00585245, 0x0052543E, 0x00555642, 0x00555543, 0x00565747, 0x00484B3B, 0x004F5340, 0x004A513C, 0x004D553E, 0x00495043, 0x00475043, 0x004E5949, 0x00495543, 0x004F5A46,
        0x00505944, 0x00525841, 0x00575A44, 0x004D5544, 0x004E5645, 0x004B5342, 0x00565D4E, 0x004D5445, 0x0052594C, 0x00484F42, 0x004D5447, 0x004E5044, 0x00505246, 0x004F5145, 0x004A4E42, 0x004B4F43, 0x004C5346, 0x004B5245, 0x00484F42, 0x004D4F43,
        0x004A5144, 0x00485343, 0x00475444, 0x0045513F, 0x00484C39, 0x0054503D, 0x005D5643, 0x0045493D, 0x0044483C, 0x004B4F43, 0x004B4F43, 0x0044483C, 0x0045493D, 0x00494D41, 0x004C5044, 0x00424C40, 0x0032443D, 0x003F6363, 0x004F858C, 0x003F8390,
        0x00317E8E, 0x00287A8C, 0x00136779, 0x00197080, 0x001F697B, 0x00216075, 0x00054861, 0x00004666, 0x00157FA8, 0x0039ABE0, 0x002C9FDC, 0x0015668B, 0x001D3944, 0x003D493D, 0x00394A3D, 0x0045493D, 0x00424B31, 0x003B4A2B, 0x0058523F, 0x00494E3F,
        0x00464B3C, 0x00424738, 0x00404536, 0x00404536, 0x00414637, 0x00424738, 0x00424738, 0x00404738, 0x00414839, 0x00414839, 0x0042493A, 0x00414839, 0x00404738, 0x003F4637, 0x003E4536, 0x00434938, 0x00414736, 0x00404635, 0x00414736, 0x00434938,
        0x00444A39, 0x00444A39, 0x00444A39, 0x0044463A, 0x00434539, 0x00424438, 0x00424438, 0x00424438, 0x00424438, 0x00434539, 0x0044463A, 0x003E4536, 0x00404738, 0x00414839, 0x00434839, 0x00424738, 0x00434637, 0x00434637, 0x00434637, 0x004A4536,
        0x003F4337, 0x003B4538, 0x00444737, 0x00514B38, 0x003D4136, 0x0014343A, 0x00064056, 0x000A4A63, 0x000B4B64, 0x000D4D66, 0x000C4E67, 0x000D4F68, 0x000C4E67, 0x000B4E67, 0x000A4D66, 0x000B4E69, 0x000A4D68, 0x000A4D68, 0x000A4D68, 0x000A4D68,
        0x000B4E69, 0x000C4F6A, 0x000D506B, 0x000F4E6A, 0x00005063, 0x005AC9D3, 0x0092F4FE, 0x009BF7FF, 0x008BEDFD, 0x007FE8FD, 0x0088ECFF, 0x0094EBF5, 0x0097FAFE, 0x0086F4F2, 0x0086F3F1, 0x008EF0F6, 0x0095EEFF, 0x007CD7F6, 0x0010729A, 0x00094967,
        0x00034C62, 0x00084D61, 0x00104D67, 0x000A506D, 0x00045B6F, 0x00186A6F, 0x0038776E, 0x000D0C0E, 0x00010200, 0x001E2118, 0x003B3E2F, 0x003F4232, 0x00474838, 0x00424234, 0x00333325, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFEFFFD, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00585C50, 0x0042493A, 0x00040F07, 0x0010110F, 0x00423533, 0x002A2E22, 0x00335F4E, 0x002B7066, 0x001D6166, 0x0019596B, 0x00125669, 0x000D5266, 0x000F536A, 0x0011546B,
        0x00135267, 0x00155266, 0x00155365, 0x0021506F, 0x0027566B, 0x00195164, 0x0012546D, 0x00115366, 0x001A5564, 0x000A4D6C, 0x00338AC3, 0x00329FBF, 0x0088AFC5, 0x00FAE4E9, 0x00FFEAE5, 0x00EEEFEB, 0x00A1AEAC, 0x0049504B, 0x00404438, 0x004F5439,
        0x004E5540, 0x00404137, 0x0036282C, 0x00003639, 0x00123542, 0x00243E4F, 0x009EB6CA, 0x008B9B94, 0x00A6B5AD, 0x007A887D, 0x00444E42, 0x004B5243, 0x00535646, 0x00484A37, 0x004E4F3B, 0x00505344, 0x004F4F41, 0x005A5A48, 0x00898572, 0x0089816A,
        0x0090866E, 0x00C6B99F, 0x00D5C7AB, 0x00DBCAAF, 0x00DBC9AC, 0x00D6C4A5, 0x00D8C9A9, 0x00D7CCAE, 0x00A39C81, 0x005A5840, 0x00646551, 0x005C5B4D, 0x005B5A4C, 0x00626252, 0x004D5041, 0x00868C81, 0x009FABA5, 0x008B9D9C, 0x009CB3B5, 0x0046818A,
        0x00277E98, 0x002EA4D3, 0x002CACE7, 0x0035ADE9, 0x0039A8E0, 0x0032A6DB, 0x0034B0E6, 0x00298DB7, 0x000A4965, 0x001B6179, 0x0042A8D3, 0x002C9AD4, 0x002EABDE, 0x002CB2E2, 0x003CADE6, 0x0030A8DC, 0x002C95C0, 0x00418699, 0x0081A29B, 0x00A1B2A7,
        0x00A8B9BC, 0x00384242, 0x005B5548, 0x00585A47, 0x00585A47, 0x00585A47, 0x00565949, 0x00555848, 0x00515746, 0x00505546, 0x00525748, 0x0054564A, 0x00525448, 0x0057594D, 0x005A5A4C, 0x00545446, 0x00535444, 0x00575747, 0x00555545, 0x00595949,
        0x00595949, 0x00585848, 0x00575747, 0x00565646, 0x00555545, 0x00555545, 0x00555545, 0x00595A4A, 0x00525343, 0x004E4F3F, 0x00515242, 0x00525343, 0x00515242, 0x00525343, 0x00555646, 0x00545545, 0x00555646, 0x00555646, 0x00545545, 0x00575848,
        0x005B5C4C, 0x005B5C4C, 0x00585949, 0x00525545, 0x00515444, 0x004F5242, 0x004E5141, 0x004E5141, 0x004F5242, 0x00505343, 0x00515444, 0x00515242, 0x004F5040, 0x004F5040, 0x004F5040, 0x00515242, 0x00525343, 0x00525343, 0x00515242, 0x00494C3C,
        0x004A4D3D, 0x004D5040, 0x004E5141, 0x004E5141, 0x004C4F3F, 0x00494C3C, 0x00484B3B, 0x00474D3C, 0x00494F3E, 0x004B5140, 0x004C5241, 0x004B5140, 0x004B5140, 0x004C5241, 0x004D5342, 0x00474739, 0x001F3327, 0x009A9C96, 0x0097ACA3, 0x0076988D,
        0x0083AFB0, 0x0028879A, 0x001781A6, 0x002189AC, 0x002186A6, 0x00308FA9, 0x000D6780, 0x00004867, 0x001D7CA7, 0x00379ED5, 0x00319EDC, 0x000F75A5, 0x00002A49, 0x004D4E52, 0x00302D1E, 0x004D5947, 0x00223328, 0x00445754, 0x00112927, 0x00444B46,
        0x00252F29, 0x00415048, 0x00192C23, 0x00314539, 0x00283C30, 0x002A3E32, 0x002D3F32, 0x0033413D, 0x00202F2B, 0x00293B34, 0x0031443B, 0x001F3327, 0x0037483B, 0x00202E22, 0x00404D3F, 0x00232F1B, 0x00474B3F, 0x002F2C27, 0x003C4140, 0x00223532,
        0x002C473E, 0x00193326, 0x00394C3D, 0x00273228, 0x00414C42, 0x00263127, 0x00384339, 0x0029342A, 0x00323D33, 0x00323D33, 0x002D382E, 0x00333839, 0x002E3334, 0x003B4041, 0x002B3333, 0x00333B3B, 0x00222C2C, 0x00404A4A, 0x001E2828, 0x00465252,
        0x0009262B, 0x00434C4F, 0x00132A1B, 0x004A514A, 0x0004323D, 0x00083249, 0x00144658, 0x000C4E60, 0x000D4E63, 0x000E4E67, 0x000C4D69, 0x000C4C6A, 0x000B4C68, 0x00094C65, 0x00084C63, 0x000D506B, 0x000B4E69, 0x00094C67, 0x00084B66, 0x00094C67,
        0x00094C67, 0x00084B66, 0x00074A65, 0x000E4462, 0x0009536F, 0x005ABED7, 0x0081F0FF, 0x007EE9FF, 0x007EE2FA, 0x0082E5F9, 0x008AEFFE, 0x006EE5F4, 0x0076E7F7, 0x007CE5F8, 0x0078E6F8, 0x0077EDFE, 0x007CF2FF, 0x0070D9EE, 0x0018758C, 0x000B4A66,
        0x00064960, 0x000B5365, 0x00075066, 0x00084F6A, 0x00165D71, 0x00256E72, 0x00348074, 0x000D0C0E, 0x00000100, 0x001D2017, 0x00353829, 0x003A3D2D, 0x00474838, 0x00404032, 0x00343426, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFEFFFD, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00585C50, 0x00464D3E, 0x00061109, 0x000E0F0D, 0x003B2E2C, 0x0025291D, 0x00325E4D, 0x00296E64, 0x00185C61, 0x001C566C, 0x0018546C, 0x0018536D, 0x0019546E, 0x0018536D,
        0x00174F6A, 0x001B536C, 0x0020566D, 0x00154E6E, 0x001E546B, 0x00195369, 0x0011526E, 0x00155167, 0x00205766, 0x000B4C6B, 0x00388DC5, 0x0035A4C4, 0x0023617F, 0x00718597, 0x00889292, 0x009EAB9D, 0x0099A494, 0x00607168, 0x00203F3C, 0x003E3F3B,
        0x0064595B, 0x00435359, 0x002E3D4D, 0x000A4150, 0x0005394A, 0x003C8797, 0x00639DB0, 0x00B0BEB3, 0x007B867C, 0x004D574B, 0x004A5144, 0x00444737, 0x00464634, 0x00777662, 0x00A7A48F, 0x005F6253, 0x00494A3A, 0x00585644, 0x006D6956, 0x0087806C,
        0x008D836B, 0x0092876C, 0x00C0B399, 0x00CDBA9F, 0x00D7C4A9, 0x00DFCBAC, 0x00DAC8A9, 0x00D8CAAD, 0x00D0C7AC, 0x00A7A28D, 0x00605F4B, 0x00625F50, 0x005A5748, 0x0053513F, 0x00616151, 0x004B4F43, 0x0088938B, 0x009DAEAB, 0x006C8081, 0x00144B54,
        0x000C607A, 0x002CA0CF, 0x0028A6E1, 0x002DA2DF, 0x003DAAE2, 0x003BADE2, 0x0032ACE2, 0x002D8DB5, 0x000F4A64, 0x00185B74, 0x0042A6D0, 0x0034A0DA, 0x0036B0E6, 0x002DB0E2, 0x0037A6E4, 0x002FA5D9, 0x00248CB7, 0x003A7F92, 0x0073958B, 0x008D9E93,
        0x009CAEAF, 0x00343E3E, 0x005A5748, 0x00595B48, 0x005D5F4C, 0x005B5D4A, 0x00535646, 0x00545747, 0x00575C4D, 0x00565B4C, 0x004F5445, 0x0057594D, 0x00535549, 0x00515347, 0x00535345, 0x00535345, 0x00575848, 0x005B5B4B, 0x00585848, 0x00565646,
        0x00565646, 0x00565646, 0x00565646, 0x00555545, 0x00555545, 0x00555545, 0x00545444, 0x00555646, 0x00515242, 0x004F5040, 0x00505141, 0x00525343, 0x00535444, 0x00545545, 0x00555646, 0x00535444, 0x00555646, 0x00555646, 0x00545545, 0x00555646,
        0x00585949, 0x00575848, 0x00535444, 0x00505343, 0x004F5242, 0x004E5141, 0x004E5141, 0x004E5141, 0x004F5242, 0x00505343, 0x00505343, 0x00545545, 0x00525343, 0x00515242, 0x00515242, 0x00525343, 0x00525343, 0x00505141, 0x004E4F3F, 0x004D5040,
        0x004E5141, 0x004F5242, 0x00505343, 0x00505343, 0x004E5141, 0x004C4F3F, 0x004B4E3E, 0x00484E3D, 0x00494F3E, 0x004B5140, 0x004C5241, 0x004C5241, 0x004C5241, 0x004C5241, 0x004C5241, 0x004A4A3C, 0x001E3226, 0x0092948E, 0x008BA097, 0x006A8C81,
        0x007AA6A7, 0x00248396, 0x001781A6, 0x00107B9D, 0x001C83A3, 0x002586A0, 0x003190AA, 0x00016081, 0x001F82AE, 0x003EAAE0, 0x002998D6, 0x002B95CB, 0x001D5D80, 0x007A96A1, 0x00415951, 0x0079978C, 0x003A514D, 0x006D8583, 0x002F534D, 0x00698782,
        0x00405E59, 0x00678580, 0x0045615B, 0x00607C76, 0x00436259, 0x0054736A, 0x0054766C, 0x0044625D, 0x0065807C, 0x003A5551, 0x00617C78, 0x00405E59, 0x006D8B86, 0x00365651, 0x006D8F89, 0x00265749, 0x00638A82, 0x00324F53, 0x0076959E, 0x00507785,
        0x006B97A4, 0x00496F7B, 0x0074929D, 0x00457D88, 0x00568E99, 0x00467E89, 0x00508893, 0x00477F8A, 0x00467E89, 0x00477F8A, 0x00407883, 0x00548C91, 0x00457D82, 0x00599398, 0x003B757A, 0x0059969A, 0x003D7A7E, 0x005D9A9E, 0x00337276, 0x00769C96,
        0x00477E81, 0x00588184, 0x001B5249, 0x00799F9F, 0x004894A6, 0x005BA1BF, 0x0038829A, 0x000B4D5F, 0x000C4D62, 0x000D4D66, 0x000C4D69, 0x000C4C6A, 0x000C4D69, 0x000A4D66, 0x00094D64, 0x000C4F6A, 0x000B4E69, 0x00094C67, 0x00084B66, 0x00094C67,
        0x00094C67, 0x00084B66, 0x00074A65, 0x0010426C, 0x00004A71, 0x003FAED4, 0x004FD4FA, 0x0040CCF1, 0x0043CDF1, 0x0045D0F1, 0x0046D5F4, 0x0042CCF7, 0x0048CBF7, 0x0046C5F2, 0x0043C5F4, 0x0042CBF9, 0x004AD2FF, 0x0053CEFF, 0x000A78AC, 0x000A4965,
        0x00074A61, 0x000A5264, 0x00075066, 0x0009506B, 0x00145B6F, 0x00246D71, 0x003B877B, 0x00141315, 0x00000100, 0x001C1F16, 0x00353829, 0x00383B2B, 0x00454636, 0x003F3F31, 0x00333325, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFEFFFD, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00565A4E, 0x00454C3D, 0x00040F07, 0x000B0C0A, 0x003A2D2B, 0x00313529, 0x0044705F, 0x0030756B, 0x0013575C, 0x001A5471, 0x001A506E, 0x001F5371, 0x001D516F, 0x001B516F,
        0x00164C6A, 0x001A4E6C, 0x0021506F, 0x000A5172, 0x000C4C65, 0x00114E68, 0x00135274, 0x001A526D, 0x001A4E5F, 0x0001415F, 0x003D93C9, 0x0041AFD3, 0x00004E74, 0x0044809D, 0x004F7F81, 0x00617D6A, 0x006A7964, 0x0044645F, 0x0000353F, 0x00122C3D,
        0x00232740, 0x00003146, 0x002A6077, 0x000F455E, 0x00386A81, 0x003695A4, 0x00004553, 0x00626A5F, 0x00494F44, 0x00515445, 0x004B4C3C, 0x0052503E, 0x007C7762, 0x0097917A, 0x00B1A992, 0x00959587, 0x006A6B5B, 0x00514F3D, 0x004D4936, 0x00726B57,
        0x008D856E, 0x00A1977F, 0x00998D75, 0x00CCB89F, 0x00E1CEB3, 0x00DCC7AB, 0x00CFBA9E, 0x00D1C0A5, 0x00BDB199, 0x00ACA591, 0x00686150, 0x0057513E, 0x00696350, 0x005C5742, 0x005C5B47, 0x00555646, 0x004D554A, 0x005D6B65, 0x00283B38, 0x0010434D,
        0x0013627D, 0x0041AFDF, 0x0035AFEB, 0x0033A4E2, 0x0040ABE4, 0x003FAFE4, 0x0030A7DE, 0x003190B7, 0x00134A65, 0x0014576E, 0x0042A3CF, 0x00349EDB, 0x0035AEE6, 0x002DAEE5, 0x003AA8E8, 0x0032A6DB, 0x00268CB7, 0x00438899, 0x0074938A, 0x00849489,
        0x0099ABAC, 0x00333F3F, 0x00605D4E, 0x005C5E4B, 0x005D5F4C, 0x005E5F4F, 0x005A5D4D, 0x005A5D4E, 0x005A5F50, 0x00565B4C, 0x004E5246, 0x00525448, 0x0055574B, 0x0054564A, 0x00525244, 0x00545446, 0x00575848, 0x00575747, 0x00555545, 0x00515242,
        0x00525343, 0x00535444, 0x00545545, 0x00545545, 0x00545545, 0x00535444, 0x00535444, 0x00515242, 0x00515242, 0x00505141, 0x00505141, 0x00525343, 0x00545545, 0x00555646, 0x00545545, 0x00535444, 0x00555646, 0x00545545, 0x00535444, 0x00535444,
        0x00555646, 0x00535444, 0x004F5040, 0x004D5040, 0x004D5040, 0x004E5141, 0x004E5141, 0x004E5141, 0x004F5242, 0x004F5242, 0x00505343, 0x00565747, 0x00535444, 0x00525343, 0x00535444, 0x00555646, 0x00545545, 0x00515242, 0x004D4E3E, 0x004F5242,
        0x004F5242, 0x00505343, 0x00505343, 0x00505343, 0x004F5242, 0x004E5141, 0x004D5040, 0x00494F3E, 0x00494F3E, 0x004A503F, 0x004B5140, 0x004D5342, 0x004D5342, 0x004C5241, 0x004B5140, 0x004C4C3E, 0x001F3327, 0x0090928C, 0x00869B92, 0x0067897E,
        0x0079A5A6, 0x00258497, 0x001C86AB, 0x001B88A8, 0x000E7897, 0x002187A4, 0x002285A3, 0x002187AA, 0x00228DB9, 0x0031A1D6, 0x0030A3E0, 0x0032A0E0, 0x003E94C2, 0x00488DA1, 0x000F4F53, 0x004B7E80, 0x0048686D, 0x0089A9A8, 0x0036685E, 0x00407F7D,
        0x001F5857, 0x003F716F, 0x0046706F, 0x00618987, 0x00527D7A, 0x00487A76, 0x00376B64, 0x002A5C58, 0x006E9D9B, 0x00497274, 0x005D8387, 0x00345E63, 0x0045757B, 0x00245C61, 0x0064A2A8, 0x003A7872, 0x004B8182, 0x003A6C78, 0x006EA7BC, 0x003B84A0,
        0x0054A5C6, 0x003F90B3, 0x00529BC1, 0x00418FB4, 0x004795BA, 0x004795BA, 0x004B99BE, 0x004E9CC1, 0x004B99BE, 0x0055A3C8, 0x00509EC3, 0x00539DBF, 0x004693B4, 0x0058A5C6, 0x003F8CAD, 0x005AA9CA, 0x004998B9, 0x0058A9CA, 0x003C8DAE, 0x006A9FB3,
        0x004F95B2, 0x005B8FAD, 0x0025626E, 0x004C6F7D, 0x001A5B70, 0x00508098, 0x0078A6B1, 0x000B4D5F, 0x000B4C61, 0x000D4D66, 0x000C4D69, 0x000D4D6B, 0x000C4D69, 0x000A4D66, 0x000A4E65, 0x000C4F6A, 0x000A4D68, 0x00094C67, 0x00084B66, 0x00094C67,
        0x00094C67, 0x00094C67, 0x00084B66, 0x00124E5E, 0x00005666, 0x004DC1D2, 0x0062E5F9, 0x0060DEF6, 0x0077E8FF, 0x007FE6FF, 0x0080E5FE, 0x005CDCF9, 0x0065DEFE, 0x0069DCFD, 0x006BE4FF, 0x0062E0FF, 0x005DDBFD, 0x0064D6FB, 0x00187DA4, 0x00094864,
        0x00094C63, 0x00095163, 0x00064F65, 0x000A516C, 0x0011586C, 0x00226B6F, 0x00469286, 0x001E1D1F, 0x00000100, 0x001A1D14, 0x00373A2B, 0x00363929, 0x00424333, 0x003F3F31, 0x00323224, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFDFEFC, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x0055594D, 0x00474E3F, 0x000A150D, 0x00131412, 0x003C2F2D, 0x00303428, 0x0044705F, 0x002B7066, 0x000E5257, 0x00115473, 0x00104B6B, 0x001B4E6E, 0x00174B69, 0x0017516E,
        0x00104E6C, 0x00134C6C, 0x001A4D6E, 0x0005516E, 0x0014566F, 0x00195572, 0x000A486C, 0x00144A69, 0x00225468, 0x000D4D6B, 0x00398FC3, 0x00359DC8, 0x000F6386, 0x00498E9F, 0x00367271, 0x00618E85, 0x0051706F, 0x00184550, 0x0000485C, 0x000B4961,
        0x0000354E, 0x00056277, 0x004D90A9, 0x00144A61, 0x00738EA3, 0x00508B95, 0x00093840, 0x00434539, 0x00515347, 0x00646355, 0x004D4B39, 0x004D4734, 0x00918874, 0x00B1A690, 0x008C8068, 0x009E9F8F, 0x006E6E5E, 0x00575543, 0x00585441, 0x006A6451,
        0x00736C58, 0x00A89F8B, 0x00BBB39C, 0x00A2927B, 0x00C1B096, 0x00DCC9AE, 0x00DECBB0, 0x00C0AF95, 0x00695B45, 0x00665C4A, 0x0060594A, 0x0069624E, 0x005D5642, 0x006D6750, 0x0058533E, 0x005B5B49, 0x004F5649, 0x00435048, 0x00354440, 0x00194752,
        0x0018627E, 0x0044ADDE, 0x0034ACE8, 0x0038A7E5, 0x0040A9E2, 0x003CA9DF, 0x0033AAE1, 0x002E8DB4, 0x000E4661, 0x0013556E, 0x0049AAD6, 0x00339AD8, 0x0032A9E1, 0x002FAEE5, 0x0041AAED, 0x0035A8DB, 0x002E92BC, 0x005698AA, 0x007F9E95, 0x0086978A,
        0x009AACAD, 0x00303D3B, 0x00585848, 0x00636454, 0x005C5D4D, 0x005D5E4E, 0x005B5E4F, 0x004D5041, 0x00393E2F, 0x00303428, 0x002E3226, 0x003B3D31, 0x004B4D41, 0x0055574B, 0x0058584A, 0x0058584A, 0x00575848, 0x00555545, 0x00545444, 0x00515242,
        0x00525343, 0x00535444, 0x00555646, 0x00555646, 0x00545545, 0x00535444, 0x00525343, 0x004F5040, 0x00525343, 0x00525343, 0x00505141, 0x00515242, 0x00555646, 0x00555646, 0x00515242, 0x00545545, 0x00555646, 0x00535444, 0x00515242, 0x00515242,
        0x00545545, 0x00535444, 0x004F5040, 0x004D5040, 0x004D5040, 0x004E5141, 0x004F5242, 0x00505343, 0x00505343, 0x00505343, 0x00505343, 0x00545545, 0x00525343, 0x00525343, 0x00545545, 0x00575848, 0x00575848, 0x00545545, 0x00505141, 0x004E5141,
        0x004E5141, 0x004E5141, 0x004D5040, 0x004D5040, 0x004D5040, 0x004D5040, 0x004D5040, 0x004C5241, 0x004B5140, 0x00494F3E, 0x004A503F, 0x004C5241, 0x004D5342, 0x004D5342, 0x004C5241, 0x004E4E40, 0x0023372B, 0x0093958F, 0x00889D94, 0x00698B80,
        0x0078A4A5, 0x001F7E91, 0x001680A5, 0x001681A2, 0x003EAAC9, 0x00097392, 0x001B84A5, 0x00238EB4, 0x0030A0CE, 0x00269BD2, 0x00269ED9, 0x00299DE4, 0x003098CD, 0x002386A2, 0x00106C79, 0x001D626C, 0x00779EA7, 0x007FA7A6, 0x007DB7AC, 0x003D9491,
        0x003C8887, 0x00488889, 0x006CA2A3, 0x006D9EA0, 0x006BA1A1, 0x00306C6B, 0x000A4C4A, 0x00165755, 0x00518B8A, 0x0079ACAF, 0x006F9FA5, 0x0062959F, 0x003C7985, 0x00327E8A, 0x003F939F, 0x0090B8B6, 0x00638A8C, 0x0073A1AC, 0x00428398, 0x0024829F,
        0x002397BA, 0x00229BC5, 0x002199C7, 0x002194C1, 0x001C8FBC, 0x002194C1, 0x001B8EBB, 0x002295C2, 0x001C8FBC, 0x002B9ECB, 0x00299CC9, 0x001B88BE, 0x002390C6, 0x002592C8, 0x001F8FC4, 0x002191C6, 0x00289ACF, 0x002395CA, 0x001C8EC3, 0x002391C5,
        0x001794CE, 0x002D92C6, 0x000E728B, 0x00034151, 0x00004C55, 0x001C4E4E, 0x00628C7A, 0x000A4C5E, 0x000B4C61, 0x000D4D66, 0x000C4D69, 0x000D4D6B, 0x000D4E6A, 0x000B4E67, 0x000B4F66, 0x000C4F6A, 0x000A4D68, 0x00084B66, 0x00084B66, 0x00094C67,
        0x00094C67, 0x00094C67, 0x00084B66, 0x001D4968, 0x00044D6B, 0x0047B6D6, 0x0051D7F9, 0x0045CEF5, 0x0054D7FF, 0x0056D4FD, 0x0058D6FF, 0x004AD5F6, 0x0055D7FA, 0x0055D3F6, 0x0058DAFF, 0x004ED8FC, 0x0049D2F8, 0x0050CCF4, 0x0000709A, 0x00084763,
        0x000A4D64, 0x00085062, 0x00054E64, 0x000C536E, 0x000E5569, 0x0020696D, 0x004E9A8E, 0x00282729, 0x00000100, 0x001A1D14, 0x00393C2D, 0x00363929, 0x00414232, 0x003F3F31, 0x00323224, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFDFEFC, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x0053574B, 0x003B4233, 0x00051008, 0x00131412, 0x00342725, 0x0022261A, 0x003A6655, 0x002A6F65, 0x001D6166, 0x000E5C79, 0x000D4E6A, 0x001F526C, 0x00164B60, 0x00145669,
        0x000C5269, 0x000E4F6B, 0x00184E6F, 0x000D5065, 0x00155063, 0x00144C67, 0x00165276, 0x00205776, 0x001A4F64, 0x000C4D6C, 0x002F88BB, 0x0044A5D7, 0x001E6079, 0x0082B1AE, 0x00487B73, 0x00134954, 0x000A3958, 0x00144362, 0x00134E62, 0x00094757,
        0x00196B77, 0x00409FA9, 0x0083B5C7, 0x004C8894, 0x007E8E9A, 0x00596F74, 0x00012624, 0x003A3E33, 0x0057594D, 0x0049493B, 0x00605D4E, 0x00635D4A, 0x004D4430, 0x00857A64, 0x00BBAF97, 0x007B7B69, 0x0050503E, 0x00585644, 0x00666250, 0x0095917E,
        0x00918B78, 0x00706956, 0x00837C69, 0x00988B75, 0x009C8E77, 0x00CABBA1, 0x00D3C2A8, 0x00AC9C85, 0x0060523F, 0x00615746, 0x005C5447, 0x00605945, 0x0067604C, 0x005F5942, 0x00625D48, 0x00545442, 0x00575E51, 0x002F3C34, 0x0021302C, 0x00103A46,
        0x00115A76, 0x003FA8D9, 0x002FA4E1, 0x0038A9E7, 0x003DA8E1, 0x0036A6DB, 0x0034AEE4, 0x00238BB6, 0x00054563, 0x000C536E, 0x004AAFDC, 0x00339DDA, 0x0036ABE2, 0x0034B0E6, 0x0040A7E6, 0x001C8ABE, 0x00207FAA, 0x005090A2, 0x007E9C91, 0x00859689,
        0x009DB2B0, 0x00364442, 0x005F5F4D, 0x00616252, 0x005C5D4D, 0x005C5C4E, 0x00515445, 0x00373A2B, 0x001F2317, 0x001B1F13, 0x001B1F13, 0x00212317, 0x0035372B, 0x004A4C40, 0x00575749, 0x005C5C4E, 0x005C5D4D, 0x005B5B4B, 0x00585848, 0x00525343,
        0x00535444, 0x00555646, 0x00555646, 0x00555646, 0x00545545, 0x00525343, 0x00515242, 0x004F5040, 0x00535444, 0x00545545, 0x00515242, 0x00505141, 0x00535444, 0x00535444, 0x004F5040, 0x00545545, 0x00545545, 0x00525343, 0x004F5040, 0x00505141,
        0x00545545, 0x00555646, 0x00535444, 0x004E5141, 0x004F5242, 0x00505343, 0x00515444, 0x00515444, 0x00525545, 0x00525545, 0x00525545, 0x00545545, 0x00535444, 0x00535444, 0x00555646, 0x00575848, 0x00575848, 0x00535444, 0x00505141, 0x004F5242,
        0x004F5242, 0x004E5141, 0x004E5141, 0x004D5040, 0x004D5040, 0x004E5141, 0x004E5141, 0x004F5544, 0x004C5241, 0x00494F3E, 0x00484E3D, 0x004A503F, 0x004C5241, 0x004D5342, 0x004E5443, 0x004F4F41, 0x0025392D, 0x0093958F, 0x00879C93, 0x0066887D,
        0x00729E9F, 0x00157487, 0x000C769B, 0x00127C9B, 0x00319ABB, 0x0042ADCF, 0x00036E93, 0x001282AC, 0x0036A9DB, 0x002BA2D9, 0x0028A3DD, 0x001B94DA, 0x002B98CC, 0x00026682, 0x00298794, 0x002D727C, 0x00295059, 0x00416767, 0x002E685D, 0x00166D6A,
        0x00186463, 0x001E5E5F, 0x002A6061, 0x002E5F61, 0x00316767, 0x00185453, 0x00115351, 0x001A5C57, 0x001C5655, 0x003E7173, 0x002F5F65, 0x002D606A, 0x0026636F, 0x0016626E, 0x000E626E, 0x0035574D, 0x00375752, 0x003F6567, 0x000D4851, 0x00136B7B,
        0x002A95B0, 0x001D8FB3, 0x002FA0C8, 0x002C97BC, 0x002994B9, 0x002792B7, 0x00238EB3, 0x00248FB4, 0x001F8AAF, 0x002893B8, 0x002893B8, 0x001F85B5, 0x00298FBF, 0x002991C0, 0x00258DBC, 0x00248CBB, 0x002C96C5, 0x00258FBE, 0x00228CBB, 0x00208EC2,
        0x000683BD, 0x00298DC3, 0x001C809C, 0x000E4E60, 0x00004D5A, 0x0014494C, 0x00457262, 0x000A4C5E, 0x000B4C61, 0x000D4D66, 0x000C4D69, 0x000D4D6B, 0x000D4E6A, 0x000B4E67, 0x000B4F66, 0x000B4E69, 0x000A4D68, 0x00084B66, 0x00084B66, 0x00094C67,
        0x000A4D68, 0x00094C67, 0x00094C67, 0x000E4462, 0x00004D6A, 0x0043B8D5, 0x0056DEFF, 0x004FDBFF, 0x0055DBFF, 0x0052D5FD, 0x0055D9FF, 0x004DDBFA, 0x0057DEFE, 0x0054D5F6, 0x0052D8FA, 0x0050DDFE, 0x004FDBFF, 0x0051D0F6, 0x0004769E, 0x00084763,
        0x000B4E65, 0x00085062, 0x00044D63, 0x000C536E, 0x000D5468, 0x001E676B, 0x00509C90, 0x002B2A2C, 0x00020301, 0x001A1D14, 0x003A3D2E, 0x00373A2A, 0x00414232, 0x00404032, 0x00343426, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFDFEFC, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x0052564A, 0x00444B3C, 0x0008130B, 0x00131412, 0x00342725, 0x00272B1F, 0x003E6A59, 0x0024695F, 0x0014585D, 0x0005556C, 0x00124E64, 0x00356172, 0x002A5764, 0x00205E68,
        0x000F5763, 0x00145368, 0x00245672, 0x003F6C77, 0x003B666F, 0x0017495D, 0x000E4B6D, 0x00135070, 0x00124C62, 0x001E6586, 0x00338DC3, 0x00369BCF, 0x00336A7F, 0x00819B95, 0x002A514F, 0x0008455F, 0x00104B79, 0x001B496B, 0x00567E8A, 0x00739398,
        0x0088BFC2, 0x00417B80, 0x00A9C4CE, 0x007ABDBE, 0x0079969A, 0x004E6A6A, 0x00093A32, 0x002B342A, 0x00444C42, 0x004F554A, 0x00484A3E, 0x004D4D3D, 0x004E4A38, 0x005F5946, 0x0099927E, 0x00ACAA98, 0x0073715F, 0x00514F3D, 0x005F5D4B, 0x008A8674,
        0x00969280, 0x0075715F, 0x005D5947, 0x008D8873, 0x00908A73, 0x00968C74, 0x00796D55, 0x00756951, 0x006B614F, 0x00686152, 0x00585247, 0x00595340, 0x005B5542, 0x0069644F, 0x0061604C, 0x004C4D3D, 0x003B4338, 0x00182620, 0x00091C19, 0x00083540,
        0x00105975, 0x0047B0E1, 0x002FA7E3, 0x0038ABE8, 0x003DACE4, 0x0033A7DC, 0x002BA9DF, 0x002699CC, 0x00115B7F, 0x00045473, 0x003AA4D3, 0x002F9AD7, 0x003CB0E5, 0x0038B0DE, 0x003EA2D9, 0x001784B7, 0x002381AC, 0x004F8D9D, 0x00789389, 0x007E8F81,
        0x0095AAA8, 0x0032413D, 0x00585A47, 0x005A5B4B, 0x005F5F51, 0x005E5E50, 0x00444738, 0x0026281C, 0x001E2216, 0x0024281D, 0x0021251A, 0x001F2115, 0x0027291D, 0x003C3E32, 0x00525244, 0x005A5A4C, 0x005D5E4E, 0x005D5D4D, 0x00555545, 0x00515444,
        0x00525545, 0x00525545, 0x00535646, 0x00525545, 0x00525545, 0x00505343, 0x00505343, 0x00505141, 0x00535444, 0x00535444, 0x00525343, 0x00505141, 0x00515242, 0x00515242, 0x00505141, 0x00535444, 0x00535444, 0x00515242, 0x004F5040, 0x00515242,
        0x00555646, 0x00565747, 0x00545545, 0x00505343, 0x00505343, 0x00505343, 0x00515444, 0x00515444, 0x00525545, 0x00525545, 0x00535646, 0x00565747, 0x00565747, 0x00555646, 0x00555646, 0x00545545, 0x00535444, 0x00505141, 0x004E4F3F, 0x00525545,
        0x00515444, 0x00515444, 0x00505343, 0x00505343, 0x00505343, 0x00505343, 0x00505343, 0x004F5544, 0x004D5342, 0x004A503F, 0x00484E3D, 0x00494F3E, 0x004B5140, 0x004D5342, 0x004F5544, 0x004F4F41, 0x0025392D, 0x0090928C, 0x0082978E, 0x0065877C,
        0x0074A0A1, 0x001C7B8E, 0x001781A6, 0x00096C8C, 0x002286A8, 0x00349CC1, 0x003DA9D3, 0x000170A0, 0x001B90C3, 0x002DA4DB, 0x001F98D0, 0x0026A1DF, 0x003B9CC8, 0x005BA8BB, 0x003E8588, 0x0081B9BA, 0x00527579, 0x008BABAA, 0x00427168, 0x00599896,
        0x00417A79, 0x006C9E9C, 0x00547E7D, 0x007CA4A2, 0x0057827F, 0x00659793, 0x00649891, 0x006A9D96, 0x006A9A94, 0x00648F8C, 0x00769E9D, 0x004D797A, 0x007BACAE, 0x00478082, 0x0061A1A2, 0x00416E5E, 0x0081A79B, 0x0053786E, 0x0076A49E, 0x00427F81,
        0x0085CCD6, 0x0063A4B9, 0x0079B1CE, 0x0069A9C1, 0x0077B7CF, 0x006AAAC2, 0x0076B6CE, 0x006EAEC6, 0x0074B4CC, 0x0070B0C8, 0x0073B3CB, 0x006FAFC1, 0x006EAEC0, 0x0078BACC, 0x005FA1B3, 0x0075BACB, 0x0067ACBD, 0x0073B8C9, 0x0060A6B7, 0x0089BED2,
        0x005CA2BF, 0x0083B9D8, 0x0067A8B7, 0x00759FB2, 0x001B617F, 0x00457B9C, 0x0042788F, 0x000B4D5F, 0x000B4C61, 0x000D4D66, 0x000C4D69, 0x000D4D6B, 0x000C4D69, 0x000A4D66, 0x000A4E65, 0x000B4E69, 0x00094C67, 0x00084B66, 0x00084B66, 0x00094C67,
        0x000A4D68, 0x000A4D68, 0x00094C67, 0x00004D58, 0x00005B67, 0x003FB9C7, 0x0064E4F6, 0x0072EAFF, 0x0077E5FD, 0x0074DEF5, 0x0077E1F8, 0x005CDBF4, 0x0069E0FA, 0x006ADDF8, 0x0067DDFA, 0x0065E3FF, 0x005FDDFA, 0x0057C8E8, 0x00187C9E, 0x00094864,
        0x000B4E65, 0x00085062, 0x00044D63, 0x000C536E, 0x000E5569, 0x001E676B, 0x004B978B, 0x00282729, 0x00020301, 0x001A1D14, 0x00383B2C, 0x00393C2C, 0x00434434, 0x00404032, 0x00363628, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFDFEFC, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00505448, 0x00444B3C, 0x00040F07, 0x000F100E, 0x00382B29, 0x0034382C, 0x004B7766, 0x00286D63, 0x0013575C, 0x0013596A, 0x0041707E, 0x008FAAB4, 0x0093B0B4, 0x0088B8B9,
        0x0071ABB0, 0x007DAEBC, 0x0099BBD2, 0x009FB1B0, 0x00AEC6C4, 0x00527C88, 0x000B4A66, 0x00074B68, 0x0035788D, 0x006CB9DA, 0x004EABE2, 0x002B9BC9, 0x00286684, 0x00809AA8, 0x00355C6A, 0x0003455E, 0x000D4A6A, 0x002A5265, 0x0096B0B0, 0x00829893,
        0x00A0B0AF, 0x002B4A4B, 0x00A2B4BD, 0x004B888C, 0x0038646B, 0x001E5356, 0x003A676A, 0x008E9D99, 0x00303E38, 0x003D4A42, 0x00495248, 0x003B4235, 0x004D5041, 0x004D4E3E, 0x00575745, 0x006C6B57, 0x005B5A46, 0x00585644, 0x00918F7D, 0x00787566,
        0x00595647, 0x005E5B4C, 0x00514E40, 0x00696A56, 0x008C8B76, 0x008F8B73, 0x00716C53, 0x0067614A, 0x00615B48, 0x005B584A, 0x00605E53, 0x005F5C4D, 0x00646152, 0x004E4C3A, 0x00606050, 0x0044483C, 0x00242F27, 0x0081928F, 0x003F5354, 0x00194651,
        0x0009536F, 0x003FADDD, 0x002CA8E4, 0x0030A8E4, 0x0036AAE1, 0x0032ACE0, 0x0024A8DD, 0x0029A9E4, 0x002C83AF, 0x000D678A, 0x002C9BCB, 0x002A98D2, 0x003EB2E1, 0x002BA1CA, 0x003190C1, 0x001F88BB, 0x00308CB5, 0x00508C9C, 0x00759184, 0x007E8F81,
        0x0093A8A5, 0x0034433F, 0x00575C47, 0x005C5C4E, 0x00606052, 0x005C5C4E, 0x003E4034, 0x001E2014, 0x001B1F14, 0x0022261B, 0x001B1F14, 0x0025271B, 0x00222418, 0x00383A2E, 0x00515143, 0x00545446, 0x00575848, 0x00595949, 0x00505040, 0x004F5242,
        0x00505343, 0x00505343, 0x00505343, 0x00515444, 0x00515444, 0x00515444, 0x00515444, 0x004F5141, 0x004F5242, 0x00515242, 0x00525343, 0x00515242, 0x004F5040, 0x00515242, 0x00535444, 0x00505141, 0x00525343, 0x00515242, 0x00505141, 0x00525343,
        0x00555646, 0x00535444, 0x00505242, 0x00505343, 0x00505343, 0x00505343, 0x004F5242, 0x004F5242, 0x00505343, 0x00515444, 0x00525545, 0x00555646, 0x00565747, 0x00565747, 0x00545545, 0x00525343, 0x00505141, 0x004F5040, 0x004F5040, 0x00515444,
        0x00515444, 0x00515444, 0x00515444, 0x00505343, 0x00505343, 0x00505343, 0x004F5242, 0x004D5342, 0x004D5342, 0x004C5241, 0x004B5140, 0x004A503F, 0x004B5140, 0x004C5241, 0x004E5443, 0x004E4E40, 0x0023372B, 0x008C8E88, 0x007E938A, 0x0065877C,
        0x0079A5A6, 0x00248396, 0x00248EB3, 0x00177495, 0x00004A6C, 0x001A7FA6, 0x003FAAD6, 0x002B9ACC, 0x002195CA, 0x002B9FD8, 0x002AA1D9, 0x0024A1D4, 0x0058A9CA, 0x0099C4CD, 0x0052756B, 0x0097BBAF, 0x00516A66, 0x00B6CECC, 0x004E706A, 0x0095B3AE,
        0x00587671, 0x0094B2AD, 0x005C7872, 0x0095B1AB, 0x005F7E75, 0x0083A299, 0x006C8E84, 0x00719087, 0x007F9C93, 0x00728F86, 0x0087A49B, 0x005C7B72, 0x008BAAA1, 0x005C7E74, 0x0095B8AE, 0x00517870, 0x0092B1A8, 0x00516A60, 0x009DBBB0, 0x00436963,
        0x009DC5C4, 0x0083A1AC, 0x00A1B5C6, 0x006EA5AC, 0x008EC5CC, 0x006DA4AB, 0x0089C0C7, 0x0075ACB3, 0x0086BDC4, 0x0075ACB3, 0x007DB4BB, 0x007DB2B5, 0x007AB1B4, 0x0087BEC1, 0x006DA4A7, 0x0084BDBF, 0x006FA8AA, 0x0086C1C3, 0x006FAAAC, 0x00A4C9C1,
        0x0071A8AB, 0x009DC7CC, 0x006CA7A3, 0x00AEDCE4, 0x004DA3C1, 0x005DAEDB, 0x00146B93, 0x000B4D5F, 0x000C4D62, 0x000D4D66, 0x000C4D69, 0x000C4C6A, 0x000C4D69, 0x000A4D66, 0x00094D64, 0x000A4D68, 0x00094C67, 0x00084B66, 0x00084B66, 0x00094C67,
        0x000A4D68, 0x000A4D68, 0x00094C67, 0x0012496E, 0x00014B6F, 0x001A789C, 0x001E87AE, 0x00218CB2, 0x001C8AAE, 0x00148BAB, 0x000F8FAC, 0x001788B0, 0x00218BB4, 0x00258BB5, 0x001C85B0, 0x001B8DB6, 0x001989B4, 0x001D82AF, 0x00055D8C, 0x000A4965,
        0x000A4D64, 0x00085062, 0x00054E64, 0x000B526D, 0x000F566A, 0x001E676B, 0x00449084, 0x00201F21, 0x00010200, 0x00181B12, 0x00353829, 0x00393C2C, 0x00444535, 0x003F3F31, 0x00373729, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFDFEFC, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00505448, 0x00414839, 0x00051008, 0x00151614, 0x00382B29, 0x002C3024, 0x003F6B5A, 0x0022675D, 0x00195D62, 0x00104B5A, 0x00577782, 0x00C0CBCF, 0x00C6D3D1, 0x00AACCC6,
        0x007DACAA, 0x0082A6B0, 0x009DB2C7, 0x00BFC0B6, 0x00C0CBC3, 0x0051757B, 0x0011516A, 0x00034D69, 0x001E677B, 0x005BACCD, 0x003495CD, 0x0029A8CF, 0x0009547B, 0x00507597, 0x0023526D, 0x000B4F62, 0x0015515D, 0x002B4E51, 0x00B3C8C0, 0x00396155,
        0x006B6968, 0x004B6466, 0x008CA5AF, 0x0024555F, 0x00194654, 0x002F747E, 0x00ABC1D3, 0x007C8F8C, 0x006F837E, 0x00384841, 0x0033423A, 0x00455046, 0x00424B3E, 0x00515647, 0x00454A3B, 0x004D4C38, 0x0052513D, 0x00545240, 0x00696755, 0x00565344,
        0x005D5A4C, 0x00555244, 0x00646153, 0x00555C47, 0x00636650, 0x0085856D, 0x00A6A48C, 0x00817E69, 0x00595745, 0x00555547, 0x0056574D, 0x005A594B, 0x00525143, 0x00656555, 0x00303324, 0x00343A2F, 0x0088948E, 0x006B7D7C, 0x00788F91, 0x0044727D,
        0x000D5A75, 0x003CABDB, 0x0030AEE9, 0x002EA8E4, 0x0031A6DD, 0x0031AEE1, 0x0022AADE, 0x0021A9E9, 0x0046A4D2, 0x002180A7, 0x002CA2D3, 0x002FA0D9, 0x003CB1DE, 0x00188EB1, 0x001B79A4, 0x00268FC2, 0x003B97C0, 0x00528E9E, 0x00759184, 0x00819082,
        0x0090A5A2, 0x002F403C, 0x00525742, 0x005F5F51, 0x005D5D4F, 0x005B5B4F, 0x0046483C, 0x00292B1F, 0x0021251A, 0x00262A1F, 0x0021251A, 0x00222418, 0x001E2014, 0x00393B2F, 0x00555547, 0x00515143, 0x00515242, 0x00595949, 0x00525242, 0x004D5040,
        0x004D5040, 0x004D5040, 0x004E5141, 0x004F5242, 0x00515343, 0x00535545, 0x00545645, 0x004E503E, 0x004C4D3D, 0x00515242, 0x00565747, 0x00535444, 0x004F5040, 0x00515242, 0x00565747, 0x004E4F3F, 0x00505141, 0x00525343, 0x00515242, 0x00525343,
        0x00535444, 0x00535444, 0x00515242, 0x00505141, 0x004F5040, 0x00515343, 0x00515343, 0x004E5141, 0x004F5242, 0x00505343, 0x00515444, 0x00525343, 0x00535444, 0x00545545, 0x00535444, 0x00505141, 0x004F5040, 0x00515242, 0x00535444, 0x004E5141,
        0x004E5141, 0x004E5141, 0x004F5242, 0x004E5141, 0x004E5141, 0x004D5040, 0x004D5040, 0x004B5140, 0x004D5342, 0x004E5443, 0x004D5342, 0x004C5241, 0x004B5140, 0x004B5140, 0x004C5241, 0x004E4E40, 0x0023372B, 0x008A8C86, 0x007A8F86, 0x00618378,
        0x00739FA0, 0x001E7D90, 0x001D87AC, 0x0051ABCA, 0x00147093, 0x00004D77, 0x00248CBB, 0x0037A5D9, 0x0030A1D9, 0x002DA1DA, 0x002DA1DA, 0x001D9AC6, 0x00256883, 0x008C9E9F, 0x0066705F, 0x0093A794, 0x00576D61, 0x00819491, 0x00516765, 0x00979E99,
        0x0056605A, 0x0096A59D, 0x00586B62, 0x0085998D, 0x0063776B, 0x0085998D, 0x00637568, 0x007C8B83, 0x00728378, 0x0075897D, 0x00708477, 0x00768B7C, 0x007D8F7E, 0x006A7A68, 0x008F9D8B, 0x005F6E71, 0x00979F9F, 0x00636A67, 0x008D9C94, 0x00547267,
        0x0084A8A2, 0x00617F80, 0x0095AAB2, 0x00677B80, 0x0092A6AB, 0x0062767B, 0x00889CA1, 0x006C8085, 0x00899DA2, 0x0073878C, 0x00809499, 0x00798996, 0x008595A2, 0x008999A6, 0x007F909D, 0x007F909D, 0x00768996, 0x008EA1AE, 0x008093A0, 0x00A5B0AE,
        0x00648186, 0x009CA8AC, 0x0069847B, 0x0098A7AA, 0x0029627B, 0x001E567F, 0x00003D63, 0x000C4E60, 0x000D4E63, 0x000E4E67, 0x000C4D69, 0x000C4C6A, 0x000B4C68, 0x00094C65, 0x00084C63, 0x000A4D68, 0x00094C67, 0x00084B66, 0x00084B66, 0x00094C67,
        0x000A4D68, 0x000A4D68, 0x000A4D68, 0x00244D66, 0x000E445D, 0x000E4D69, 0x00074361, 0x000F4361, 0x0010405C, 0x000B4459, 0x00024254, 0x00024A56, 0x000C4B59, 0x00134E5E, 0x00084656, 0x00044A5B, 0x00024859, 0x00124C5F, 0x001A465D, 0x000B4A66,
        0x000A4D64, 0x00095163, 0x00064F65, 0x000B526D, 0x0010576B, 0x001E676B, 0x003F8B7F, 0x0019181A, 0x00000100, 0x00171A11, 0x00323526, 0x00393C2C, 0x00444535, 0x003D3D2F, 0x00363628, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFF, 0xFFFCFBFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x0054584D, 0x003B4534, 0x00061409, 0x00131614, 0x00382C2A, 0x00292D22, 0x004D7869, 0x002C7069, 0x0014585F, 0x00004B6A, 0x0040636D, 0x00BDACA3, 0x00DCC1B7, 0x00768A8F,
        0x00044553, 0x00255966, 0x00ACB5BF, 0x00BCCCCB, 0x0063878F, 0x00164E61, 0x0019556D, 0x00164D68, 0x001E5B7B, 0x002E80AA, 0x003398CC, 0x002DA9DF, 0x0007647D, 0x0080C0C1, 0x00558E97, 0x00014366, 0x00044877, 0x00174965, 0x006B888C, 0x005B7068,
        0x006A969D, 0x005C8C92, 0x006F8D8E, 0x00275164, 0x002375A4, 0x006FCDFB, 0x006EB8D0, 0x00768889, 0x00747C7B, 0x00838E86, 0x002E4939, 0x00314D36, 0x00515843, 0x0053523D, 0x004A5039, 0x00485448, 0x004A5346, 0x00585A4E, 0x004F4E40, 0x005A5546,
        0x005D5947, 0x005C5B47, 0x00575844, 0x00595844, 0x005D5946, 0x006C6552, 0x009C9281, 0x00766C5B, 0x0062594B, 0x005D5647, 0x00585344, 0x00555842, 0x00545D50, 0x003A3935, 0x00493D39, 0x008E8E82, 0x006A8673, 0x0065857A, 0x009AA7A9, 0x002E82AC,
        0x00136F9A, 0x003AA2CD, 0x0030A3D0, 0x001D96C8, 0x0032AFE2, 0x002BA6DE, 0x002FAAE4, 0x0015A6DA, 0x003BB6EE, 0x002485B7, 0x0040A1CD, 0x001C97C9, 0x0030B4EA, 0x00318EAF, 0x0070999B, 0x0039B9E9, 0x0031A5D4, 0x003C90AC, 0x006E9695, 0x00859689,
        0x0098A6A2, 0x0033403E, 0x00555B50, 0x00606050, 0x005E5E4E, 0x005E5E4E, 0x00585848, 0x00404030, 0x00252515, 0x00202010, 0x002B2B1B, 0x001E1F0F, 0x002F3020, 0x004B4C3C, 0x00525343, 0x00535444, 0x00575848, 0x00525343, 0x00555646, 0x004F5243,
        0x004B4E3F, 0x00515445, 0x004B4E3E, 0x00545646, 0x00575948, 0x00565747, 0x00525343, 0x00525544, 0x00565747, 0x00565747, 0x004F5040, 0x00535444, 0x00525445, 0x004E5041, 0x004C4E42, 0x00515445, 0x004F5243, 0x00505344, 0x00515343, 0x004F5141,
        0x00505241, 0x00525343, 0x00525343, 0x00535444, 0x00535444, 0x00545545, 0x00545645, 0x004E503E, 0x004C4D3D, 0x00515242, 0x00565747, 0x00545545, 0x00535444, 0x00525343, 0x00525343, 0x00525343, 0x00535444, 0x00545545, 0x00545545, 0x004D4E3E,
        0x00505141, 0x00535444, 0x00525343, 0x004F5040, 0x004E4F3F, 0x00525343, 0x00575848, 0x004E5141, 0x00505343, 0x00515444, 0x004E5141, 0x004A4D3D, 0x00494C3C, 0x004C4F3F, 0x004F5242, 0x00495041, 0x0021311F, 0x00889E8B, 0x007D9283, 0x006B807D,
        0x006D94A2, 0x002C7E97, 0x001384A4, 0x001798BF, 0x0039A7D1, 0x00106D9A, 0x002787B5, 0x0035A7D6, 0x0027A1D5, 0x002CA0DB, 0x00359CDB, 0x00146C9A, 0x00334441, 0x005D4F3D, 0x00474B40, 0x00454936, 0x0049493B, 0x00444842, 0x004E503C, 0x00484B3C,
        0x004B4E3F, 0x004D5041, 0x004D5041, 0x004C4F40, 0x004B4E3F, 0x004B4E3F, 0x004B4E3F, 0x004D4E3E, 0x004D4E3E, 0x004E4F3F, 0x004D4E3E, 0x004D4E3E, 0x004D4E3E, 0x004D4E3E, 0x004E4F3F, 0x004C4F3F, 0x004C4F3F, 0x004B4E3E, 0x004C4D3D, 0x004B4C3C,
        0x004B4B3B, 0x004C4C3C, 0x004C4C3C, 0x004A4A38, 0x004E4E3C, 0x0050503E, 0x004C4D3D, 0x004B4C3C, 0x004B4E3F, 0x004A4D3E, 0x00474A3B, 0x00484E3D, 0x004B5140, 0x00484B3B, 0x00484B3B, 0x004D5040, 0x004E4F3F, 0x004E4F3F, 0x00505141, 0x004B4D3A,
        0x004C4B3D, 0x00494E3F, 0x0045503C, 0x0051533D, 0x004B443B, 0x00233840, 0x000C495D, 0x00084B66, 0x00084B66, 0x00074A65, 0x00094C67, 0x000B4E69, 0x000C4F6A, 0x000A4D68, 0x00094C67, 0x000C4E67, 0x000C4E67, 0x000C4E67, 0x000C4E67, 0x000C4E67,
        0x000C4E67, 0x000C4E67, 0x000C4E67, 0x000A4C65, 0x000B4D66, 0x000C4E67, 0x000C4E67, 0x000C4E67, 0x000C4E67, 0x000B4D66, 0x000A4C65, 0x00094B64, 0x000A4C65, 0x000B4D66, 0x000C4E67, 0x000C4E67, 0x000C4E67, 0x000B4D66, 0x000A4C65, 0x00034C68,
        0x000B4E65, 0x000F4B61, 0x000F4F68, 0x0008516D, 0x0006556A, 0x001D6B71, 0x003B877C, 0x00171618, 0x00000100, 0x001F2219, 0x00333627, 0x003A3D2D, 0x003E3F2F, 0x003F3F31, 0x0039392B, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFEFF, 0xFFFDFCFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x0053574C, 0x00434D3C, 0x00071208, 0x00111210, 0x003A2E2C, 0x0031372C, 0x00548171, 0x0031756E, 0x0012585F, 0x0006506C, 0x00274B51, 0x005B4F45, 0x00644E43, 0x004D6264,
        0x00074851, 0x0021535F, 0x009AA3AC, 0x0094AEA8, 0x004C7C7E, 0x00003F4E, 0x00175B72, 0x0011516A, 0x00105374, 0x003C91BF, 0x00258FC5, 0x002D9BCF, 0x0021758E, 0x00B1E8EB, 0x0071A2AA, 0x00084160, 0x00145179, 0x002D5970, 0x00AEC8C8, 0x00678F8A,
        0x00164A51, 0x00377176, 0x00185755, 0x00005561, 0x004EC0E5, 0x0038A7CD, 0x00096374, 0x00607F80, 0x00638A88, 0x006F8580, 0x00848179, 0x00434337, 0x0037523E, 0x00415640, 0x005E5443, 0x00495346, 0x00585F50, 0x004C4D3D, 0x00797667, 0x00AEA796,
        0x00857F6C, 0x00686550, 0x0053523D, 0x005E5D49, 0x00615D4A, 0x00625B48, 0x00716756, 0x00594F3E, 0x005B5244, 0x005C5748, 0x00585546, 0x005D5F53, 0x00403733, 0x00393736, 0x0087968E, 0x006B7A6C, 0x006B776B, 0x0091B6B4, 0x003B858B, 0x003188B4,
        0x002886B3, 0x0037A0CC, 0x002D9FCE, 0x001E97C9, 0x0027A3D9, 0x0029A4DC, 0x002DA8E2, 0x0029ADE3, 0x003CADE6, 0x002581B6, 0x0045A3D1, 0x00249ACE, 0x0031ACE6, 0x003B8CAD, 0x0092B0B1, 0x002289AA, 0x003D9EC2, 0x005DA8BE, 0x00779F9A, 0x007F9386,
        0x0095A6A2, 0x002F3C3A, 0x005B5C52, 0x005D5D4D, 0x005B5B4B, 0x005B5B4B, 0x00595949, 0x00494939, 0x00333323, 0x00292919, 0x002B2B1B, 0x00343525, 0x00414232, 0x00575848, 0x00595A4A, 0x00575848, 0x00575848, 0x004F5040, 0x004F5040, 0x00545748,
        0x00515445, 0x00525546, 0x004A4D3D, 0x00515343, 0x00585949, 0x00555646, 0x00525343, 0x004F5040, 0x004D4E3E, 0x00545545, 0x00555646, 0x004F5040, 0x00525343, 0x00505243, 0x0046483C, 0x00515445, 0x004E5142, 0x004C4F40, 0x00525444, 0x00545646,
        0x00525343, 0x00505141, 0x00535444, 0x00575848, 0x00585949, 0x00565747, 0x00525343, 0x00525544, 0x00565747, 0x00565747, 0x004F5040, 0x00545545, 0x00555646, 0x00555646, 0x00555646, 0x00555646, 0x00565747, 0x00575848, 0x00585949, 0x00515242,
        0x00515242, 0x00525343, 0x00525343, 0x00535444, 0x00535444, 0x00545545, 0x00545545, 0x00505343, 0x00525545, 0x00535646, 0x00515444, 0x004F5242, 0x004E5141, 0x004F5242, 0x00515444, 0x00434D3D, 0x0022301E, 0x00879988, 0x007C8E81, 0x006E8580,
        0x00749CA1, 0x00397A88, 0x001E7284, 0x001286A7, 0x002597BC, 0x002C9DC8, 0x002399CA, 0x001A99CC, 0x0024A3D6, 0x00269CD0, 0x0033A0D4, 0x00136B99, 0x00324340, 0x005D4F3D, 0x00484C41, 0x00434936, 0x00474739, 0x0040443E, 0x00484A36, 0x00414637,
        0x0044493A, 0x00474C3D, 0x00494E3F, 0x00494E3F, 0x00464B3C, 0x0044493A, 0x00424738, 0x00474A3A, 0x00474A3A, 0x00474A3A, 0x00484B3B, 0x00494C3C, 0x00484B3B, 0x00464939, 0x00444737, 0x00454838, 0x00454838, 0x00464939, 0x00494A3A, 0x00484939,
        0x00484838, 0x00474737, 0x00464636, 0x00464634, 0x004A4A38, 0x004B4B39, 0x00484939, 0x00474838, 0x0046493A, 0x00454839, 0x00434637, 0x00404635, 0x00414736, 0x003F4534, 0x00434636, 0x00484B3B, 0x00474838, 0x00444535, 0x00484939, 0x00484A37,
        0x00474638, 0x00404536, 0x003B4632, 0x00464832, 0x00423B32, 0x001D323A, 0x00074458, 0x00084B66, 0x00084B66, 0x00084B66, 0x00094C67, 0x000B4E69, 0x000C4F6A, 0x000A4D68, 0x00094C67, 0x000C4E67, 0x000C4E67, 0x000C4E67, 0x000C4E67, 0x000C4E67,
        0x000C4E67, 0x000C4E67, 0x000C4E67, 0x000A4C65, 0x000B4D66, 0x000C4E67, 0x000C4E67, 0x000C4E67, 0x000C4E67, 0x000B4D66, 0x000A4C65, 0x000B4D66, 0x000B4D66, 0x000C4E67, 0x000D4F68, 0x000D4F68, 0x000D4F68, 0x000C4E67, 0x000B4D66, 0x0007506C,
        0x000D5067, 0x00114D63, 0x00105069, 0x0008516D, 0x0007566B, 0x001E6C72, 0x003E8A7F, 0x001D1C1E, 0x00000100, 0x001A1D14, 0x002E3122, 0x00383B2B, 0x003E3F2F, 0x003D3D2F, 0x00363628, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x0053574C, 0x00495140, 0x00051006, 0x000F100E, 0x003D312F, 0x00353B30, 0x00538070, 0x0030766F, 0x00135B62, 0x00165B6F, 0x002B5054, 0x00565247, 0x005F5047, 0x005E7676,
        0x000F4D53, 0x002A5E65, 0x00ABB7BD, 0x00C0DACD, 0x00598584, 0x000E4E59, 0x001D6075, 0x00175370, 0x00135278, 0x003588BB, 0x00349BD9, 0x0041A6DA, 0x000A5A77, 0x00346D76, 0x00376975, 0x000F4A64, 0x00104D6D, 0x00235567, 0x007FA4A2, 0x003A7174,
        0x00185C63, 0x0067A3A9, 0x0055888B, 0x00015261, 0x0041C2DD, 0x0036B1CB, 0x0000505C, 0x00195E5B, 0x00628C8B, 0x007A898B, 0x00777F7E, 0x007D8781, 0x00384137, 0x00434C3F, 0x004D5445, 0x00535D4C, 0x00484E3D, 0x00535341, 0x0088826F, 0x00BFB8A4,
        0x00B6B099, 0x0089856D, 0x00646047, 0x005B5C48, 0x005A5945, 0x005A5342, 0x00595140, 0x00635A4C, 0x00615C4D, 0x00535343, 0x006B6B5D, 0x00504541, 0x00342F2E, 0x00889692, 0x005E7C71, 0x00688074, 0x00839D9D, 0x004E93A4, 0x00108DA9, 0x002583B0,
        0x002B90BD, 0x002591C0, 0x002598CA, 0x0028A1D3, 0x0027A3D9, 0x002EA9E1, 0x002FAAE4, 0x0038ACE5, 0x003FA9E6, 0x002781BA, 0x003E9FD1, 0x00279BD4, 0x0037ADE8, 0x00428CAE, 0x0090A5A6, 0x003A7B89, 0x0061A6B9, 0x0076B0BC, 0x0070958D, 0x00738C7E,
        0x0094A9A6, 0x002D3A38, 0x0059574C, 0x005C5C4C, 0x00595949, 0x00585848, 0x005B5B4B, 0x005B5B4B, 0x00565646, 0x00535343, 0x00535343, 0x00515242, 0x00555646, 0x005C5D4D, 0x00575848, 0x00525343, 0x00525343, 0x004F5040, 0x00515242, 0x00535647,
        0x00494C3D, 0x004A4D3E, 0x00505242, 0x00535545, 0x00545545, 0x00545545, 0x00545545, 0x00505141, 0x00535444, 0x00585949, 0x004D4E3E, 0x004C4D3D, 0x00505141, 0x00535546, 0x004E5044, 0x004C4F40, 0x004F5243, 0x004F5243, 0x00525444, 0x00555646,
        0x00535444, 0x00515242, 0x00535444, 0x00575848, 0x00585949, 0x00555646, 0x00525343, 0x004F5040, 0x004D4E3E, 0x00545545, 0x00555646, 0x004F5040, 0x00515242, 0x00535444, 0x00545545, 0x00535444, 0x00535444, 0x00555646, 0x00575848, 0x00555646,
        0x00525343, 0x00505141, 0x00535444, 0x00575848, 0x00585949, 0x00565747, 0x00525343, 0x00505343, 0x00515444, 0x00525545, 0x00535646, 0x00525545, 0x00515444, 0x00505343, 0x00505343, 0x00445141, 0x002F3929, 0x008A9386, 0x0091A297, 0x00607F76,
        0x006B958E, 0x008BB8B5, 0x00648D8F, 0x000F687C, 0x002691AD, 0x001E9FC6, 0x0019A6D9, 0x0020A8E2, 0x001D9BD5, 0x002FA5D8, 0x00269BC8, 0x000C6794, 0x002D403D, 0x005A4E3C, 0x00484C41, 0x00444A37, 0x00474739, 0x003D443D, 0x00444934, 0x00424C3C,
        0x00434D3D, 0x00454F3F, 0x00475141, 0x00485242, 0x00475141, 0x00444E3E, 0x00424C3C, 0x00454D3C, 0x00434B3A, 0x00424A39, 0x00444C3B, 0x00474F3E, 0x00474F3E, 0x00434B3A, 0x003E4635, 0x004C5241, 0x004B4E3E, 0x00464939, 0x00424535, 0x00424333,
        0x00434434, 0x00464636, 0x00484838, 0x00444432, 0x00474735, 0x00474936, 0x00454636, 0x00424535, 0x00434637, 0x00454839, 0x00434839, 0x00444C3B, 0x00454B3A, 0x00434938, 0x00454B3A, 0x004A4D3D, 0x00454838, 0x00404131, 0x00444535, 0x004A4C39,
        0x0049483A, 0x00424738, 0x003D4834, 0x00484A34, 0x00433C33, 0x001D323A, 0x00084559, 0x00094B64, 0x00094B64, 0x00094B64, 0x000A4C65, 0x000C4E67, 0x000C4E67, 0x000B4D66, 0x000A4C65, 0x000B4D66, 0x000B4D66, 0x000B4D66, 0x000B4D66, 0x000B4D66,
        0x000B4D66, 0x000B4D66, 0x000B4D66, 0x000B4D66, 0x000B4D66, 0x000C4E67, 0x000C4E67, 0x000C4E67, 0x000C4E67, 0x000B4D66, 0x000B4D66, 0x000C4E67, 0x000D4F68, 0x000D4F68, 0x000D4F68, 0x000D4F68, 0x000D4F68, 0x000D4F68, 0x000C4E67, 0x0007506C,
        0x000D5067, 0x00134F65, 0x00105069, 0x000A536F, 0x0009586D, 0x001F6D73, 0x00449085, 0x00232224, 0x00000100, 0x00161910, 0x002B2E1F, 0x00363929, 0x003D3E2E, 0x003C3C2E, 0x00313123, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x0053574C, 0x00464E3D, 0x00030E04, 0x0010110F, 0x003D312F, 0x002C3429, 0x00407161, 0x002A756D, 0x00196369, 0x00135365, 0x004E787D, 0x00A2ADA5, 0x00A1A19B, 0x0095B3B4,
        0x004C8C91, 0x00568C93, 0x008EA1A8, 0x00A3B1A6, 0x00779999, 0x00326976, 0x0018546A, 0x001F5774, 0x002A698F, 0x003D90C3, 0x001C86C3, 0x0048B6EA, 0x002987AB, 0x00004C63, 0x000D5468, 0x000A5673, 0x00095978, 0x00065167, 0x000A4D56, 0x00114D5D,
        0x001F6C75, 0x0077ABB2, 0x00A6B3C3, 0x00598298, 0x00188398, 0x0076DBEA, 0x00B1D6E4, 0x00498886, 0x002A5657, 0x00678D8F, 0x00668F91, 0x00677F7F, 0x00878182, 0x00413B36, 0x003D4E43, 0x004D5642, 0x005B5F4C, 0x00565541, 0x00544F3A, 0x00958D76,
        0x00C4BCA5, 0x00AEA990, 0x00A29E82, 0x0050503E, 0x0062604E, 0x00585442, 0x005D5647, 0x005D5849, 0x0059584A, 0x00636657, 0x002C3324, 0x0043312A, 0x0095A49C, 0x0053746D, 0x0059706B, 0x0088A8A7, 0x004F96A4, 0x00299AC2, 0x001D9CD9, 0x001B83B2,
        0x001E87B8, 0x001685B7, 0x002598CB, 0x0035ADE1, 0x0033ADE3, 0x0031ACE4, 0x002BA9E0, 0x0033A5E1, 0x0043AEEB, 0x002387BE, 0x003099CA, 0x001E99D3, 0x0033ACEA, 0x003889AE, 0x00476A6D, 0x006D9393, 0x008BBAC2, 0x007CABAF, 0x006D8F84, 0x00758F82,
        0x0093A9A7, 0x002E3B39, 0x00555244, 0x005D5D4D, 0x005B5B4B, 0x00585848, 0x00585848, 0x005C5C4C, 0x005F5F4F, 0x005F5F4F, 0x005D5D4D, 0x00585949, 0x00585949, 0x00575848, 0x00535444, 0x00505141, 0x00505141, 0x00515242, 0x00535444, 0x004F5243,
        0x004D5041, 0x004D5041, 0x004E5141, 0x00505242, 0x00505141, 0x00535444, 0x00565747, 0x00555646, 0x004F5345, 0x00485343, 0x00485343, 0x004D5241, 0x00535444, 0x00525444, 0x00535549, 0x00474A3B, 0x004E5142, 0x004D5041, 0x00525444, 0x00535444,
        0x00535444, 0x00535444, 0x00545545, 0x00545545, 0x00545545, 0x00545545, 0x00545545, 0x00505141, 0x00535444, 0x00585949, 0x004D4E3E, 0x004C4D3D, 0x00505141, 0x00535444, 0x00545545, 0x00525343, 0x00515242, 0x00535444, 0x00555646, 0x00555646,
        0x00535444, 0x00515242, 0x00535444, 0x00575848, 0x00585949, 0x00555646, 0x00525343, 0x004F5040, 0x00505141, 0x00525343, 0x00545545, 0x00555646, 0x00545545, 0x00515242, 0x004E4F3F, 0x00334534, 0x002B3225, 0x0097988E, 0x007D8C84, 0x005A7E72,
        0x006E9A8D, 0x0079978A, 0x0093A195, 0x0073A4A6, 0x00348894, 0x0030ABCB, 0x0018A5D8, 0x00179DDD, 0x00239BDC, 0x002599D2, 0x00269FD0, 0x00086390, 0x002A3D3A, 0x00574B39, 0x00454B40, 0x00454B38, 0x00474A3B, 0x00404740, 0x00474C37, 0x00495444,
        0x00475242, 0x00455040, 0x00465141, 0x00495444, 0x004B5646, 0x004C5747, 0x004D5848, 0x004C5747, 0x00495444, 0x00465141, 0x00495444, 0x004D5848, 0x004F5A4A, 0x004B5646, 0x00465141, 0x004F5544, 0x004A503F, 0x00434938, 0x00404333, 0x003F4232,
        0x00434434, 0x00474838, 0x00494A3A, 0x00464835, 0x00474936, 0x00474936, 0x00444737, 0x00434636, 0x0044493A, 0x00494E3F, 0x004D5243, 0x004A5142, 0x004A5142, 0x004C5142, 0x00484D3E, 0x004C5142, 0x004F5243, 0x00454839, 0x0046493A, 0x00464835,
        0x00464537, 0x00434839, 0x003E4935, 0x00494B35, 0x00423B32, 0x001A2F37, 0x00023F53, 0x00084A63, 0x00094B64, 0x00094B64, 0x000A4C65, 0x000B4D66, 0x000C4E67, 0x000B4D66, 0x000B4D66, 0x000B4D66, 0x000B4D66, 0x000B4D66, 0x000B4D66, 0x000B4D66,
        0x000B4D66, 0x000B4D66, 0x000B4D66, 0x000B4D66, 0x000C4E67, 0x000C4E67, 0x000C4E67, 0x000C4E67, 0x000C4E67, 0x000C4E67, 0x000B4D66, 0x000D4F68, 0x000D4F68, 0x000D4F68, 0x000D4F68, 0x000C4E67, 0x000C4E67, 0x000C4E67, 0x000C4E67, 0x00034C68,
        0x000A4D64, 0x00134F65, 0x00105069, 0x000B5470, 0x000A596E, 0x001F6D73, 0x0049958A, 0x00232224, 0x00000100, 0x00171A11, 0x002E3122, 0x00383B2B, 0x003D3E2E, 0x003B3B2D, 0x00303022, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x0055594E, 0x004B5140, 0x00060F05, 0x00111210, 0x003A312E, 0x00263024, 0x00356958, 0x002A776F, 0x001B696F, 0x001C5C6E, 0x004C7F89, 0x0099B7B8, 0x0095A8AB, 0x0085AFB4,
        0x004A8F98, 0x0059949E, 0x007592A0, 0x006F8482, 0x008EBAC1, 0x00377789, 0x000B546A, 0x00175D75, 0x000D5976, 0x003799C1, 0x001188B9, 0x002EABDE, 0x004ABFEC, 0x004DB7DC, 0x0057B9DB, 0x004FB1D3, 0x0045ABCE, 0x00238AAA, 0x00107693, 0x00024B69,
        0x00488D9E, 0x00A8DBE5, 0x006A92A4, 0x004E8398, 0x001F606F, 0x0082A9B2, 0x00B6B5BF, 0x00D4DADF, 0x008EC8C7, 0x003E9290, 0x00629B9D, 0x006C8288, 0x00727E80, 0x007E8784, 0x0035352F, 0x00434B3A, 0x00505441, 0x00525240, 0x005C5643, 0x0058513D,
        0x008B856E, 0x00BBB69D, 0x00817D64, 0x00545442, 0x00595745, 0x005C594A, 0x00544F40, 0x005F5E50, 0x00545748, 0x00353F2F, 0x00364033, 0x00929984, 0x00556F61, 0x005B7C78, 0x007B9EA2, 0x0055919D, 0x003399B6, 0x0037B0E8, 0x00279AEB, 0x002696CA,
        0x001888BC, 0x001C8FC2, 0x002EA2D7, 0x003AAFE6, 0x0035AFE5, 0x0029A7DE, 0x0028A7DE, 0x002BA6E0, 0x003AB1E9, 0x001A88B8, 0x002E9EC9, 0x00219FD5, 0x0024A7E6, 0x002890BB, 0x000F515C, 0x005A7C7B, 0x00739EA7, 0x00608D91, 0x006E8E83, 0x007B9486,
        0x008BA29E, 0x0032403C, 0x00595647, 0x00585848, 0x005A5A4A, 0x005A5A4A, 0x00595949, 0x00595949, 0x00595949, 0x00565646, 0x00525242, 0x00505141, 0x00525343, 0x00545545, 0x00575848, 0x00565747, 0x00535444, 0x00515242, 0x004F5040, 0x004F5243,
        0x00545748, 0x004E5142, 0x004A4E3C, 0x004F5243, 0x00515242, 0x00545545, 0x00565747, 0x00565646, 0x004E5040, 0x004D5040, 0x004F5141, 0x00505242, 0x00525444, 0x004F5444, 0x00565D4E, 0x004D5445, 0x0052594C, 0x00494F42, 0x00515546, 0x00525343,
        0x00545545, 0x00555646, 0x00535444, 0x00515242, 0x00505141, 0x00535444, 0x00565747, 0x00555646, 0x004F5345, 0x00485343, 0x00485343, 0x004D5241, 0x00545545, 0x00575848, 0x00575848, 0x00555646, 0x00535444, 0x00545545, 0x00565747, 0x00535444,
        0x00535444, 0x00535444, 0x00545545, 0x00545545, 0x00545545, 0x00545545, 0x00545545, 0x00505141, 0x00505141, 0x00525343, 0x00545545, 0x00565747, 0x00555646, 0x00525343, 0x004F5040, 0x00445443, 0x002C3024, 0x008A8B82, 0x008C9B93, 0x005C8177,
        0x00629083, 0x007C9F91, 0x00748479, 0x007F948C, 0x00114A4C, 0x00208399, 0x002DA6D2, 0x00249BD9, 0x002696DC, 0x00279ADD, 0x001D96D4, 0x000A6592, 0x002B3E3B, 0x00554B39, 0x00454B40, 0x00424B37, 0x00484B3C, 0x00414942, 0x00484F3A, 0x00495444,
        0x00475242, 0x00465141, 0x00475242, 0x004A5545, 0x004D5848, 0x004F5A4A, 0x00505B4B, 0x004A5545, 0x00465141, 0x00434E3E, 0x00455040, 0x004A5545, 0x004C5747, 0x004B5646, 0x00485343, 0x00434B3A, 0x00434938, 0x00414736, 0x00404635, 0x00434636,
        0x00444737, 0x00454636, 0x00444535, 0x00484A37, 0x00484A37, 0x00454936, 0x00444737, 0x00424837, 0x00464B3C, 0x004E5344, 0x00535A4B, 0x00474E3F, 0x004A5142, 0x004C5344, 0x00454A3B, 0x004B5041, 0x00535849, 0x004B4E3F, 0x00494C3D, 0x00474936,
        0x00474638, 0x00434839, 0x003F4A36, 0x00494B35, 0x00433C33, 0x001A2F37, 0x00034054, 0x00084B62, 0x00094C63, 0x000A4D64, 0x000B4E65, 0x000B4E65, 0x000B4E65, 0x000B4E65, 0x000B4E65, 0x000B4D66, 0x000B4D66, 0x000B4D66, 0x000B4D66, 0x000B4D66,
        0x000B4D66, 0x000B4D66, 0x000B4D66, 0x000C4E67, 0x000C4E67, 0x000C4E67, 0x000C4E67, 0x000C4E67, 0x000C4E67, 0x000C4E67, 0x000C4E67, 0x000C4E67, 0x000C4E67, 0x000C4E67, 0x000B4D66, 0x000B4D66, 0x000B4D66, 0x000A4C65, 0x000A4C65, 0x00024B67,
        0x00094C63, 0x00145066, 0x00105069, 0x000B5470, 0x0009586D, 0x001B696F, 0x0049958A, 0x00212022, 0x00000100, 0x001B1E15, 0x00353829, 0x003A3D2D, 0x003D3E2E, 0x003C3C2E, 0x00303022, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFDFDFD, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00595D52, 0x00555848, 0x000A1309, 0x00121311, 0x003D3431, 0x002D372B, 0x00396F5E, 0x00328178, 0x001B6C71, 0x00266980, 0x002C6C7E, 0x004E7F8D, 0x004D7685, 0x00477E8D,
        0x000F5C6C, 0x00286C7F, 0x005E889F, 0x0050858F, 0x006FB7C8, 0x003B95AD, 0x00036077, 0x00106476, 0x00005567, 0x002087A0, 0x002BA6C6, 0x0022A0C9, 0x0041BDE6, 0x0040B6E0, 0x0055C4EC, 0x005DC7EC, 0x0051BCE1, 0x0042B6DF, 0x0032ABD7, 0x00015D86,
        0x004D8CA1, 0x00AAEFF8, 0x0060CAD5, 0x002A8B99, 0x0088A9B2, 0x00D1CACD, 0x00AFABB0, 0x00A29B9E, 0x009DC1C1, 0x0044908F, 0x00559FA3, 0x00639198, 0x007D9095, 0x00636B6A, 0x0079817A, 0x003B4636, 0x00474E3F, 0x004F5040, 0x005C594A, 0x005A5342,
        0x00645E4B, 0x00696651, 0x00504F3A, 0x005B5B4B, 0x004A4A3A, 0x005B5849, 0x005C5B4D, 0x0058584A, 0x003F4637, 0x00323F31, 0x00809183, 0x005B8468, 0x005A726A, 0x007797A4, 0x003C8397, 0x004FB0CA, 0x003394BA, 0x001675AD, 0x004BB3F8, 0x0031ABDF,
        0x001F96CD, 0x002CA1D8, 0x0037ABE2, 0x0035AAE1, 0x0033AAE2, 0x0027A5DC, 0x002DACE3, 0x0029ACE5, 0x0033ADE3, 0x001783AC, 0x00369CBF, 0x0032A8D9, 0x0022A7EA, 0x002EA7DF, 0x002184A0, 0x003B707D, 0x00457F92, 0x0040737D, 0x006C8B82, 0x00829788,
        0x008DA19C, 0x0032403C, 0x00565747, 0x00585848, 0x00595949, 0x005A5A4A, 0x00595949, 0x00585848, 0x00585848, 0x00595949, 0x00595949, 0x00525343, 0x00545545, 0x00525343, 0x00575848, 0x00575848, 0x00525343, 0x00525343, 0x00505141, 0x004F5243,
        0x004F5243, 0x004B4E3F, 0x004E5141, 0x00535444, 0x00545545, 0x00555646, 0x00565747, 0x00545444, 0x004F5242, 0x004F5242, 0x004F5141, 0x00505141, 0x00505242, 0x004F5242, 0x004E5141, 0x004E5141, 0x004F5242, 0x00505343, 0x00525444, 0x00555646,
        0x00555646, 0x00545545, 0x00525343, 0x00515242, 0x00515242, 0x00545545, 0x00565747, 0x00565646, 0x004E5040, 0x004D5040, 0x004F5141, 0x00505242, 0x00535444, 0x00555646, 0x00555646, 0x00535444, 0x00525343, 0x00535444, 0x00545545, 0x00525343,
        0x00545545, 0x00555646, 0x00535444, 0x00515242, 0x00505141, 0x00535444, 0x00565747, 0x00555646, 0x00545545, 0x00545545, 0x00555646, 0x00575848, 0x00575848, 0x00545545, 0x00525343, 0x00434D40, 0x00252B20, 0x008A9288, 0x0072837A, 0x0062847D,
        0x00659491, 0x00306464, 0x0046797B, 0x006A8686, 0x00215157, 0x00024B5F, 0x002280A3, 0x00389FD0, 0x002994D1, 0x00289CDD, 0x001F98DD, 0x000D6A97, 0x002C413E, 0x00574D3B, 0x00434B40, 0x00414A36, 0x0044493A, 0x00404841, 0x00474E39, 0x00495343,
        0x00495343, 0x004B5545, 0x004D5747, 0x004F5949, 0x00505A4A, 0x00505A4A, 0x004F5949, 0x004B5447, 0x00495245, 0x00475043, 0x00475043, 0x00495245, 0x004B5447, 0x004D5649, 0x004D5649, 0x004C5443, 0x0048503F, 0x00454B3A, 0x00424837, 0x00424837,
        0x00434636, 0x00414434, 0x00404333, 0x00454936, 0x00444835, 0x00444835, 0x00414736, 0x00414736, 0x00434839, 0x004A5142, 0x00535A4B, 0x004B5447, 0x004C5548, 0x004F5649, 0x00434A3D, 0x004A4E42, 0x0052564A, 0x0045493D, 0x0045473B, 0x004A4C39,
        0x00484739, 0x00424738, 0x003C4733, 0x00474933, 0x00423B32, 0x001D323A, 0x00074458, 0x000A4A62, 0x000B4B63, 0x000D4D65, 0x000D4D65, 0x000D4D65, 0x000C4C64, 0x000D4D65, 0x000E4E66, 0x000B4D66, 0x000B4D66, 0x000B4D66, 0x000B4D66, 0x000B4D66,
        0x000B4D66, 0x000B4D66, 0x000B4D66, 0x000D4F68, 0x000C4E67, 0x000C4E67, 0x000C4E67, 0x000C4E67, 0x000C4E67, 0x000C4E67, 0x000D4F68, 0x000D4F68, 0x000C4E67, 0x000B4D66, 0x000A4C65, 0x000A4C65, 0x000A4C65, 0x000A4C65, 0x000A4C65, 0x00044D69,
        0x000B4E65, 0x00165268, 0x000F4F68, 0x0009526E, 0x0006556A, 0x0016646A, 0x0049958A, 0x00242325, 0x00000100, 0x001D2017, 0x00373A2B, 0x003B3E2E, 0x003D3E2E, 0x003D3D2F, 0x00313123, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFDFDFD, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x005D6156, 0x00565949, 0x000C140A, 0x00151614, 0x00433A37, 0x00364236, 0x00427968, 0x00398A81, 0x001A6E73, 0x001D6381, 0x001E6884, 0x00226782, 0x001F5A74, 0x00256881,
        0x000D637B, 0x0012617C, 0x0023597A, 0x00105A72, 0x00257D9B, 0x0046A7C8, 0x000B647F, 0x00307586, 0x004E8A96, 0x003B808F, 0x003C8FA4, 0x00309FB5, 0x0037A7C5, 0x001A88AC, 0x0002688B, 0x000C6A87, 0x001E7B9A, 0x003AA3CC, 0x0037A9DE, 0x003B9ED0,
        0x00005266, 0x002C888D, 0x0083E3F3, 0x005FA3B6, 0x0098ABAE, 0x00BFC4BB, 0x00869C97, 0x003F544C, 0x00949C9C, 0x00C4DEE4, 0x006AAAAF, 0x00478C8F, 0x00678A8D, 0x006E7F7B, 0x00617B6E, 0x00657368, 0x003F493D, 0x00484C41, 0x0058584C, 0x00514E40,
        0x005F5C4D, 0x00565644, 0x00535542, 0x00525343, 0x00595949, 0x00525242, 0x00646355, 0x002D3021, 0x003C4538, 0x007F8E80, 0x006E8172, 0x00486D5D, 0x008DB2BA, 0x005797B6, 0x002C8EB6, 0x003EA5CC, 0x001F7397, 0x00003F63, 0x00328BAD, 0x002EAFE6,
        0x0027A5DC, 0x0032A9E1, 0x0037AAE3, 0x0034A7E0, 0x0031A8E0, 0x002BA9E0, 0x002FAEE5, 0x002CACE7, 0x0038ADE0, 0x001E7C9F, 0x00267792, 0x003292C0, 0x0027A3EA, 0x002DAFF4, 0x0038AFE0, 0x004196B6, 0x003586A9, 0x00438094, 0x0073928B, 0x00879786,
        0x009AABA2, 0x00303E38, 0x004D5342, 0x005A5A4A, 0x00575747, 0x00555545, 0x00545444, 0x00535343, 0x00535343, 0x00555545, 0x00585848, 0x00585949, 0x00585949, 0x00515242, 0x00545545, 0x00535444, 0x004D4E3E, 0x00535444, 0x00525343, 0x004C4F40,
        0x004D5041, 0x00525445, 0x00535646, 0x00505141, 0x00515342, 0x00515242, 0x00515343, 0x00515343, 0x004F5242, 0x00505343, 0x00505141, 0x00515343, 0x00505242, 0x004E5141, 0x004E5141, 0x004E5141, 0x004F5242, 0x00505343, 0x00515444, 0x00575848,
        0x00565747, 0x00525343, 0x00515242, 0x00525343, 0x00545545, 0x00555646, 0x00565747, 0x00545444, 0x004F5242, 0x004F5242, 0x004F5141, 0x00505141, 0x00505141, 0x004F5141, 0x004F5141, 0x004F5141, 0x00515242, 0x00525343, 0x00535444, 0x00555646,
        0x00555646, 0x00545545, 0x00525343, 0x00515242, 0x00515242, 0x00545545, 0x00565747, 0x00575747, 0x00565646, 0x00555545, 0x00555545, 0x00555545, 0x00555545, 0x00555545, 0x00545444, 0x0046473D, 0x00293126, 0x0089978B, 0x00869990, 0x0063807D,
        0x0051828A, 0x00287585, 0x000C6D81, 0x002D7188, 0x0013536B, 0x00014159, 0x00034E68, 0x002484A2, 0x0037A7D1, 0x001B91C5, 0x00279FDB, 0x000C6996, 0x002C413E, 0x00574D3B, 0x00424A3F, 0x003E4935, 0x00434839, 0x003F4740, 0x00464D38, 0x004C5142,
        0x004E5344, 0x00505546, 0x00515647, 0x00515647, 0x00505546, 0x004F5445, 0x004E5344, 0x0051584B, 0x0051584B, 0x0051584B, 0x0050574A, 0x004E5548, 0x004E5548, 0x0051584B, 0x00535A4D, 0x00565E4D, 0x004E5645, 0x00454D3C, 0x00414736, 0x00404635,
        0x00424535, 0x00424535, 0x00424535, 0x00444835, 0x00434734, 0x00444835, 0x00434938, 0x00414736, 0x003F4637, 0x00454C3D, 0x004D5445, 0x0050594C, 0x00495245, 0x004C5548, 0x00474E41, 0x004B5245, 0x004F5347, 0x003D4135, 0x00414539, 0x00454734,
        0x00434234, 0x003D4233, 0x0038432F, 0x0043452F, 0x003F382F, 0x001A2F37, 0x00044155, 0x00094A5F, 0x000B4C61, 0x000D4E63, 0x000D4E63, 0x000C4D62, 0x000C4D62, 0x000D4E63, 0x000E4F64, 0x000C4E67, 0x000C4E67, 0x000C4E67, 0x000C4E67, 0x000C4E67,
        0x000C4E67, 0x000C4E67, 0x000C4E67, 0x000D4F68, 0x000D4F68, 0x000C4E67, 0x000B4D66, 0x000B4D66, 0x000C4E67, 0x000D4F68, 0x000D4F68, 0x000E5069, 0x000D4F68, 0x000C4E67, 0x000B4D66, 0x000A4C65, 0x000A4C65, 0x000A4C65, 0x000B4D66, 0x00054E6A,
        0x000B4E65, 0x00155167, 0x000C4C65, 0x0008516D, 0x0006556A, 0x0017656B, 0x00509C91, 0x002D2C2E, 0x00000100, 0x00191C13, 0x00343728, 0x00393C2C, 0x003C3D2D, 0x003D3D2F, 0x002F2F21, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFDFDFD, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00606459, 0x00515444, 0x000B1309, 0x00191A18, 0x00483F3C, 0x003C483C, 0x00467D6C, 0x003C8F86, 0x001A6E73, 0x00236B8D, 0x00136588, 0x00176589, 0x00226689, 0x001C6787,
        0x000B6583, 0x00136888, 0x00205E86, 0x001B6589, 0x00136890, 0x004FA6CE, 0x005398B9, 0x00A5CDE0, 0x00E0F3FF, 0x00D6EEFA, 0x00CCEEFE, 0x0070CBD2, 0x0042A1B4, 0x0052B0CD, 0x001F7691, 0x000F5B71, 0x00115D74, 0x000E668E, 0x0046ACE1, 0x0046A5DD,
        0x00005F6E, 0x001F8689, 0x0099B3D1, 0x00E6D8FA, 0x00B8C8C7, 0x009AC8B2, 0x00234F42, 0x00678278, 0x00A7B8B5, 0x00A3A9B0, 0x00D8E8F4, 0x003E757A, 0x00004942, 0x00598F82, 0x007D877B, 0x007A8981, 0x0067746C, 0x00353D33, 0x0047483E, 0x005A5A4E,
        0x00565648, 0x00525546, 0x00545747, 0x00545545, 0x005C5C4C, 0x00575648, 0x003A3A2C, 0x00383C30, 0x00818B7E, 0x006D7E70, 0x0063776A, 0x00A4ABAE, 0x004A899D, 0x002F98C3, 0x003397D1, 0x004196C8, 0x000E617D, 0x00004B58, 0x0024656D, 0x0027ACE5,
        0x002FADE7, 0x002EA6E1, 0x0032A6DF, 0x0035A8E1, 0x0032A9E1, 0x002CAAE1, 0x0024A5DC, 0x002CA8E4, 0x0047B2E5, 0x00287897, 0x0006445C, 0x001C6A98, 0x002595E1, 0x001A9DEC, 0x0027A9E5, 0x00329DC9, 0x002182AE, 0x00488EA6, 0x0074928D, 0x00828E7C,
        0x00A1AFA4, 0x00303F37, 0x004E5848, 0x00555545, 0x00525242, 0x00535343, 0x00585848, 0x005A5A4A, 0x00575747, 0x00555545, 0x00565646, 0x00555646, 0x00575848, 0x00515242, 0x00565747, 0x00545545, 0x004B4C3C, 0x004F5040, 0x00515242, 0x00545646,
        0x004F5141, 0x00525343, 0x00525343, 0x00515242, 0x00595A4A, 0x00555646, 0x004E5041, 0x004E5141, 0x004F5142, 0x004E5040, 0x004F5040, 0x004D5040, 0x004D5040, 0x004E5141, 0x004E5141, 0x004E5141, 0x004E5241, 0x004E5141, 0x00505242, 0x00545545,
        0x00525343, 0x00535444, 0x00525343, 0x00515242, 0x00515242, 0x00525343, 0x00525343, 0x00515343, 0x004F5242, 0x00505343, 0x00505141, 0x00515343, 0x00515343, 0x004F5141, 0x004F5141, 0x004D5141, 0x00515343, 0x00545646, 0x00575848, 0x00585949,
        0x00565747, 0x00525343, 0x00515242, 0x00525343, 0x00545545, 0x00555646, 0x00565747, 0x00565646, 0x00555545, 0x00535343, 0x00525242, 0x00515141, 0x00525242, 0x00525242, 0x00535343, 0x004B493F, 0x002C3629, 0x00859889, 0x00778C83, 0x00637C7E,
        0x005F92A2, 0x002E8DA7, 0x001598B9, 0x002E96C1, 0x003689AF, 0x00175672, 0x0005495C, 0x00004B5C, 0x0011859E, 0x0030AAD2, 0x001C92C5, 0x00096693, 0x00293E3B, 0x00534C39, 0x00424A3F, 0x003F4A36, 0x0044493A, 0x003D4840, 0x00464D38, 0x004B4E3F,
        0x004C4F40, 0x004B4E3F, 0x00494C3D, 0x00474A3B, 0x0046493A, 0x00484B3C, 0x00494C3D, 0x0045493D, 0x00484C40, 0x004A4E42, 0x00484C40, 0x0043473B, 0x00414539, 0x0043473B, 0x00464A3E, 0x00475140, 0x00444C3B, 0x003F4736, 0x003E4635, 0x00414736,
        0x00424837, 0x00434636, 0x00414434, 0x00444835, 0x00444835, 0x00454B38, 0x00464C3B, 0x00414938, 0x003E4536, 0x0042493A, 0x00475141, 0x00464F42, 0x003A4336, 0x00414A3D, 0x00454C3F, 0x004C5346, 0x004A5144, 0x003B3F33, 0x0045493D, 0x00454734,
        0x00464537, 0x00434839, 0x003F4A36, 0x004B4D37, 0x00453E35, 0x001D323A, 0x00064357, 0x00094A5F, 0x000B4C61, 0x000D4E63, 0x000D4E63, 0x000C4D62, 0x000C4D62, 0x000D4E63, 0x000E4F64, 0x000C4E67, 0x000C4E67, 0x000C4E67, 0x000C4E67, 0x000C4E67,
        0x000C4E67, 0x000C4E67, 0x000C4E67, 0x000E5069, 0x000D4F68, 0x000C4E67, 0x000B4D66, 0x000B4D66, 0x000C4E67, 0x000D4F68, 0x000E5069, 0x0010526B, 0x000F516A, 0x000D4F68, 0x000C4E67, 0x000B4D66, 0x000B4D66, 0x000B4D66, 0x000C4E67, 0x00034C68,
        0x00084B62, 0x00134F65, 0x000A4A63, 0x0007506C, 0x0009586D, 0x001B696F, 0x0059A59A, 0x00353436, 0x00010200, 0x0015180F, 0x002F3223, 0x00363929, 0x003C3D2D, 0x003D3D2F, 0x002E2E20, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFDFFFC, 0xFFFBFEFC, 0xFFFDFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x005D6358, 0x00566759, 0x00191F14, 0x001A140D, 0x003D3633, 0x00424A49, 0x00567E7C, 0x003F8B87, 0x0013766E, 0x00276E89, 0x00236A85, 0x00266D88, 0x00276E89, 0x00216883,
        0x00216883, 0x00236A85, 0x001F6681, 0x00116386, 0x0018758C, 0x007DC5CF, 0x00E0FBFF, 0x00F8FFFF, 0x00F3FFFE, 0x00F3FDFD, 0x00FFFAFF, 0x00F6FFF8, 0x00C2F0EA, 0x0056AEB5, 0x004ABAD1, 0x00087A9E, 0x00006187, 0x00005E81, 0x0046B0CF, 0x004AC3D7,
        0x00005567, 0x006D98A1, 0x00AFBEC0, 0x0096A69F, 0x00A7C1BB, 0x00325551, 0x00547C7B, 0x00BAB3C0, 0x00BFBBC1, 0x008C989E, 0x0082B1BF, 0x0058A8C1, 0x0000405F, 0x001C556E, 0x00819EAD, 0x0075807D, 0x00707B78, 0x00747D7A, 0x0039403B, 0x0040483D,
        0x004C5443, 0x004E5841, 0x004E593F, 0x00675C3C, 0x005A5643, 0x00333A33, 0x002F3933, 0x008F988E, 0x006D7B6F, 0x005B726A, 0x0088A8A7, 0x002E839D, 0x002B7B8C, 0x0032828D, 0x0077CDD9, 0x004AA7BE, 0x001E7A97, 0x00004A64, 0x0019647A, 0x0032ABDC,
        0x0032AADE, 0x0031AAE2, 0x0031A9E5, 0x002FA7E3, 0x002EA6E1, 0x002CA7DF, 0x002DA9DF, 0x0021A1E2, 0x0037ADE8, 0x001879A5, 0x0000445C, 0x0012505A, 0x00246C7E, 0x003899C5, 0x002DA5E7, 0x002B9EC9, 0x001E8CA6, 0x00409196, 0x006F9387, 0x0087937F,
        0x00A4B4A2, 0x00303E38, 0x00525258, 0x00565646, 0x00585848, 0x00585848, 0x00565646, 0x00575747, 0x005A5A4A, 0x005A5A4A, 0x00585848, 0x00535444, 0x00575848, 0x00585949, 0x004B4C3C, 0x004E4F3F, 0x00535444, 0x00535444, 0x00515242, 0x00565747,
        0x00515242, 0x00565747, 0x00545545, 0x004B4C3C, 0x004F5040, 0x00515242, 0x00545646, 0x004F5141, 0x00525443, 0x005A5B4B, 0x00525343, 0x004E5141, 0x004D5040, 0x004E5141, 0x004F5242, 0x004F5444, 0x004D5242, 0x004B5040, 0x004D503F, 0x00535444,
        0x00525343, 0x00515242, 0x00535444, 0x00555646, 0x00555646, 0x00535444, 0x00505141, 0x004F5141, 0x004E5141, 0x004E5040, 0x004F5040, 0x004E5040, 0x004D5040, 0x004D5040, 0x004D5040, 0x004C5241, 0x004C5140, 0x004B4F3E, 0x004F5040, 0x00515242,
        0x00525343, 0x00535444, 0x00525343, 0x00515242, 0x00515242, 0x00525343, 0x00535444, 0x00565646, 0x00555545, 0x00555545, 0x00565646, 0x00575747, 0x00575747, 0x00555545, 0x00535343, 0x004C4746, 0x002A3A2F, 0x007F9583, 0x00838D7D, 0x006D7C74,
        0x00619699, 0x002A8495, 0x001C84A1, 0x001F8CB2, 0x002A92BD, 0x003089B5, 0x00095474, 0x00004354, 0x00045262, 0x00177E97, 0x002BA6CA, 0x00116D90, 0x00213945, 0x003F4239, 0x003A4B40, 0x0041463D, 0x00494533, 0x00484E37, 0x004C4C3E, 0x00444B3C,
        0x00474E3F, 0x0042493A, 0x00444B3C, 0x00434A3B, 0x00414839, 0x00454C3D, 0x0042493A, 0x00484B3C, 0x0046493A, 0x00454839, 0x00484B3C, 0x00474A3B, 0x00444738, 0x00434637, 0x00444738, 0x00454839, 0x00424536, 0x00434637, 0x00434637, 0x00404334,
        0x00424536, 0x00434637, 0x003D4031, 0x00434637, 0x00404334, 0x00404334, 0x00414637, 0x00434839, 0x00414839, 0x00414839, 0x00444B3C, 0x00414637, 0x003F4435, 0x00404536, 0x00414637, 0x00414637, 0x00424738, 0x00424738, 0x003F4435, 0x004B4435,
        0x0043473B, 0x003B4538, 0x003F4534, 0x00454430, 0x002D352A, 0x000F3339, 0x0006455A, 0x0008475B, 0x0009485D, 0x000B4A5F, 0x000D4C61, 0x000F4D65, 0x000F4D65, 0x000F4C66, 0x000F4C66, 0x00044D61, 0x00084F63, 0x000F536A, 0x00034960, 0x00054D65,
        0x00004A64, 0x00074E69, 0x000B506B, 0x00084D68, 0x00024663, 0x000F4F6D, 0x000B4868, 0x000D4868, 0x0011516F, 0x00024865, 0x0004516B, 0x00044E68, 0x00044B66, 0x000B4E67, 0x00084A63, 0x00084860, 0x000B4E65, 0x00074B62, 0x00084D61, 0x00125166,
        0x00164866, 0x001D476A, 0x001A4C70, 0x000A4F6A, 0x000D5F6B, 0x001C6C6B, 0x0058A39B, 0x00354342, 0x00000300, 0x000F1C0E, 0x002F3B27, 0x002C361F, 0x003A3F2A, 0x003C3C2C, 0x00333126, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFCFFFB, 0xFFF9FBFB, 0xFFFCFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00686E63, 0x005B6C5E, 0x00091106, 0x001C1911, 0x00453E3B, 0x003A4241, 0x004F7674, 0x003D857F, 0x0019766F, 0x001A6A89, 0x00186887, 0x001C6C8B, 0x001E6E8D, 0x001A6A89,
        0x001B6B8A, 0x001C6C8B, 0x00186887, 0x0029698B, 0x0044829A, 0x00BAE7F4, 0x00ECFFFF, 0x00E2E4E4, 0x00F3F4F2, 0x00FDF8FA, 0x00FFFBFF, 0x00FFFFFB, 0x00E3F5F6, 0x00AFE5F0, 0x004591A7, 0x0057AAC9, 0x001C6C91, 0x0008597E, 0x004CA0C3, 0x003BB9DC,
        0x000D6A89, 0x00285D72, 0x009CB5BF, 0x00B9C8CA, 0x00637673, 0x00768887, 0x00B7C9CA, 0x0081ACA9, 0x00708E89, 0x00132A26, 0x003B6068, 0x006BADC0, 0x0002536E, 0x0008566D, 0x004B90A1, 0x00698984, 0x00637F79, 0x00647873, 0x00727E78, 0x003C4138,
        0x004B4B3D, 0x00585644, 0x00575340, 0x005E5A42, 0x00404334, 0x002E3734, 0x00869391, 0x0062716D, 0x00637E7B, 0x0074A0A7, 0x00488093, 0x001F819F, 0x00206F82, 0x00528893, 0x007DA4B2, 0x00729CB3, 0x00396F8E, 0x00003A58, 0x00286B84, 0x0032ABDC,
        0x0032AADE, 0x0033AAE2, 0x0031A9E5, 0x0031A9E5, 0x002FAAE4, 0x002DA8E0, 0x0029A5DB, 0x0029AAE9, 0x0032ADE7, 0x00359ECF, 0x00095E7E, 0x0000485A, 0x00085467, 0x00156F91, 0x002790C1, 0x003DAADD, 0x0038A4C6, 0x0051A2B1, 0x00739B9A, 0x00829388,
        0x009BADA0, 0x002F3E36, 0x00585656, 0x005A5A4A, 0x005A5A4A, 0x00585848, 0x00545444, 0x00535343, 0x00575747, 0x00595949, 0x00585848, 0x00535444, 0x00545545, 0x00565747, 0x00535444, 0x00535444, 0x00515242, 0x00535343, 0x00535444, 0x00575848,
        0x00585949, 0x004B4C3C, 0x004E4F3F, 0x00535444, 0x00535444, 0x00515242, 0x00565747, 0x00515242, 0x00565747, 0x00545545, 0x004B4C3C, 0x004F5040, 0x004E5141, 0x00505343, 0x00505343, 0x004F5544, 0x004D5342, 0x004A503F, 0x004A4F3E, 0x00525444,
        0x00525343, 0x00525343, 0x00545545, 0x00575848, 0x00575848, 0x00535444, 0x00505141, 0x004F5242, 0x00505242, 0x004D4E3E, 0x00515343, 0x004D5040, 0x004D5040, 0x004E5141, 0x004E5141, 0x004F5544, 0x004C5241, 0x004A4F3F, 0x004C4F3E, 0x00525444,
        0x00525343, 0x00515242, 0x00525343, 0x00545545, 0x00545545, 0x00525343, 0x00505141, 0x00575747, 0x00565646, 0x00565646, 0x00565646, 0x00575747, 0x00575747, 0x00565646, 0x00565646, 0x004D4441, 0x0029372C, 0x007A9182, 0x007C8D80, 0x00647C7A,
        0x005996A2, 0x0023809A, 0x00117BA0, 0x00118AB6, 0x001D93C2, 0x002791C0, 0x00338CB1, 0x000D5970, 0x00004A5A, 0x00004D63, 0x0022839F, 0x001C7590, 0x0034464D, 0x004B493E, 0x0037483B, 0x0041443B, 0x004C4836, 0x00494E39, 0x00494B3F, 0x004D5445,
        0x004E5546, 0x00484F40, 0x004A5142, 0x00495041, 0x00464D3E, 0x004A5142, 0x00484F40, 0x004C5142, 0x004C5142, 0x004D5243, 0x004F5445, 0x004E5344, 0x004A4F40, 0x00484D3E, 0x004A4F40, 0x00525748, 0x004D5243, 0x004F5445, 0x00505546, 0x004D5243,
        0x004C5142, 0x004B5041, 0x00474C3D, 0x004B4E3F, 0x00474A3B, 0x00454839, 0x00464B3C, 0x00474C3D, 0x00444B3C, 0x00444B3C, 0x00454C3D, 0x00474C3D, 0x00484D3E, 0x00474C3D, 0x00474C3D, 0x00484D3E, 0x00454A3B, 0x00414637, 0x003F4435, 0x004C4536,
        0x0044483C, 0x003B4538, 0x00404635, 0x00464531, 0x002F372C, 0x0011353B, 0x0007465B, 0x0008475B, 0x000A495E, 0x000C4B60, 0x000D4C61, 0x000F4D65, 0x000F4D65, 0x000F4C66, 0x000F4C66, 0x00114D65, 0x00145068, 0x00175069, 0x00114B61, 0x0018546A,
        0x00145066, 0x0019566A, 0x000D485C, 0x00144E64, 0x00174F68, 0x00154A65, 0x001C4E6C, 0x00184A68, 0x00134A65, 0x001A566E, 0x00104F64, 0x00064C6A, 0x00074B68, 0x000C4E6B, 0x0011516F, 0x000E4F6B, 0x000A4B67, 0x000E5069, 0x0010526B, 0x000A586F,
        0x000B4D6A, 0x000F496C, 0x000C4C6F, 0x00004D68, 0x00015967, 0x00126769, 0x004E9B97, 0x00432E31, 0x00120000, 0x00271B11, 0x00403729, 0x00393523, 0x00404030, 0x0036392A, 0x002C2D23, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFDFFFE, 0xFFFBFDFD, 0xFFFBFDFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00686E63, 0x006A7B6E, 0x00060E04, 0x001C1914, 0x0045423E, 0x003B4342, 0x00597A76, 0x0045827E, 0x0024726B, 0x00247491, 0x0020708D, 0x001E6E8B, 0x001C6C89, 0x00186885,
        0x00196986, 0x001B6B88, 0x00196986, 0x00265D78, 0x007CA3B9, 0x00E4FEFF, 0x00BFD6D8, 0x00A8B5B3, 0x00FDF9F8, 0x00FFFEFF, 0x00F9FDFE, 0x00E6F4F3, 0x00DCFEFE, 0x00C6FFFF, 0x0043929B, 0x0053A8B8, 0x002F879F, 0x00005674, 0x0051AECD, 0x0050C7F4,
        0x0000587F, 0x000C4A68, 0x00567A8A, 0x0092A8AE, 0x00A8B5B7, 0x008F9797, 0x00C4C8C9, 0x0076A5A3, 0x000E3A34, 0x003F7068, 0x005B9999, 0x001A6A75, 0x00004056, 0x001C6682, 0x003F7B99, 0x00114A42, 0x005A8A84, 0x006E928C, 0x005E726D, 0x007A817A,
        0x0037312A, 0x005F544C, 0x0051443C, 0x003D4135, 0x00252D26, 0x0094A29E, 0x0063726E, 0x005F7672, 0x00709A9F, 0x004588A1, 0x003288B2, 0x00329EC0, 0x0023768B, 0x004F838A, 0x0027474C, 0x00294857, 0x00244D66, 0x00053B5A, 0x00296583, 0x0035ACDD,
        0x0036ACE0, 0x0033AAE2, 0x002EA6E2, 0x0030A8E4, 0x0031ACE6, 0x002CAAE1, 0x0027A5DB, 0x0027A7E2, 0x0028A6E1, 0x0038ACE5, 0x00349DC9, 0x00035D7C, 0x00004358, 0x00277D91, 0x002A8398, 0x002C8AB8, 0x003797BB, 0x004793A9, 0x00658E97, 0x00778D8B,
        0x008EA69C, 0x002E3E33, 0x0057544F, 0x00595949, 0x005A5A4A, 0x00585848, 0x00545444, 0x00535343, 0x00565646, 0x00575747, 0x00555545, 0x00565747, 0x00515242, 0x004C4D3D, 0x00525343, 0x00505141, 0x00535343, 0x00565747, 0x00535444, 0x00545545,
        0x00565747, 0x00535444, 0x00535444, 0x00515242, 0x00535343, 0x00535444, 0x00575848, 0x00585949, 0x004B4C3C, 0x004E4F3F, 0x00535444, 0x00535444, 0x004F5141, 0x004F5242, 0x004F5242, 0x004D5342, 0x004D5342, 0x004C5241, 0x00525746, 0x00515443,
        0x00535444, 0x00525343, 0x00555646, 0x00545545, 0x00535444, 0x00505141, 0x004E4F3F, 0x00525444, 0x00535545, 0x00515343, 0x00515343, 0x00505343, 0x00505343, 0x00505343, 0x00505343, 0x004F5544, 0x004D5342, 0x004A503F, 0x004A4F3E, 0x00525444,
        0x00525343, 0x00505141, 0x00525343, 0x00565747, 0x00575848, 0x00535444, 0x004F5040, 0x00565747, 0x00565747, 0x00565747, 0x00555646, 0x00555646, 0x00555646, 0x00565747, 0x00575848, 0x004F4341, 0x00263429, 0x00769082, 0x00789086, 0x005F8383,
        0x005CA0AD, 0x00338DAB, 0x002F8BB4, 0x001191BC, 0x000888B9, 0x00239CCE, 0x002794C0, 0x00328CAE, 0x00065269, 0x00004057, 0x0004475E, 0x0007586D, 0x00323E3E, 0x00524C39, 0x003C4836, 0x0044463A, 0x004E4A38, 0x00454B38, 0x0043463D, 0x004F5647,
        0x00505748, 0x004A5142, 0x004B5243, 0x004A5142, 0x00474E3F, 0x004B5243, 0x00495041, 0x00485242, 0x00485242, 0x004B5545, 0x004E5848, 0x004C5646, 0x00475141, 0x00454F3F, 0x00485242, 0x00465040, 0x003F4939, 0x00424C3C, 0x00495343, 0x00475141,
        0x00454F3F, 0x00454F3F, 0x00444E3E, 0x00484B3C, 0x00434637, 0x00434637, 0x00464B3C, 0x004C5142, 0x004C5344, 0x004C5344, 0x004D5445, 0x00494E3F, 0x004E5344, 0x004C5142, 0x004C5142, 0x00505546, 0x004A4F40, 0x00404536, 0x00404536, 0x004D4637,
        0x0044483C, 0x003B4538, 0x00404635, 0x00484733, 0x0031392E, 0x0011353B, 0x0006455A, 0x0009485C, 0x000A495E, 0x000C4B60, 0x000E4D62, 0x000F4D65, 0x000F4D65, 0x000F4C66, 0x000E4B65, 0x00044C64, 0x00004961, 0x00004B5E, 0x00226E80, 0x00378290,
        0x00055059, 0x000D5B62, 0x0028797E, 0x000B535F, 0x00135867, 0x000B4D60, 0x0004495D, 0x00054E62, 0x00024C5E, 0x00014C5A, 0x00044C58, 0x0001506B, 0x00004C67, 0x00004B65, 0x0007546E, 0x0007536A, 0x00004C63, 0x000B576E, 0x00014C62, 0x00004B61,
        0x00004C66, 0x000E5472, 0x000E5471, 0x00044F65, 0x00065560, 0x001E696B, 0x00589E98, 0x001C201B, 0x00000200, 0x001B1F14, 0x00313425, 0x00353527, 0x00434136, 0x003B362D, 0x00302A25, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFF4F9F7, 0xFFF1F6F5, 0xFFEAEEEF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00676F65, 0x0057675C, 0x00141C15, 0x0022241E, 0x003D3E3C, 0x00323A39, 0x004A6562, 0x0041706D, 0x002D6B65, 0x00326D81, 0x002F6A7E, 0x002D687C, 0x002C677B, 0x002D687C,
        0x002F6A7E, 0x00326D81, 0x00326D81, 0x00326B7A, 0x0099B8C7, 0x00DEF5FD, 0x008FB6B4, 0x008FB1AB, 0x00F0F9F6, 0x00E7F2F0, 0x00C1E1DC, 0x009BC9CA, 0x009DD3D3, 0x0093D5D0, 0x0057A39F, 0x00368588, 0x004797A2, 0x0015667B, 0x005DB1CB, 0x0067C1E3,
        0x00216F8C, 0x00286579, 0x004A7782, 0x00628287, 0x00A2BABA, 0x00859796, 0x005C6C6B, 0x002B566B, 0x00033444, 0x006DAAB4, 0x003D868E, 0x004396A5, 0x00166881, 0x00175E80, 0x004885AD, 0x0065ADAD, 0x0069A7A7, 0x005D8C8A, 0x0061807F, 0x006A7C7B,
        0x0061686B, 0x0014181D, 0x0033363B, 0x00071612, 0x0064736F, 0x006C7C75, 0x0065766B, 0x008BA69C, 0x00669AA1, 0x004B9FC2, 0x001A85BE, 0x002D96C1, 0x0067C4DB, 0x0089D5D4, 0x001C5F56, 0x00003D3E, 0x00044C5D, 0x00004663, 0x001D6283, 0x0035ABDC,
        0x0038ACE1, 0x0035A9E2, 0x002EA3E0, 0x0029A3DF, 0x002CA9E3, 0x002DACE3, 0x002AAADF, 0x002CAAE4, 0x0023A5E1, 0x00219FDF, 0x0039B1EC, 0x002893BF, 0x0026839D, 0x0082D1DE, 0x0089D3D7, 0x00599BB4, 0x0067B0C4, 0x00619EAA, 0x0073959B, 0x00809593,
        0x0092A9A1, 0x002F3F34, 0x00514F44, 0x00555545, 0x00585848, 0x00595949, 0x00575747, 0x00575747, 0x00575747, 0x00555545, 0x00717164, 0x00DCDCD9, 0x00F6F6F5, 0x00F5F5F4, 0x00F5F5F4, 0x00F5F5F4, 0x00F5F5F4, 0x00F5F5F4, 0x00F5F5F4, 0x00F5F5F4,
        0x00F4F5F4, 0x00F5F5F4, 0x00F5F5F4, 0x00F5F5F4, 0x00F5F5F4, 0x00F5F5F4, 0x00F5F5F4, 0x00F5F5F4, 0x00F5F5F4, 0x00F5F5F4, 0x00F5F5F4, 0x00F5F5F4, 0x00F5F5F4, 0x00F5F5F4, 0x00F5F5F4, 0x00F4F5F4, 0x00F5F5F4, 0x00F5F5F4, 0x00F5F5F4, 0x00F5F5F4,
        0x00F5F5F4, 0x00F5F5F4, 0x00F5F5F4, 0x00F5F5F4, 0x00F5F5F4, 0x00F5F5F4, 0x00F5F5F4, 0x00F5F5F4, 0x00F5F5F4, 0x00F5F5F4, 0x00F5F5F4, 0x00F5F5F4, 0x00F5F5F4, 0x00F5F5F4, 0x00F5F5F4, 0x00F5F5F4, 0x00F5F5F4, 0x00F4F5F4, 0x00F5F5F4, 0x00F5F5F4,
        0x00F5F5F4, 0x00F5F5F4, 0x00F5F5F4, 0x00F5F5F4, 0x00F5F5F4, 0x00F5F5F4, 0x00F5F5F4, 0x00F6F6F5, 0x00DFE0DD, 0x00747568, 0x00555646, 0x00555646, 0x00555646, 0x00555646, 0x00565747, 0x00534745, 0x00263127, 0x00768D7F, 0x00768C80, 0x00547971,
        0x00549193, 0x00418A98, 0x005296AD, 0x00208CAE, 0x002294BC, 0x001890BE, 0x001C92C3, 0x00228DB9, 0x002C85AA, 0x00135C7A, 0x0003425E, 0x00004350, 0x002C332E, 0x00554A34, 0x003F4A36, 0x0048483C, 0x004C4836, 0x00404935, 0x0043483F, 0x004C5344,
        0x004E5546, 0x00495041, 0x004B5243, 0x004B5243, 0x00484F40, 0x004C5344, 0x00495041, 0x00454F3F, 0x00465040, 0x00495343, 0x004B5545, 0x00485242, 0x00434D3D, 0x00444E3E, 0x00475141, 0x00505A4A, 0x00475141, 0x00495343, 0x004F5949, 0x004A5444,
        0x00434D3D, 0x00414B3B, 0x00404A3A, 0x004B4E3F, 0x00454839, 0x00434637, 0x00464B3C, 0x004B5041, 0x004A5142, 0x00495041, 0x00495041, 0x00404536, 0x00494E3F, 0x00474C3D, 0x00464B3C, 0x004E5344, 0x00474C3D, 0x003B4031, 0x003D4233, 0x004C4536,
        0x0042463A, 0x00394336, 0x003F4534, 0x00484733, 0x0031392E, 0x0011353B, 0x00044358, 0x0009485C, 0x000A495E, 0x000C4B60, 0x000E4D62, 0x000F4D65, 0x000F4D65, 0x000E4B65, 0x000E4B65, 0x000F546F, 0x00004A61, 0x00004F61, 0x0054A3B0, 0x007DC5CD,
        0x00175C5F, 0x00277270, 0x007FD1CC, 0x00296F6F, 0x000C4E53, 0x001B5B66, 0x00084D5C, 0x00004E5B, 0x0021727A, 0x002A7377, 0x003B7B7C, 0x00417B8E, 0x003A7686, 0x00104E5E, 0x00195767, 0x003E7D8B, 0x002D6877, 0x002F6975, 0x00386F7C, 0x0017616D,
        0x000B4E5D, 0x00044050, 0x00073E4D, 0x001C4F59, 0x00356567, 0x00426E67, 0x00588277, 0x00363930, 0x0021241B, 0x00272A21, 0x0024271E, 0x0023261D, 0x0031332D, 0x002A2B27, 0x00252624, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0x00C7CCCB, 0x00CFD3D4, 0x00D3D6DA, 0x00C6CACB, 0x00CFD4D3, 0x00BCC3BC, 0x00BAC2B8, 0x00AFBCB4, 0x00A9B3AD, 0x00AFB5B0, 0x00B6B9B7, 0x00A4ADAA, 0x00AABFBC, 0x00AECFCB, 0x00ADD6D1, 0x00ACC6CC, 0x00ABC5CB, 0x00A9C3C9, 0x00A9C3C9, 0x00ABC5CB,
        0x00AAC4CA, 0x00A7C1C7, 0x00A6C0C6, 0x0099C0C8, 0x00C2D4DB, 0x00DCEBEE, 0x00C1E4E0, 0x00CCEEE8, 0x00E6F4F0, 0x00C7D5D1, 0x00A5CAC2, 0x00B2D0D5, 0x00A9C7C8, 0x00B3CECB, 0x00ACC7C3, 0x00A2BCBC, 0x00B1CBD2, 0x00A4BACC, 0x00ADBED8, 0x0092C5CF,
        0x0061959C, 0x003D7072, 0x003B6A68, 0x0039615F, 0x0029504E, 0x006C9492, 0x0053807D, 0x0025759A, 0x004896BA, 0x000A5172, 0x00034562, 0x000C516C, 0x003E8EAB, 0x00187A9C, 0x0031A2CA, 0x007CC7D5, 0x00357A84, 0x00518A93, 0x005C8A92, 0x00385E6A,
        0x001B4251, 0x002A5467, 0x00002138, 0x0000181B, 0x00001C1D, 0x00445E58, 0x00869D8E, 0x0084A192, 0x0077AEB1, 0x003089AB, 0x002598D1, 0x003AA3D6, 0x001F7B98, 0x0056A3A5, 0x0099E2D8, 0x006FC0BD, 0x0037909E, 0x0016738C, 0x00036381, 0x002FA2D4,
        0x0035A7DC, 0x0035A9E2, 0x0030A5E2, 0x0029A3DF, 0x0029A6E0, 0x0029AAE1, 0x0029ABE0, 0x0028A6E0, 0x0028A7E4, 0x0023A5E6, 0x001D9FE0, 0x002DA6DE, 0x002E98BD, 0x00338898, 0x002B7275, 0x00668F91, 0x0076AAAA, 0x00679693, 0x00728A88, 0x007E8D89,
        0x008FA49B, 0x00304134, 0x00535347, 0x00535343, 0x00575747, 0x00585848, 0x00575747, 0x00565646, 0x00575747, 0x00555545, 0x00DBDBD8, 0x00D7D7D3, 0x008B8C81, 0x0085867A, 0x0088897E, 0x00828377, 0x0085857A, 0x00838377, 0x0088887D, 0x0087887C,
        0x00838479, 0x008B8B80, 0x0086867B, 0x0086867A, 0x0086867A, 0x0087887C, 0x00838479, 0x00808175, 0x0084857A, 0x00838378, 0x0085857A, 0x0087887C, 0x0085867A, 0x0085867A, 0x0088887D, 0x00818378, 0x0083857A, 0x0083867A, 0x0085877B, 0x00828378,
        0x0086867B, 0x0086877C, 0x0086867B, 0x00838479, 0x00838378, 0x00828377, 0x00848479, 0x007D7D72, 0x00818176, 0x00838479, 0x00828479, 0x00818378, 0x00818378, 0x00818377, 0x00818377, 0x007F8377, 0x00818579, 0x0081867A, 0x0083877A, 0x0083857A,
        0x0086867B, 0x0086867B, 0x0084857A, 0x00838378, 0x00838479, 0x0086867B, 0x0088887D, 0x0086877C, 0x00D6D6D2, 0x00DBDCD8, 0x00555646, 0x00555646, 0x00545545, 0x00525343, 0x00515242, 0x00504946, 0x00283127, 0x007F9082, 0x00839382, 0x005D7868,
        0x005B8E80, 0x005A9188, 0x007FA7A6, 0x00156479, 0x002E87A2, 0x002890B5, 0x00198EBB, 0x001389BC, 0x002796C8, 0x002A89B4, 0x00267A9E, 0x000C5A67, 0x00363D38, 0x00554A34, 0x003D4834, 0x0047473B, 0x00494533, 0x003F4834, 0x00464B42, 0x00484F40,
        0x004C5344, 0x00495041, 0x004D5445, 0x004E5546, 0x004B5243, 0x004E5546, 0x004B5243, 0x00485242, 0x00485242, 0x00495343, 0x004A5444, 0x00475141, 0x00444E3E, 0x00465040, 0x004B5545, 0x00515B4B, 0x00485242, 0x00495343, 0x004F5949, 0x004B5545,
        0x00434D3D, 0x00414B3B, 0x00404A3A, 0x004A4D3E, 0x00444738, 0x00424536, 0x00454A3B, 0x004A4F40, 0x00495041, 0x00484F40, 0x00484F40, 0x00424738, 0x004B5041, 0x00484D3E, 0x00484D3E, 0x00505546, 0x00494E3F, 0x003D4233, 0x00404536, 0x00494233,
        0x00404438, 0x00374134, 0x003E4433, 0x00474632, 0x0030382D, 0x000F3339, 0x00034257, 0x000A495D, 0x000B4A5F, 0x000C4B60, 0x000E4D62, 0x000E4C64, 0x000E4C64, 0x000E4B65, 0x000D4A64, 0x001B3E60, 0x001F4E6A, 0x0010465D, 0x004C7F8F, 0x0096BCC8,
        0x006E8E93, 0x007FA9A8, 0x0092C8C1, 0x0096BBB9, 0x00537176, 0x007693A1, 0x006991A3, 0x00457989, 0x007EB5BE, 0x00ACD2D6, 0x00AFC7C7, 0x0089A0A8, 0x007C969C, 0x003C5A5F, 0x005A7D81, 0x00C6E7EA, 0x00BDDADE, 0x00AAC1C3, 0x00AEC1C4, 0x0095C1C2,
        0x0086AFB1, 0x006B8F8F, 0x00496461, 0x0044534F, 0x004D554A, 0x00545747, 0x005A5C48, 0x00635D52, 0x005A594F, 0x005B695E, 0x00557269, 0x005A867F, 0x0069A69C, 0x0063ACA2, 0x005DAFA3, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0x008A8F8E, 0x00AFB3B4, 0x00E4E7EB, 0x00E6E9ED, 0x00E9EEED, 0x00EEF4EF, 0x00FBFFF9, 0x00F2FEF8, 0x00F8FFFC, 0x00F0F7F4, 0x00F2F9F6, 0x00F2FBF8, 0x00F3FFFF, 0x00EDFFFF, 0x00E3FAF6, 0x00FBFFFC, 0x00F9FFFA, 0x00EFF5F0, 0x00E9EFEA, 0x00E9EFEA,
        0x00E7EDE8, 0x00E4EAE5, 0x00E4EAE5, 0x00EDF6F9, 0x00ECEEEF, 0x00EFF1F2, 0x00EEFBF9, 0x00ECFAF6, 0x00E5EAE8, 0x00C1C8C5, 0x0091A19A, 0x009AAEB3, 0x00A1ADAF, 0x00A2A5A3, 0x00ABAAA6, 0x00ADAEAA, 0x00B3B2B4, 0x00B8AFB9, 0x00A1909E, 0x006A837F,
        0x0032534F, 0x0029514C, 0x00345D58, 0x00608785, 0x00658D8B, 0x00215450, 0x0018534F, 0x00186C90, 0x006AC7EE, 0x0051B8DF, 0x003297BD, 0x002382A3, 0x000D7090, 0x001B8FB2, 0x001B9FC7, 0x002F82A1, 0x00004A65, 0x003B8199, 0x003C7F94, 0x00054760,
        0x00165F7D, 0x003B8EB4, 0x0019729E, 0x00256479, 0x00023A4B, 0x001B4A4E, 0x0071968E, 0x006F9589, 0x00195254, 0x003E95B5, 0x002594CC, 0x0036A6DB, 0x000A6084, 0x001F5762, 0x0076A2A3, 0x0044787F, 0x002A7387, 0x003394AE, 0x001F8FAD, 0x002697C9,
        0x002B9DD2, 0x0032A5DE, 0x0033A8E5, 0x002EA8E4, 0x0028A6E0, 0x0025A6DD, 0x0024A8DD, 0x0027A3DF, 0x002AA6E2, 0x0027A6E3, 0x001FA2E1, 0x0029AAE9, 0x0038ABDE, 0x003695B6, 0x00004B5E, 0x00436D6C, 0x005B918C, 0x005B8A82, 0x006D857D, 0x0079897E,
        0x008EA295, 0x002E3F32, 0x00545349, 0x00575747, 0x00585848, 0x00575747, 0x00535343, 0x00535343, 0x00565646, 0x00575747, 0x00F9F9F8, 0x00838479, 0x00545545, 0x004F5040, 0x004E4F3F, 0x004D4E3E, 0x00535343, 0x00525242, 0x00555646, 0x00585949,
        0x00535444, 0x00585949, 0x004F5040, 0x00535343, 0x00505040, 0x00575848, 0x00565747, 0x00515242, 0x005B5C4C, 0x00545545, 0x00545444, 0x00545444, 0x00565747, 0x00525343, 0x00535444, 0x00505343, 0x00525545, 0x00535646, 0x00535645, 0x00515242,
        0x00535444, 0x00545545, 0x00535444, 0x00515242, 0x00515242, 0x00505141, 0x00525242, 0x00515141, 0x004D4E3E, 0x004F4F3F, 0x00525343, 0x004F5040, 0x004E4F3F, 0x00525343, 0x00575848, 0x004E5141, 0x00505343, 0x00515444, 0x00535645, 0x004F5141,
        0x00545545, 0x00555646, 0x00535444, 0x004F5040, 0x004F5040, 0x00535444, 0x00585949, 0x004F5242, 0x00828479, 0x00F9F9F8, 0x00535646, 0x00545747, 0x00525545, 0x004E5141, 0x004B4E3E, 0x0047483F, 0x00263024, 0x00839082, 0x00869080, 0x0059715F,
        0x00538371, 0x00497B6F, 0x00678881, 0x00024050, 0x001C6476, 0x00368DA7, 0x00238EB4, 0x001F97CB, 0x000781B7, 0x001E8DBD, 0x00298EB5, 0x001D6E83, 0x00354141, 0x004C4633, 0x003B4735, 0x0046483C, 0x004A4634, 0x00404633, 0x0043463D, 0x00414839,
        0x00454C3D, 0x00434A3B, 0x00474E3F, 0x00484F40, 0x00464D3E, 0x004A5142, 0x00474E3F, 0x004B5041, 0x00494E3F, 0x00494E3F, 0x004A4F40, 0x00484D3E, 0x00464B3C, 0x00494E3F, 0x004D5243, 0x004F5445, 0x00484D3E, 0x004B5041, 0x00525748, 0x00505546,
        0x004D5243, 0x004E5344, 0x004C5142, 0x00474A3B, 0x00424536, 0x00414435, 0x0044493A, 0x00494E3F, 0x00495041, 0x00495041, 0x004A5142, 0x00464B3C, 0x004B5041, 0x00494E3F, 0x00484D3E, 0x004C5142, 0x00484D3E, 0x003F4435, 0x00414637, 0x00474031,
        0x003E4236, 0x00374134, 0x003D4332, 0x00464531, 0x002F372C, 0x000E3238, 0x00024156, 0x000A495D, 0x000B4A5F, 0x000C4B60, 0x000E4D62, 0x000E4C64, 0x000E4C64, 0x000D4A64, 0x000D4A64, 0x00214767, 0x001D526D, 0x00064559, 0x001F5867, 0x004B717D,
        0x0028484E, 0x0040696B, 0x00316A67, 0x00476C64, 0x00254344, 0x0044626D, 0x00467283, 0x0022616F, 0x003B797F, 0x00638B8A, 0x00697A76, 0x00325453, 0x00375E5C, 0x0027554F, 0x002D6059, 0x00558880, 0x00628E87, 0x00779B95, 0x005E7D76, 0x00586A69,
        0x005B706D, 0x005B6D66, 0x004D554B, 0x00564E41, 0x00655140, 0x006A5540, 0x0063513A, 0x00535343, 0x004E5246, 0x00516058, 0x00536E6A, 0x005C8685, 0x0067A1A0, 0x0062A8A2, 0x005CAAA3, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0x005E6463, 0x00767B7E, 0x00B6BABF, 0x00C5CACD, 0x00CED4D3, 0x00DDE4DF, 0x00ECF4ED, 0x00E5F0ED, 0x00D6E1DE, 0x00CAD5D2, 0x00D3DCD9, 0x00D9E2DF, 0x00E9F2EF, 0x00DAE5E2, 0x00CCD7D4, 0x00D2D9D2, 0x00CFD6CF, 0x00C5CCC5, 0x00C0C7C0, 0x00C3CAC3,
        0x00C3CAC3, 0x00C1C8C1, 0x00C3CAC3, 0x00E5E0DD, 0x00E2E8E3, 0x00E0E7E4, 0x00D7DAD8, 0x00CFD2D0, 0x00C6D4D0, 0x00A5B3AD, 0x00717570, 0x00799191, 0x00919F9D, 0x00878C8A, 0x00868D86, 0x00798880, 0x00798A81, 0x00787F7A, 0x007A7675, 0x00374F55,
        0x00426267, 0x004B7074, 0x00547479, 0x00647C82, 0x009EB7BB, 0x005C8282, 0x006EA09C, 0x0070A7B4, 0x00499CB1, 0x0043B3D1, 0x004BC2E2, 0x003BA9C7, 0x002D90B0, 0x00359EC7, 0x002394C6, 0x002C91BE, 0x001C7BA6, 0x00136C91, 0x003E95B7, 0x0049A2C7,
        0x003095C2, 0x0031A2DA, 0x001C95D3, 0x0040A0CE, 0x00217BA4, 0x00004864, 0x001E5B65, 0x00275D5E, 0x00003E49, 0x00227C9F, 0x002A97CF, 0x002793CD, 0x002D82AA, 0x00084053, 0x00173F4B, 0x00174354, 0x0003435C, 0x00045675, 0x003895B4, 0x002594C6,
        0x002595CA, 0x00289BD4, 0x0030A5E2, 0x002FA9E5, 0x0028A6E0, 0x0022A6DC, 0x0021A8DC, 0x002CA4E5, 0x002DA5E0, 0x0029A3D9, 0x002DABE6, 0x001FA1E2, 0x00239EDE, 0x0041ABE0, 0x0004608B, 0x0023687B, 0x003C8692, 0x0048878B, 0x00648483, 0x00758780,
        0x008DA496, 0x002E3C30, 0x00514F45, 0x005A5A4A, 0x005A5A4A, 0x00575747, 0x00535343, 0x00525242, 0x00555545, 0x00575747, 0x00F5F5F4, 0x00828377, 0x00535444, 0x00555646, 0x00535343, 0x00565646, 0x00575747, 0x00565646, 0x00515242, 0x00555646,
        0x004F5040, 0x004E4F3F, 0x004D4E3E, 0x00535343, 0x00525242, 0x00555646, 0x00585949, 0x00535444, 0x00585949, 0x004F5040, 0x00535343, 0x00505040, 0x00575848, 0x00565747, 0x00525343, 0x00505343, 0x00515444, 0x00525545, 0x00555848, 0x00515343,
        0x00515242, 0x00525343, 0x00545545, 0x00555646, 0x00545545, 0x00515242, 0x004D4D3D, 0x00505040, 0x00515141, 0x004F5040, 0x00555646, 0x00535444, 0x00535444, 0x00545545, 0x00545545, 0x00505343, 0x00525545, 0x00535646, 0x00535645, 0x00515242,
        0x00535444, 0x00545545, 0x00535444, 0x00515242, 0x00515242, 0x00525343, 0x00545545, 0x00535646, 0x00828479, 0x00F5F5F4, 0x00525545, 0x00545747, 0x00535646, 0x004E5141, 0x004A4D3D, 0x00424738, 0x00263023, 0x00889085, 0x00899089, 0x005E7975,
        0x005A9493, 0x00418185, 0x00457680, 0x00003D51, 0x000B5567, 0x000E5F74, 0x00298AAB, 0x001D8CBA, 0x001C91C4, 0x001885B1, 0x00258BAE, 0x000E6782, 0x00273940, 0x00444237, 0x0037483B, 0x0043463D, 0x004B4735, 0x00444934, 0x00404236, 0x003D4435,
        0x00404738, 0x003C4334, 0x003F4637, 0x00404738, 0x003F4637, 0x00444B3C, 0x0042493A, 0x0049493B, 0x00474739, 0x00474739, 0x0049493B, 0x0048483A, 0x00464638, 0x00474739, 0x004B4B3D, 0x0049493B, 0x00444436, 0x00454537, 0x00474739, 0x00444436,
        0x00434335, 0x00424234, 0x003E3E30, 0x00494C3D, 0x00454839, 0x00434637, 0x00424738, 0x00434839, 0x00404738, 0x003E4536, 0x003F4637, 0x003E4334, 0x003E4334, 0x003C4132, 0x003C4132, 0x003E4334, 0x003D4233, 0x003B4031, 0x003A3F30, 0x00453E2F,
        0x003E4236, 0x00384235, 0x003F4534, 0x00464531, 0x002F372C, 0x000F3339, 0x00044358, 0x000A495D, 0x000B4A5F, 0x000D4C61, 0x000E4D62, 0x000E4C64, 0x000E4C64, 0x000D4A64, 0x000D4A64, 0x0015506A, 0x0000475D, 0x00004E5D, 0x0032818E, 0x00528C98,
        0x0003313C, 0x00276468, 0x005BA9A8, 0x00336B5E, 0x00154743, 0x001D4E56, 0x00074A59, 0x00004651, 0x000D6466, 0x0048847E, 0x0080A298, 0x00538385, 0x00225858, 0x00003E3C, 0x00003D3A, 0x00145752, 0x00286561, 0x00396C68, 0x00002926, 0x00041218,
        0x0000080B, 0x00000603, 0x000A120B, 0x00453B31, 0x00664E42, 0x005D4636, 0x00392918, 0x00504432, 0x003D3125, 0x00302422, 0x00251B21, 0x00221C27, 0x0025232F, 0x001D1F29, 0x00181D26, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0x00636968, 0x00797E81, 0x00B3B7BC, 0x00C5CACD, 0x00CDD2D3, 0x00DAE1DC, 0x00E1E9E2, 0x00DDE8E6, 0x00C7D2D0, 0x00D4DFDC, 0x00D7E2DF, 0x00C2CBC8, 0x00D4DBD8, 0x00DDE2E0, 0x00EBEEEC, 0x00C3D4D1, 0x00C6D7D4, 0x00C4D5D2, 0x00C5D6D3, 0x00C8D9D6,
        0x00C2D3D0, 0x00B6C7C4, 0x00B3C4C1, 0x00D9DAD0, 0x00CCE4D8, 0x00CBE6DD, 0x00D3DCD9, 0x00D0DBD8, 0x00AFD0C9, 0x0085A49B, 0x00767E77, 0x00929D9B, 0x009EA19F, 0x00A7A3A2, 0x008D918C, 0x00899C93, 0x00728A7E, 0x00738477, 0x00868C81, 0x003A5B6E,
        0x003D6375, 0x002E5466, 0x00213B4C, 0x00202B39, 0x004E555E, 0x00677A7D, 0x00638480, 0x009AD1C0, 0x003B8585, 0x000B6276, 0x00186788, 0x001B5D80, 0x0000385D, 0x00045D89, 0x002DA0D3, 0x002CA0D5, 0x001B88BB, 0x001F86B3, 0x00167AA4, 0x002288B8,
        0x002293CB, 0x0022A1E5, 0x0019A3EC, 0x001E98DA, 0x002EA0DC, 0x001F7FAD, 0x0034819C, 0x00266978, 0x000A5367, 0x003591BA, 0x002792CF, 0x002589C4, 0x002F87B0, 0x00267187, 0x000D5360, 0x00034B5D, 0x00034C68, 0x00004265, 0x00155377, 0x002A97CA,
        0x002390C6, 0x002192CB, 0x00299EDB, 0x002DA7E3, 0x0027A8E1, 0x0021A7DD, 0x0022AADE, 0x002AA2E4, 0x002EA2DB, 0x0037AADD, 0x00259FD5, 0x0024A6E9, 0x001E9EE7, 0x002697DA, 0x003AA0DB, 0x003B99C4, 0x0042A3C4, 0x004B98AB, 0x00638D94, 0x00768D89,
        0x0094AA9E, 0x00313F33, 0x00544F46, 0x00595949, 0x005B5B4B, 0x005A5A4A, 0x00565646, 0x00545444, 0x00555545, 0x00545444, 0x00F5F5F4, 0x00848479, 0x00525343, 0x00BDBDB7, 0x00BFBFB9, 0x00575747, 0x00575747, 0x00565646, 0x008A8A80, 0x00D7D7D4,
        0x00727366, 0x00535343, 0x00565646, 0x00575747, 0x00565646, 0x00515242, 0x00545545, 0x004F5040, 0x004E4F3F, 0x004D4E3E, 0x00535343, 0x00525242, 0x00555646, 0x00565747, 0x00525343, 0x004F5040, 0x00505141, 0x00525343, 0x00545545, 0x00545545,
        0x00535444, 0x004E4F3F, 0x004D4E3E, 0x00515242, 0x00515242, 0x00505141, 0x00535444, 0x00515243, 0x00515141, 0x004E4E3E, 0x00545545, 0x00575848, 0x00585949, 0x00565747, 0x00525343, 0x00505343, 0x00515444, 0x00525545, 0x00555848, 0x00515343,
        0x00515242, 0x00525343, 0x00545545, 0x00555646, 0x00545545, 0x00515242, 0x004F5040, 0x00565949, 0x0085877C, 0x00F5F5F4, 0x00515444, 0x00545747, 0x00545747, 0x004F5242, 0x004A4D3D, 0x00414A36, 0x00273222, 0x00868E84, 0x00828A8A, 0x00597D85,
        0x0059A0AE, 0x0033839A, 0x00226481, 0x00207994, 0x00196E84, 0x000C5F74, 0x000C6684, 0x002187B1, 0x001D87B6, 0x001F84AA, 0x0014718B, 0x00015D80, 0x001F3743, 0x0045483F, 0x003A4B40, 0x003D4239, 0x00484432, 0x00484E37, 0x0048483A, 0x00414839,
        0x00434A3B, 0x003D4435, 0x003E4536, 0x003F4637, 0x003E4536, 0x00454C3D, 0x00444B3C, 0x0049483A, 0x00464537, 0x00474638, 0x004A493B, 0x004A493B, 0x00484739, 0x00474638, 0x0049483A, 0x004B4A3C, 0x00484739, 0x0049483A, 0x0049483A, 0x00464537,
        0x00484739, 0x0049483A, 0x00434234, 0x00424536, 0x003E4132, 0x003D4031, 0x003E4334, 0x003F4435, 0x003B4233, 0x003B4233, 0x003D4435, 0x003E4334, 0x003B4031, 0x003A3F30, 0x003B4031, 0x003C4132, 0x003F4435, 0x00414637, 0x00404536, 0x00453E2F,
        0x003F4337, 0x003A4437, 0x00404635, 0x00474632, 0x002F372C, 0x0010343A, 0x00054459, 0x000B4A5E, 0x000B4A5F, 0x000D4C61, 0x000E4D62, 0x000E4C64, 0x000E4C64, 0x000D4A64, 0x000C4963, 0x0010465F, 0x000E5569, 0x00004959, 0x00297182, 0x008CBDCD,
        0x006E93A1, 0x0074A7B1, 0x007CC2C9, 0x007CAD9F, 0x003F6765, 0x006E96A2, 0x00528E9E, 0x001C707C, 0x0053A5AA, 0x009ACDC9, 0x00DDF2E9, 0x008FA4B3, 0x00587381, 0x00254953, 0x0046717A, 0x00A0CCD3, 0x0096BAC2, 0x008EA7B1, 0x0094A5AE, 0x00637383,
        0x00546F79, 0x004A6869, 0x00405350, 0x004F4C47, 0x00584841, 0x0065594F, 0x00635D52, 0x004E5C44, 0x00415140, 0x0044564F, 0x004E6769, 0x005B7D83, 0x00658F96, 0x00629598, 0x005D9497, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0x0060666B, 0x0081888B, 0x00A7AFAF, 0x00B2BAB9, 0x00CAD2D1, 0x00CCD5D2, 0x00C4CEC8, 0x00D5E1DB, 0x00D5E1DB, 0x00CDD9D3, 0x00C8D2CC, 0x00C4CEC8, 0x00D4DBD6, 0x00CCD3CE, 0x00CED5D0, 0x00D0DCD6, 0x00E2EEE8, 0x00E0ECE6, 0x00D0DCD6, 0x00CAD6D0,
        0x00DAE6E0, 0x00D9E5DF, 0x00ACB8B2, 0x00C8D5CD, 0x00D5E2DA, 0x00D4E1D9, 0x00CFDDD7, 0x00C2D0CA, 0x00BBCAC6, 0x0082918D, 0x0074837F, 0x0099A4A2, 0x008A9593, 0x00929D9B, 0x007A8583, 0x00798482, 0x00808B89, 0x00798482, 0x00788381, 0x0035536E,
        0x001E6182, 0x00005985, 0x00004575, 0x00085586, 0x001574A6, 0x000A80BB, 0x001394D9, 0x002D91D9, 0x0031B1EC, 0x0025ADDD, 0x0038A9DB, 0x002B94C5, 0x001486AA, 0x00005668, 0x001E5E63, 0x0053A3C8, 0x003299D8, 0x00005A99, 0x00003855, 0x00488591,
        0x0064AED0, 0x001C78B3, 0x003D9EE2, 0x002FA3E4, 0x002294D3, 0x0039A9E5, 0x0048B5EB, 0x0041ABE0, 0x002891C4, 0x002B91C5, 0x003197CC, 0x002087B4, 0x001977A4, 0x003789B3, 0x002B7298, 0x00074769, 0x00054460, 0x00114F67, 0x0007485D, 0x0011527E,
        0x003393B7, 0x002889AF, 0x00298CBE, 0x0028A1DF, 0x002BA3EB, 0x002D9FE6, 0x0019A4E3, 0x0029ABD6, 0x0024A6DB, 0x0023A1DC, 0x0031A5DC, 0x002D97C6, 0x003EA9D5, 0x003BB0E7, 0x001B9DDE, 0x003E98D1, 0x00157BAF, 0x00397997, 0x00718684, 0x00809382,
        0x0098A29C, 0x003C3739, 0x00484C47, 0x00585749, 0x00575648, 0x00555547, 0x00545446, 0x00535345, 0x00505344, 0x00515445, 0x00F5F5F4, 0x00848479, 0x00585949, 0x00CBCBC6, 0x00FFFFFF, 0x00AAAAA2, 0x00545444, 0x00525242, 0x008E8E84, 0x00FFFFFF,
        0x00DFDFDD, 0x005E5E4F, 0x00555545, 0x00575747, 0x00565646, 0x00505141, 0x00535444, 0x00555646, 0x00535343, 0x00565646, 0x00575747, 0x00565646, 0x00505142, 0x00565647, 0x00535444, 0x00505141, 0x00505141, 0x00525343, 0x00545545, 0x00565747,
        0x00545545, 0x004F5040, 0x004D4E3E, 0x00515242, 0x00515242, 0x004F5040, 0x00535444, 0x004E5042, 0x00505142, 0x00515242, 0x00535444, 0x00575848, 0x00585949, 0x00555646, 0x00525343, 0x004F5040, 0x00505141, 0x00525343, 0x00545545, 0x00545545,
        0x00535444, 0x004E4F3F, 0x004D4E3E, 0x00515242, 0x00515242, 0x00505141, 0x00535444, 0x004D5041, 0x007F8177, 0x00F5F5F4, 0x00505344, 0x00525546, 0x00545748, 0x004D5041, 0x004E5142, 0x00504541, 0x00232F29, 0x008D8F89, 0x00759283, 0x005A8578,
        0x0074A6AC, 0x003399B6, 0x002A94C9, 0x001F9BC3, 0x001F97C1, 0x001785AF, 0x000B6588, 0x000A556B, 0x00165B6E, 0x001B6B84, 0x00227B9D, 0x0001537D, 0x00293841, 0x004F4E3A, 0x00364732, 0x003E403A, 0x0048433A, 0x003D4435, 0x0041483B, 0x00414736,
        0x00424837, 0x00434938, 0x00424837, 0x00404635, 0x00404635, 0x00414736, 0x00424837, 0x0044463A, 0x0046483C, 0x0047493D, 0x0047493D, 0x0045473B, 0x0045473B, 0x0046483C, 0x00484A3E, 0x00444738, 0x00444738, 0x00444738, 0x00444738, 0x00434637,
        0x00434637, 0x00434637, 0x00444738, 0x00414539, 0x003F4337, 0x003D4135, 0x003D4135, 0x003E4236, 0x003F4337, 0x003E4236, 0x003D4135, 0x003C4334, 0x003A4132, 0x003A4132, 0x003D4233, 0x003F4435, 0x00424536, 0x00404334, 0x003F4233, 0x00424633,
        0x00434337, 0x003D4239, 0x00394336, 0x00454535, 0x003E3831, 0x00193236, 0x00044553, 0x0008475C, 0x000A495E, 0x000C4B60, 0x000D4C61, 0x000C4B60, 0x000B4A5F, 0x000C4B60, 0x000D4C61, 0x00064A67, 0x001D4E5E, 0x0014424D, 0x00205968, 0x0047717D,
        0x003F4C4E, 0x004E6666, 0x002F696F, 0x00597778, 0x002F3A3E, 0x00496167, 0x002E717A, 0x001F697B, 0x00588093, 0x007B8B91, 0x006A8276, 0x00305056, 0x0044666C, 0x0023474D, 0x00365C61, 0x0070949A, 0x007F9FA5, 0x00718B92, 0x006F868E, 0x0073878C,
        0x006C7D80, 0x006C7878, 0x00565D58, 0x0053544A, 0x00585344, 0x00605946, 0x00635844, 0x00574741, 0x00514A47, 0x00626A6A, 0x004C666C, 0x00608C93, 0x005E989E, 0x0060A4A9, 0x0063ACB0, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0x00595F64, 0x007F8689, 0x00B5BDBD, 0x00BAC2C1, 0x00C9D1D0, 0x00D0D9D6, 0x00D0DAD4, 0x00C1CDC7, 0x00C0CCC6, 0x00B4C0BA, 0x00BDC7C1, 0x00CCD6D0, 0x00CED8D2, 0x00C5CCC7, 0x00DFE6E1, 0x00E6F2EC, 0x00D1DDD7, 0x00C8D4CE, 0x00CEDAD4, 0x00C9D5CF,
        0x00C6D2CC, 0x00CFDBD5, 0x00CFDBD5, 0x00CFDCD4, 0x00CDDAD2, 0x00C9D6CE, 0x00C9D7D1, 0x00BBC9C3, 0x00ACBBB7, 0x00707F7B, 0x006A7975, 0x0099A4A2, 0x00919C9A, 0x008D9896, 0x007B8684, 0x00848F8D, 0x00747F7D, 0x005C6765, 0x005E6967, 0x002F5255,
        0x00185962, 0x000C5B6E, 0x0008465E, 0x000D3F56, 0x001B576F, 0x001E688A, 0x00226F9D, 0x002275A2, 0x0014789B, 0x001780A1, 0x001D7DA5, 0x0039A2CE, 0x0034ADD5, 0x00288DAD, 0x00074A61, 0x00006073, 0x002C9CC6, 0x0038A2D8, 0x0013638C, 0x00195874,
        0x004088A6, 0x00217DAC, 0x00117CB5, 0x0034A2DC, 0x0029A0D8, 0x0023A1D7, 0x00249ED2, 0x0039ABE0, 0x0037A4DA, 0x002EA2D9, 0x002BA4DC, 0x002491C4, 0x00248ABA, 0x001873A0, 0x003D8CB3, 0x002B7294, 0x00094C67, 0x0006495E, 0x000F5366, 0x0012516D,
        0x00459EB2, 0x00247B8F, 0x001F7998, 0x000B7FAE, 0x0034A9E6, 0x002C9DDB, 0x0027B1E6, 0x0029A7D7, 0x0024A5DC, 0x0024A3E0, 0x0035AAE1, 0x00157EAA, 0x000A6B8F, 0x001F84AB, 0x002893BF, 0x001975A4, 0x00147DA8, 0x004A8FAA, 0x0073908D, 0x00728F7F,
        0x00899F9A, 0x00333738, 0x003E493F, 0x00575648, 0x00555446, 0x00525244, 0x00505042, 0x00505042, 0x004F5243, 0x00515445, 0x00F5F5F4, 0x0086867B, 0x00545546, 0x00656559, 0x00E9E9E7, 0x00FEFEFE, 0x007E8075, 0x00515445, 0x00535444, 0x00B6B7B0,
        0x00FFFFFF, 0x00BFBFB9, 0x00555545, 0x00545444, 0x00525242, 0x00535444, 0x00525343, 0x00545444, 0x00525242, 0x00555545, 0x00575747, 0x00545545, 0x00505042, 0x004F5041, 0x004F5142, 0x00505241, 0x00595A49, 0x00555646, 0x00555646, 0x00575848,
        0x00555646, 0x004F5040, 0x004D4E3E, 0x00515242, 0x00505141, 0x004F5040, 0x00535444, 0x00505244, 0x00535444, 0x00535444, 0x00545545, 0x00545545, 0x00545545, 0x00545545, 0x00545545, 0x00505141, 0x00505141, 0x00525343, 0x00545545, 0x00565747,
        0x00545545, 0x004F5040, 0x004D4E3E, 0x00515242, 0x00515242, 0x004F5040, 0x00535444, 0x00505344, 0x00818378, 0x00F5F5F4, 0x004F5243, 0x00505344, 0x00515445, 0x00494C3D, 0x00494C3D, 0x004F483F, 0x00223129, 0x008B8C88, 0x00748E81, 0x005B8175,
        0x006C9C9E, 0x0027879E, 0x001E84AF, 0x001785A7, 0x002091B9, 0x001F8AB6, 0x002282A6, 0x0015657E, 0x00004355, 0x00034E64, 0x001A6885, 0x001E709A, 0x00303F48, 0x004B4A36, 0x00384934, 0x00444640, 0x004C473E, 0x003D4435, 0x003C4336, 0x003F4534,
        0x00404635, 0x00414736, 0x00414736, 0x00404635, 0x00404635, 0x00424837, 0x00444A39, 0x00434539, 0x0045473B, 0x0046483C, 0x0045473B, 0x0044463A, 0x00434539, 0x0044463A, 0x0045473B, 0x00454839, 0x00454839, 0x00454839, 0x00454839, 0x0046493A,
        0x0046493A, 0x00454839, 0x00454839, 0x00404438, 0x003D4135, 0x003B3F33, 0x003B3F33, 0x003C4034, 0x003D4135, 0x003D4135, 0x003C4034, 0x003E4536, 0x003D4435, 0x003C4334, 0x003F4435, 0x00404536, 0x00424536, 0x00414435, 0x003F4233, 0x00414532,
        0x00424236, 0x003B4037, 0x00364033, 0x00424232, 0x003A342D, 0x00152E32, 0x00014250, 0x000A495E, 0x000B4A5F, 0x000C4B60, 0x000C4B60, 0x000C4B60, 0x000C4B60, 0x000D4C61, 0x000D4C61, 0x00144C67, 0x00174960, 0x00004162, 0x001676A4, 0x002E8AB5,
        0x00003346, 0x00206463, 0x006BCCC8, 0x00175F59, 0x00024C46, 0x000C504F, 0x000E4C56, 0x00004457, 0x00004A56, 0x001F6F6A, 0x00397B68, 0x00336565, 0x001A4E4E, 0x00063C3C, 0x00023838, 0x00184C4C, 0x003E6E6F, 0x003B6768, 0x00002123, 0x0000090E,
        0x0000090C, 0x00000303, 0x00000601, 0x00393A30, 0x004E493A, 0x00403926, 0x003F3420, 0x00515238, 0x00484A34, 0x00121506, 0x00171A11, 0x00191A18, 0x00241F20, 0x00251D1E, 0x00160C0C, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0x00575D62, 0x007E8588, 0x00AFB7B7, 0x00B1B9B8, 0x00CAD2D1, 0x00D7E0DD, 0x00CED8D2, 0x00C9D7D1, 0x00C6D4CE, 0x00B5C1BB, 0x00AFBBB5, 0x00BFC9C3, 0x00C9D3CD, 0x00C4CEC8, 0x00DBE2DD, 0x00D5E1DB, 0x00BCC8C2, 0x00BCC8C2, 0x00C6D2CC, 0x00C3CFC9,
        0x00BDC9C3, 0x00BDC9C3, 0x00C2CEC8, 0x00D8E5DD, 0x00C8D5CD, 0x00C1CDC7, 0x00CBD9D3, 0x00D2E0DC, 0x00CFDEDA, 0x0084938F, 0x006A7876, 0x00929D9B, 0x008C9795, 0x007F8A88, 0x00737E7C, 0x007F8A88, 0x006E7977, 0x005D6866, 0x005A6563, 0x00304742,
        0x00174B4B, 0x000B4A52, 0x0004313E, 0x0003242D, 0x00053039, 0x00013748, 0x0000324D, 0x00114C56, 0x00134E57, 0x00134D59, 0x000F556D, 0x00005177, 0x001B96C2, 0x0043ABD6, 0x00276790, 0x00055359, 0x0012687A, 0x00409FCA, 0x00359BD0, 0x00004B74,
        0x0000526B, 0x00217D96, 0x001782A8, 0x001A87B3, 0x001887B5, 0x001084B3, 0x000C87B9, 0x001EA0D5, 0x0027AAE3, 0x002BADE9, 0x002BAAE7, 0x0030A7DF, 0x00188ABF, 0x00258CBD, 0x001B77A2, 0x00388AAD, 0x0028728E, 0x00064F65, 0x00004759, 0x00144E5A,
        0x0089D6D8, 0x005FA3A2, 0x003C8490, 0x002D98B9, 0x002899CB, 0x003EAEE3, 0x0021A8D6, 0x002FA6DE, 0x0029A6E3, 0x001D9BDB, 0x0035ACE4, 0x00127BA4, 0x00004761, 0x000D596B, 0x002B7384, 0x00459FBE, 0x002892B1, 0x004790A4, 0x006B908E, 0x00709788,
        0x008AA8A3, 0x00313C3A, 0x00404F41, 0x00565547, 0x00545345, 0x004F4F41, 0x004D4D3F, 0x004D4D3F, 0x004D5041, 0x00515445, 0x00F5F5F4, 0x0084857A, 0x00515243, 0x00505042, 0x007D7D72, 0x00FCFCFB, 0x00E9EAE8, 0x00646759, 0x00545545, 0x00595A4C,
        0x00D5D5D1, 0x00FFFFFF, 0x00989A91, 0x00515445, 0x00515445, 0x00535444, 0x00585949, 0x00565646, 0x00545444, 0x00555545, 0x00545444, 0x00505040, 0x00525344, 0x004F4F41, 0x004F5243, 0x004B4C3C, 0x00565747, 0x00535343, 0x00555545, 0x00555545,
        0x00545444, 0x00505040, 0x004D4E3E, 0x00505141, 0x00505141, 0x004F5040, 0x00535444, 0x004F5042, 0x00535444, 0x00545546, 0x00525343, 0x00505242, 0x00505242, 0x00525344, 0x00565747, 0x00555646, 0x00545545, 0x00545545, 0x00555646, 0x00575848,
        0x00555646, 0x004F5040, 0x004D4E3E, 0x00515242, 0x00505141, 0x004F5040, 0x00535444, 0x00505344, 0x00818378, 0x00F5F5F4, 0x004E5142, 0x004E5142, 0x004F5243, 0x00484B3C, 0x00484B3C, 0x00434234, 0x001B2C21, 0x00868785, 0x00788D85, 0x00638378,
        0x006C9391, 0x001B7580, 0x0012738D, 0x00217E97, 0x002C90B3, 0x00228DB9, 0x002E96C1, 0x00227C9B, 0x00004258, 0x00004358, 0x001B5E75, 0x001E709A, 0x002C3B44, 0x00484733, 0x00344530, 0x00393B35, 0x00454037, 0x003C4334, 0x00363D30, 0x003A402F,
        0x003B4130, 0x003C4231, 0x003C4231, 0x003C4231, 0x003E4433, 0x00404635, 0x00424837, 0x0047493D, 0x0047493D, 0x00484A3E, 0x00484A3E, 0x0047493D, 0x0046483C, 0x0047493D, 0x0047493D, 0x00434637, 0x00424536, 0x00424536, 0x00444738, 0x0046493A,
        0x00474A3B, 0x00454839, 0x00434637, 0x0043473B, 0x00414539, 0x003F4337, 0x003E4236, 0x003E4236, 0x003F4337, 0x00404438, 0x00404438, 0x003F4637, 0x003E4536, 0x003C4334, 0x003E4334, 0x003E4334, 0x003F4233, 0x003E4132, 0x003D4031, 0x00424633,
        0x00424236, 0x003C4138, 0x00374134, 0x00424232, 0x003B352E, 0x00173034, 0x00034452, 0x000C4B60, 0x000C4B60, 0x000B4A5F, 0x000C4B60, 0x000D4C61, 0x000E4D62, 0x000E4D62, 0x000E4D62, 0x00064865, 0x00144658, 0x00124656, 0x003C7F94, 0x0077ACC0,
        0x0068858A, 0x0084A9A7, 0x0084C8CD, 0x0083ABAA, 0x00445D5F, 0x0076999D, 0x00589BA4, 0x002A7486, 0x006FA1B3, 0x00B0D1D4, 0x00B2D6C8, 0x007D9F9F, 0x004A6E6E, 0x00264C4C, 0x00406666, 0x0091B5B5, 0x009FBEBF, 0x0089A5A6, 0x006E8587, 0x0054686D,
        0x00516265, 0x00566262, 0x00464D48, 0x004D4E44, 0x00544F40, 0x0058513E, 0x00594E3A, 0x00514F44, 0x00474C43, 0x00445551, 0x003A595A, 0x00507D80, 0x00538A8D, 0x00518E90, 0x004B8B8C, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0x005D6368, 0x00848B8E, 0x00A9B1B1, 0x009FA7A6, 0x00B3BBBA, 0x00C5CECB, 0x00C4CEC8, 0x00BAC8C2, 0x00B7C5BF, 0x00BFCDC7, 0x00C6D2CC, 0x00C8D4CE, 0x00CDD7D1, 0x00C2CCC6, 0x00BBC5BF, 0x00D3DFD9, 0x00C9D5CF, 0x00D0DCD6, 0x00D0DCD6, 0x00CFDBD5,
        0x00D2DED8, 0x00C3CFC9, 0x00B8C4BE, 0x00BAC6C0, 0x00B2BEB8, 0x00ADB9B3, 0x00BAC8C4, 0x00D4E2DE, 0x00EAF8F6, 0x00A3B1AF, 0x00788684, 0x0096A19F, 0x008C9795, 0x00808B89, 0x0075807E, 0x00737E7C, 0x0066716F, 0x0065706E, 0x00525D5B, 0x00444D56,
        0x00395C6A, 0x00225369, 0x00153E54, 0x00194251, 0x0015525C, 0x000E586A, 0x00185E7B, 0x007AA49D, 0x0093ADA7, 0x009CAEAD, 0x0086B3BE, 0x00025C75, 0x0000698E, 0x00429BC7, 0x0072A7D2, 0x006D7D7C, 0x008CAFB3, 0x004F9DBA, 0x0029A0D7, 0x0030AAD8,
        0x00177582, 0x00004B51, 0x002C7D92, 0x001C7998, 0x00479FC3, 0x00439FCA, 0x002594C6, 0x001EA5DB, 0x001CACE6, 0x0022A4E5, 0x002B9EE1, 0x0022A3E2, 0x002CA8E4, 0x001A8CC1, 0x002088B7, 0x0017749B, 0x00378DAB, 0x0025758C, 0x0000485B, 0x00154C5B,
        0x00367775, 0x0077A69D, 0x008CBFC2, 0x00328FA9, 0x0039A6D9, 0x0039A4DE, 0x002FAEE1, 0x0030A2E1, 0x002FA7E8, 0x002BA7E7, 0x0036ADE4, 0x00086F96, 0x00186A7C, 0x0075AFB4, 0x0092C0BA, 0x0066B5CA, 0x0046A6BE, 0x00599EAF, 0x006F9190, 0x00668C80,
        0x007F9A96, 0x00333836, 0x004F5948, 0x00575648, 0x00545345, 0x00505042, 0x004D4D3F, 0x004D4D3F, 0x004D5041, 0x00505344, 0x00F5F5F4, 0x00828377, 0x004D4E3F, 0x004D4D3F, 0x004D4D3F, 0x009D9E96, 0x00FFFFFF, 0x00CACBC6, 0x00535444, 0x00515243,
        0x00656559, 0x00ECECEB, 0x00F9FAF9, 0x00787A6F, 0x00535647, 0x00545545, 0x00545546, 0x00545446, 0x00535345, 0x00505344, 0x00515445, 0x00505344, 0x00515143, 0x00525244, 0x004B4E3F, 0x00535345, 0x004A4A3C, 0x00515141, 0x00525242, 0x00515141,
        0x00515141, 0x004F4F3F, 0x004D4E3E, 0x00505141, 0x004F5040, 0x004E4F3F, 0x00525344, 0x00525345, 0x00515343, 0x00525445, 0x00505243, 0x004F5243, 0x00525445, 0x00515343, 0x00555646, 0x00575747, 0x00565646, 0x00555545, 0x00555545, 0x00555545,
        0x00545444, 0x00505040, 0x004D4E3E, 0x00505141, 0x00505141, 0x004F5040, 0x00535444, 0x004F5243, 0x00808277, 0x00F5F5F4, 0x004E5142, 0x004F5243, 0x00515445, 0x004A4D3E, 0x004B4E3F, 0x00464835, 0x001E3225, 0x008A8B89, 0x007D8E8A, 0x00658076,
        0x0060827C, 0x00025557, 0x00005061, 0x00125F72, 0x002481A2, 0x002692C1, 0x002D9BCB, 0x002182A6, 0x00004C65, 0x00044659, 0x002A6378, 0x00156791, 0x002B3A43, 0x00474632, 0x001D2E19, 0x0012140E, 0x002D281F, 0x003D4435, 0x0040473A, 0x003E4334,
        0x003E4334, 0x003E4334, 0x003E4334, 0x003F4435, 0x00414637, 0x00434839, 0x00454A3B, 0x0045493D, 0x00464A3E, 0x00464A3E, 0x00474B3F, 0x00474B3F, 0x00474B3F, 0x00474B3F, 0x00484C40, 0x0045493D, 0x0044483C, 0x0044483C, 0x00474B3F, 0x004A4E42,
        0x004B4F43, 0x00484C40, 0x0045493D, 0x0045493D, 0x0043473B, 0x00414539, 0x00404438, 0x00404438, 0x00414539, 0x0042463A, 0x0043473B, 0x00444B3E, 0x00434A3D, 0x0041483B, 0x0042463A, 0x00404438, 0x00414337, 0x00414337, 0x00404236, 0x003E422F,
        0x00404034, 0x003C4138, 0x00384235, 0x00434333, 0x003C362F, 0x00173034, 0x00034452, 0x000B4A5F, 0x000A495E, 0x000B4A5F, 0x000D4C61, 0x00104F64, 0x00115065, 0x00104F64, 0x000E4D62, 0x00024A68, 0x001C4D5B, 0x0019464A, 0x002A5E65, 0x0052747A,
        0x004E5552, 0x005D6F6E, 0x00376C76, 0x005A7375, 0x00424248, 0x004E6067, 0x00297179, 0x00136172, 0x004E6F83, 0x008A9299, 0x007C9084, 0x0035504D, 0x003F5C59, 0x002F4E4B, 0x003B5A57, 0x0089A6A3, 0x00859D9B, 0x00899B9A, 0x008C9C9B, 0x00809499,
        0x0077888B, 0x007D8989, 0x00626964, 0x004C4D43, 0x004B4637, 0x00564F3C, 0x00564B37, 0x00574845, 0x004B4645, 0x00636E72, 0x00496B71, 0x00659AA4, 0x005FA7AF, 0x005CB0B6, 0x0059B4B8, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0x0060666B, 0x008A9194, 0x00B8C0C0, 0x00ADB5B4, 0x00B0B8B7, 0x00C0C9C6, 0x00D7E1DB, 0x00C9D9D2, 0x00B3C3BC, 0x00B7C5BF, 0x00C0CEC8, 0x00C3CFC9, 0x00BFCBC5, 0x00C3CDC7, 0x00CFD9D3, 0x00C9D5CF, 0x00C1CDC7, 0x00CCD8D2, 0x00D3DFD9, 0x00D5E1DB,
        0x00D0DCD6, 0x00B8C4BE, 0x00ABB7B1, 0x00C5D1CB, 0x00C8D4CE, 0x00BFCAC7, 0x00B9C7C3, 0x00B8C5C3, 0x00C6D4D2, 0x00919F9D, 0x006D7B7A, 0x00919C9A, 0x008A9593, 0x00838E8C, 0x00808B89, 0x00788381, 0x005C6765, 0x00596462, 0x004B5654, 0x00354552,
        0x002F5468, 0x001D4C67, 0x00153C58, 0x00164358, 0x00165968, 0x001E6A81, 0x002B7293, 0x00668A84, 0x00AEB9B1, 0x00C6C6C0, 0x0083A2A3, 0x00408C98, 0x00247C94, 0x004E90AD, 0x006B91AF, 0x003B4643, 0x004A615D, 0x003C778A, 0x003697C3, 0x002786AD,
        0x00236169, 0x002C4F4B, 0x00385C64, 0x0079A4B9, 0x005EA0B9, 0x00187596, 0x00006C98, 0x002091C9, 0x0036A7E5, 0x0033A7E8, 0x002AA5E5, 0x0020A3E6, 0x0020A1E0, 0x0030ABE5, 0x002093C5, 0x001F88B3, 0x001A7A9E, 0x00378FAD, 0x001E718D, 0x00064561,
        0x00094349, 0x009EBAB4, 0x00638388, 0x00227595, 0x002D95D0, 0x0040A8EB, 0x002BA3DF, 0x0033A7E8, 0x002299D7, 0x00249CD7, 0x0038ADE0, 0x001E87AE, 0x004B9EB4, 0x008AC2C7, 0x00689189, 0x001B6074, 0x00217991, 0x005690A3, 0x00748C8A, 0x00728E81,
        0x0091A29F, 0x003C3837, 0x004A4B3B, 0x00575648, 0x00565547, 0x00525244, 0x00505042, 0x004F4F41, 0x004D5041, 0x004D5041, 0x00F5F5F4, 0x00828377, 0x004E4F40, 0x004E4E40, 0x004D4D3F, 0x004E5142, 0x00C9CAC5, 0x00FFFFFF, 0x00A2A29A, 0x004D4E3F,
        0x004D4D3F, 0x00818177, 0x00FFFFFF, 0x00E5E6E3, 0x00636558, 0x00525343, 0x00515243, 0x00505042, 0x00505042, 0x004F5243, 0x00515445, 0x00515445, 0x004C4D3E, 0x00535345, 0x004B4E3F, 0x00515347, 0x004D4F42, 0x00555545, 0x00565646, 0x00555545,
        0x00515242, 0x004E4F3F, 0x004D4E3E, 0x00505141, 0x004E4F3F, 0x004E4F3F, 0x00525344, 0x00545648, 0x00505344, 0x00525546, 0x004F5243, 0x004F5243, 0x00515445, 0x004D4F40, 0x00515343, 0x00565646, 0x00555545, 0x00535343, 0x00525242, 0x00515141,
        0x00515141, 0x004F4F3F, 0x004D4E3E, 0x00505141, 0x004F5040, 0x004E4F3F, 0x00535444, 0x00515445, 0x00818378, 0x00F5F5F4, 0x004F5243, 0x004F5243, 0x00525546, 0x004C4F40, 0x004D5041, 0x00484C39, 0x00203427, 0x008A8B87, 0x007C8E87, 0x00657E74,
        0x005C7C77, 0x00004E51, 0x00004A5A, 0x00003F51, 0x000F698B, 0x002896C6, 0x00289ACF, 0x00177FAA, 0x0000506E, 0x00003D54, 0x00256479, 0x00166892, 0x002C3B44, 0x004B4A36, 0x0023341F, 0x0012140E, 0x002A251C, 0x003D4435, 0x0041483B, 0x003F4435,
        0x003F4435, 0x003E4334, 0x003E4334, 0x003F4435, 0x003F4435, 0x00404536, 0x00404536, 0x0043473B, 0x0043473B, 0x0043473B, 0x0044483C, 0x00464A3E, 0x00474B3F, 0x00474B3F, 0x00474B3F, 0x0043473B, 0x0042463A, 0x0042463A, 0x0045493D, 0x00484C40,
        0x00494D41, 0x00464A3E, 0x0043473B, 0x0043473B, 0x0042463A, 0x00414539, 0x00404438, 0x003F4337, 0x00404438, 0x00414539, 0x0042463A, 0x0041483B, 0x0040473A, 0x003F4639, 0x003F4337, 0x003D4135, 0x003E4034, 0x003E4034, 0x003E4034, 0x003B3F2C,
        0x003F3F33, 0x003C4138, 0x00384235, 0x00424232, 0x0039332C, 0x00142D31, 0x0000404E, 0x0007465B, 0x0008475C, 0x000A495E, 0x000E4D62, 0x00125166, 0x00135267, 0x00115065, 0x000F4E63, 0x00104D67, 0x00164B60, 0x0000425F, 0x0013729D, 0x003088B0,
        0x00003646, 0x001C5E5D, 0x0052B3AF, 0x001A605A, 0x00004640, 0x000D4F4E, 0x00074851, 0x00004557, 0x0000515D, 0x001E6B67, 0x003B7B68, 0x0045736D, 0x00285852, 0x00093C35, 0x00063A33, 0x00194C45, 0x000E3A34, 0x00254D48, 0x00001F1B, 0x0000070C,
        0x00000609, 0x00000606, 0x00020904, 0x00313228, 0x00464132, 0x003F3825, 0x003C311D, 0x00534630, 0x004B3F2D, 0x001C1208, 0x001C130F, 0x001D1516, 0x0022191C, 0x0026181C, 0x001A0C0E, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0x005E6469, 0x0082898C, 0x00B2BABA, 0x00BBC3C2, 0x00C8D0CF, 0x00C9D2CF, 0x00CDD7D1, 0x00BFCFC8, 0x00BCCCC5, 0x00BCCCC5, 0x00B6C4BE, 0x00BECCC6, 0x00B8C4BE, 0x00B4C0BA, 0x00C3CFC9, 0x00C0CCC6, 0x00C2CEC8, 0x00CBD7D1, 0x00CFDBD5, 0x00D1DDD7,
        0x00CFDBD5, 0x00BFCBC5, 0x00B2BEB8, 0x00C5D0CD, 0x00C6D1CE, 0x00B8C3C0, 0x00BAC7C5, 0x00ABB8B6, 0x00A4B2B0, 0x007C8A89, 0x00647271, 0x00828D8B, 0x00828D8B, 0x007B8684, 0x007E8987, 0x00808B89, 0x0056615F, 0x004B5654, 0x00535E5C, 0x002E4E4D,
        0x0018484E, 0x000B3C4C, 0x000C3042, 0x00002735, 0x0000333E, 0x0000374C, 0x00001B3E, 0x0037575C, 0x00ACB1B0, 0x00A4A29A, 0x0043625B, 0x00478383, 0x007AB7C1, 0x0081ADBA, 0x0096B7C0, 0x0052928C, 0x00528986, 0x006FA0AA, 0x0077A3BA, 0x00476578,
        0x003B464A, 0x004D4F49, 0x00646765, 0x00CEC6D7, 0x00A1D5E5, 0x005CCCE2, 0x00279FC3, 0x00096197, 0x003079B7, 0x004AAEE9, 0x001DAADD, 0x0025A5E6, 0x0021A2E1, 0x002DABE5, 0x0030AADE, 0x00198BBA, 0x00248DB8, 0x0016759D, 0x003089AE, 0x00176492,
        0x000A4B5A, 0x003A514D, 0x002A4046, 0x00217295, 0x003CA8E8, 0x002B94DD, 0x002BA3E4, 0x002AA5E3, 0x0031A8E0, 0x002598CB, 0x0035A3D3, 0x003CA5D1, 0x003993B5, 0x00347E90, 0x0048848A, 0x00357D9B, 0x002983A2, 0x0050899E, 0x00738885, 0x007C9384,
        0x0098A6A2, 0x003E3636, 0x0049483A, 0x00565547, 0x00565547, 0x00535345, 0x00515143, 0x00505042, 0x004C4F40, 0x004B4E3F, 0x00F4F5F4, 0x00838478, 0x00565747, 0x008C8C82, 0x004F4F41, 0x004D5041, 0x005E6154, 0x00E8E8E7, 0x00FDFDFD, 0x007C7D71,
        0x004E4E40, 0x004D4D3F, 0x00A5A69F, 0x00FFFFFF, 0x00C8C9C4, 0x00505141, 0x004D4E3F, 0x004D4D3F, 0x004D4D3F, 0x004D5041, 0x00515445, 0x00545647, 0x00535345, 0x00545446, 0x004B4E3F, 0x0043443A, 0x00525247, 0x00555546, 0x00555545, 0x00515242,
        0x004E5040, 0x004E5040, 0x004E4F3F, 0x004F5040, 0x004E4F3F, 0x004D4E3E, 0x00525344, 0x00525546, 0x004E5142, 0x00515445, 0x004E5142, 0x004E5142, 0x00505344, 0x004B4E3F, 0x004D5041, 0x00565646, 0x00555545, 0x00555545, 0x00565646, 0x00555545,
        0x00515242, 0x004E4F3F, 0x004D4E3E, 0x00505141, 0x004E4F3F, 0x004E4F3F, 0x00535444, 0x00545748, 0x0083857A, 0x00F5F5F4, 0x004F5243, 0x004F5243, 0x00515445, 0x004B4E3F, 0x004B4E3F, 0x00454838, 0x001C3023, 0x00888A84, 0x007C9286, 0x00698578,
        0x006E8F8B, 0x001E6F77, 0x00176E88, 0x0012687C, 0x00107195, 0x001F8FC3, 0x002195CC, 0x00258FBE, 0x00167394, 0x00004A66, 0x00065772, 0x001A6C96, 0x0026353E, 0x004B4A36, 0x003B4C37, 0x00393B35, 0x00423D34, 0x003F4637, 0x003D4437, 0x00404438,
        0x003F4337, 0x003F4337, 0x003F4337, 0x003F4337, 0x003F4337, 0x003E4236, 0x003D4135, 0x0041483B, 0x0041483B, 0x0041483B, 0x0042493C, 0x00444B3E, 0x00454C3F, 0x00454C3F, 0x00454C3F, 0x003F453A, 0x003E4439, 0x003E4439, 0x003F453A, 0x0042483D,
        0x0042483D, 0x0040463B, 0x003E4439, 0x0042463A, 0x0042463A, 0x0042463A, 0x00414539, 0x00404438, 0x00404438, 0x00414539, 0x0042463A, 0x003E4439, 0x003D4338, 0x003C4237, 0x003C4035, 0x003A3E33, 0x003C3D33, 0x003D3E34, 0x003E3F35, 0x003F4330,
        0x00434337, 0x0040453C, 0x003B4538, 0x00444434, 0x003A342D, 0x00142D31, 0x0000414F, 0x0006455A, 0x0008475C, 0x000B4A5F, 0x000E4D62, 0x00115065, 0x00125166, 0x00115065, 0x00104F64, 0x00084B66, 0x0013485C, 0x00074458, 0x002C7C99, 0x0069AEC9,
        0x0056818A, 0x006C9E9C, 0x0071C3C4, 0x006FA4A1, 0x00305C5B, 0x005F9092, 0x004B9099, 0x002B7789, 0x0063A4B3, 0x0096CACA, 0x00A0D1C1, 0x007FA7A6, 0x00477170, 0x00133F3E, 0x003B6A68, 0x007EAAA9, 0x00769E9D, 0x007EA0A0, 0x00607F80, 0x004D6166,
        0x0048595C, 0x004B5757, 0x003C433E, 0x0044453B, 0x004E493A, 0x00544D3A, 0x00564B37, 0x004E4E3E, 0x004D5145, 0x00424F47, 0x003E5351, 0x00496768, 0x004C6F72, 0x00507678, 0x004C7375, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0x005C6267, 0x007B8285, 0x00A3ABAB, 0x00ADB5B4, 0x00C8D0CF, 0x00C6CFCC, 0x00B3BDB7, 0x00B8C8C1, 0x00C1D1CA, 0x00C5D5CE, 0x00B0C0B9, 0x00B3C1BB, 0x00B2C0BA, 0x00B3BFB9, 0x00B8C4BE, 0x00BBC7C1, 0x00C7D3CD, 0x00C5D1CB, 0x00BBC7C1, 0x00B9C5BF,
        0x00C2CEC8, 0x00CBD7D1, 0x00C5D1CB, 0x00CBD6D3, 0x00C1CCC9, 0x00A9B4B1, 0x00C1CECC, 0x00BCC9C7, 0x00ACBAB9, 0x00879594, 0x006C7A79, 0x007C8785, 0x007E8987, 0x007A8583, 0x0075807E, 0x00788381, 0x00576260, 0x004B5654, 0x00515C5A, 0x00325148,
        0x001D4948, 0x00123F4A, 0x001A3C4C, 0x00153F4B, 0x0014505C, 0x0018546C, 0x00063257, 0x00354F5B, 0x00A1A4A8, 0x00A3A69D, 0x00486B5D, 0x001C4F48, 0x0052777B, 0x00385559, 0x00527977, 0x002D797F, 0x00266972, 0x00648E93, 0x007B8781, 0x004C4A40,
        0x004D4C48, 0x004C504A, 0x004E4E40, 0x00817A81, 0x00417078, 0x00238B9C, 0x0050C5E4, 0x0040A0CE, 0x00186CA0, 0x001B82B3, 0x002AACD7, 0x0027A2E0, 0x002FACE9, 0x0024A2DC, 0x0024A2D9, 0x0032AADE, 0x001A89BB, 0x002389BA, 0x001877A8, 0x002689BD,
        0x00226F82, 0x006B857F, 0x00546C6C, 0x00247894, 0x002B9FDA, 0x0031A2E5, 0x0026A3DD, 0x0025A5E0, 0x0034AADD, 0x001783AD, 0x001178A5, 0x003EA7D8, 0x003BA2D3, 0x00096991, 0x00328AA8, 0x002581AC, 0x00157EA5, 0x0042869D, 0x00738F89, 0x007E9A86,
        0x008FA299, 0x00313230, 0x00475043, 0x00545345, 0x00535244, 0x00515143, 0x00505042, 0x004E4E40, 0x004B4E3F, 0x004B4E3F, 0x00F4F5F4, 0x00838478, 0x00515242, 0x00E3E3E0, 0x0087887D, 0x004C4F40, 0x004B4E3F, 0x00797B70, 0x00FDFDFD, 0x00E9E9E7,
        0x00656557, 0x004F4F41, 0x004F5243, 0x00C9C9C5, 0x00FFFFFF, 0x00A4A49C, 0x004F5041, 0x004E4E40, 0x004D4D3F, 0x004D5041, 0x00515344, 0x00545646, 0x00535345, 0x004D4D3F, 0x00515445, 0x004B4E45, 0x004D4E42, 0x00515343, 0x00525343, 0x004F5242,
        0x004F5141, 0x004D4F40, 0x004F5142, 0x004E5040, 0x004E4F3F, 0x004D4E3E, 0x00535344, 0x004E5142, 0x004A4D3E, 0x004E5142, 0x004C4F40, 0x004E5142, 0x00515445, 0x004D5041, 0x004E5142, 0x00575747, 0x00565646, 0x00565646, 0x00565646, 0x00525242,
        0x004E4F3F, 0x004E4F3F, 0x004E4F3F, 0x004F5040, 0x004E4F3F, 0x004D4E3E, 0x00535444, 0x00525546, 0x00818379, 0x00F5F5F4, 0x004E5142, 0x004E5142, 0x00505344, 0x004B4E3F, 0x004C4F40, 0x004C4C3E, 0x001E3225, 0x008B9087, 0x007E9888, 0x00668778,
        0x00729898, 0x00287E90, 0x00237BA4, 0x002B8FA8, 0x00228CB5, 0x001A8EC5, 0x001B8CC5, 0x002E97C8, 0x003497BD, 0x00127496, 0x00006285, 0x001E709A, 0x0023323B, 0x0041402C, 0x00374833, 0x003F413B, 0x0048433A, 0x003F4637, 0x003C4336, 0x00414539,
        0x00404438, 0x00404438, 0x00414539, 0x0042463A, 0x00414539, 0x003F4337, 0x003C4034, 0x003E4538, 0x003C4336, 0x003C4336, 0x003C4336, 0x003E4538, 0x003F4639, 0x003E4538, 0x003D4437, 0x003D4338, 0x003C4237, 0x003C4237, 0x003D4338, 0x003D4338,
        0x003D4338, 0x003D4338, 0x003C4237, 0x003B3F33, 0x003C4034, 0x003E4236, 0x003D4135, 0x003C4034, 0x003A3E32, 0x003B3F33, 0x003B3F33, 0x003C4237, 0x003C4237, 0x003C4237, 0x003C4035, 0x003A3E33, 0x003D3E34, 0x003F4036, 0x00414238, 0x003D412E,
        0x00414135, 0x003D4239, 0x00384235, 0x00414131, 0x0039332C, 0x00162F33, 0x00034452, 0x0008475C, 0x000A495E, 0x000C4B60, 0x000D4C61, 0x000E4D62, 0x000F4E63, 0x00104F64, 0x00115065, 0x00004B68, 0x001A4E5B, 0x00164346, 0x00235659, 0x004F7073,
        0x00515752, 0x005C6C6B, 0x00255A64, 0x00566D6F, 0x0047454B, 0x004A5A61, 0x002B747C, 0x001D6D7E, 0x00557489, 0x009699A1, 0x00819287, 0x00375659, 0x003F6063, 0x0026494C, 0x003B5E61, 0x0085A6A9, 0x00A0BDC1, 0x0096AFB3, 0x0085999E, 0x008EA2A7,
        0x00809194, 0x00869292, 0x00646B66, 0x00404137, 0x003F3A2B, 0x00564F3C, 0x00574C38, 0x00413E3A, 0x003C4443, 0x00617C80, 0x0046787E, 0x005EA7AF, 0x0056B1B8, 0x0053BEC2, 0x0058C9CB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0x00595F64, 0x00848B8E, 0x00B1B9B9, 0x00AAB2B1, 0x00BFC7C6, 0x00D2DBD8, 0x00D3DDD7, 0x00DBEDE6, 0x00D0E0D9, 0x00D8E8E1, 0x00C8D8D1, 0x00BAC8C2, 0x00B1BFB9, 0x00BFCBC5, 0x00C4D0CA, 0x00B3BFB9, 0x00C2CEC8, 0x00C1CDC7, 0x00C0CCC6, 0x00B9C5BF,
        0x00B6C2BC, 0x00C6D2CC, 0x00CDD9D3, 0x00CCD7D4, 0x00BEC9C6, 0x0099A4A2, 0x00B4C1BF, 0x00B2BEBE, 0x00A2B0AF, 0x00849291, 0x00637072, 0x00727D7B, 0x0076817F, 0x007E8987, 0x00727D7B, 0x006E7977, 0x00636E6C, 0x005B6664, 0x00485351, 0x00364442,
        0x00324F56, 0x001F4355, 0x00153A50, 0x000D4558, 0x00085C6E, 0x0017718F, 0x00246F9B, 0x005D707D, 0x009FA1A2, 0x00C0C8BD, 0x004C7161, 0x00376259, 0x0094ABAD, 0x0097AEB0, 0x0075A39D, 0x00255063, 0x00114159, 0x0097BABE, 0x00D1DDBF, 0x006B724F,
        0x00445B4D, 0x003A524A, 0x002A3622, 0x00193431, 0x002D575C, 0x0000394B, 0x0008708D, 0x0046C4E7, 0x001C9DC4, 0x00006991, 0x003198BF, 0x002CA4E0, 0x0027A1DD, 0x002AA7E1, 0x002BAAE1, 0x002FA8E0, 0x0034A5DD, 0x00258CC3, 0x001F83BA, 0x00087AAF,
        0x00308898, 0x004A6B5D, 0x00A7C4BB, 0x0058B3C8, 0x00209DD0, 0x0034ACE7, 0x0026A7D8, 0x001EA4DA, 0x0037B0DC, 0x00339DC2, 0x0000618B, 0x00026CA1, 0x0040B0EC, 0x0031A1D6, 0x002A99C7, 0x00349FD2, 0x00249BC8, 0x004393AA, 0x00638880, 0x006C9078,
        0x0089A396, 0x002B3633, 0x00394D40, 0x00525143, 0x00515042, 0x004F4F41, 0x004E4E40, 0x004D4D3F, 0x004A4D3E, 0x004B4E3F, 0x00F4F5F4, 0x00828377, 0x004B4C3C, 0x00E8E8E6, 0x00EEEEED, 0x00626457, 0x004B4E3F, 0x004A4D3E, 0x00A4A49C, 0x00FFFFFF,
        0x00CCCCC8, 0x00535445, 0x004C4F40, 0x005C5F51, 0x00E6E6E4, 0x00FFFFFF, 0x00D5D5D1, 0x00D3D3D0, 0x00D2D2CF, 0x00D2D2CF, 0x00D2D2CF, 0x00D2D3CF, 0x00D2D2CE, 0x00D1D1CD, 0x00D1D2CE, 0x00D0D1CF, 0x00D2D2CF, 0x00D2D2CF, 0x00D2D2CE, 0x00D3D3CF,
        0x00D3D4D0, 0x00D3D3CF, 0x00D3D3CF, 0x00D2D3CF, 0x00D2D2CE, 0x00D2D2CE, 0x00D1D1CD, 0x00D1D2CF, 0x00D1D3CF, 0x00D1D2CF, 0x00D1D2CE, 0x00D1D2CE, 0x00D2D3CF, 0x00D2D3CF, 0x00D2D3CF, 0x00D4D4D0, 0x00D4D4D0, 0x00D4D4D0, 0x00D4D4D0, 0x00D2D2CE,
        0x00D2D2CE, 0x00D2D2CE, 0x00D2D2CE, 0x00D2D2CE, 0x00D3D3CF, 0x00CFCFCB, 0x00808175, 0x004E5142, 0x007F8176, 0x00F5F5F4, 0x004C4F40, 0x004E5142, 0x00515445, 0x004D5041, 0x004E5142, 0x0049473C, 0x001D2F22, 0x008A9085, 0x007C9684, 0x005D8371,
        0x00699294, 0x00217892, 0x001570A3, 0x00077593, 0x002394BF, 0x00269BD2, 0x001A8BC4, 0x00238ABB, 0x003299C0, 0x002C97BD, 0x001082AB, 0x0012648E, 0x0022313A, 0x00403F2B, 0x002D3E29, 0x0032342E, 0x003B362D, 0x00313829, 0x002C3326, 0x0032362A,
        0x0032362A, 0x0033372B, 0x0034382C, 0x00363A2E, 0x0035392D, 0x0032362A, 0x002F3327, 0x00343B2E, 0x0032392C, 0x0030372A, 0x0030372A, 0x0031382B, 0x0031382B, 0x0030372A, 0x002E3528, 0x002E3429, 0x002E3429, 0x002E3429, 0x002D3328, 0x002C3227,
        0x002C3227, 0x002D3328, 0x002D3328, 0x002E3226, 0x00303428, 0x0032362A, 0x0032362A, 0x00303428, 0x002F3327, 0x002E3226, 0x002F3327, 0x002D3328, 0x002E3429, 0x002E3429, 0x002E3227, 0x002D3126, 0x00303127, 0x0033342A, 0x0036372D, 0x00313522,
        0x00353529, 0x0031362D, 0x002C3629, 0x00373727, 0x00322C25, 0x00122B2F, 0x00024351, 0x000C4B60, 0x000C4B60, 0x000D4C61, 0x000C4B60, 0x000B4A5F, 0x000C4B60, 0x000F4E63, 0x00115065, 0x000A4B67, 0x0010475C, 0x0000415A, 0x00167196, 0x003184A4,
        0x00002D3A, 0x00124E4D, 0x003C9794, 0x00175954, 0x00003632, 0x00114D4D, 0x0000444D, 0x00004456, 0x00095462, 0x001C5E5C, 0x0034705E, 0x0046797C, 0x00194E51, 0x00073E41, 0x0000373A, 0x00154A4D, 0x00649498, 0x005C898D, 0x00083035, 0x00000E13,
        0x00000205, 0x00000404, 0x00040B06, 0x00323329, 0x004A4536, 0x00423B28, 0x00332814, 0x00554735, 0x00493E30, 0x001F1A11, 0x00151312, 0x00161819, 0x00181B1F, 0x001A1D21, 0x00111418, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0x005B6265, 0x0080878A, 0x00A6AEAE, 0x009FA7A7, 0x00B9C1C0, 0x00C3CBCA, 0x00B1B9B8, 0x00D4E1D9, 0x00D3E0D8, 0x00D5E2DA, 0x00CAD7CF, 0x00B7C4BC, 0x00CFDCD4, 0x00CCD9D1, 0x00B6C3BB, 0x00A6B4B0, 0x00ABB9B5, 0x00B8C6C2, 0x00B8C6C2, 0x00B7C5C1,
        0x00B6C4C0, 0x00AEBCB8, 0x00B5C3BF, 0x00BBC7C1, 0x00B6C2BC, 0x00AFBBB5, 0x00B4C2BE, 0x00ADBBB7, 0x00A8B6B4, 0x00758381, 0x006A7876, 0x00808784, 0x00878E8B, 0x008D9491, 0x00767D7A, 0x00737A77, 0x006D7471, 0x00666D6A, 0x00606764, 0x00374141,
        0x002D4D53, 0x00194251, 0x00133241, 0x00082730, 0x00013135, 0x00003642, 0x0020546B, 0x004E796C, 0x0096A4A0, 0x008D999B, 0x004E7779, 0x004D8586, 0x00557B7F, 0x002E4D50, 0x00719D9C, 0x0000514E, 0x00145A59, 0x005A8685, 0x007A8F8D, 0x00555D5D,
        0x00434D4D, 0x003F5452, 0x00193837, 0x0005503A, 0x001F5A52, 0x000A3E4A, 0x00004A61, 0x00006F89, 0x005CD6EC, 0x00258799, 0x000F5465, 0x002B96B8, 0x0037ADD7, 0x0029A9E4, 0x0017A2E7, 0x0019A1E9, 0x0028A6E7, 0x0037A7DC, 0x00288EB9, 0x001A89B1,
        0x002189AE, 0x003491B2, 0x00277EA0, 0x002782A9, 0x003CA2D6, 0x002DA4E2, 0x001B9CE1, 0x0026A6E1, 0x001D9ED7, 0x002DABE1, 0x00269DCE, 0x00005E87, 0x00116E8D, 0x004391A8, 0x0042879A, 0x001B87B1, 0x002995AD, 0x0039959A, 0x00548F8B, 0x00778C8D,
        0x00A2A1A3, 0x002E322C, 0x0040503F, 0x00505344, 0x004E5142, 0x004C4F40, 0x004B4E3F, 0x004B4E3F, 0x004C4F40, 0x004B4E3F, 0x00F4F5F4, 0x007F8177, 0x004F5243, 0x00E1E1DF, 0x00FFFFFF, 0x00CFD0CC, 0x004F5244, 0x004C4F40, 0x00545444, 0x00C8C8C3,
        0x00FFFFFF, 0x00A4A59D, 0x004C4E3F, 0x004B4E3F, 0x0075776B, 0x00ECECEA, 0x00FAFAFA, 0x00FAFAFA, 0x00FAFAFA, 0x00FAFAFA, 0x00FAFAFA, 0x00FAFAFA, 0x00FAFAFA, 0x00FAFAFA, 0x00FAFAFA, 0x00FAFAFA, 0x00FAFAFA, 0x00FAFAFA, 0x00FAFAFA, 0x00FAFAFA,
        0x00FAFAFA, 0x00FAFAFA, 0x00FAFAFA, 0x00FAFAFA, 0x00FAFAFA, 0x00FAFAFA, 0x00FAFAFA, 0x00FAFAFA, 0x00FAFAFA, 0x00FAFAFA, 0x00FAFAFA, 0x00FAFAFA, 0x00FAFAFA, 0x00FAFAFA, 0x00FAFAFA, 0x00FAFAFA, 0x00FAFAFA, 0x00FAFAFA, 0x00FAFAFA, 0x00FAFAFA,
        0x00FAFAFA, 0x00FAFAFA, 0x00FAFAFA, 0x00FAFAFA, 0x00FAFAFA, 0x00F8F8F7, 0x008D8E84, 0x004B5041, 0x00808379, 0x00F4F5F4, 0x00494E3F, 0x00494E3F, 0x004D5243, 0x004E5344, 0x004D5243, 0x00434B40, 0x00272B1F, 0x008C8E82, 0x00869187, 0x00587778,
        0x005998A6, 0x002786A0, 0x001486AA, 0x002C8992, 0x00168698, 0x00149AB8, 0x00129CCA, 0x000886C0, 0x00198CC9, 0x002A9BD4, 0x002195CA, 0x000478B3, 0x000C4E6B, 0x0053686A, 0x00253331, 0x004D6A61, 0x00103521, 0x00507261, 0x0013342D, 0x0051625E,
        0x0019362D, 0x00335C4D, 0x00224737, 0x00405A4C, 0x00304438, 0x00364D45, 0x002C4842, 0x00304B47, 0x00374E46, 0x00314237, 0x003A5444, 0x001E412D, 0x0040634F, 0x00213829, 0x004A564A, 0x00152D25, 0x0056685B, 0x00212E1E, 0x0056655D, 0x00203537,
        0x00455F65, 0x00293F3D, 0x004E5F54, 0x00193C3F, 0x0035585B, 0x001D4043, 0x00335659, 0x001F4245, 0x002F5255, 0x00274A4D, 0x00284B4E, 0x002D5053, 0x00224548, 0x0035585B, 0x00133639, 0x003D6063, 0x0014373A, 0x00395C5F, 0x0014373A, 0x004F5B5B,
        0x002A3C3B, 0x004C5957, 0x0025282D, 0x004D5D6E, 0x001B5370, 0x00499CC9, 0x00015890, 0x0009495B, 0x000A4A5C, 0x000D4D5F, 0x00104F63, 0x000F4E62, 0x000D4C61, 0x000E4D62, 0x00115065, 0x000E5063, 0x00114F61, 0x00043C4D, 0x004F8390, 0x0078ABB5,
        0x00295B61, 0x00558A8D, 0x008FC7C8, 0x0047868E, 0x0024534B, 0x00527E77, 0x002E707B, 0x000D5F71, 0x0064A8AF, 0x009DC5C3, 0x00C4DCDC, 0x0095B3B8, 0x00527277, 0x0022484A, 0x00335959, 0x0093B8B6, 0x0084A5A1, 0x0087A4A1, 0x006B8480, 0x00425856,
        0x00344F53, 0x002B454C, 0x00283837, 0x003C3E32, 0x00564F3B, 0x00534C39, 0x00484439, 0x00574A3C, 0x0048463C, 0x00394743, 0x00284748, 0x00316064, 0x00427980, 0x003C7780, 0x003C7A82, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0x005D6467, 0x007C8386, 0x00A7AFAF, 0x00B2BABA, 0x00BAC2C1, 0x00B6BEBD, 0x00C0C8C7, 0x00CCD9D1, 0x00C7D4CC, 0x00D5E2DA, 0x00DBE8E0, 0x00C0CDC5, 0x00BAC7BF, 0x00B9C6BE, 0x00C0CDC5, 0x00BCCAC6, 0x00BCCAC6, 0x00B5C3BF, 0x00B5C3BF, 0x00B6C4C0,
        0x00B8C6C2, 0x00C2D0CC, 0x00C6D4D0, 0x00B9C5BF, 0x00B9C5BF, 0x00B7C3BD, 0x00B5C3BF, 0x00AAB8B4, 0x00B0BEBC, 0x00808E8C, 0x0063716F, 0x007E8582, 0x008B928F, 0x008E9592, 0x00767D7A, 0x00787F7C, 0x00707774, 0x00656C69, 0x00656C69, 0x00354141,
        0x00204248, 0x000B3443, 0x000A2938, 0x0006252E, 0x00003034, 0x00002A37, 0x00053950, 0x002F5D57, 0x003B5052, 0x0044565D, 0x00427077, 0x003B777D, 0x001E4C54, 0x001A3F47, 0x0075A5A9, 0x006B9B9C, 0x0056807F, 0x006E8F8B, 0x006F8681, 0x00283831,
        0x004D5A52, 0x00434E46, 0x00404B43, 0x00B8C9C0, 0x0091B9B8, 0x00216670, 0x00004D64, 0x00075070, 0x008CD2F0, 0x003F90A5, 0x0011717E, 0x004CABC5, 0x003199BE, 0x002DA3D7, 0x002CACED, 0x001FA3E9, 0x0026A6E7, 0x0035ACE4, 0x0032A2D6, 0x001D90BD,
        0x001A86B0, 0x002687AD, 0x001C779C, 0x00217DA6, 0x003399CA, 0x002699D2, 0x001591D1, 0x002AA4E0, 0x0027A3DF, 0x0021A0D7, 0x002DAADC, 0x002396C1, 0x0004688B, 0x00004662, 0x000A546C, 0x0025698C, 0x005BA3B5, 0x00589B9C, 0x005E8B88, 0x00768889,
        0x0095969A, 0x0030342E, 0x00475444, 0x004F5243, 0x004E5142, 0x004C4F40, 0x004C4F40, 0x004D5041, 0x004D5041, 0x004C4F40, 0x00F4F5F4, 0x007D7F74, 0x004D5041, 0x00E1E1DF, 0x00FFFFFF, 0x00FFFFFF, 0x00A9AAA3, 0x00515243, 0x00545545, 0x00616254,
        0x00E5E5E3, 0x00FDFDFD, 0x0078796E, 0x004C4E3F, 0x004B4E3F, 0x00575848, 0x00525344, 0x00535445, 0x00555647, 0x00525547, 0x00525547, 0x00515446, 0x00595A4A, 0x00535547, 0x004D5042, 0x00535648, 0x00585949, 0x00565747, 0x00595949, 0x004F4F40,
        0x00545546, 0x00575949, 0x00565949, 0x00555848, 0x00555848, 0x00525546, 0x00545647, 0x00515647, 0x0054594A, 0x00555A4B, 0x00535849, 0x00525748, 0x00535849, 0x00525748, 0x004F5446, 0x00585949, 0x00595A4A, 0x005A5C4C, 0x005E5F4E, 0x00535445,
        0x00535445, 0x00555647, 0x00535445, 0x00525344, 0x00545546, 0x00545546, 0x004D4E3E, 0x004B5041, 0x0081847A, 0x00F5F5F4, 0x004A4F40, 0x004A4F40, 0x004C5142, 0x004C5142, 0x004A4F40, 0x0041473C, 0x002E3226, 0x008A9085, 0x00829189, 0x00547370,
        0x00548A91, 0x004693A3, 0x00348FA4, 0x007FB9BF, 0x003F909F, 0x001D89A8, 0x002098C6, 0x001992CA, 0x001F90CE, 0x002497D0, 0x001E93CA, 0x001E9BD5, 0x00277D9B, 0x0070A4AA, 0x00386366, 0x00668F91, 0x0044675D, 0x0077988A, 0x003A5D59, 0x00678988,
        0x0035615B, 0x0054887E, 0x004D7B6F, 0x00698C82, 0x00486760, 0x004F726E, 0x004B7875, 0x00436C6F, 0x006A8B8E, 0x00486262, 0x005B7A77, 0x003B645F, 0x005B8A87, 0x003F6668, 0x007A989D, 0x00285A66, 0x0049767A, 0x003B6362, 0x00729CA1, 0x00558694,
        0x006CA0B0, 0x004D7E86, 0x00739F9E, 0x00568A91, 0x00689CA3, 0x005A8E95, 0x00699DA4, 0x005B8F96, 0x0064989F, 0x005E9299, 0x005C9097, 0x0062969D, 0x005D9198, 0x00679BA2, 0x00558990, 0x006B9FA6, 0x00578B92, 0x006B9FA6, 0x0053878E, 0x006EA2AF,
        0x004A858E, 0x00609396, 0x003E5D60, 0x006B8C8F, 0x00245D5F, 0x004B9198, 0x0073B3BE, 0x000F4F61, 0x000C4C5E, 0x000B4B5D, 0x000E4D61, 0x000E4D61, 0x000B4A5F, 0x000C4B60, 0x00115065, 0x000B4D60, 0x000F4D5F, 0x000E4657, 0x00245966, 0x004C7F89,
        0x003A6E74, 0x004E8588, 0x00619A9B, 0x00818E9E, 0x003E3E3E, 0x00747A79, 0x00698D9D, 0x00427E94, 0x00427982, 0x007FA4A2, 0x00768E8E, 0x00305357, 0x00496E72, 0x00284F51, 0x00396160, 0x0080A7A5, 0x008DB0AC, 0x0086A5A2, 0x008AA5A1, 0x008AA09E,
        0x0086A1A5, 0x007C969D, 0x005E6E6D, 0x004B4D41, 0x004B4430, 0x0049422F, 0x0049453A, 0x00493C2C, 0x0056564A, 0x005C736B, 0x00568582, 0x00579B9A, 0x0059ACAD, 0x0056B3B4, 0x0059BBBB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0x00575E61, 0x00838A8D, 0x00BAC2C2, 0x00B6BEBE, 0x00B8C0BF, 0x00C3CBCA, 0x00D4DCDB, 0x00CBD7D1, 0x00C4D0CA, 0x00BAC6C0, 0x00ADB9B3, 0x00ABB7B1, 0x00C3CFC9, 0x00BDC9C3, 0x00ABB7B1, 0x00ABB9B5, 0x00BDCBC7, 0x00BDCBC7, 0x00BAC8C4, 0x00B3C1BD,
        0x00B6C4C0, 0x00CAD8D4, 0x00C7D5D1, 0x00AFBBB5, 0x00B1BDB7, 0x00B0BCB6, 0x00A3B1AD, 0x0097A5A1, 0x00AAB8B6, 0x007F8D8B, 0x00556361, 0x0078817E, 0x0087908D, 0x0089928F, 0x00707976, 0x00757E7B, 0x006B7471, 0x00606966, 0x00656E6B, 0x00344143,
        0x00143840, 0x00002B3A, 0x00062737, 0x0007262F, 0x0006363C, 0x00002E3B, 0x00003148, 0x000D4147, 0x00193944, 0x00244352, 0x00194D5D, 0x000C4D5C, 0x000A4352, 0x001E4F5D, 0x003C707C, 0x00617177, 0x0063787A, 0x008DA9A9, 0x0086A6A1, 0x002E4B42,
        0x00465A4E, 0x00434B40, 0x00646458, 0x00C9C7C7, 0x0089AEB2, 0x00509AA6, 0x003A889F, 0x00225F7F, 0x005D94B3, 0x0026758A, 0x0050BAC5, 0x00438FA1, 0x000F647E, 0x002B8FB9, 0x0044B5ED, 0x0026A2E2, 0x0020A0E1, 0x0026A7E6, 0x0025A3DE, 0x0030A7DE,
        0x001D8EC0, 0x001F88B4, 0x002587B1, 0x002B8DB7, 0x003096C6, 0x002795C9, 0x00289CD5, 0x001A89C7, 0x00279CD9, 0x0025A3DD, 0x0025A7DC, 0x002BA7D7, 0x002D9BC5, 0x0008668A, 0x00003555, 0x00456277, 0x0082A6B0, 0x00618987, 0x00597B75, 0x00748385,
        0x008D9295, 0x002B322B, 0x00384432, 0x004B4E3F, 0x004B4E3F, 0x004A4D3E, 0x004B4E3F, 0x004C4F40, 0x004C4F40, 0x004B4E3F, 0x00F4F4F4, 0x007C7E73, 0x004C4F40, 0x00E1E1DF, 0x00FFFFFF, 0x00FFFFFF, 0x00A9AAA2, 0x00555545, 0x00575747, 0x00636355,
        0x00E5E5E3, 0x00FDFDFD, 0x007E7E72, 0x004F5141, 0x004D4F40, 0x00545749, 0x00585B4D, 0x0055584A, 0x00555547, 0x00535648, 0x00545749, 0x00545749, 0x005A5B4D, 0x00525445, 0x004F5244, 0x0056584B, 0x005A5B4C, 0x00595A4B, 0x005B5B4C, 0x005A5A4B,
        0x00565748, 0x00585849, 0x005B5C4D, 0x0058594A, 0x00575849, 0x00595A4C, 0x0057594B, 0x0053584A, 0x00565B4D, 0x00585C4E, 0x00565A4C, 0x0055594B, 0x00565B4D, 0x0054594B, 0x00515648, 0x00585B4C, 0x00595B4C, 0x00595C4D, 0x005C5E4E, 0x00545748,
        0x00565748, 0x00565748, 0x00555647, 0x00555647, 0x00575849, 0x00575848, 0x004F5040, 0x004A4F40, 0x0081847A, 0x00F5F5F4, 0x004C5142, 0x004B5041, 0x004C5142, 0x004B5041, 0x00484D3E, 0x0045473B, 0x00303429, 0x00848D83, 0x0082958C, 0x0062807B,
        0x00668E8C, 0x0074A6A6, 0x00548C8D, 0x00829799, 0x002E5B68, 0x00055671, 0x00218AB5, 0x00289CD3, 0x002498D3, 0x002296D1, 0x002195CE, 0x001B99D4, 0x001B87A6, 0x002B848F, 0x0013616E, 0x00316D79, 0x00557C7E, 0x00678A86, 0x00537D7C, 0x0041797E,
        0x001C5C5D, 0x00337270, 0x00568D8A, 0x0074A09F, 0x005F8B8C, 0x003D7477, 0x0024676A, 0x002E6B75, 0x0063949E, 0x00608790, 0x004D767F, 0x003F767F, 0x0021616C, 0x00246476, 0x004B859B, 0x004D8983, 0x00478379, 0x00488882, 0x00318089, 0x001F82A0,
        0x001B8EB9, 0x000C84B2, 0x001C93C0, 0x002183AD, 0x002688B2, 0x002789B3, 0x002D8FB9, 0x002A8CB6, 0x002D8FB9, 0x002C8EB8, 0x002A8CB6, 0x00298BB5, 0x002A8CB6, 0x002D8FB9, 0x00298BB5, 0x002A8CB6, 0x002C8EB8, 0x002F91BB, 0x002385AF, 0x002690C5,
        0x001487B4, 0x00238BB0, 0x0004526F, 0x00094B5D, 0x00004148, 0x001F5F5F, 0x0076A5A3, 0x00135365, 0x000C4C5E, 0x0009495B, 0x000D4C60, 0x000D4C60, 0x0009485D, 0x000A495E, 0x00104F64, 0x00105166, 0x000D4A5E, 0x00124C5F, 0x00033A49, 0x0000323E,
        0x0000353C, 0x00124C51, 0x00023D3F, 0x0003424A, 0x00114038, 0x001A4B43, 0x00004650, 0x00004455, 0x00004B51, 0x00316460, 0x00587D7B, 0x00557B7F, 0x00214A4D, 0x000C3839, 0x000B3736, 0x00234E4B, 0x00123733, 0x0033524F, 0x001A3833, 0x00001412,
        0x00001115, 0x0000161D, 0x000E1E1D, 0x00333529, 0x004E4733, 0x003E3724, 0x00252116, 0x004D412F, 0x00423B2C, 0x00232119, 0x000E1011, 0x000F1119, 0x00181622, 0x00231929, 0x00261929, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0x0051585B, 0x0080878A, 0x00B7BFBF, 0x00A7AFAF, 0x00A7AFAE, 0x00B9C1C0, 0x00CDD5D4, 0x00B5C1BB, 0x00C3CFC9, 0x00D1DDD7, 0x00C8D4CE, 0x00B9C5BF, 0x00B7C3BD, 0x00ACB8B2, 0x00A6B2AC, 0x009DABA7, 0x00B5C3BF, 0x00C7D5D1, 0x00C2D0CC, 0x00B3C1BD,
        0x00B5C3BF, 0x00BAC8C4, 0x00ADBBB7, 0x00A7B3AD, 0x00B0BCB6, 0x00B6C2BC, 0x00AFBDB9, 0x00ADBBB7, 0x00B9C7C5, 0x00879593, 0x005E6C6A, 0x007B8481, 0x00838C89, 0x0087908D, 0x00737C79, 0x00737C79, 0x006C7572, 0x00666F6C, 0x0067706D, 0x00334244,
        0x0011363E, 0x00012E3C, 0x00092A3A, 0x0005232E, 0x0008363D, 0x00003645, 0x00063751, 0x00063F4E, 0x000F3D4F, 0x00113D54, 0x00043C55, 0x00004158, 0x0003465B, 0x00185366, 0x000D4354, 0x0013333E, 0x000F333D, 0x00224B54, 0x001C484F, 0x00062F32,
        0x00092928, 0x00122925, 0x001C2C25, 0x00265154, 0x0025565E, 0x00104A5D, 0x002B738B, 0x004195AF, 0x002A829A, 0x002D8395, 0x00196C7B, 0x00124F59, 0x00004053, 0x000D5F7E, 0x002F8DBB, 0x0038A6E0, 0x002EA9E9, 0x001EA2E2, 0x0019A3E5, 0x002DA8E6,
        0x002197D2, 0x002191C5, 0x00218BBA, 0x00248BB8, 0x002891BD, 0x002993C2, 0x00329ECE, 0x00369DDB, 0x002393CF, 0x00209CD8, 0x0022A7E0, 0x0024A6DB, 0x0039B0E1, 0x002E96C1, 0x00005880, 0x00486371, 0x00739497, 0x005F847C, 0x00668780, 0x00798E8F,
        0x008E9A9C, 0x00333B34, 0x00454D3C, 0x00474A3B, 0x00474A3B, 0x00474A3B, 0x00484B3C, 0x004A4D3E, 0x004A4D3E, 0x00484B3C, 0x00F4F4F3, 0x007B7D72, 0x004C4F40, 0x00E1E1DF, 0x00FFFFFF, 0x00D1D1CD, 0x00565647, 0x00555545, 0x00555545, 0x00C9C9C4,
        0x00FFFFFF, 0x00A5A69E, 0x00545444, 0x00515242, 0x00797B6F, 0x00EDEDEC, 0x00FCFCFC, 0x00FDFDFD, 0x00FDFDFD, 0x00FDFDFD, 0x00FDFDFD, 0x00FDFDFD, 0x00FDFDFD, 0x00FDFDFD, 0x00FDFDFD, 0x00FDFDFD, 0x00FDFDFD, 0x00FDFDFD, 0x00FDFDFD, 0x00FDFDFD,
        0x00FDFDFD, 0x00FDFDFD, 0x00FDFDFD, 0x00FDFDFD, 0x00FDFDFD, 0x00FDFDFD, 0x00FDFDFD, 0x00FDFDFD, 0x00FDFDFD, 0x00FDFDFD, 0x00FDFDFD, 0x00FDFDFD, 0x00FDFDFD, 0x00FDFDFD, 0x00FDFDFD, 0x00FDFDFD, 0x00FDFDFD, 0x00FDFDFD, 0x00FDFDFD, 0x00FDFDFD,
        0x00FDFDFD, 0x00FDFDFD, 0x00FDFDFD, 0x00FDFDFD, 0x00FDFDFD, 0x00FAFAFA, 0x00919288, 0x004A4F40, 0x0081847A, 0x00F5F5F4, 0x004C5142, 0x004B5041, 0x004D5243, 0x004B5041, 0x00484D3E, 0x004C4A3F, 0x002D3126, 0x00808D85, 0x007A9189, 0x0066837A,
        0x006B8D83, 0x007D9F94, 0x00547567, 0x007B8A86, 0x0031575C, 0x000B546A, 0x002A91B8, 0x002AA0D3, 0x001B96D0, 0x001C92CD, 0x002497D0, 0x002194D1, 0x002392B2, 0x0005707E, 0x00288A9C, 0x001F687E, 0x00619098, 0x0052817F, 0x0064A0A0, 0x003C848C,
        0x002F797F, 0x002C7376, 0x004A8789, 0x004C7C80, 0x0051858B, 0x00387981, 0x002A7B82, 0x0029757B, 0x004C8A92, 0x0051828A, 0x00538690, 0x00478792, 0x00348191, 0x0025768B, 0x002C7C95, 0x00748A85, 0x005B736B, 0x00597B75, 0x00205661, 0x001C6D90,
        0x001B7FB6, 0x002690D0, 0x00258FCF, 0x000E85BD, 0x000B82BA, 0x00138AC2, 0x00138AC2, 0x00158CC4, 0x00158CC4, 0x00178EC6, 0x00178EC6, 0x001289C1, 0x00138AC2, 0x001990C8, 0x00138AC2, 0x001188C0, 0x00168DC5, 0x00168DC5, 0x000E85BD, 0x001384C2,
        0x00148FC7, 0x001E93C6, 0x0018749F, 0x0000395A, 0x0000485A, 0x000D464F, 0x005C7E84, 0x00135365, 0x000B4B5D, 0x00074759, 0x000D4C60, 0x000E4D61, 0x0009485D, 0x000A495E, 0x000F4E63, 0x000A4A62, 0x0008475C, 0x00134E62, 0x00174F60, 0x000A414E,
        0x00215C65, 0x0069A7AD, 0x00529296, 0x005F98A1, 0x00638C85, 0x00779D97, 0x004A8692, 0x001F667A, 0x00679EA7, 0x00A8C4C4, 0x00D2DEE0, 0x0078A3A6, 0x003B686B, 0x001D4B4C, 0x002D5C5A, 0x0084AFAC, 0x00668B87, 0x006B8A87, 0x004E6965, 0x003B514F,
        0x00355054, 0x00334D54, 0x002C3C3B, 0x0037392D, 0x004B4430, 0x004B4431, 0x00464237, 0x00604F3C, 0x00554D3C, 0x00363C31, 0x00304340, 0x00395859, 0x003D6266, 0x003C6469, 0x0031595E, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0x005B6265, 0x007C8386, 0x00ABB3B3, 0x00AFB7B7, 0x00A7AFAE, 0x00A3ABAA, 0x00BAC2C1, 0x00B7C3BD, 0x00B4C0BA, 0x00BAC6C0, 0x00B9C5BF, 0x00C4D0CA, 0x00CFDBD5, 0x00C4D0CA, 0x00B3BFB9, 0x00B7C5C1, 0x00ABB9B5, 0x00BBC9C5, 0x00B4C2BE, 0x00ABB9B5,
        0x00B6C4C0, 0x00B3C1BD, 0x00B2C0BC, 0x00A9B5AF, 0x00AAB6B0, 0x00A5B1AB, 0x009EACA8, 0x00AAB8B4, 0x00AFBDBB, 0x00849290, 0x00717F7D, 0x0085908D, 0x007F8A87, 0x00889390, 0x00798481, 0x00727D7A, 0x00707B78, 0x00707B78, 0x00687370, 0x002D4043,
        0x000D363F, 0x00012F40, 0x000A2C3C, 0x0001212C, 0x0004323A, 0x00003242, 0x0004334E, 0x00033E52, 0x00043D53, 0x00063B56, 0x000A425F, 0x00084B66, 0x0000485E, 0x00074B5E, 0x000F4458, 0x0007505E, 0x00004556, 0x00054459, 0x00023C52, 0x000A3F54,
        0x00235567, 0x0020505C, 0x0005363E, 0x00004B51, 0x00084352, 0x001A4B61, 0x00003852, 0x0000536B, 0x00005368, 0x00044D61, 0x000B3E52, 0x000D4550, 0x001A5565, 0x00003F58, 0x00035175, 0x003694C2, 0x003AA9E1, 0x0021A0DD, 0x001BA3E3, 0x001E9CDD,
        0x0029A4E2, 0x0029A1DC, 0x00188ABF, 0x001281B1, 0x00218BBA, 0x002790BC, 0x002990BD, 0x00359CD5, 0x002190C8, 0x001590CA, 0x00199CD5, 0x0024A5DC, 0x002BA5DB, 0x0033A2D4, 0x00389ECF, 0x00266476, 0x00215E62, 0x002F635C, 0x005C857D, 0x00718E8B,
        0x008D9D9C, 0x002A352D, 0x003D4332, 0x00484B3C, 0x00474A3B, 0x00474A3B, 0x00494C3D, 0x004A4D3E, 0x004A4D3E, 0x00484B3C, 0x00F4F4F3, 0x007C7E73, 0x004C4F40, 0x00E8E8E6, 0x00EEEEED, 0x0068685B, 0x00535345, 0x00505344, 0x00A3A49D, 0x00FFFFFF,
        0x00CCCDC8, 0x005B5C4D, 0x00565646, 0x00646456, 0x00E6E7E4, 0x00FFFFFF, 0x00D1D1CE, 0x00CECECA, 0x00CECFCA, 0x00CFD0CC, 0x00CFCFCB, 0x00CECFCB, 0x00CFD0CC, 0x00D0D0CC, 0x00CFD0CB, 0x00D0D1CC, 0x00D1D1CD, 0x00D0D0CC, 0x00D1D1CD, 0x00D1D1CD,
        0x00D0D0CC, 0x00CFCFCB, 0x00D1D1CD, 0x00D2D2CD, 0x00D2D2CE, 0x00D1D2CD, 0x00D0D0CC, 0x00D0D0CC, 0x00D1D2CD, 0x00D0D1CC, 0x00D0D0CC, 0x00CFD0CC, 0x00D0D0CC, 0x00CFCFCB, 0x00CFD0CC, 0x00CFD0CB, 0x00CFD0CB, 0x00CFD0CC, 0x00CFD0CC, 0x00CFD1CC,
        0x00CFD0CC, 0x00CECFCB, 0x00CFCFCB, 0x00CFCFCB, 0x00CFCFCB, 0x00CCCDC8, 0x007D7D71, 0x00494E3F, 0x00808379, 0x00F4F5F4, 0x004A4F40, 0x004B5041, 0x004D5243, 0x004D5243, 0x004B5041, 0x004D4B40, 0x002A2E23, 0x008B9890, 0x007F968E, 0x006A877E,
        0x0072948A, 0x0077998E, 0x00547567, 0x00386159, 0x0012494C, 0x00025466, 0x002691B6, 0x00219CCE, 0x001695CC, 0x001C94CF, 0x002697D0, 0x003193CF, 0x001D7D9B, 0x00248491, 0x002D899A, 0x00176074, 0x001A4E55, 0x00346B68, 0x002E7473, 0x001D6168,
        0x0010575B, 0x00256869, 0x00276061, 0x002F5F61, 0x00205054, 0x001D5B61, 0x000C5A60, 0x0017645D, 0x00225F5B, 0x00376866, 0x00235553, 0x00286868, 0x00146164, 0x00095A62, 0x00105F6C, 0x002B697B, 0x0028636C, 0x00104F4D, 0x00206868, 0x00116773,
        0x003695A9, 0x003190A4, 0x003A93A7, 0x003290AD, 0x00308EAB, 0x00318FAC, 0x00318FAC, 0x002D8BA8, 0x002F8DAA, 0x002E8CA9, 0x003290AD, 0x00308EAB, 0x002C8AA7, 0x003B99B6, 0x002987A4, 0x003391AE, 0x002B89A6, 0x003492AF, 0x002886A3, 0x004290A7,
        0x00308DA2, 0x003A95AA, 0x003C859B, 0x0027667A, 0x00094A58, 0x000D4550, 0x00527680, 0x000E4E60, 0x0008485A, 0x00074759, 0x000D4C60, 0x000F4E62, 0x000B4A5F, 0x000B4A5F, 0x000E4D62, 0x000D4F68, 0x00114F67, 0x00104B5F, 0x000F495C, 0x0005404F,
        0x0015535D, 0x00408189, 0x0024686D, 0x00677C8B, 0x00394140, 0x00687674, 0x00497684, 0x00276A7F, 0x0037757D, 0x00719997, 0x006C8888, 0x00275457, 0x003C696C, 0x001E4C4D, 0x00305F5D, 0x007EA6A4, 0x008BAEAA, 0x0085A29F, 0x007E9793, 0x00889E9C,
        0x00839EA2, 0x0079939A, 0x005C6C6B, 0x004B4D41, 0x004E4733, 0x004E4734, 0x004F4B40, 0x004B4430, 0x00575D4C, 0x00547063, 0x005E938A, 0x0066B2AE, 0x0064BFBC, 0x0063C9C4, 0x005DC7C1, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0x00555C5F, 0x00838A8D, 0x00BCC4C4, 0x00BCC4C4, 0x00BCC4C3, 0x00B4BCBB, 0x00B0B8B7, 0x00A1ACA9, 0x00B7C2BF, 0x00D0DBD8, 0x00BEC9C6, 0x00ACB7B4, 0x00ADB8B5, 0x00B2BDBA, 0x00ADB8B5, 0x00B5C3BF, 0x009DABA7, 0x00BBC9C5, 0x00C0CECA, 0x00B1BFBB,
        0x00AFBDB9, 0x00A2B0AC, 0x00ABB9B5, 0x00A3AFA9, 0x00ABB7B1, 0x00AFBBB5, 0x00B1BFBB, 0x00BFCDC9, 0x00B0BEBC, 0x00768482, 0x0063716F, 0x00889390, 0x00788380, 0x00848F8C, 0x007A8582, 0x00727D7A, 0x00727D7A, 0x00727D7A, 0x00616C69, 0x002A3F41,
        0x000A353E, 0x00003040, 0x000B2F41, 0x00082835, 0x000A3840, 0x00003445, 0x0005324D, 0x00013A4F, 0x00044358, 0x0008435D, 0x000F445F, 0x0003435C, 0x00004C5F, 0x00004556, 0x001A4B5B, 0x00004852, 0x0000495A, 0x00034D67, 0x00054A6B, 0x0000395C,
        0x003C7F9E, 0x001B6179, 0x00004458, 0x00094759, 0x000C475B, 0x00073F58, 0x00134B66, 0x000B4764, 0x000C455E, 0x0014465D, 0x00204B60, 0x000C4A5A, 0x00144F62, 0x00053F55, 0x0001415F, 0x000F5D82, 0x002B89B6, 0x0040B2E7, 0x002FADE7, 0x0025A0E2,
        0x002AA6E6, 0x0029A5E1, 0x00209BD3, 0x001A90C4, 0x001786B8, 0x001C86B5, 0x002A8FBC, 0x002391C1, 0x00299ACC, 0x002BA0D7, 0x001F9AD2, 0x001E99D3, 0x001C93CB, 0x002B9CD4, 0x003CA9DF, 0x002F9ABF, 0x000A657A, 0x00246566, 0x00618B84, 0x0077928E,
        0x0096A7A3, 0x0029372C, 0x00384232, 0x004B4E3F, 0x004A4D3E, 0x004A4D3E, 0x004A4D3E, 0x004B4E3F, 0x004C4F40, 0x004A4D3E, 0x00F4F4F4, 0x007B7D72, 0x004D5041, 0x00E2E2E0, 0x0086867B, 0x004F4F41, 0x00505042, 0x007C7E73, 0x00FDFDFD, 0x00E9E9E7,
        0x00656657, 0x00545546, 0x00565648, 0x00CACAC6, 0x00FFFFFF, 0x00A3A49D, 0x00515344, 0x004E5142, 0x004B4C3C, 0x004E4F3F, 0x004D503F, 0x004D5040, 0x00525243, 0x00525242, 0x00535444, 0x00525343, 0x00545444, 0x00525242, 0x00555545, 0x00565647,
        0x00525343, 0x00515242, 0x00535444, 0x00575848, 0x00585949, 0x00555646, 0x00525343, 0x00515242, 0x00535444, 0x00505141, 0x004E4F3F, 0x00525444, 0x00535545, 0x00515343, 0x00515343, 0x00505343, 0x00505343, 0x00505343, 0x00505343, 0x004F5544,
        0x004D5342, 0x004A503F, 0x004A4F3E, 0x004E4F3F, 0x004A4B3B, 0x004A4B3B, 0x004D4E3E, 0x00494E3F, 0x007F8378, 0x00F4F5F4, 0x004A4F40, 0x004B5041, 0x004D5243, 0x004E5344, 0x004C5142, 0x00494B3F, 0x0025291E, 0x008A9389, 0x0080938A, 0x00607E79,
        0x005F8785, 0x00407272, 0x00144C4D, 0x000A4E47, 0x00014A4E, 0x0001576D, 0x002A95BB, 0x00239ED0, 0x001D9ED5, 0x00239CD4, 0x002698CD, 0x00308AC0, 0x000A556F, 0x0081C1C6, 0x0063A1A9, 0x0089C0C9, 0x003D6968, 0x008ABAB4, 0x003C7675, 0x0081B1B2,
        0x00467B78, 0x006EA49D, 0x004D7C74, 0x008CAEA8, 0x005C7D79, 0x0076A2A1, 0x00528C8B, 0x00538D82, 0x0075A397, 0x00698D81, 0x007BA195, 0x00427468, 0x0068A49A, 0x003A7571, 0x0077AFB0, 0x00567B89, 0x0085A9A9, 0x004B6F63, 0x0089B5A8, 0x003B726F,
        0x0088C4CA, 0x00669DA6, 0x0084B6BC, 0x0065A8B7, 0x0073B6C5, 0x0064A7B6, 0x0070B3C2, 0x0061A4B3, 0x006EB1C0, 0x0064A7B6, 0x006FB2C1, 0x006AADBC, 0x0065A8B7, 0x0077BAC9, 0x005FA2B1, 0x0072B5C4, 0x005FA2B1, 0x0072B5C4, 0x0060A3B2, 0x0087C4C8,
        0x0059A3A5, 0x007CC4CB, 0x00609CA8, 0x0078B3C6, 0x0038849A, 0x004695B0, 0x00397C9B, 0x0008485A, 0x00074759, 0x0009495B, 0x000D4C60, 0x000F4E62, 0x000D4C61, 0x000C4B60, 0x000D4C61, 0x00084A63, 0x00074760, 0x00104C62, 0x000F4A5E, 0x00104C5C,
        0x00064853, 0x0000434B, 0x00004349, 0x0001474E, 0x000A4138, 0x000E473E, 0x0000424A, 0x00004A59, 0x00005356, 0x002C726B, 0x0039716C, 0x003F6A6D, 0x00224D50, 0x000E3A3B, 0x000B3534, 0x001E4543, 0x001D3C39, 0x00415755, 0x002E413E, 0x00001210,
        0x00000D11, 0x00001017, 0x00081817, 0x002F3125, 0x004A432F, 0x003A3320, 0x00221E13, 0x004E4433, 0x003F392C, 0x0021221E, 0x0010191C, 0x00131E26, 0x00161F2C, 0x00191E2D, 0x001B1B2B, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0x00495053, 0x00878E91, 0x00C5CDCD, 0x00B0B8B8, 0x00B8C0BF, 0x00C2CAC9, 0x00B1B9B8, 0x00A0ABA8, 0x00A2ADAA, 0x00C0CBC8, 0x00BBC6C3, 0x00A5B0AD, 0x009AA5A2, 0x00B1BCB9, 0x00C5D0CD, 0x00B8C6C2, 0x00A8B6B2, 0x00BECCC8, 0x00B6C4C0, 0x009BA9A5,
        0x009EACA8, 0x00A6B4B0, 0x00AEBCB8, 0x00A5B1AB, 0x00ACB8B2, 0x00B1BDB7, 0x00ACBAB6, 0x00B6C4C0, 0x00AAB8B6, 0x00768482, 0x005E6C6A, 0x00828D8A, 0x00727D7A, 0x007B8683, 0x0075807D, 0x00737E7B, 0x00717C79, 0x006A7572, 0x0056615E, 0x00274042,
        0x000C3A42, 0x00003244, 0x000C3042, 0x000C2C39, 0x000D3A45, 0x00033547, 0x000B3754, 0x000A3F53, 0x00003B4E, 0x00003F54, 0x0013455C, 0x000B465A, 0x00267884, 0x00216973, 0x003E6874, 0x00437074, 0x003C707C, 0x00125368, 0x00034E6E, 0x00004F72,
        0x003987AB, 0x00165E7C, 0x00044762, 0x00144761, 0x0005425C, 0x000E516A, 0x0004465F, 0x00083F5A, 0x00255670, 0x000B4257, 0x00114E62, 0x00044E68, 0x0002445D, 0x00144E64, 0x00154B62, 0x00003955, 0x000A587C, 0x003092BC, 0x0031A0CE, 0x002AA2E3,
        0x00239EDE, 0x001D9CD9, 0x0025A5E0, 0x0023A1D8, 0x00168ABF, 0x001580B3, 0x00248ABB, 0x001D94BB, 0x001A90BA, 0x002B9ED0, 0x0032A3DB, 0x002B9CD5, 0x001788C1, 0x001F90C9, 0x002B9CD4, 0x0028B0F0, 0x00218DB7, 0x00438493, 0x0071908F, 0x00798982,
        0x008C9A94, 0x00233328, 0x003F4F3E, 0x004C4F40, 0x004B4E3F, 0x00494C3D, 0x00494C3D, 0x004A4D3E, 0x004A4D3E, 0x00494C3D, 0x00F4F4F4, 0x007A7C72, 0x004F5244, 0x00888A80, 0x004D4E3E, 0x004D4D3F, 0x005E5E52, 0x00E8E8E6, 0x00FDFDFD, 0x00808277,
        0x00525343, 0x00515243, 0x00A6A69F, 0x00FFFFFF, 0x00C6C7C3, 0x00535446, 0x00515343, 0x00515344, 0x00525548, 0x00535445, 0x004D503E, 0x00515243, 0x00515445, 0x00525546, 0x00575848, 0x005D5E4E, 0x005B5B4B, 0x00555545, 0x00555545, 0x00545444,
        0x00505141, 0x005D5E4F, 0x005E5F50, 0x00545545, 0x00545545, 0x00545545, 0x00545545, 0x00505141, 0x00555647, 0x0059594A, 0x00515243, 0x004D4D3D, 0x00505141, 0x004F5141, 0x00515444, 0x00545747, 0x00555848, 0x00555848, 0x00505343, 0x004D5342,
        0x004D5342, 0x00505545, 0x00575B4A, 0x00535544, 0x004A4B3B, 0x004A4B3B, 0x004D4E3E, 0x00494E3F, 0x00808379, 0x00F5F5F4, 0x004C5142, 0x004C5142, 0x004D5243, 0x004C5142, 0x00494E3F, 0x00444A3F, 0x00272B1F, 0x00858B80, 0x0087968E, 0x00648380,
        0x005B9198, 0x00297686, 0x0000576C, 0x00095554, 0x00044E5A, 0x00024F6F, 0x002D89B8, 0x002193C8, 0x001998CF, 0x001D9ACD, 0x002398CB, 0x00389BC7, 0x000C4A5A, 0x008FAFAA, 0x00627B77, 0x0099B7B2, 0x004F6B5E, 0x0098B3A9, 0x00466564, 0x009DB2AA,
        0x0058766B, 0x008DB1A1, 0x005C7C6B, 0x0098AD9E, 0x00657669, 0x00879C93, 0x00618077, 0x007B9692, 0x0080928B, 0x00808E83, 0x00849689, 0x006B8879, 0x007FA092, 0x00647F76, 0x0090A19D, 0x0058736F, 0x009CB6A6, 0x00607B61, 0x0093B89E, 0x00396B5F,
        0x0085BCBF, 0x005E909C, 0x008FBBC8, 0x006A929E, 0x008CB4C0, 0x006D95A1, 0x0089B1BD, 0x006E96A2, 0x0088B0BC, 0x00749CA8, 0x0085ADB9, 0x007AA2AE, 0x007AA2AE, 0x0083ABB7, 0x00749CA8, 0x0083ABB7, 0x00739BA7, 0x0087AFBB, 0x00729AA6, 0x0095BEC7,
        0x0066979F, 0x00A0CCD3, 0x007B99A4, 0x0097BDCF, 0x004C8FA6, 0x004293B4, 0x0005547B, 0x00054557, 0x0008485A, 0x000B4B5D, 0x000B4A5E, 0x000C4B5F, 0x000D4C61, 0x000D4C61, 0x000C4B60, 0x000B4C68, 0x00084861, 0x000D4B63, 0x00114E62, 0x000E4C5C,
        0x00115562, 0x001F6870, 0x00216F75, 0x00387E85, 0x0040756C, 0x0046776F, 0x002B707A, 0x00025164, 0x00529199, 0x00A8CDCB, 0x00C0D2D3, 0x007AA3A6, 0x00456E71, 0x002D5658, 0x00365C5C, 0x0087A7A6, 0x0068807E, 0x00788A89, 0x0064716F, 0x00304644,
        0x002A4549, 0x002A444B, 0x002A3A39, 0x003C3E32, 0x00534C38, 0x00524B38, 0x004A463B, 0x006A4F45, 0x0054403B, 0x00383233, 0x002C3239, 0x0032424E, 0x003B4E5D, 0x00344859, 0x00354758, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0x00596063, 0x008C9396, 0x00BAC2C2, 0x00A6AEAE, 0x00A6AEAD, 0x00B2BAB9, 0x00BCC4C3, 0x00B8C3C0, 0x00B5C0BD, 0x00BDC8C5, 0x00A0ABA8, 0x00939E9B, 0x00A3AEAB, 0x00B2BDBA, 0x00A2ADAA, 0x009CAAA6, 0x00A5B3AF, 0x00BDCBC7, 0x00B6C4C0, 0x00A2B0AC,
        0x00B3C1BD, 0x00BFCDC9, 0x00ABB9B5, 0x009CA8A2, 0x00A3AFA9, 0x00ACB8B2, 0x00A1AFAB, 0x00A9B7B3, 0x00ACBAB8, 0x00849290, 0x00647270, 0x007E8C88, 0x00717F7B, 0x00778581, 0x00717F7B, 0x00788682, 0x0072807C, 0x0063716D, 0x00505E5A, 0x002B4448,
        0x0013404B, 0x00023647, 0x00082E40, 0x00052532, 0x0004313C, 0x00002F41, 0x000B3754, 0x0007394B, 0x00004052, 0x000B495B, 0x00144057, 0x001D5568, 0x0085D6DE, 0x0080C8CF, 0x007499A1, 0x006C6768, 0x0090A2A9, 0x006396A6, 0x003F8CA6, 0x00338DAC,
        0x000E6181, 0x00004362, 0x000B415F, 0x00074864, 0x00054863, 0x00024964, 0x0000445C, 0x00055168, 0x00003E51, 0x00045465, 0x00004A5B, 0x00004869, 0x00064F6B, 0x00114A63, 0x000D3F55, 0x0011475E, 0x00014562, 0x00005579, 0x003499C0, 0x00269AD9,
        0x0029A2E0, 0x0021A0DD, 0x001CA0DC, 0x0026A7E0, 0x002AA1D8, 0x002290C4, 0x001B81B5, 0x000C8AAC, 0x001D96BD, 0x002696C4, 0x00248EC4, 0x00359DD8, 0x002691CB, 0x001987C1, 0x00168AC1, 0x000B9DEF, 0x002894CE, 0x004A829D, 0x00718487, 0x00818782,
        0x00949D93, 0x00213225, 0x0034493A, 0x004A4D3E, 0x00484B3C, 0x0046493A, 0x00454839, 0x00454839, 0x0046493A, 0x00454839, 0x00F4F4F3, 0x007A7C72, 0x00494C3D, 0x004C4F40, 0x004D4E3E, 0x004D4E41, 0x00C8C8C4, 0x00FFFFFF, 0x00A2A49C, 0x00525546,
        0x004F5040, 0x00818277, 0x00FFFFFF, 0x00E4E4E2, 0x005E6052, 0x00535647, 0x0084867C, 0x00D9DAD6, 0x00E4E5E3, 0x00E6E7E5, 0x00BABBB4, 0x00575A4A, 0x006E7164, 0x00DADBD7, 0x00DDDDDA, 0x00DCDCD9, 0x00DDDDDA, 0x00ADADA7, 0x00505344, 0x00727569,
        0x00D0D1CD, 0x00EBEBE9, 0x00EAEAE8, 0x00D0D0CC, 0x0075776A, 0x00525344, 0x005A5B4B, 0x00ADAEA6, 0x00E7E7E5, 0x00EAEAE9, 0x00E3E3E1, 0x009C9C93, 0x004F5040, 0x005E6052, 0x00D2D3CF, 0x00DCDDDA, 0x00DBDCD8, 0x00DBDCD9, 0x00B8B9B3, 0x00515646,
        0x00BBBEB7, 0x00DDDEDB, 0x00DBDCD9, 0x00DCDDDA, 0x00C5C5C0, 0x0067685B, 0x004E4F3F, 0x00494E3F, 0x00808379, 0x00F5F5F4, 0x004E5344, 0x004D5243, 0x004D5243, 0x004A4F40, 0x00464B3C, 0x0041493E, 0x002F3327, 0x0086887C, 0x008B968C, 0x005D7C7D,
        0x005392A0, 0x002E8DA7, 0x001183A7, 0x00054E56, 0x0006485B, 0x000B4C72, 0x003D8EC1, 0x003099D2, 0x001E99D1, 0x001C99CC, 0x002198C9, 0x002390B6, 0x000F4A54, 0x00677165, 0x0056564A, 0x006C7669, 0x00525E4C, 0x006B7467, 0x00545A59, 0x007A7C70,
        0x00424F3F, 0x006E856F, 0x004A6048, 0x006E7762, 0x0060624F, 0x00717667, 0x004E584B, 0x006A7174, 0x00585858, 0x006D6A66, 0x006B6E65, 0x005A665A, 0x005E6C60, 0x0065685F, 0x007B706C, 0x00485466, 0x0070777A, 0x004F5445, 0x007B816E, 0x00535D50,
        0x00777E7B, 0x00565453, 0x008D817F, 0x00555D53, 0x00848C82, 0x00586056, 0x007F877D, 0x00596157, 0x007A8278, 0x005E665C, 0x00727A70, 0x00676F65, 0x006D756B, 0x006B7369, 0x00697167, 0x006F776D, 0x00676F65, 0x00777F75, 0x00646C62, 0x007E7F83,
        0x0059605D, 0x00817E76, 0x0078635B, 0x008F837F, 0x002E4344, 0x00023038, 0x00154354, 0x00044456, 0x000A4A5C, 0x000D4D5F, 0x000A495D, 0x0009485C, 0x000D4C61, 0x000E4D62, 0x000B4A5F, 0x00064664, 0x0011506C, 0x000A4860, 0x000F4B61, 0x00003F51,
        0x00266C79, 0x0067B2BB, 0x003A8A91, 0x0094A4B4, 0x00545958, 0x008B9392, 0x006F93A3, 0x0040798F, 0x0053848E, 0x00839F9F, 0x00869597, 0x0030565A, 0x0043696D, 0x00315759, 0x00456969, 0x0093B2B1, 0x00A1B7B5, 0x00A8B6B5, 0x00A5ADAC, 0x0094AAA8,
        0x008DA8AC, 0x007F99A0, 0x00627271, 0x00515347, 0x00534C38, 0x00514A37, 0x00514D42, 0x00443E33, 0x004C534C, 0x005E7976, 0x00609396, 0x0063ADB3, 0x0064BEC5, 0x0060C2C8, 0x006BD1D6, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0x004F585C, 0x00778083, 0x00A3ADAD, 0x00ABB6B4, 0x00AEB9B7, 0x00A4AFAC, 0x00C0CCC6, 0x00C0D1CD, 0x00B0BFBB, 0x009FAEAA, 0x00B0BFBB, 0x0099A7A3, 0x00B2C0BC, 0x00A8B3B0, 0x00ADB8B5, 0x0094A29E, 0x00AFBDB9, 0x00BFCDC9, 0x00B1BFBB, 0x00C1CFCB,
        0x00D1DFDB, 0x00B5C3BF, 0x00A8B6B2, 0x00AFB9B3, 0x00AFB9B3, 0x009FABA5, 0x00A3AEAB, 0x00A3AEAB, 0x009CA9A7, 0x007B8886, 0x00606D6B, 0x00777E7B, 0x0079807D, 0x00737A77, 0x00838A87, 0x00838A87, 0x00727976, 0x006B726F, 0x00535A57, 0x002F403D,
        0x00004654, 0x00003B56, 0x0018354A, 0x0005232E, 0x00022937, 0x00103543, 0x000D3E40, 0x00003F46, 0x0002414F, 0x0008445A, 0x0000425A, 0x00156477, 0x0035848F, 0x00317172, 0x00386562, 0x002B5242, 0x00599388, 0x00135E5C, 0x0009545D, 0x00115366,
        0x00114962, 0x000E465F, 0x00034159, 0x00054867, 0x00044663, 0x00054863, 0x0000425B, 0x0004445C, 0x00054459, 0x0009465A, 0x000A485A, 0x00004260, 0x00024865, 0x0000415E, 0x0000425B, 0x00064960, 0x00024358, 0x000D4C60, 0x0065A4B8, 0x003A91A5,
        0x002C8CBA, 0x002EA1EC, 0x001C9EF1, 0x0018A1E6, 0x0024A2DC, 0x002A9BD3, 0x001C87C1, 0x000082BE, 0x002095C8, 0x004AABD7, 0x00116A96, 0x00035F92, 0x003CA3DA, 0x00279BD2, 0x000B83B7, 0x001692BA, 0x0039A2CD, 0x00478AA5, 0x0060807F, 0x00788F81,
        0x00869D98, 0x002C3A36, 0x004C463B, 0x00494E3F, 0x00474C3D, 0x00474C3D, 0x00484D3E, 0x00464B3C, 0x0044493A, 0x00454A3B, 0x00F4F5F4, 0x00797B70, 0x00454839, 0x004A4D3E, 0x004B4C3C, 0x009B9C94, 0x00FFFFFF, 0x00C8C9C4, 0x004E5142, 0x004E5142,
        0x00646557, 0x00ECECEB, 0x00F9F9F9, 0x00747469, 0x004B4E3F, 0x00515446, 0x00EBECEA, 0x00CFCFCB, 0x005B5D4F, 0x0077786C, 0x00D2D2CE, 0x00686A5D, 0x0086887E, 0x00FFFFFF, 0x008E8F85, 0x00747569, 0x00737368, 0x00656559, 0x005E6153, 0x00ECECEB,
        0x00D5D6D3, 0x006D6E62, 0x006C6E61, 0x00D1D2CE, 0x00B2B3AD, 0x00515343, 0x00A7A89F, 0x00FEFEFE, 0x008E8E84, 0x00656557, 0x009F9F96, 0x00E4E4E2, 0x005A5A4C, 0x006D6D60, 0x00FFFFFF, 0x009B9B92, 0x00717265, 0x00757569, 0x006E6F61, 0x00565949,
        0x00F8F8F8, 0x00BDBFB9, 0x00727466, 0x00797A6E, 0x00F8F8F8, 0x00BCBCB7, 0x004F4E40, 0x00464C3B, 0x007F8377, 0x00F5F5F4, 0x004E5443, 0x004C5241, 0x004A503F, 0x00474D3C, 0x00444A39, 0x004D413B, 0x00173228, 0x007E8F84, 0x00859688, 0x006C8074,
        0x00679497, 0x002193AA, 0x00118DBD, 0x002881AD, 0x00015A7C, 0x0000516B, 0x00268FB0, 0x00259CCD, 0x001492CC, 0x001D95D0, 0x002396C9, 0x000C6B96, 0x00233540, 0x0047402D, 0x00343E2D, 0x00353934, 0x00393A31, 0x00333C2F, 0x003C3D33, 0x00363A2E,
        0x003A3E32, 0x003C4034, 0x003B3F33, 0x003A3E32, 0x003C4034, 0x003C4034, 0x003B3F33, 0x00383D2E, 0x003B4031, 0x003E4334, 0x003F4435, 0x003E4334, 0x003C4132, 0x003C4132, 0x003C4132, 0x003B3F33, 0x003A3E32, 0x00393D31, 0x00393B2F, 0x00383A2E,
        0x003A3A2E, 0x003B3B2F, 0x003C3C30, 0x003F4030, 0x003F4030, 0x003E3F2F, 0x003B3E2E, 0x003B3E2E, 0x003A402F, 0x003A402F, 0x00393F2E, 0x0037382E, 0x003F4036, 0x003C3D33, 0x00393A30, 0x003A3B31, 0x00393A30, 0x0037382E, 0x0036372D, 0x002D3B29,
        0x0037362C, 0x00393530, 0x0034382D, 0x00373C2D, 0x0030332A, 0x00152D33, 0x000A4051, 0x00054459, 0x0007465B, 0x0009485D, 0x000A495E, 0x000A495E, 0x000A495E, 0x000A495E, 0x000B4A5F, 0x000F4E63, 0x000D4C61, 0x000A4860, 0x000E4D62, 0x000C4C5E,
        0x00064853, 0x00185C61, 0x00004343, 0x001F4D58, 0x000A312F, 0x00144341, 0x00074B5E, 0x00004660, 0x00124F59, 0x003C6A64, 0x003B645C, 0x002D5651, 0x00214A4D, 0x00133A42, 0x000E373A, 0x00184139, 0x00214537, 0x003D5953, 0x001F3436, 0x00091E1C,
        0x0000171B, 0x0000121A, 0x000D1B1A, 0x0036362A, 0x004C432F, 0x0038311E, 0x002A2419, 0x004E4029, 0x00483E2C, 0x002C281D, 0x001A1C16, 0x001A2221, 0x001F2B2D, 0x00212D2F, 0x00182426, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0x004D565A, 0x00767F82, 0x00A1ABAB, 0x00ABB6B4, 0x00BBC6C4, 0x00B1BCB9, 0x00B7C3BD, 0x00A2B1AD, 0x0098A7A3, 0x009AA9A5, 0x00B2C1BD, 0x009FADA9, 0x00A3B1AD, 0x0095A09D, 0x009FAAA7, 0x009DA8A5, 0x00B2BDBA, 0x00BDC8C5, 0x00A9B4B1, 0x00B3BEBB,
        0x00CDD8D5, 0x00BBC6C3, 0x00A8B3B0, 0x00ADB7B1, 0x00A4AEA8, 0x00A4B0AA, 0x00ACB7B4, 0x009FAAA7, 0x009CA9A7, 0x00808D8B, 0x005D6A68, 0x00767D7A, 0x00787F7C, 0x00787F7C, 0x00818885, 0x007C8380, 0x00727976, 0x006B726F, 0x00535A57, 0x0039424B,
        0x000B4E67, 0x00003B62, 0x00153859, 0x000E374D, 0x0005374E, 0x00033149, 0x00003746, 0x00003645, 0x0015485C, 0x000B3B57, 0x000C4461, 0x005092AB, 0x006DADBF, 0x005B8C94, 0x007A9DA1, 0x007E868D, 0x0092ABB5, 0x003C6D7B, 0x000F4E62, 0x00003D58,
        0x00075070, 0x00237898, 0x002C8BAC, 0x001B86B2, 0x001D89B3, 0x001F8BB5, 0x001B87B0, 0x001887AF, 0x001E8DB3, 0x001A89AF, 0x001A89AF, 0x001B8AB8, 0x001683AF, 0x001885B1, 0x001E8AB4, 0x001983AC, 0x001B84AB, 0x0010789D, 0x001981A6, 0x00015261,
        0x000F5A7A, 0x00358BC1, 0x0034A5E4, 0x0023A5E1, 0x00219ED8, 0x002EA8DE, 0x00219DD3, 0x001895CF, 0x002296CD, 0x0047ADDE, 0x00176E9A, 0x00003F65, 0x001D759D, 0x00349BC8, 0x002E9FD1, 0x000C8BB8, 0x001C88B7, 0x003E84A1, 0x00678786, 0x00829586,
        0x008FA69E, 0x002C3A36, 0x00514C43, 0x00484D3E, 0x00454A3B, 0x00454A3B, 0x00464B3C, 0x00454A3B, 0x00434839, 0x0044493A, 0x00F4F4F4, 0x007C7F74, 0x00474A3B, 0x004A4D3E, 0x0078796D, 0x00FCFCFC, 0x00E8E8E6, 0x005E6053, 0x004B4E3F, 0x00515445,
        0x00D5D5D1, 0x00FFFFFF, 0x00999990, 0x004C4D3F, 0x004A4C3D, 0x00505344, 0x00BDBEBA, 0x00F3F3F2, 0x00CACBC6, 0x00A3A39B, 0x0077786C, 0x004E5141, 0x0086887E, 0x00FEFEFE, 0x00C4C4BF, 0x00B6B7B1, 0x00B6B6B0, 0x006F6F64, 0x00818378, 0x00FFFFFF,
        0x007A7C6F, 0x00505042, 0x006A6C5F, 0x00797B70, 0x00737669, 0x00515344, 0x00E8E8E6, 0x00C5C5C0, 0x00545545, 0x005D5E4F, 0x00737367, 0x007D7D71, 0x005B5B4C, 0x006E6F62, 0x00FBFBFB, 0x00CCCDC8, 0x00B9B9B3, 0x00B9BAB3, 0x00838478, 0x00535646,
        0x00F1F1F0, 0x00C8C9C4, 0x008B8C81, 0x00919087, 0x00EEEEED, 0x009B9A93, 0x004C4B3D, 0x00474D3C, 0x007F8377, 0x00F4F5F4, 0x004A503F, 0x00484E3D, 0x00494F3E, 0x00484E3D, 0x00464C3B, 0x004A4138, 0x00132F22, 0x007D8B80, 0x00859387, 0x00697C73,
        0x00639198, 0x001E91AC, 0x001390C2, 0x002B93C2, 0x00268BB1, 0x00127698, 0x00208DB3, 0x002298CB, 0x001996D0, 0x001D96CE, 0x002194C7, 0x00076691, 0x0020323D, 0x00463F2C, 0x0036402F, 0x00373B36, 0x003B3C33, 0x00333C2F, 0x003B3C32, 0x00393D31,
        0x003C4034, 0x003E4236, 0x003B3F33, 0x003A3E32, 0x003C4034, 0x003C4034, 0x003B3F33, 0x003B4031, 0x003C4132, 0x003E4334, 0x003E4334, 0x003D4233, 0x003C4132, 0x003B4031, 0x003B4031, 0x00393D31, 0x003B3F33, 0x003C4034, 0x003F4135, 0x003F4135,
        0x00414135, 0x00404034, 0x003F3F33, 0x003F4030, 0x003F4030, 0x003F4030, 0x003D4030, 0x003C3F2F, 0x003A402F, 0x003A402F, 0x003A402F, 0x003C3D33, 0x003F4036, 0x003B3C32, 0x003B3C32, 0x003F4036, 0x003E3F35, 0x003C3D33, 0x003F4036, 0x00303E2C,
        0x003A392F, 0x003C3833, 0x0035392E, 0x00383D2E, 0x0030332A, 0x00142C32, 0x00093F50, 0x00054459, 0x0007465B, 0x0009485D, 0x000A495E, 0x000A495E, 0x000A495E, 0x000A495E, 0x000B4A5F, 0x0006455A, 0x0016556A, 0x000E4C64, 0x0008475C, 0x000F4F61,
        0x0010525D, 0x002B6F74, 0x00246A6A, 0x0019656B, 0x0024675E, 0x00256863, 0x00106273, 0x00055972, 0x003C7D86, 0x00A6D2CC, 0x00B5DAD2, 0x0085AEA9, 0x00487174, 0x00194048, 0x001B4447, 0x0084ADA5, 0x006C9082, 0x006B8781, 0x004C6163, 0x00314644,
        0x00233C40, 0x001C333B, 0x0022302F, 0x003E3E32, 0x00544B37, 0x004C4532, 0x00474136, 0x00545045, 0x0043443B, 0x00272F2E, 0x0026363C, 0x002D4650, 0x002A4853, 0x00284855, 0x00264953, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0x00475054, 0x00737C7F, 0x009BA5A5, 0x00A7B2B0, 0x00BFCAC8, 0x00B2BDBA, 0x00A1ADA7, 0x00B4C3BF, 0x00A8B7B3, 0x00A1B0AC, 0x009FADA9, 0x00909E9A, 0x0096A19E, 0x009DA8A5, 0x00B4BFBC, 0x00ABB6B3, 0x0098A3A0, 0x009CA7A4, 0x009DA8A5, 0x00A0ABA8,
        0x00A6B1AE, 0x009CA7A4, 0x0098A3A0, 0x00A5AFA9, 0x009DA7A1, 0x00A6B2AC, 0x00ACB7B4, 0x00A0ABA8, 0x00A0ADAB, 0x007E8B89, 0x00606D6B, 0x00707976, 0x0079827F, 0x00858E8B, 0x00838C89, 0x00747D7A, 0x00717A77, 0x006E7774, 0x005A6360, 0x002D334A,
        0x000D527A, 0x0000457A, 0x00114776, 0x00155379, 0x00044C76, 0x00003662, 0x00003D5F, 0x00014562, 0x00044466, 0x00034268, 0x0001486E, 0x001B678B, 0x00256F8B, 0x001A5B70, 0x002F6576, 0x001D3A59, 0x002E5A79, 0x000B4B69, 0x00015170, 0x00005578,
        0x001A83AC, 0x003FB7E5, 0x0049CCFD, 0x0042C9FF, 0x0040C7FD, 0x003CC8FD, 0x0039C7FE, 0x0031C2F9, 0x0035CBFF, 0x002CC4FA, 0x0030C8FF, 0x003BC8FF, 0x0034C1FA, 0x003BC8FF, 0x0043CEFF, 0x0035BFF4, 0x0040CAFF, 0x0039C1F5, 0x0020A8DC, 0x00035D6E,
        0x0000394F, 0x001B5572, 0x003392B9, 0x0031AADC, 0x002199D5, 0x0024A1DB, 0x0017A7D7, 0x00299FD3, 0x002B9FDA, 0x00369FD8, 0x00166C96, 0x00003F54, 0x00074A59, 0x00227692, 0x003298C3, 0x001694CA, 0x00117EB2, 0x003A82A0, 0x00648581, 0x00819382,
        0x0099ACA3, 0x00273432, 0x00424038, 0x00474C3D, 0x00434839, 0x00424738, 0x00434839, 0x00434839, 0x00424738, 0x00424738, 0x00F4F4F3, 0x007C7F74, 0x0046493A, 0x005B5D50, 0x00E8E8E6, 0x00FEFEFD, 0x0072746A, 0x004B4E3F, 0x004A4E3F, 0x00B0B2AB,
        0x00FFFFFF, 0x00BCBDB7, 0x00525444, 0x004D4F3F, 0x004A4B3C, 0x004C4F40, 0x0050524B, 0x0083857C, 0x00B2B3AC, 0x00DCDCD9, 0x00F7F7F6, 0x008D8F85, 0x007E8075, 0x00FEFEFE, 0x00B0B1AA, 0x009F9F97, 0x009E9E96, 0x0066665A, 0x0086887D, 0x00FFFFFF,
        0x00767669, 0x004B4B3B, 0x00B4B5AE, 0x00DDDEDB, 0x00EFEFED, 0x005F6153, 0x00E7E8E6, 0x00C0C0BA, 0x00515242, 0x00838378, 0x00D1D1CD, 0x00F5F6F5, 0x009B9B91, 0x00646455, 0x00FBFBFB, 0x00BDBEB7, 0x00A4A59C, 0x00A2A39A, 0x00747669, 0x00515446,
        0x00ECECEA, 0x00E7E8E5, 0x00CBCCC7, 0x00E0E0DD, 0x00F4F4F4, 0x006E6E63, 0x0048483A, 0x00454B3A, 0x007E8276, 0x00F4F5F4, 0x00494F3E, 0x00474D3C, 0x00484E3D, 0x00484E3D, 0x00464C3B, 0x00484537, 0x00153223, 0x00868E87, 0x00929A93, 0x0070817D,
        0x0063919C, 0x001A8FAC, 0x00118DC3, 0x001D9ACC, 0x002FA6D3, 0x002395BE, 0x002393C1, 0x001E94C8, 0x001E97CF, 0x002198CF, 0x001C92C3, 0x0002618C, 0x001D2F3A, 0x00453E2B, 0x0036402F, 0x00383C37, 0x003C3D34, 0x00343D30, 0x003B3C32, 0x003C4034,
        0x003F4337, 0x003F4337, 0x003C4034, 0x003A3E32, 0x003C4034, 0x003D4135, 0x003C4034, 0x003E4334, 0x003E4334, 0x003D4233, 0x003D4233, 0x003D4233, 0x003D4233, 0x003C4132, 0x003B4031, 0x00383C30, 0x00393D31, 0x00393D31, 0x003C3E32, 0x003C3E32,
        0x003E3E32, 0x003D3D31, 0x003C3C30, 0x003F4030, 0x00404131, 0x00414232, 0x003F4232, 0x003C3F2F, 0x00393F2E, 0x003B4130, 0x003E4433, 0x003F4036, 0x003F4036, 0x003C3D33, 0x003B3C32, 0x003E3F35, 0x003C3D33, 0x0036372D, 0x0037382E, 0x00344230,
        0x003D3C32, 0x003E3A35, 0x00373B30, 0x00383D2E, 0x002F3229, 0x00122A30, 0x00073D4E, 0x00054459, 0x0007465B, 0x0009485D, 0x000A495E, 0x000A495E, 0x000A495E, 0x000A495E, 0x000B4A5F, 0x00115065, 0x00034257, 0x000A4860, 0x00104F64, 0x0008485A,
        0x002A6C77, 0x006BAFB4, 0x00519797, 0x006E7E8B, 0x003B4545, 0x00647B7D, 0x005C8EA2, 0x003D7E9A, 0x00508B95, 0x006C9C96, 0x007CABA2, 0x00365F5A, 0x00436C6F, 0x00295058, 0x00355E61, 0x0092BBB3, 0x0096BAAC, 0x0095B1AB, 0x0091A6A8, 0x0090A5A3,
        0x008BA4A8, 0x00859CA4, 0x006A7877, 0x00505044, 0x004B422E, 0x004F4835, 0x005B554A, 0x00474338, 0x004E564C, 0x00556E6A, 0x00669495, 0x0068ADB0, 0x0059B0B2, 0x0057BBBD, 0x005EC9C7, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0x00475054, 0x00717A7D, 0x00929C9C, 0x00A1ACAA, 0x00BEC9C7, 0x00BCC7C4, 0x00B2BEB8, 0x009DACA8, 0x00A2B1AD, 0x00ABB9B5, 0x00A1AFAB, 0x00A1ACA9, 0x00A4AFAC, 0x00AAB3B0, 0x00B2BBB8, 0x00B8C3C0, 0x00939E9B, 0x009EA9A6, 0x00B9C4C1, 0x00B5C0BD,
        0x00A3AEAB, 0x0095A09D, 0x0096A19E, 0x00A7B1AB, 0x00A8B2AC, 0x00A8B4AE, 0x00A5B0AD, 0x00A7B2AF, 0x00A4B1AF, 0x0074817F, 0x0063706E, 0x00737B7A, 0x007A8281, 0x00878F8E, 0x007D8584, 0x006D7574, 0x006F7776, 0x00656D6C, 0x004C5453, 0x00314165,
        0x001E71A5, 0x00066AAB, 0x001464A1, 0x001975A8, 0x001A81BA, 0x001F7FBB, 0x002A90C4, 0x0036A3D6, 0x002A98CC, 0x003CACE1, 0x003DB1E6, 0x002EA4D7, 0x0032A9D6, 0x003DAED6, 0x003EACCE, 0x0034A7D4, 0x003CB2DC, 0x0032AFD5, 0x0037B9DE, 0x002DB3DD,
        0x0036BFF0, 0x0034C4FE, 0x002AC0FF, 0x0033BFFA, 0x002DBCF6, 0x002CBBF8, 0x002DC1FD, 0x0026BDFA, 0x0027C2FF, 0x001BBAF8, 0x0022C1FF, 0x002CC3FF, 0x002CC3FF, 0x0027BFFA, 0x002CC2FE, 0x0022B8F4, 0x002AC0FC, 0x002CC2FE, 0x0028BEFA, 0x002DA7CB,
        0x00115F7C, 0x0000394F, 0x0006637D, 0x002C9ECD, 0x002B99D9, 0x002199D5, 0x0010A1CF, 0x0031A2D4, 0x0035AAE7, 0x002C9DDC, 0x00176F98, 0x000D4852, 0x001D4F4D, 0x00418592, 0x003D93B7, 0x00289CD5, 0x00238DC2, 0x00418BA7, 0x005F837D, 0x007D8D7B,
        0x009BACA3, 0x002D3A38, 0x0043453F, 0x00474C3D, 0x00434839, 0x00404536, 0x00424738, 0x00434839, 0x00424738, 0x00424738, 0x00F4F4F3, 0x00797B70, 0x00424536, 0x00C6C7C2, 0x00FFFFFF, 0x00A3A39C, 0x00454738, 0x0045483A, 0x0085877D, 0x00FFFFFF,
        0x00DFDFDC, 0x005B5D4E, 0x00505142, 0x00505243, 0x00505243, 0x004F5243, 0x00C6C7C3, 0x00A5A69E, 0x004D4D3D, 0x005F6051, 0x00F5F5F4, 0x00B5B6AF, 0x007F8175, 0x00FFFFFF, 0x007E7F73, 0x00626354, 0x00646457, 0x00606053, 0x00616356, 0x00F5F5F4,
        0x00C9CAC5, 0x00626254, 0x005E5F50, 0x00C7C8C3, 0x00FFFFFF, 0x00595C4E, 0x00ABACA5, 0x00FAFAFA, 0x007E7F73, 0x00595A4B, 0x008D8E83, 0x00FFFFFF, 0x00A2A29A, 0x0067685A, 0x00FFFFFF, 0x00929288, 0x00666759, 0x00616456, 0x005D6053, 0x00525749,
        0x00F7F7F7, 0x00ABAEA7, 0x004D5243, 0x005D5F53, 0x00FFFFFF, 0x00A6A69F, 0x0049493B, 0x00434636, 0x007E8075, 0x00F4F5F4, 0x004B4E3E, 0x004A4D3D, 0x004A4D3D, 0x00494C3C, 0x00464939, 0x00454535, 0x00132D1F, 0x00848882, 0x008F9590, 0x006E7E7D,
        0x005F8F9B, 0x001E90AE, 0x001F94C7, 0x00109AC9, 0x001598C9, 0x001A97CA, 0x00279CD3, 0x001F93CC, 0x001E95CD, 0x00249CD0, 0x001A91C2, 0x0001608B, 0x001C2E39, 0x00443D2A, 0x0036402F, 0x00383C37, 0x003C3D34, 0x00333C2F, 0x003A3B31, 0x003B4235,
        0x003E4538, 0x003E4538, 0x003A4134, 0x00394033, 0x003C4336, 0x003E4538, 0x003D4437, 0x003F4639, 0x003D4437, 0x003B4235, 0x003B4235, 0x003D4437, 0x003E4538, 0x003D4437, 0x003C4336, 0x0043473B, 0x00404438, 0x003C4034, 0x003B3D31, 0x003A3C30,
        0x003D3D31, 0x003E3E32, 0x003E3E32, 0x003F3F31, 0x00404032, 0x00414133, 0x003E4132, 0x003C3F30, 0x00393E2F, 0x003E4334, 0x00454A3B, 0x0043473C, 0x0045493E, 0x0045493E, 0x00404439, 0x0044483D, 0x0044483D, 0x00373B30, 0x0032362B, 0x00344230,
        0x003D3C32, 0x003E3A35, 0x00363A2F, 0x00373C2D, 0x002F3229, 0x00122A30, 0x00063C4D, 0x00054459, 0x0007465B, 0x0009485D, 0x000A495E, 0x000A495E, 0x000A495E, 0x000A495E, 0x000B4A5F, 0x000A495E, 0x00104F64, 0x000D4B63, 0x0009485D, 0x00044456,
        0x0000424D, 0x00165A5F, 0x00004444, 0x0017424B, 0x00123531, 0x001D4845, 0x00054557, 0x00004860, 0x000F4D55, 0x0028574F, 0x00366158, 0x002A534E, 0x001B4447, 0x00113840, 0x00113A3D, 0x00113A32, 0x00274B3D, 0x004B6761, 0x002A3F41, 0x00112624,
        0x00031C20, 0x00081F27, 0x00142221, 0x0029291D, 0x003F3622, 0x003B3421, 0x00302A1F, 0x005B4932, 0x004E3E2D, 0x002D241A, 0x001C1C16, 0x00202625, 0x00222B2E, 0x00202C2E, 0x00172325, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0x00464F53, 0x006F787B, 0x00899393, 0x00939E9C, 0x00A1ACAA, 0x00A3AEAB, 0x00ABB7B1, 0x00A6B4B0, 0x00A5B3AF, 0x00A9B7B3, 0x009FAAA7, 0x00A3AEAB, 0x00A7B0AD, 0x00A9B2AF, 0x00ABB4B1, 0x009CA5A2, 0x0089928F, 0x008E9794, 0x00939C99, 0x008C9592,
        0x00939C99, 0x009DA6A3, 0x009FA8A5, 0x0099A39D, 0x0098A29C, 0x0095A19B, 0x00949F9C, 0x009DA8A5, 0x009FACAA, 0x00717E7C, 0x00626F6D, 0x006C7775, 0x006D7876, 0x00747F7D, 0x006E7977, 0x00697472, 0x006F7A78, 0x005E6967, 0x003D4846, 0x0024446D,
        0x00177BB5, 0x000077BF, 0x000166AA, 0x00006EAB, 0x00098BCE, 0x001D99E0, 0x0024A7E6, 0x001FAFF6, 0x0023B6FC, 0x0023BCFF, 0x0024BDFF, 0x002CC4FF, 0x0030C7FF, 0x002BC3FC, 0x0030C9FF, 0x0022CAFF, 0x0023C8F9, 0x0025C6F3, 0x002FD0FD, 0x002CCCFC,
        0x002ACAFF, 0x0022C0FF, 0x0024BFFF, 0x0027BBFD, 0x0026BBFD, 0x0026BBFE, 0x0025BCFF, 0x0025BEFF, 0x0029C2FF, 0x0026C1FF, 0x0024BFFF, 0x0020BFFD, 0x0024C3FF, 0x001AB8F8, 0x001FBDFD, 0x001CBCFC, 0x001EBEFE, 0x001BBBFB, 0x0020C0FF, 0x002DC6FF,
        0x0031A5D4, 0x00046182, 0x00004A6C, 0x001E89BC, 0x003BA1E2, 0x002D9CDA, 0x001C9FD1, 0x002B9ACA, 0x00239CDA, 0x0029A1E3, 0x001C7CAA, 0x0004444F, 0x002B5E57, 0x0079B1B6, 0x004D96AC, 0x002285B7, 0x002D8DBB, 0x00438FA6, 0x00668F88, 0x00839683,
        0x0091A098, 0x00283331, 0x0040433A, 0x00484D3E, 0x00434839, 0x00414637, 0x00434839, 0x0044493A, 0x00434839, 0x00434839, 0x00F4F4F3, 0x00777A6F, 0x00424536, 0x00B8B9B3, 0x00BDBDB8, 0x004C4E3F, 0x00494B3C, 0x00484B3C, 0x0084867C, 0x00D5D6D2,
        0x006F7164, 0x00505242, 0x00505242, 0x00515242, 0x004C4E3F, 0x00474A3B, 0x0091938B, 0x00EBEBE9, 0x00E1E1DE, 0x00E3E3E0, 0x00D7D7D3, 0x0068685B, 0x00707266, 0x00EDEDEB, 0x00ECECEA, 0x00EBEBE9, 0x00EBEBEA, 0x00D0D0CC, 0x004D5040, 0x007E7F74,
        0x00E4E4E1, 0x00ECECEA, 0x00E5E5E3, 0x00C9C9C5, 0x00E3E4E1, 0x005C5F51, 0x00575A4C, 0x00C1C2BD, 0x00F2F3F2, 0x00E6E6E4, 0x00D9D9D6, 0x00D7D7D4, 0x00A0A098, 0x005D5E4F, 0x00E6E6E4, 0x00EDEEEC, 0x00EBEBEA, 0x00EBEBEA, 0x00D9DAD6, 0x005C6153,
        0x00DFE0DD, 0x009D9F97, 0x004C5142, 0x004C5142, 0x00DFDFDD, 0x00AEAEA8, 0x004B4B3D, 0x00454838, 0x007E8075, 0x00F4F5F4, 0x00484B3B, 0x00474A3A, 0x00494C3C, 0x00494C3C, 0x00474A3A, 0x00474735, 0x00173022, 0x008B8C88, 0x00959B96, 0x00718481,
        0x00639399, 0x00288EA5, 0x002B8EBA, 0x00179ECA, 0x001197C7, 0x001495CE, 0x00209AD6, 0x002197D2, 0x002095CC, 0x00259BCE, 0x001C95C7, 0x0004638E, 0x001E303B, 0x00443D2A, 0x00343E2D, 0x00363A35, 0x003A3B32, 0x00323B2E, 0x003A3B31, 0x003A4134,
        0x003D4437, 0x003E4538, 0x003B4235, 0x003B4235, 0x003E4538, 0x0041483B, 0x0040473A, 0x0040473A, 0x003E4538, 0x003D4437, 0x003D4437, 0x003F4639, 0x0041483B, 0x0042493C, 0x0041483B, 0x0044483C, 0x00404438, 0x003A3E32, 0x00393B2F, 0x00383A2E,
        0x003C3C30, 0x003D3D31, 0x003D3D31, 0x003F3F31, 0x003E3E30, 0x003F3F31, 0x003D4031, 0x003B3E2F, 0x00393E2F, 0x00424738, 0x004C5142, 0x0043473C, 0x00484C41, 0x00494D42, 0x003E4237, 0x0044483D, 0x004D5146, 0x003F4338, 0x00373B30, 0x00313F2D,
        0x003B3A30, 0x003C3833, 0x0035392E, 0x00363B2C, 0x002E3128, 0x0011292F, 0x00063C4D, 0x00054459, 0x0007465B, 0x0009485D, 0x000A495E, 0x000A495E, 0x000A495E, 0x000A495E, 0x000B4A5F, 0x00014055, 0x000D4C61, 0x0009475F, 0x0009485D, 0x000E4E60,
        0x0010525D, 0x00397D82, 0x003F8585, 0x00628B94, 0x00496D67, 0x00547F7C, 0x002C6D7C, 0x001B637B, 0x0055939B, 0x0095C4BC, 0x009AC4B9, 0x0077A09B, 0x00365F62, 0x00194048, 0x00224B4E, 0x00709991, 0x005C8072, 0x006B8781, 0x00475C5E, 0x002E4341,
        0x001B3438, 0x001B323A, 0x00253332, 0x003B3B2F, 0x00534A36, 0x004E4734, 0x00423C31, 0x00505137, 0x00464834, 0x00232D20, 0x00172A21, 0x002A433F, 0x003C5858, 0x00395857, 0x00254544, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0x00475054, 0x00767F82, 0x00929C9C, 0x0098A3A1, 0x009AA5A3, 0x00A2ADAA, 0x00B9C5BF, 0x00B6C4C0, 0x00A1AFAB, 0x009FAAA7, 0x00A1ACA9, 0x00A7B0AD, 0x00A7B0AD, 0x00A6AFAC, 0x00AEB5B2, 0x0099A29F, 0x009BA4A1, 0x00A3ACA9, 0x009FA8A5, 0x00949D9A,
        0x00969F9C, 0x00A0A9A6, 0x00A6AFAC, 0x00939D97, 0x008B958F, 0x008C9892, 0x00929D9A, 0x00919C99, 0x0096A3A1, 0x0073807E, 0x005A6765, 0x00697373, 0x00727C7C, 0x00778181, 0x00747E7E, 0x006C7676, 0x00687272, 0x005E6868, 0x004A5454, 0x001C496E,
        0x00107FB7, 0x00007CC3, 0x000067AC, 0x000068A9, 0x000087CF, 0x000E95E1, 0x000798DC, 0x0010A0F2, 0x0017AEFF, 0x0012B0FE, 0x0012AFF9, 0x0024BBFF, 0x0027C0FF, 0x001EBBFD, 0x001AC0FF, 0x0029C6FE, 0x002BC3FC, 0x002DC2FA, 0x002EC7FE, 0x0021C2F8,
        0x0019BEF7, 0x001EBCF8, 0x002EC3FF, 0x0031CAFF, 0x0032CAFF, 0x002CC2FF, 0x0028BAFB, 0x0036C4FF, 0x0031BAF8, 0x0041C9FF, 0x0039BFF9, 0x0031C0F9, 0x0039CAFF, 0x003ACAFF, 0x0039CBFF, 0x002FC1FD, 0x0033C7FF, 0x002DC0FE, 0x002BC1FE, 0x0028BEFF,
        0x0038C9FF, 0x001A9BC8, 0x00006490, 0x00298CC0, 0x003CA4DF, 0x00299AD8, 0x002B9FDE, 0x0030A5D8, 0x00229DDB, 0x0028A3E7, 0x00319ED2, 0x001B6F89, 0x0017555B, 0x004B8388, 0x00225D67, 0x003A85A5, 0x002D80A0, 0x00347C8E, 0x00628C85, 0x008B9E8F,
        0x0095A39F, 0x002C3433, 0x00484A3E, 0x00484D3E, 0x0044493A, 0x00424738, 0x0044493A, 0x0044493A, 0x00424738, 0x00434839, 0x00F4F4F3, 0x00797B70, 0x0046493A, 0x004C4F40, 0x004C4F40, 0x004C4F40, 0x004D5041, 0x004D5041, 0x004C4F40, 0x004D5041,
        0x00505344, 0x004D4F40, 0x004F5141, 0x00505142, 0x00494B3B, 0x0046493A, 0x004D4F41, 0x005B5B4C, 0x00737467, 0x00717163, 0x00555545, 0x004D4E3E, 0x00505141, 0x0056594B, 0x005B5D4F, 0x00585A4B, 0x00565849, 0x00545548, 0x004F5141, 0x00505141,
        0x00595A4B, 0x00717266, 0x006C6C5F, 0x004D4D3E, 0x00606255, 0x00515344, 0x00505243, 0x00535546, 0x00646759, 0x00737569, 0x005C5D4E, 0x0059594B, 0x005E5E50, 0x00545546, 0x00595A4A, 0x005B5D4E, 0x00585B4D, 0x005A5E50, 0x00585D4F, 0x004D5243,
        0x00565B4D, 0x00525648, 0x004B5041, 0x00484D3E, 0x005A5B4B, 0x00545748, 0x00494C3D, 0x004B4C3C, 0x007F7F74, 0x00F4F4F4, 0x00464737, 0x00454636, 0x00484939, 0x004B4C3C, 0x004C4D3D, 0x00454031, 0x00132A1C, 0x0084837F, 0x0089908B, 0x00657C74,
        0x00618D8C, 0x00308994, 0x003B84A4, 0x00289ABE, 0x002CA4D2, 0x001F9DD7, 0x001390CD, 0x00229AD5, 0x002399CD, 0x002197CA, 0x002098CC, 0x00076691, 0x0020323D, 0x00443D2A, 0x00333D2C, 0x00343833, 0x00393A31, 0x00323B2E, 0x003A3B31, 0x00374033,
        0x003A4336, 0x003C4538, 0x003A4336, 0x003A4336, 0x003E473A, 0x0040493C, 0x0040493C, 0x003E463B, 0x003D453A, 0x003C4439, 0x003D453A, 0x003F473C, 0x0040483D, 0x00424A3F, 0x00424A3F, 0x003E4236, 0x003A3E32, 0x00373B2F, 0x00383A2E, 0x00393B2F,
        0x003B3B2F, 0x003A3A2E, 0x0039392D, 0x00404034, 0x003D3D31, 0x003D3D31, 0x003D3F33, 0x003C3E32, 0x003A3E32, 0x0043473B, 0x004F5347, 0x00454B40, 0x00464C41, 0x00464C41, 0x00383E33, 0x003D4338, 0x00484E43, 0x003A4035, 0x00363C31, 0x00303E2C,
        0x003A392F, 0x003B3732, 0x0034382D, 0x00363B2C, 0x002E3128, 0x00122A30, 0x00073D4E, 0x00054459, 0x0007465B, 0x0009485D, 0x000A495E, 0x000A495E, 0x000A495E, 0x000A495E, 0x000B4A5F, 0x00155469, 0x0009485D, 0x0006445C, 0x000B4A5F, 0x00044456,
        0x000E505B, 0x00468A8F, 0x00458B8B, 0x007E8A96, 0x003C4443, 0x00657A78, 0x00558597, 0x003A7A92, 0x005F999F, 0x0077A69D, 0x007CAA9E, 0x00345D58, 0x00365F62, 0x001F464E, 0x0030595C, 0x0094BDB5, 0x0089AD9F, 0x0089A59F, 0x00899EA0, 0x008EA3A1,
        0x0087A0A4, 0x007F969E, 0x00677574, 0x00505044, 0x004D4430, 0x004C4532, 0x00534D42, 0x0038382C, 0x004A554B, 0x0052706B, 0x005E9292, 0x006CB6B8, 0x0070CCCD, 0x0071D8DA, 0x006CDAD8, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0x00485155, 0x007E878A, 0x009DA7A7, 0x009CA7A5, 0x009AA5A3, 0x00A8B3B0, 0x00BBC7C1, 0x00BCC7C4, 0x009CA7A4, 0x008F9A97, 0x0099A29F, 0x0097A09D, 0x009EA7A4, 0x009DA4A1, 0x00A3AAA7, 0x00A7AEAB, 0x009EA5A2, 0x00969D9A, 0x009CA3A0, 0x009DA4A1,
        0x00929996, 0x009AA19E, 0x00B3BAB7, 0x00A7B1AB, 0x00A6B0AA, 0x00A1ADA7, 0x00A3AEAB, 0x0099A4A1, 0x00909D9B, 0x006D7A78, 0x00505D5B, 0x00697373, 0x00798383, 0x00778181, 0x00727C7C, 0x00646E6E, 0x00505A5A, 0x004C5656, 0x00465050, 0x001F4C6D,
        0x00137EB1, 0x000274BA, 0x000560A5, 0x000066A7, 0x000B86D0, 0x001997E5, 0x0019A4E9, 0x0022A5F6, 0x001EADF8, 0x0022B8FF, 0x0028BBFF, 0x002BB9FA, 0x0030BCFE, 0x002EC5FF, 0x0020C4FF, 0x0033C4FB, 0x0034C1FA, 0x0036C0FB, 0x0030C2FE, 0x0026C0FB,
        0x002AC5FD, 0x003BC8FF, 0x0043C1FB, 0x001C94BE, 0x001286AF, 0x001784AA, 0x002B8FB2, 0x0047A1C0, 0x001D6D8A, 0x0039839D, 0x00347A92, 0x003885A0, 0x00428EAB, 0x004593B0, 0x003B8BAA, 0x002B7C9D, 0x002F81A4, 0x0024759A, 0x002D81A5, 0x004ABAEF,
        0x0033C8FA, 0x0029BFEE, 0x001C88B8, 0x003690BF, 0x0032A3D5, 0x001B9BD6, 0x00269BE6, 0x0025A1D7, 0x001E9ED9, 0x00199AD9, 0x002FA9E5, 0x003BA4D0, 0x0021738C, 0x003A7981, 0x00215351, 0x007BB0BD, 0x00488C9F, 0x0039808A, 0x0055847C, 0x00799185,
        0x0096A3A1, 0x002C3330, 0x00494A3A, 0x00464B3C, 0x00434839, 0x00434839, 0x0044493A, 0x00434839, 0x00414637, 0x00424738, 0x00F8F9F8, 0x007A7C72, 0x00494C3D, 0x004B4E3F, 0x004A4D3E, 0x004B4E3F, 0x004C4F40, 0x004C4F40, 0x004B4E3F, 0x00494C3D,
        0x004C4F40, 0x004C4E3F, 0x004C4F40, 0x004E5142, 0x004B4D3E, 0x0046493A, 0x004D5042, 0x00545545, 0x00515242, 0x004D4D3D, 0x00505040, 0x00515141, 0x00505142, 0x004F5243, 0x004E5042, 0x00515343, 0x004D4F40, 0x004B4E41, 0x004D4F3F, 0x004F5040,
        0x00535444, 0x004E5042, 0x00505142, 0x004F5141, 0x00505242, 0x00525545, 0x00545647, 0x00555646, 0x00525343, 0x00515242, 0x00535444, 0x00505141, 0x004F5040, 0x00525445, 0x00505243, 0x004F5142, 0x004A4F40, 0x004D5243, 0x004F5344, 0x004D5142,
        0x004C5041, 0x004D5243, 0x004B5041, 0x00484D3E, 0x004F5242, 0x004B4E3E, 0x00484B3B, 0x004A4B3B, 0x00808175, 0x00F9F9F8, 0x00484939, 0x00464737, 0x00484939, 0x004A4B3B, 0x00494A3A, 0x00544B3D, 0x001E3226, 0x00858682, 0x00828F87, 0x00638071,
        0x00719B90, 0x00539B9B, 0x006898AA, 0x0017718A, 0x002B91BB, 0x0029A0D8, 0x001190CD, 0x001E99D1, 0x002399CC, 0x002096CA, 0x001E95CD, 0x00076691, 0x0020323D, 0x00453E2B, 0x00343E2D, 0x00353934, 0x00393A31, 0x00323B2E, 0x003A3B31, 0x00374033,
        0x003B4437, 0x003D4639, 0x003B4437, 0x003B4437, 0x003E473A, 0x003F483B, 0x003E473A, 0x003C4439, 0x003D453A, 0x003E463B, 0x003E463B, 0x003E463B, 0x003F473C, 0x0040483D, 0x0041493E, 0x0044483C, 0x00404438, 0x003B3F33, 0x003C3E32, 0x003D3F33,
        0x00404034, 0x003F3F33, 0x003D3D31, 0x00414135, 0x003D3D31, 0x003D3D31, 0x003E4034, 0x003E4034, 0x003A3E32, 0x0042463A, 0x004D5145, 0x004C5247, 0x00474D42, 0x004A5045, 0x0040463B, 0x0043493E, 0x00474D42, 0x00373D32, 0x00393F34, 0x0032402E,
        0x003B3A30, 0x003C3833, 0x0035392E, 0x00373C2D, 0x002F3229, 0x00122A30, 0x00073D4E, 0x00054459, 0x0007465B, 0x0009485D, 0x000A495E, 0x000A495E, 0x000A495E, 0x000A495E, 0x000B4A5F, 0x00044358, 0x00125166, 0x000C4A62, 0x000C4B60, 0x00105062,
        0x00003D48, 0x0002464B, 0x00003C3C, 0x0000393B, 0x00044438, 0x0007483F, 0x00004451, 0x00004C61, 0x00104C52, 0x003B645C, 0x00517368, 0x00335C57, 0x00264F52, 0x00123941, 0x000F383B, 0x000E372F, 0x0024483A, 0x0047635D, 0x002E4345, 0x00122725,
        0x000A2327, 0x000B222A, 0x00172524, 0x00343428, 0x00483F2B, 0x003E3724, 0x00383227, 0x0052362F, 0x0049332E, 0x00302224, 0x00252029, 0x00272836, 0x00242B3A, 0x00252F40, 0x00222D3B, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0x0040494D, 0x008F989B, 0x00C0CACA, 0x00BFCAC8, 0x00B6C1BF, 0x00B7C2BF, 0x00B5C1BB, 0x0098A3A0, 0x0086918E, 0x0086918E, 0x009DA6A3, 0x009BA4A1, 0x00ADB4B1, 0x00A2A9A6, 0x009BA29F, 0x00C5CCC9, 0x00B0B7B4, 0x00969D9A, 0x009AA19E, 0x00A2A9A6,
        0x008C9390, 0x00848B88, 0x00989F9C, 0x00A1ABA5, 0x00B3BDB7, 0x00A6B2AC, 0x00A5B0AD, 0x00A0ABA8, 0x008B9896, 0x0063706E, 0x00515E5C, 0x00525E5E, 0x005D6969, 0x00505C5C, 0x00546060, 0x00535F5F, 0x003F4B4B, 0x003B4747, 0x00354141, 0x00204763,
        0x001A7CAC, 0x000B73B6, 0x001560A4, 0x000F66A8, 0x00107BC5, 0x001688D5, 0x001A9CE1, 0x0023A3EA, 0x0020ACEE, 0x001BB1ED, 0x0024B7EF, 0x0034BEF3, 0x0034BEF3, 0x002AC1F4, 0x0021C5F9, 0x0025C8F5, 0x0025BFF2, 0x0027BCF5, 0x0026BCF9, 0x001EB8F3,
        0x002ABBF3, 0x0031ADE3, 0x001E84B8, 0x00094F5C, 0x00003843, 0x00134950, 0x00517A7D, 0x007A9592, 0x0025332D, 0x003B4037, 0x003E3E32, 0x003C3B37, 0x0042403F, 0x003E3F3D, 0x0037393A, 0x00373C3F, 0x00363C41, 0x0020262D, 0x00394148, 0x006DB4D9,
        0x0038C3EA, 0x0036D1FE, 0x002A91C2, 0x002E82AC, 0x002BA5CD, 0x0018A7E0, 0x001D97EA, 0x001FA0D9, 0x001EA1DA, 0x001498D4, 0x000E91D0, 0x001991CC, 0x002F90B6, 0x0069AEB8, 0x00417067, 0x00668C8C, 0x0036717B, 0x0043878C, 0x0056877F, 0x00738B83,
        0x009BA9A8, 0x002C3330, 0x00454533, 0x0044493A, 0x00434839, 0x00424738, 0x00434839, 0x00414637, 0x003F4435, 0x00414637, 0x00D8D9D6, 0x00D4D4D1, 0x0082847A, 0x007F8177, 0x007F8177, 0x00808278, 0x00818379, 0x00818379, 0x00808278, 0x007F8176,
        0x00818378, 0x0083867B, 0x0083857A, 0x0083857A, 0x00818379, 0x007E8076, 0x007F8077, 0x0086877C, 0x0086867B, 0x0088887D, 0x0086877D, 0x0086867B, 0x0085867A, 0x0084867B, 0x0084857B, 0x0088887D, 0x0087887E, 0x0081837A, 0x007E7F75, 0x0084857A,
        0x0088887D, 0x0086877D, 0x0088887D, 0x0088887D, 0x0088897E, 0x0088897E, 0x0088897E, 0x0088897E, 0x0088897E, 0x0086867B, 0x0085867A, 0x00838378, 0x0084857A, 0x0085867A, 0x0085877D, 0x0085877D, 0x0082867A, 0x0085877D, 0x0086887D, 0x0084867B,
        0x0083867B, 0x0083877C, 0x0083877C, 0x0083867B, 0x0086877C, 0x00818378, 0x007E8076, 0x00818177, 0x00D5D5D1, 0x00DADAD7, 0x004D4E3E, 0x004C4D3D, 0x004A4B3B, 0x00474838, 0x00434434, 0x004D4135, 0x001E2F24, 0x00898A88, 0x0086958D, 0x0064826F,
        0x006B9282, 0x0045847B, 0x0054727D, 0x00003D51, 0x000F688D, 0x002798D0, 0x001A9AD5, 0x001A98CF, 0x002197CA, 0x00249ACE, 0x00188EC9, 0x00066590, 0x001F313C, 0x00453E2B, 0x00353F2E, 0x00363A35, 0x003A3B32, 0x00333C2F, 0x003A3B31, 0x00384134,
        0x003C4538, 0x003E473A, 0x003C4538, 0x003C4538, 0x003D4639, 0x003E473A, 0x003C4538, 0x003C4439, 0x003D453A, 0x003E463B, 0x003E463B, 0x003D453A, 0x003C4439, 0x003E463B, 0x003F473C, 0x004A4E42, 0x0043473B, 0x003A3E32, 0x0037392D, 0x0037392D,
        0x003B3B2F, 0x003C3C30, 0x003C3C30, 0x00414135, 0x003E3E32, 0x003E3E32, 0x00404236, 0x003F4135, 0x003A3E32, 0x003F4337, 0x00494D41, 0x0042483D, 0x003A4035, 0x0043493E, 0x0043493E, 0x00474D42, 0x00444A3F, 0x0030362B, 0x00383E33, 0x00344230,
        0x003D3C32, 0x003E3A35, 0x00363A2F, 0x00383D2E, 0x002F3229, 0x00122A30, 0x00073D4E, 0x00054459, 0x0007465B, 0x0009485D, 0x000A495E, 0x000A495E, 0x000A495E, 0x000A495E, 0x000B4A5F, 0x000B4A5F, 0x00054459, 0x000B4961, 0x000E4D62, 0x00034355,
        0x00145661, 0x004E9297, 0x00418787, 0x0067939A, 0x004E736B, 0x00618D87, 0x002F6E7C, 0x00064C63, 0x00437D83, 0x0092BDB4, 0x00A4CABE, 0x0098C1BC, 0x00446D70, 0x00153C44, 0x001D4649, 0x00689189, 0x00628678, 0x00708C86, 0x00415658, 0x00142927,
        0x000D262A, 0x000C232B, 0x00172524, 0x0038382C, 0x004E4531, 0x00433C29, 0x00413B30, 0x004C4D33, 0x0041432F, 0x00222B1E, 0x0017281F, 0x00243936, 0x002F4747, 0x002E4646, 0x00213939, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0x004E5459, 0x00959BA0, 0x00AEB5B8, 0x00ACB3B6, 0x00A4ACAC, 0x008C9494, 0x00959D9D, 0x00878F8F, 0x00757D7D, 0x00757C7F, 0x007C8184, 0x0085888D, 0x0093969B, 0x00909096, 0x0084838C, 0x0095A0A4, 0x00808B8F, 0x00727D81, 0x00747F83, 0x007B868A,
        0x00838E92, 0x007F8A8E, 0x00727D81, 0x00879895, 0x007E8B8D, 0x007B858C, 0x00858994, 0x008E909B, 0x0079797F, 0x00606060, 0x0070726C, 0x00818988, 0x007C8785, 0x006F7B7B, 0x00737F81, 0x00747F83, 0x006A7377, 0x0072757D, 0x007D7F87, 0x003B525A,
        0x00253E48, 0x00122F3D, 0x00032437, 0x00022B41, 0x000D3C57, 0x000F415D, 0x000D4361, 0x00054F69, 0x000C5670, 0x0009546E, 0x000A5772, 0x000B5A75, 0x000B5B78, 0x0010607D, 0x00055874, 0x0013646B, 0x00105E83, 0x0014699B, 0x00087A9F, 0x00007EA5,
        0x000F75B0, 0x001969A0, 0x000D6A81, 0x00005A9C, 0x00055C84, 0x008BB5C1, 0x00ADBAB2, 0x005B7466, 0x00364A3E, 0x002F3730, 0x00284339, 0x0036403A, 0x003C433E, 0x00373D38, 0x003B3E3C, 0x003A3F3D, 0x00414746, 0x00222D2B, 0x003F4D4B, 0x004A8581,
        0x00C2CBD8, 0x00BDECFF, 0x002896B2, 0x000D6F99, 0x001C6A9F, 0x002F92C6, 0x002592C6, 0x001AA5D6, 0x0027A3D9, 0x002A95CE, 0x00288DC4, 0x00248ABA, 0x003495B9, 0x0055A9C3, 0x0067ACC0, 0x005586B2, 0x004E88B2, 0x00649CB5, 0x0067908B, 0x00749483,
        0x0092ACA6, 0x0022302E, 0x00424035, 0x00474B3F, 0x0045493D, 0x0043473B, 0x0042463A, 0x00414539, 0x00404438, 0x003E4236, 0x005D6056, 0x00D6D7D4, 0x00F3F3F2, 0x00F3F4F3, 0x00F4F4F3, 0x00F3F3F2, 0x00F3F3F2, 0x00F5F5F4, 0x00F3F3F2, 0x00F5F5F4,
        0x00F4F4F3, 0x00F3F3F2, 0x00F4F4F3, 0x00F5F5F5, 0x00F3F4F2, 0x00F5F5F5, 0x00F3F3F2, 0x00F5F5F4, 0x00F6F6F5, 0x00F5F5F4, 0x00F2F2F1, 0x00F2F2F1, 0x00F5F5F5, 0x00F5F5F4, 0x00F2F3F1, 0x00F2F2F1, 0x00F5F5F4, 0x00F6F6F5, 0x00F3F3F2, 0x00F2F2F1,
        0x00F3F3F2, 0x00F5F5F4, 0x00F6F6F5, 0x00F2F2F1, 0x00F3F3F2, 0x00F3F3F2, 0x00F5F6F5, 0x00F4F4F3, 0x00F2F2F1, 0x00F4F4F3, 0x00F5F6F5, 0x00F4F4F3, 0x00F3F3F2, 0x00F4F4F3, 0x00F6F6F5, 0x00F5F5F5, 0x00F3F3F2, 0x00F2F2F1, 0x00F5F5F4, 0x00F6F6F5,
        0x00F4F4F3, 0x00F1F1F0, 0x00F3F3F2, 0x00F5F6F5, 0x00F4F4F3, 0x00F3F3F2, 0x00F1F2F0, 0x00F3F3F2, 0x00D4D4D0, 0x0066675A, 0x0049493B, 0x0049493B, 0x0049493B, 0x0049493B, 0x0048483A, 0x003C452A, 0x001A2D1C, 0x008A8586, 0x00839392, 0x00637C78,
        0x00768483, 0x0055787C, 0x00627184, 0x00124248, 0x00003E50, 0x00106A8D, 0x002898CC, 0x001C98D4, 0x001793CF, 0x002599D0, 0x002593C3, 0x00106595, 0x00112C40, 0x00383C36, 0x003B3F33, 0x003E382D, 0x003C3E2A, 0x002F402B, 0x00343832, 0x00383E33,
        0x00383E33, 0x00383E33, 0x00393F34, 0x003B4136, 0x003C4237, 0x003B4136, 0x003A4035, 0x003E3F35, 0x003A3B31, 0x003A3B31, 0x003E3F35, 0x003E3F35, 0x003B3C32, 0x003A3B31, 0x003D3E34, 0x0038392F, 0x003D3E34, 0x0037382E, 0x003A3B31, 0x0036372D,
        0x003C3D33, 0x0038392F, 0x003C3D33, 0x00373D32, 0x00393F34, 0x00373D32, 0x00373D32, 0x003A4035, 0x003C4237, 0x003A4035, 0x00373D32, 0x003F3E34, 0x003E3D33, 0x00403F35, 0x003F3E34, 0x003C3B31, 0x003C3B31, 0x003E3D33, 0x003E3D33, 0x003B3D31,
        0x003A3D34, 0x00363930, 0x003A3A2C, 0x003B3D2A, 0x00253328, 0x000C3036, 0x000C4156, 0x0006455A, 0x0007465B, 0x0009485D, 0x000A495E, 0x000B4A5F, 0x000A495E, 0x000A495E, 0x0009485D, 0x00054A5B, 0x000D4F61, 0x000B4C5B, 0x000B4959, 0x00044050,
        0x001C5766, 0x004E8796, 0x004A8392, 0x007C8686, 0x003C484E, 0x005D7483, 0x00557F92, 0x00437E8E, 0x004A858E, 0x00729E9F, 0x007F9A97, 0x003F5B62, 0x002F464E, 0x00243A3F, 0x00416061, 0x0085B5AF, 0x008BBEB6, 0x008CB7AE, 0x009BBDB3, 0x008EA4AF,
        0x00A5A8A6, 0x0095A69B, 0x00627975, 0x00544745, 0x005A4131, 0x00514A36, 0x00584F46, 0x0053483A, 0x00434539, 0x0050695F, 0x0077A7A1, 0x0083C5C4, 0x0078C4CA, 0x0075C5D0, 0x0079C8D5, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0x005C6267, 0x0051575C, 0x0041484B, 0x0040474A, 0x004D5555, 0x003A4242, 0x00283030, 0x002E3636, 0x00232B2B, 0x002B3031, 0x002C3134, 0x00292C30, 0x0032353A, 0x0034373C, 0x00323238, 0x002C3539, 0x00283135, 0x002A3337, 0x002D363A, 0x002E373B,
        0x00313A3E, 0x00313A3E, 0x002A3337, 0x00283837, 0x00293638, 0x00343F47, 0x00363E4B, 0x002F3645, 0x00292F3A, 0x00252D34, 0x00313A3D, 0x00435265, 0x004B596B, 0x00475462, 0x00424F57, 0x00414F55, 0x003B494F, 0x003A484E, 0x003F4D53, 0x0011262E,
        0x00001119, 0x0000151F, 0x00011E2C, 0x0000202E, 0x00002335, 0x00022C3F, 0x00103B4E, 0x000A3E4B, 0x000F4350, 0x000C414E, 0x000A4150, 0x000D4655, 0x000D4857, 0x000E4959, 0x00155161, 0x00004F5D, 0x001388AF, 0x002DB7EB, 0x0035C3F2, 0x0034BBF1,
        0x0032B4F9, 0x0036BAF6, 0x0037C2E3, 0x0034C2FF, 0x003EC1E8, 0x0087D0DE, 0x0094B3B2, 0x00637F79, 0x003D4B47, 0x00484040, 0x003A413C, 0x00384039, 0x003C433C, 0x003D413B, 0x003F403C, 0x00393D38, 0x003A3F3D, 0x00242D2A, 0x0053615D, 0x004F827A,
        0x00AAB1BA, 0x00C1E9FB, 0x002C92A9, 0x00157599, 0x003685B6, 0x002E91C3, 0x002F9ED0, 0x0023A2D5, 0x002EA0D5, 0x002F93CD, 0x003297CE, 0x002A95C8, 0x00117FA9, 0x00167C9F, 0x002B88A9, 0x00327AA2, 0x002F7CA3, 0x00488BA2, 0x005F8883, 0x007D9787,
        0x009DAEAA, 0x002C3231, 0x00494036, 0x00464A3E, 0x0044483C, 0x0042463A, 0x00414539, 0x00414539, 0x00414539, 0x00404438, 0x00414539, 0x00474A3B, 0x005D5F52, 0x005A5C4F, 0x00585B4D, 0x005F6255, 0x005E6153, 0x0057594B, 0x005F6154, 0x0055584A,
        0x00595C4E, 0x00626456, 0x005F6053, 0x005E5E50, 0x00676759, 0x005B5D4F, 0x005D6054, 0x00545648, 0x005A5B4D, 0x005D5E4F, 0x00727367, 0x00737366, 0x00595B4C, 0x00505243, 0x00636558, 0x006E7065, 0x00595C4D, 0x0053574A, 0x005D5F51, 0x006D7068,
        0x00616458, 0x005F6052, 0x00575849, 0x00717367, 0x006B6D60, 0x00626457, 0x005C5E50, 0x005D5F50, 0x00797A6D, 0x0069695B, 0x00595A4B, 0x00616254, 0x00646456, 0x00676759, 0x005A5A4D, 0x00575A4B, 0x0068685A, 0x0077786B, 0x005E5F50, 0x00565748,
        0x00626456, 0x00787A6D, 0x00656758, 0x00595B4C, 0x00616455, 0x0065685A, 0x006F7165, 0x005D5F51, 0x00626558, 0x004B4D3E, 0x004A4B3C, 0x004A4A3C, 0x004A4A3C, 0x004A4A3C, 0x0049493B, 0x00414730, 0x001A2D1E, 0x00898786, 0x00819894, 0x00638A82,
        0x00759B9B, 0x00387D86, 0x00175069, 0x0011484D, 0x000B4B56, 0x00004861, 0x00016288, 0x002593C3, 0x00299DD4, 0x001990C8, 0x001E95CD, 0x00146996, 0x00152F3F, 0x00393C33, 0x00393D31, 0x003E382D, 0x003A3C28, 0x002E3F2A, 0x00373933, 0x00373D32,
        0x00363C31, 0x00363C31, 0x00383E33, 0x003B4136, 0x003C4237, 0x003B4136, 0x00393F34, 0x003E4237, 0x003F4338, 0x003F4338, 0x003E4237, 0x003C4035, 0x003B3F34, 0x003A3E33, 0x00393D32, 0x003D4136, 0x003A3E33, 0x003A3E33, 0x0041453A, 0x00383C31,
        0x003E4237, 0x003F4338, 0x003E4237, 0x0040463B, 0x00373D32, 0x00363C31, 0x003C4237, 0x003C4237, 0x00383E33, 0x003B4136, 0x0041473C, 0x003F4036, 0x00414238, 0x00404137, 0x003E3F35, 0x003F4036, 0x003D3E34, 0x003C3D33, 0x003E3F35, 0x003A3C30,
        0x003A3D34, 0x0035382F, 0x003A3A2C, 0x003B3D2A, 0x00243227, 0x000C3036, 0x000B4055, 0x0006455A, 0x0007465B, 0x0009485D, 0x000A495E, 0x000A495E, 0x000A495E, 0x0009485D, 0x0009485D, 0x000C4E61, 0x00084A5D, 0x00064559, 0x00104E60, 0x000F4A5D,
        0x000D4959, 0x00104B5B, 0x00003747, 0x001D4446, 0x00012830, 0x00174253, 0x00074055, 0x00004456, 0x0000434F, 0x00054246, 0x000B3B3C, 0x00012235, 0x000B2738, 0x00193343, 0x00092B38, 0x001D4C54, 0x00679A9D, 0x00739C9F, 0x001C3A3F, 0x001B3241,
        0x00252A2B, 0x0019302C, 0x000E2D30, 0x00282429, 0x0043372B, 0x003B3F2C, 0x00373A31, 0x0047322A, 0x00342921, 0x002B2F29, 0x00253A37, 0x001B393A, 0x0015353A, 0x0016343F, 0x000F2A38, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFCDD1D6, 0xFFC3C8CB, 0xFFC8CDD0, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00070D0C, 0x00030908, 0x00000201, 0x00050A0B, 0x0004090A, 0x00000003, 0x00020509, 0x00080B0F, 0x000A0D12, 0x0000070A, 0x00030C0F, 0x00081114, 0x00050E11, 0x0000080B,
        0x00020B0E, 0x00060F12, 0x00040D10, 0x00071416, 0x0007151B, 0x001F2B35, 0x00233040, 0x000F1D30, 0x00061528, 0x00051728, 0x0007192A, 0x00051A40, 0x000D2041, 0x0009172D, 0x00000814, 0x00000B11, 0x00001013, 0x00000A0F, 0x00000C12, 0x0005191E,
        0x00001116, 0x00091F24, 0x000D2328, 0x00041D21, 0x000B262A, 0x001A3539, 0x00233E42, 0x002F4543, 0x00344A48, 0x00374F4F, 0x00334D4D, 0x00365252, 0x002F4D4E, 0x00224041, 0x003E5D5E, 0x0077BDD5, 0x004FCBF3, 0x001EC6FB, 0x001EC0FB, 0x002CB8FF,
        0x0022B7FF, 0x0021C7FF, 0x0025C8F9, 0x001EBDFB, 0x003ACBF1, 0x0078CEE0, 0x00799FA3, 0x00608281, 0x003C4B4D, 0x003E3839, 0x00363E37, 0x00394136, 0x00393E35, 0x00404138, 0x00404138, 0x003F3F39, 0x003B3F39, 0x00212823, 0x005A645E, 0x00527469,
        0x009CA1A2, 0x00C7EAF4, 0x00247B8B, 0x000B6583, 0x004090B9, 0x001879A5, 0x000F7FAD, 0x002599D4, 0x0037A3DD, 0x003096D1, 0x00218AC3, 0x001A8ABF, 0x001B91C2, 0x00269AC9, 0x002C9CCA, 0x003399BC, 0x002F93B6, 0x003E8AA0, 0x005B847F, 0x00869789,
        0x00A1AAA7, 0x00313131, 0x004D4137, 0x0045493D, 0x0043473B, 0x00404438, 0x003F4337, 0x00404438, 0x00414539, 0x00414539, 0x00BDBFBB, 0x007C7E73, 0x00C4C5C0, 0x009D9F96, 0x0091938A, 0x00B9BAB4, 0x00C6C7C2, 0x0066695C, 0x00E1E2DF, 0x007A7C71,
        0x00AAABA4, 0x00B5B7B0, 0x00B5B6B0, 0x00787B6F, 0x00E4E5E2, 0x006A6C60, 0x00CBCCC8, 0x00575A4C, 0x004C4F40, 0x00A0A199, 0x00D1D2CE, 0x00C6C6C2, 0x00777A6E, 0x0076796D, 0x00D3D3D0, 0x00C9C9C4, 0x00AEAFA7, 0x00616357, 0x00D6D6D3, 0x00CDCECB,
        0x00DDDDDA, 0x008D8D82, 0x0087887D, 0x00E0E0DD, 0x00CBCBC7, 0x00DBDCD9, 0x00606355, 0x00BABBB5, 0x00C7C8C3, 0x00D3D3CF, 0x00747568, 0x00B5B5AE, 0x00DADAD7, 0x00ADADA6, 0x004D4F40, 0x006D7165, 0x00D9D9D6, 0x00D4D4D0, 0x00B4B4AE, 0x00636456,
        0x00CECECA, 0x00CECFCA, 0x00D6D7D3, 0x006C6F61, 0x00AFB0A9, 0x00D1D2CE, 0x00DDDEDB, 0x00CFD0CC, 0x00D5D7D3, 0x00CDCFCA, 0x004B4D3E, 0x004C4C3E, 0x004B4B3D, 0x004A4A3C, 0x004A4A3C, 0x00474838, 0x001C2D20, 0x008A8A84, 0x007A958C, 0x00528178,
        0x0066A2A2, 0x002F9BAD, 0x00117CA2, 0x0010555F, 0x00074C56, 0x0000414F, 0x0000495F, 0x00166E8C, 0x002C92BD, 0x002599CE, 0x00128ECA, 0x0017688D, 0x0018303C, 0x0035392E, 0x00353C2F, 0x003F382F, 0x003B3D2A, 0x0030402E, 0x003B3D37, 0x0041473C,
        0x003F453A, 0x003D4338, 0x003F453A, 0x0042483D, 0x0042483D, 0x0040463B, 0x003D4338, 0x003E463B, 0x00454D42, 0x00474F44, 0x00424A3F, 0x003F473C, 0x0040483D, 0x003F473C, 0x003C4439, 0x00444C41, 0x003A4237, 0x003D453A, 0x004B5348, 0x003D453A,
        0x00424A3F, 0x00454D42, 0x00424A3F, 0x0041473C, 0x00363C31, 0x003A4035, 0x00454B40, 0x00444A3F, 0x00444A3F, 0x004B5146, 0x004D5348, 0x0043493E, 0x00484E43, 0x00444A3F, 0x0042483D, 0x00474D42, 0x0043493E, 0x003C4237, 0x003F453A, 0x00393B2F,
        0x00393C33, 0x0035382F, 0x0039392B, 0x003A3C29, 0x00233126, 0x000B2F35, 0x000A3F54, 0x0006455A, 0x0007465B, 0x0008475C, 0x000A495E, 0x000A495E, 0x000A495E, 0x0009485D, 0x0009485D, 0x00084860, 0x00094961, 0x000A495E, 0x000C4B60, 0x000E4A60,
        0x000E495D, 0x000E495D, 0x000A4559, 0x000C4D55, 0x000E4756, 0x00154A5F, 0x0007435B, 0x0000455C, 0x00024C5E, 0x00054654, 0x000B424B, 0x00103D58, 0x00002440, 0x00062943, 0x00032C43, 0x00002034, 0x0016485A, 0x00264E60, 0x00001529, 0x00001526,
        0x00000911, 0x0000161B, 0x00002634, 0x00071626, 0x001F2422, 0x00162D1F, 0x001C322D, 0x002C1C16, 0x001A1009, 0x0015120D, 0x0010140F, 0x00121513, 0x001F1F1F, 0x002B2427, 0x0025171D, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFBFEFF, 0xFFF8FBFF, 0xFFFBFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x000A0F0E, 0x000A0F0D, 0x00000200, 0x00030807, 0x00050A09, 0x00000506, 0x00080D0E, 0x000C1114, 0x000C1114, 0x000A1316, 0x000D1619, 0x000C1518, 0x00060F12, 0x00030C0F,
        0x00060F12, 0x00081114, 0x00040D10, 0x00030F13, 0x0000080E, 0x000F1D29, 0x00253545, 0x001D3045, 0x0011283E, 0x000D2640, 0x000A253F, 0x00173050, 0x00112641, 0x00071424, 0x0000060D, 0x000C1112, 0x00131D1D, 0x000A1B1E, 0x000B2126, 0x0025383B,
        0x00192B2C, 0x0020302F, 0x00162724, 0x00061511, 0x0014221C, 0x0028352D, 0x002B3830, 0x00363832, 0x00383C36, 0x0041453F, 0x003D433E, 0x00414843, 0x0037403D, 0x001F2A27, 0x0056615E, 0x008EB0C8, 0x0088CEF3, 0x0041C8FA, 0x0016BCF9, 0x0022B5FF,
        0x0032BCFF, 0x0039C6FF, 0x0030B1EA, 0x003EB2E9, 0x0048B4D6, 0x0096D1E1, 0x007F979D, 0x005F7F7E, 0x003B524E, 0x0029342A, 0x00304C38, 0x00383E33, 0x00363A2F, 0x003F4036, 0x003C3A32, 0x003F3D35, 0x003D3F39, 0x00232A23, 0x0059645C, 0x00667C70,
        0x0099A29F, 0x00ABCACD, 0x000A515B, 0x00003F54, 0x00237293, 0x001D789F, 0x00339FC8, 0x00219CE0, 0x002BA3E5, 0x002EA0DF, 0x002496D2, 0x001889C1, 0x00188BBE, 0x00208FC1, 0x001482B2, 0x001A8EAF, 0x00208CAE, 0x00358197, 0x005E837F, 0x008C9B8D,
        0x00A0A9A6, 0x002A2F2E, 0x00423E33, 0x0045493D, 0x0043473B, 0x00404438, 0x003E4236, 0x003F4337, 0x00404438, 0x00414539, 0x00AFB0AB, 0x00C3C4BF, 0x00D4D5D2, 0x00CACBC6, 0x00CDCECA, 0x008C8E84, 0x00C2C3BF, 0x00BBBCB6, 0x00E5E5E3, 0x00B1B2AC,
        0x00D9D9D6, 0x007D7F74, 0x00DADBD8, 0x00B4B5AF, 0x00E9EAE8, 0x00BBBCB6, 0x00CDCEC9, 0x0045483A, 0x00494C3F, 0x00AEAEA8, 0x00D9DAD6, 0x00B8B9B3, 0x007B7D71, 0x00C5C6C1, 0x00D7D8D4, 0x00ADAEA6, 0x00E3E3E1, 0x00B4B5AF, 0x00D3D3CF, 0x004E5042,
        0x00CDCDC8, 0x00ADADA6, 0x00D4D4D0, 0x008B8B81, 0x005E6052, 0x00EDEDEC, 0x008E9086, 0x00F4F5F4, 0x00A8A9A1, 0x00DCDCD8, 0x00ACACA5, 0x00CECEC9, 0x00B1B1AA, 0x00545547, 0x004D4E3F, 0x00BFC0BB, 0x00C0C2BC, 0x00555747, 0x0078796D, 0x00AAAAA2,
        0x00D3D3CF, 0x004E4F40, 0x00C1C1BC, 0x00BBBDB6, 0x00C5C6C0, 0x009D9F96, 0x00989990, 0x00D0D1CD, 0x00696E5F, 0x00F1F2F0, 0x004D5242, 0x004C4E3F, 0x004A4A3C, 0x0049493B, 0x0048483A, 0x00434337, 0x001B2B20, 0x008F8D85, 0x0082988C, 0x004D786D,
        0x004D898F, 0x001C94B1, 0x001A9DCF, 0x0024829F, 0x0001566C, 0x00004653, 0x0007454F, 0x00014552, 0x00176B85, 0x002F95BF, 0x002396C9, 0x00176582, 0x001E343A, 0x00373A2B, 0x00353C2F, 0x003F3932, 0x00383B2B, 0x00303E2C, 0x003E3B36, 0x0043493E,
        0x0041473C, 0x003E4439, 0x003F453A, 0x0041473C, 0x0041473C, 0x003D4338, 0x00393F34, 0x00384236, 0x003E483C, 0x00424C40, 0x00404A3E, 0x003E483C, 0x003E483C, 0x003E483C, 0x003C463A, 0x00404A3E, 0x00374135, 0x00384236, 0x00465044, 0x003B4539,
        0x003D473B, 0x003C463A, 0x003C463A, 0x003F453A, 0x00383E33, 0x003E4439, 0x00444A3F, 0x0041473C, 0x00474D42, 0x00484E43, 0x003B4136, 0x003F473C, 0x00464E43, 0x00424A3F, 0x0040483D, 0x00474F44, 0x003F473C, 0x00323A2F, 0x00353D32, 0x00383A2E,
        0x00383B32, 0x0034372E, 0x0039392B, 0x003A3C29, 0x00233126, 0x000A2E34, 0x00093E53, 0x0006455A, 0x0007465B, 0x0008475C, 0x0009485D, 0x000A495E, 0x000A495E, 0x0009485D, 0x0008475C, 0x0003405A, 0x000B4862, 0x000C4963, 0x0004425A, 0x0006445C,
        0x000C485E, 0x000A465C, 0x000E4A60, 0x00044D5B, 0x000B485C, 0x0011425C, 0x00104260, 0x00013B58, 0x0005455D, 0x000D465B, 0x000C3E50, 0x00053E57, 0x00063953, 0x0006344C, 0x00003046, 0x00003045, 0x002D6578, 0x002C576C, 0x00001E33, 0x0004243B,
        0x000B1E2D, 0x00073546, 0x000D4E6A, 0x00001D39, 0x00032025, 0x0008332A, 0x0028504E, 0x0021221E, 0x00000200, 0x00010801, 0x000C140D, 0x001A1F16, 0x0026241C, 0x002F2720, 0x00251A12, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFDFEFF, 0xFFFCFEFF, 0xFFFDFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00161917, 0x00111510, 0x00000300, 0x00000503, 0x00030806, 0x00010706, 0x00070F0E, 0x00091111, 0x00081010, 0x00091013, 0x000C1316, 0x000C1316, 0x000A1114, 0x000C1316,
        0x000E1518, 0x000B1215, 0x00060D10, 0x000B131A, 0x00000C12, 0x00030F19, 0x00142631, 0x001F3344, 0x001C3549, 0x0019344E, 0x00193651, 0x00132C36, 0x00091B22, 0x00040B0E, 0x000B0908, 0x00191612, 0x001D1E1C, 0x001E2324, 0x00232F31, 0x00627271,
        0x003F4F4E, 0x00384543, 0x002E3A34, 0x001B241A, 0x001D2318, 0x002C3024, 0x00373A2B, 0x003C3935, 0x003C3B37, 0x0042413D, 0x003D3E3C, 0x00424543, 0x003D4240, 0x002A302F, 0x007A807F, 0x0071818D, 0x00CBD0E9, 0x0085D8FE, 0x0016C1F4, 0x0024C5FF,
        0x0045BDF9, 0x002B8EC2, 0x00004B7C, 0x0000466E, 0x00074D65, 0x0073939E, 0x00848D90, 0x006A8280, 0x004A5B57, 0x00353A2B, 0x002E4428, 0x00363E33, 0x00373D32, 0x0042433A, 0x0039372F, 0x00393933, 0x003C403A, 0x00283029, 0x00515B55, 0x005F736E,
        0x00788F8B, 0x00759495, 0x00144C51, 0x0000414F, 0x00004960, 0x00136382, 0x0041A2C3, 0x001C9EE4, 0x001297DB, 0x001395D8, 0x0027A2E0, 0x002798D1, 0x001177AB, 0x0013719E, 0x00207CA5, 0x00097799, 0x00157B9E, 0x002F788E, 0x005D7E7A, 0x008C998B,
        0x009CAAA6, 0x00253331, 0x003D4639, 0x00464A3E, 0x0043473B, 0x003F4337, 0x003D4135, 0x003D4135, 0x003E4236, 0x003F4337, 0x006D7067, 0x00FFFFFF, 0x00ADAFA8, 0x00CACBC7, 0x00F0F0EF, 0x004C5042, 0x00999B93, 0x00FFFFFF, 0x0095978F, 0x00EDEDEC,
        0x00CFD0CC, 0x00494C3D, 0x00C6C7C2, 0x00F4F4F3, 0x00999B92, 0x00FFFFFF, 0x00A0A199, 0x0077796E, 0x006B6D5F, 0x008A8A80, 0x00A4A59C, 0x00D0D0CD, 0x00D0D1CD, 0x00BFC0BA, 0x00D7D8D4, 0x0096978E, 0x00A8A9A1, 0x0094958C, 0x00E2E3E0, 0x007C7D73,
        0x00DDDDDA, 0x00A5A69D, 0x00C4C4BF, 0x00B5B5AE, 0x008A8B81, 0x00EEEFED, 0x0084867C, 0x00F3F3F2, 0x009B9D94, 0x00AEAFA8, 0x007D7D71, 0x00D3D3CF, 0x0093948A, 0x006F7164, 0x0077786D, 0x00B0B1AB, 0x00D1D2CE, 0x0076776B, 0x00A0A097, 0x009F9F96,
        0x00E0E0DD, 0x00666759, 0x00D1D1CD, 0x00AFAFA8, 0x00C6C7C2, 0x0093948A, 0x0097978D, 0x00CBCBC6, 0x00616355, 0x00F3F4F2, 0x00515444, 0x004F5040, 0x0049493B, 0x00474739, 0x00464638, 0x0045443A, 0x001D2E23, 0x008E8B83, 0x008D9B8F, 0x00658077,
        0x0055828D, 0x001783A5, 0x001C9AD5, 0x002A9ED3, 0x001177A1, 0x0001536C, 0x00064750, 0x000A464C, 0x00084D57, 0x0010657B, 0x002282A0, 0x00145D71, 0x00263837, 0x003D3F2C, 0x00363D30, 0x003E3A35, 0x0036392A, 0x002C3A28, 0x00393530, 0x0041473C,
        0x0040463B, 0x003E4439, 0x003F453A, 0x0041473C, 0x0041473C, 0x003F453A, 0x003C4237, 0x003B4539, 0x003C463A, 0x00404A3E, 0x00434D41, 0x00404A3E, 0x003B4539, 0x003B4539, 0x003F493D, 0x00404A3E, 0x003C463A, 0x00374135, 0x00434D41, 0x003E483C,
        0x003D473B, 0x00374135, 0x003D473B, 0x0041473C, 0x00373D32, 0x003B4136, 0x0041473C, 0x0042483D, 0x00494F44, 0x00484E43, 0x00373D32, 0x003E463B, 0x00464E43, 0x00434B40, 0x0041493E, 0x00474F44, 0x003E463B, 0x002F372C, 0x0030382D, 0x0037392D,
        0x00373A31, 0x0034372E, 0x0039392B, 0x003A3C29, 0x00233126, 0x000A2E34, 0x00093E53, 0x00054459, 0x0006455A, 0x0008475C, 0x0009485D, 0x000A495E, 0x0009485D, 0x0009485D, 0x0008475C, 0x000D4A64, 0x0008455F, 0x0005425C, 0x0005435B, 0x000C4A62,
        0x000D4E63, 0x0007485D, 0x0007485D, 0x00004B5C, 0x0004495D, 0x000C445D, 0x00164D68, 0x000D4A64, 0x0005485F, 0x0007465B, 0x000C4358, 0x00014655, 0x00074452, 0x000A4352, 0x00064150, 0x0000424F, 0x00317280, 0x002F6471, 0x000C3544, 0x00083148,
        0x0008273C, 0x0008465E, 0x001B6E94, 0x00002B52, 0x00002936, 0x00023E38, 0x00306764, 0x00323533, 0x00000200, 0x00010803, 0x000E170D, 0x00192317, 0x001D2417, 0x00232819, 0x00191C0C, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFCFBFD, 0xFFFFFEFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x001F201E, 0x00171913, 0x00050602, 0x00050904, 0x00040A05, 0x00000704, 0x00030C09, 0x00040F0D, 0x0005100E, 0x00040C0C, 0x00070F0F, 0x00060E0E, 0x00070F0F, 0x00091111,
        0x00081010, 0x00050D0D, 0x00060E0E, 0x000A1017, 0x000C141B, 0x00000B0F, 0x00000E11, 0x00061920, 0x00071D29, 0x00041A2C, 0x0000172B, 0x00011814, 0x0000100F, 0x00020A0A, 0x00101010, 0x00140E0F, 0x00130F0E, 0x00201F1B, 0x00222621, 0x00485857,
        0x00364442, 0x00313F3B, 0x0026302A, 0x00192019, 0x00262920, 0x00323329, 0x0036362A, 0x00393A36, 0x003B3C38, 0x003E413F, 0x003B403E, 0x003E4443, 0x00394140, 0x00283030, 0x00818B8B, 0x005A736F, 0x00C5B4BD, 0x0081BFD7, 0x0017C1EA, 0x002ECBFD,
        0x002F98BF, 0x00035771, 0x00023B5A, 0x0007455D, 0x00003D48, 0x00294C50, 0x00364548, 0x001B363A, 0x001E2A2C, 0x00473B35, 0x004F4B38, 0x00373F38, 0x00343B34, 0x00383C36, 0x00343531, 0x00383C37, 0x003A3F3D, 0x001F2825, 0x0024322E, 0x0010292D,
        0x00194546, 0x00244A4E, 0x00164347, 0x000F555C, 0x00004352, 0x000C4C64, 0x00156780, 0x001D94CC, 0x0029A9E4, 0x001CA3E1, 0x00199CDB, 0x002A9CD8, 0x002787BC, 0x00247AA4, 0x002B7DA0, 0x001A7EA1, 0x002280A4, 0x003E8198, 0x0062817E, 0x00869587,
        0x0098A9A5, 0x00213431, 0x003B483A, 0x0044483C, 0x00414539, 0x003E4236, 0x003C4034, 0x003C4034, 0x003D4135, 0x003D4135, 0x0041453A, 0x00BDBEB9, 0x006D7064, 0x008D8E85, 0x00A7A9A2, 0x00464B3C, 0x00616558, 0x00C3C4BF, 0x00575B4E, 0x00B0B2AB,
        0x0087897F, 0x0045493A, 0x0083867B, 0x00B8BAB4, 0x00585D4F, 0x00C2C3BF, 0x0066695C, 0x00A6A7A0, 0x00898A7F, 0x008A8A80, 0x00C9C9C4, 0x00C1C1BC, 0x00888A7F, 0x0065685A, 0x00C2C3BE, 0x00C7C8C4, 0x0093958C, 0x00545648, 0x00B1B2AC, 0x00BCBDB8,
        0x00E7E7E5, 0x00A1A199, 0x00707063, 0x00C6C6C1, 0x00BDBDB7, 0x00F4F4F3, 0x00606355, 0x009A9C94, 0x00CACBC7, 0x00BCBDB7, 0x00636457, 0x00A4A59D, 0x0076796D, 0x00909289, 0x009FA098, 0x005E6053, 0x00C4C5BF, 0x00D4D4D0, 0x009D9D94, 0x00565647,
        0x00B2B2AB, 0x00D1D1CD, 0x00BCBCB6, 0x00636455, 0x00A1A299, 0x007F8074, 0x00808074, 0x00A1A299, 0x005A5D4E, 0x00BABBB5, 0x00535646, 0x004F5140, 0x0048483A, 0x00464638, 0x00454537, 0x00444339, 0x00203128, 0x008C8883, 0x008E978D, 0x0075857E,
        0x006B8994, 0x002384A6, 0x002097CF, 0x001595D6, 0x002195CC, 0x001B7CA2, 0x000A596E, 0x00044953, 0x00064750, 0x00014754, 0x00034B5C, 0x00024855, 0x0025352E, 0x003E3F2B, 0x00363D30, 0x003E3B36, 0x0037392D, 0x00323D2D, 0x003E3833, 0x003D4338,
        0x003D4338, 0x003E4439, 0x0040463B, 0x0042483D, 0x0043493E, 0x0043493E, 0x0042483D, 0x00424A3F, 0x0041493E, 0x00434B40, 0x00464E43, 0x00434B40, 0x003C4439, 0x003B4338, 0x0040483D, 0x00444C41, 0x00434B40, 0x003C4439, 0x00444C41, 0x00434B40,
        0x00444C41, 0x003B4338, 0x0041493E, 0x00444A3F, 0x0033392E, 0x00343A2F, 0x0041473C, 0x00464C41, 0x00484E43, 0x004A5045, 0x00474D42, 0x0041473C, 0x00474D42, 0x00464C41, 0x00454B40, 0x00484E43, 0x0040463B, 0x00343A2F, 0x00343A2F, 0x0037392D,
        0x00373A31, 0x0035382F, 0x003A3A2C, 0x003B3D2A, 0x00233126, 0x000A2E34, 0x00083D52, 0x00054459, 0x0006455A, 0x0008475C, 0x0009485D, 0x0009485D, 0x0009485D, 0x0008475C, 0x0008475C, 0x000B475F, 0x000A465E, 0x00115065, 0x00155469, 0x0006475C,
        0x00003F52, 0x0003475A, 0x00094D60, 0x00004E5D, 0x00004E5F, 0x00004557, 0x00004355, 0x00004E5F, 0x00004656, 0x00004455, 0x00074C5F, 0x00034B53, 0x0004424C, 0x0008434D, 0x00064750, 0x0000454D, 0x0000424A, 0x0000313D, 0x0010414F, 0x0010445B,
        0x000E394E, 0x00105C79, 0x002F93C3, 0x00004170, 0x00003A4D, 0x00054745, 0x00377470, 0x00393132, 0x00050000, 0x00100B08, 0x0016130E, 0x001B1C12, 0x00202216, 0x00252A1B, 0x00151B0A, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFCFBFD, 0xFFFFFEFF, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00181917, 0x001C1C16, 0x00070903, 0x00060A04, 0x00060C07, 0x00010803, 0x00020D0A, 0x0003110D, 0x0005130F, 0x00090E0F, 0x00090E0F, 0x00070C0D, 0x000B1011, 0x000F1415,
        0x00090E0F, 0x00030809, 0x00080D0E, 0x000A0C16, 0x0013171C, 0x000A1212, 0x0006110E, 0x00071513, 0x00051416, 0x0004141B, 0x00000D16, 0x00041A1F, 0x000F212A, 0x000F1A28, 0x00131A29, 0x000D0F1A, 0x0017191A, 0x0035392E, 0x00282E1D, 0x00223330,
        0x002D3B39, 0x0034413F, 0x001F2A27, 0x00121B18, 0x00232826, 0x002C302B, 0x00262A25, 0x00363B32, 0x003B4037, 0x003D453B, 0x003E463F, 0x003A453D, 0x00333D37, 0x00212D27, 0x007C8882, 0x00567770, 0x00B2AEAD, 0x0092D9E7, 0x003ED3FB, 0x002997CB,
        0x00004D6A, 0x00003B43, 0x00165766, 0x000A475B, 0x00004852, 0x000D4148, 0x000B333F, 0x00002B3B, 0x00102E3F, 0x0028242F, 0x00262423, 0x001F2A27, 0x001C2522, 0x00212825, 0x00222726, 0x00252B2A, 0x00232B2B, 0x000D1919, 0x00031312, 0x00032737,
        0x00003B43, 0x001B4D53, 0x00284E53, 0x00135357, 0x0005434D, 0x00134557, 0x0006485B, 0x00186A89, 0x002B93B8, 0x0026A3D5, 0x001CA0DC, 0x00279FE0, 0x003AA3DC, 0x003C9AC7, 0x002482A5, 0x0016779B, 0x001D789D, 0x0044889F, 0x00678884, 0x0089988A,
        0x00A1AFAB, 0x0025302E, 0x00393B2F, 0x00404438, 0x003E4236, 0x003C4034, 0x003C4034, 0x003C4034, 0x003D4135, 0x003C4034, 0x003C4034, 0x00404334, 0x00424637, 0x00414536, 0x00434637, 0x00434738, 0x00434739, 0x00424738, 0x00434637, 0x00434738,
        0x00414435, 0x003E4132, 0x00434536, 0x00484B3D, 0x00484C3E, 0x00484B3C, 0x0046493A, 0x004D4F41, 0x00515242, 0x00505141, 0x00555546, 0x00545445, 0x004D4E3E, 0x004F5141, 0x00515445, 0x004D5042, 0x004C4F40, 0x005C5E51, 0x00C9CAC6, 0x00ACACA7,
        0x00DBDBD8, 0x00757669, 0x008F9085, 0x00C8C9C4, 0x00B9B9B2, 0x00CACAC5, 0x00545647, 0x004E5041, 0x00555748, 0x00545545, 0x004B4B3B, 0x004D4F3F, 0x004E5142, 0x00505344, 0x004C4E3F, 0x004D4F40, 0x00515242, 0x00555646, 0x00505141, 0x00535444,
        0x00515243, 0x00565646, 0x004E4E3E, 0x00545545, 0x00575848, 0x00585949, 0x00555646, 0x00515343, 0x004E5142, 0x00505343, 0x00515444, 0x004C4E3F, 0x0048493B, 0x00464638, 0x00464638, 0x003F3B30, 0x001B2C23, 0x008A8B87, 0x008E9B93, 0x006F817A,
        0x0064838C, 0x00197E97, 0x00108DBA, 0x001591D1, 0x00249AD5, 0x002C9BC9, 0x0016789A, 0x00004F67, 0x0000485A, 0x000B4A58, 0x00003A46, 0x0000373E, 0x00243227, 0x0041402B, 0x00323B2E, 0x003C3935, 0x00383A2E, 0x00364131, 0x00443B37, 0x00363C31,
        0x00373D32, 0x00393F34, 0x003B4136, 0x003B4136, 0x003B4136, 0x003C4237, 0x003D4338, 0x003E4237, 0x003E4237, 0x003E4237, 0x003F4338, 0x003D4136, 0x003A3E33, 0x00393D32, 0x003A3E33, 0x003F4338, 0x003C4035, 0x00373B30, 0x003F4338, 0x003A3E33,
        0x0041453A, 0x003D4136, 0x003C4035, 0x003E4439, 0x00343A2F, 0x0033392E, 0x00393F34, 0x003A4035, 0x00373D32, 0x00383E33, 0x003D4338, 0x003C3D33, 0x003E3F35, 0x003F4036, 0x003E3F35, 0x003D3E34, 0x00393A30, 0x0036372D, 0x0035362C, 0x0037392D,
        0x00383B32, 0x0035382F, 0x003A3A2C, 0x003C3E2B, 0x00243227, 0x000A2E34, 0x00083D52, 0x00054459, 0x0006455A, 0x0007465B, 0x0009485D, 0x0009485D, 0x0009485D, 0x0008475C, 0x0008475C, 0x0009465A, 0x00084559, 0x0008475B, 0x00054759, 0x00003C4D,
        0x00165B6A, 0x004F96A4, 0x005AA1AF, 0x0055AAB4, 0x005FABB7, 0x0069B0BA, 0x00549FA8, 0x0056ABB3, 0x0050A8AF, 0x0058A8B3, 0x005BA1AE, 0x0062A1AF, 0x0072ABBA, 0x006299A8, 0x00145262, 0x00003F4D, 0x00004A58, 0x00034557, 0x000E4357, 0x00044155,
        0x00043B50, 0x000D6786, 0x003DABDF, 0x00004E82, 0x0006465E, 0x00105754, 0x004C8985, 0x00383433, 0x00040000, 0x000E0906, 0x00140F0C, 0x001E1B16, 0x0022231A, 0x00272B20, 0x0013190E, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFEFF, 0xFFFFFFFF, 0xFFFDFBFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x0024231F, 0x001E1F16, 0x00070701, 0x00040600, 0x00040B04, 0x00040B06, 0x0007130D, 0x00071511, 0x00061511, 0x000A0F10, 0x00090E0F, 0x000C1112, 0x001A1F20, 0x0024292A,
        0x00181D1E, 0x00090E0F, 0x00080D0E, 0x000D0E18, 0x000D1014, 0x00080F0C, 0x00111A10, 0x00101B11, 0x0009150F, 0x00101B19, 0x000E171A, 0x00071D2F, 0x00162A43, 0x000B1D3C, 0x00071532, 0x00000B21, 0x001C272B, 0x004B5646, 0x00323E22, 0x00041512,
        0x00172523, 0x002C3A38, 0x00263232, 0x001B2525, 0x00232B2B, 0x002D3535, 0x00393E41, 0x003C4231, 0x00404536, 0x003D4435, 0x003D4737, 0x00394336, 0x00323F31, 0x00293529, 0x00849286, 0x005A7572, 0x0095A09D, 0x0079CBD6, 0x002397C6, 0x000B417E,
        0x000F3E5A, 0x00025A5A, 0x00034A54, 0x000F455C, 0x00044B59, 0x000C4957, 0x0000384C, 0x00004B66, 0x002A6481, 0x00041C32, 0x00000812, 0x00000705, 0x00000A0A, 0x000C1414, 0x000B1313, 0x0001080B, 0x0000080A, 0x00051417, 0x000D1E21, 0x0000263D,
        0x00003E4B, 0x004A838C, 0x006F939B, 0x00407D7F, 0x002B676D, 0x00497380, 0x00528B9A, 0x006E9FA7, 0x003C889E, 0x002596BE, 0x0028A9E2, 0x000E8CCD, 0x000B7CBA, 0x00208DC0, 0x001A87AD, 0x00197DA0, 0x0017779B, 0x0042889F, 0x005E837F, 0x00849385,
        0x00AAB3B0, 0x00343434, 0x00483E34, 0x003D4135, 0x003C4034, 0x003B3F33, 0x003B3F33, 0x003C4034, 0x003D4135, 0x003D4135, 0x003C4034, 0x003E4132, 0x00454839, 0x00434738, 0x00404536, 0x00424738, 0x00434839, 0x00424738, 0x00424737, 0x0045493A,
        0x00404232, 0x00464838, 0x004A4C3C, 0x004C4E3F, 0x004F5041, 0x004C4E3F, 0x0046493A, 0x004D5042, 0x00545545, 0x00515242, 0x004D4D3D, 0x00505040, 0x00515141, 0x004E5040, 0x00515445, 0x004A4D3E, 0x004D4F41, 0x00515343, 0x004D4F40, 0x004B4E41,
        0x004D4F3F, 0x004F5040, 0x00535444, 0x004E5042, 0x00505142, 0x004F5141, 0x00505242, 0x00515444, 0x004F5243, 0x00505142, 0x00515141, 0x004D4E3E, 0x004F5141, 0x00515445, 0x004E5142, 0x004D5041, 0x00505243, 0x00515242, 0x004F5040, 0x00535444,
        0x004E5042, 0x00505142, 0x00515242, 0x00535444, 0x00575848, 0x00575848, 0x00515444, 0x004C5041, 0x00494E3F, 0x00494E3F, 0x004D5243, 0x004C4F40, 0x0049493B, 0x00474739, 0x00464638, 0x004C4339, 0x0015291D, 0x00838984, 0x008A9F97, 0x0069807B,
        0x005F858A, 0x0019899B, 0x000F9ABB, 0x002396CF, 0x001B90C7, 0x002398CB, 0x002B9BC6, 0x001A7B9F, 0x0000506B, 0x00004154, 0x00104756, 0x00003539, 0x002B382A, 0x0046462E, 0x00313A2D, 0x00383531, 0x0031352A, 0x00313C2C, 0x003F3632, 0x003A4035,
        0x003C4237, 0x003D4338, 0x003D4338, 0x003A4035, 0x00393F34, 0x003A4035, 0x003B4136, 0x003A3B31, 0x003E3F35, 0x003E3F35, 0x003A3B31, 0x003B3C32, 0x003E3F35, 0x003E3F35, 0x003A3B31, 0x003B3C32, 0x0034352B, 0x0034352B, 0x003D3E34, 0x0033342A,
        0x003F4036, 0x00414238, 0x00393A30, 0x0031372C, 0x00373D32, 0x00393F34, 0x00363C31, 0x00353B30, 0x00353B30, 0x00363C31, 0x00383E33, 0x003A392F, 0x003A392F, 0x003B3A30, 0x003B3A30, 0x0038372D, 0x0038372D, 0x003A392F, 0x003A392F, 0x0037392D,
        0x00383B32, 0x0035382F, 0x003B3B2D, 0x003C3E2B, 0x00243227, 0x000A2E34, 0x00083D52, 0x00054459, 0x0006455A, 0x0007465B, 0x0009485D, 0x0009485D, 0x0009485D, 0x0008475C, 0x0008475C, 0x000F4A5D, 0x000B495B, 0x00054655, 0x00064958, 0x00094E5D,
        0x00367E8A, 0x0058A2AE, 0x002C7682, 0x003C7884, 0x0048808B, 0x0075ACB5, 0x0064A2A8, 0x005EA8AC, 0x005EAAB0, 0x0067AAB3, 0x004B808D, 0x00397287, 0x0040758A, 0x0077A9BF, 0x004D879D, 0x0000475D, 0x0000394F, 0x00084A63, 0x00033A55, 0x00014657,
        0x00003C50, 0x00076687, 0x0039AEE5, 0x00004C82, 0x0003475E, 0x000E5552, 0x004D8983, 0x00404E4A, 0x00000300, 0x00010803, 0x000B110C, 0x00181E19, 0x001C231C, 0x00222A23, 0x000F1A12, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFEFF, 0xFFFFFCFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00161917, 0x001A1E18, 0x00060802, 0x00090A06, 0x00040803, 0x00020904, 0x00091713, 0x00021611, 0x00041B16, 0x00141918, 0x000F1111, 0x00161315, 0x002A232A, 0x00352F3A,
        0x002A2B39, 0x000E1B2B, 0x002D4152, 0x002E4D44, 0x000B1D1C, 0x0022262B, 0x001C1C1C, 0x002B2F29, 0x002F3D37, 0x0022373F, 0x00041C32, 0x00032633, 0x000D2A39, 0x00072538, 0x00022130, 0x0007121A, 0x003A2D2B, 0x0064584C, 0x00364029, 0x0000211F,
        0x00134650, 0x0014455B, 0x00103549, 0x00203239, 0x003A3830, 0x004D4234, 0x004F4234, 0x004E453B, 0x00464237, 0x0049473C, 0x00414337, 0x003F453A, 0x00384036, 0x002F362F, 0x007F8580, 0x00515F6B, 0x007697A7, 0x005798AD, 0x0001516A, 0x00023E56,
        0x00799AAA, 0x007AA6A5, 0x004C9787, 0x003D7D81, 0x00457579, 0x00729898, 0x00828790, 0x005192AE, 0x0030A1C9, 0x007FA0C1, 0x00535958, 0x00706B68, 0x0051535B, 0x00003250, 0x00096FA3, 0x00044365, 0x00364B42, 0x004D634B, 0x00445B57, 0x00156370,
        0x00588D9A, 0x00647F89, 0x00879DA2, 0x00789A99, 0x0052827C, 0x0078A7A4, 0x00739A98, 0x009E9E80, 0x00236C64, 0x0000687D, 0x0033A3CE, 0x001F9FDA, 0x00016FB1, 0x00095E8B, 0x00198285, 0x00227291, 0x00237A9C, 0x00368299, 0x00567F82, 0x0084928E,
        0x00A2AAAA, 0x0029302D, 0x00363C29, 0x00383F32, 0x003A4134, 0x003B4235, 0x003E4334, 0x003D4233, 0x00404333, 0x00434636, 0x00454838, 0x00454838, 0x00474B3C, 0x00434839, 0x00414637, 0x00434839, 0x0044493A, 0x00434839, 0x00434839, 0x0044493A,
        0x00444738, 0x00484A3B, 0x004F5142, 0x00525345, 0x00515343, 0x004E5142, 0x0046493A, 0x0046483B, 0x00515242, 0x00505141, 0x00535444, 0x00515243, 0x00515141, 0x004D4D3E, 0x00505243, 0x004A4C3D, 0x004D4E40, 0x00535444, 0x00525445, 0x00494C3F,
        0x00464839, 0x004E4F3F, 0x00525343, 0x00505244, 0x00535444, 0x00535444, 0x00535444, 0x00505242, 0x004E5040, 0x004D4D3D, 0x00505040, 0x00515141, 0x004E5040, 0x00515445, 0x004E5142, 0x004E5142, 0x004E5143, 0x004D4F40, 0x004E5040, 0x00535444,
        0x00505244, 0x00535444, 0x00535444, 0x00545545, 0x00535444, 0x00505343, 0x004E5243, 0x004D5243, 0x004A4F40, 0x004A4F40, 0x004B5041, 0x0045493A, 0x00464A3A, 0x00494C3C, 0x00494C3C, 0x003C443D, 0x0021251A, 0x008C8F80, 0x008A9487, 0x005B7B76,
        0x004E8A96, 0x001E7896, 0x001D89B2, 0x0028A1CB, 0x001D98CA, 0x00108DC7, 0x001E98D4, 0x002694C8, 0x001E7D9E, 0x0004535E, 0x00064846, 0x0000343B, 0x001D2D22, 0x00483B2B, 0x00423634, 0x00303233, 0x00393E35, 0x00363C2B, 0x002E372A, 0x00373B30,
        0x00393D32, 0x0035392E, 0x003D4136, 0x00393D32, 0x003E4237, 0x00383C31, 0x00383C31, 0x003B3F33, 0x003A3E32, 0x00393D31, 0x00383C30, 0x00373B2F, 0x00363A2E, 0x00363A2E, 0x00363A2E, 0x00393B2F, 0x00383A2E, 0x00393B2F, 0x003B3D31, 0x00393B2F,
        0x0035372B, 0x0036382C, 0x003A3C30, 0x00363A2E, 0x00363A2E, 0x00373B2F, 0x00373B2F, 0x00373B2F, 0x00383C30, 0x00383C30, 0x00383C30, 0x00373D2C, 0x00383E2D, 0x003A3D2D, 0x003A3D2D, 0x00393C2C, 0x003A3B2B, 0x00393A2A, 0x00383929, 0x00333B2A,
        0x002E372A, 0x00353A31, 0x003C3C30, 0x003A3A2A, 0x00283428, 0x00103232, 0x000D414E, 0x00034355, 0x00074759, 0x000A4A5C, 0x0008475B, 0x00064559, 0x0008475C, 0x0009485D, 0x0008475C, 0x00034859, 0x000D4D5F, 0x00064456, 0x00034857, 0x00014C5A,
        0x005CA4B0, 0x003A7180, 0x00638B9D, 0x00598390, 0x001A525D, 0x006DBBC2, 0x009BF7FC, 0x0096F2F7, 0x00AAF8FF, 0x006EA6B1, 0x0028525F, 0x004F8499, 0x00507D92, 0x003A7180, 0x0044909C, 0x0000434E, 0x00094356, 0x0013455C, 0x0008445C, 0x00043E5B,
        0x000C3E4A, 0x00046A8D, 0x0030ADEA, 0x00095482, 0x000B475F, 0x00095C64, 0x0042897F, 0x00434546, 0x00000100, 0x000B0F09, 0x00181C11, 0x001A1E12, 0x00292B1F, 0x002A2B21, 0x001D1E15, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFEFF, 0xFFFFFCFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00171A18, 0x00161A14, 0x00020400, 0x00080905, 0x000B0F0A, 0x00080F0A, 0x000D1B17, 0x000D211C, 0x00031A15, 0x00001E22, 0x0000282D, 0x00001E23, 0x00102A30, 0x001D373E,
        0x0018353E, 0x000E313B, 0x00254B57, 0x00274858, 0x00071F35, 0x0017283D, 0x00051521, 0x00102B27, 0x00244C41, 0x001E514D, 0x0000363D, 0x00092F34, 0x0018383E, 0x00062A30, 0x00001D21, 0x00061B19, 0x005A524B, 0x00948B7D, 0x005B654E, 0x00001110,
        0x001D3944, 0x002C4E65, 0x0018394D, 0x0011272D, 0x002B352F, 0x00404439, 0x003E3F36, 0x00384739, 0x00364333, 0x00383F30, 0x0043473C, 0x00454642, 0x002D3035, 0x0008101D, 0x00252F41, 0x00003F4A, 0x002B6B7D, 0x00045067, 0x0000425C, 0x00478A9F,
        0x00B0CBD9, 0x00979F9F, 0x00959F93, 0x00568D8A, 0x0077989B, 0x008D9A9C, 0x007B737A, 0x0091D6E7, 0x0049C2DC, 0x0086AFC5, 0x0091948B, 0x007B9F8F, 0x005D7274, 0x00095978, 0x003BBEF0, 0x004194BA, 0x007D9095, 0x0088978F, 0x00709096, 0x006FB5B5,
        0x0087BDBD, 0x00688985, 0x007A918C, 0x008BA39B, 0x006B8A81, 0x00789992, 0x0071938D, 0x0041594D, 0x001D6565, 0x00004255, 0x00226187, 0x00379ED5, 0x0013A2DC, 0x0005749C, 0x001E525F, 0x00408596, 0x002E7C93, 0x003A7F92, 0x005A8183, 0x0082908C,
        0x009BA2A5, 0x00232C29, 0x003A402D, 0x00373E31, 0x00394033, 0x003C4336, 0x003F4435, 0x003F4435, 0x00414434, 0x00424535, 0x00434636, 0x00414434, 0x00484D3E, 0x0044493A, 0x00424738, 0x0044493A, 0x0044493A, 0x00424738, 0x00434839, 0x00454A3B,
        0x00444738, 0x00484A3B, 0x00525344, 0x00545648, 0x00505344, 0x00525445, 0x004D5041, 0x004B4E41, 0x004D4F3F, 0x004F5040, 0x00535444, 0x004E5042, 0x00505142, 0x004F5141, 0x00505242, 0x004B4E3E, 0x004C4E3F, 0x004C4F40, 0x00525445, 0x00494B3D,
        0x00494B3B, 0x004E5041, 0x004F5142, 0x004F5142, 0x00505141, 0x00505142, 0x004C4D3F, 0x004F5141, 0x00505141, 0x00535444, 0x00515243, 0x00515141, 0x004D4D3E, 0x00505243, 0x004E5041, 0x00505243, 0x00535546, 0x004E5141, 0x00505243, 0x00555646,
        0x00515243, 0x00525343, 0x00535445, 0x00505141, 0x004F5141, 0x004B4F40, 0x004D5243, 0x004E5344, 0x004C5142, 0x004A4F40, 0x00494D3E, 0x00464A3A, 0x00464939, 0x00454838, 0x00424535, 0x0041453F, 0x00262A1F, 0x007C8376, 0x00829084, 0x005F7E77,
        0x005F9197, 0x00367E90, 0x000C617B, 0x001E89AF, 0x002A9CCB, 0x00219CD6, 0x001795D5, 0x001C97D1, 0x0035A2CE, 0x00217D9A, 0x00005061, 0x0000343E, 0x0024352C, 0x00473D2C, 0x003C302E, 0x002F3132, 0x00343930, 0x00313726, 0x00384134, 0x0032362A,
        0x0035392D, 0x0034382C, 0x003B3F33, 0x00383C30, 0x003E4236, 0x003A3E32, 0x003B3F33, 0x003F4337, 0x003E4236, 0x003C4034, 0x003A3E32, 0x00383C30, 0x00373B2F, 0x00373B2F, 0x00363A2E, 0x00393B2F, 0x00383A2E, 0x00393B2F, 0x003C3E32, 0x003C3E32,
        0x00393B2F, 0x003A3C30, 0x003C3E32, 0x003B3F33, 0x003A3E32, 0x003A3E32, 0x003A3E32, 0x00393D31, 0x00393D31, 0x00383C30, 0x00383C30, 0x00383D2E, 0x00383D2E, 0x00373C2D, 0x00393C2D, 0x00393C2D, 0x003B3B2D, 0x003B3B2D, 0x003B3B2D, 0x00383E2D,
        0x00343A2F, 0x00383B32, 0x003B392E, 0x003C392A, 0x00283226, 0x000E2D2E, 0x000D3E4C, 0x00034355, 0x00074759, 0x0009495B, 0x0007465A, 0x0007465A, 0x0008475C, 0x0009485D, 0x0008475C, 0x00004354, 0x00044456, 0x00064456, 0x00024756, 0x0000404E,
        0x0058A0AC, 0x00366D7C, 0x0041697B, 0x007CC4CC, 0x0072B7C0, 0x000C4A54, 0x00629FA9, 0x00A1DEE8, 0x003B7983, 0x000D525B, 0x00559DA5, 0x0075A7BD, 0x00335E73, 0x00326978, 0x004995A1, 0x0000424D, 0x00104A5D, 0x00083C53, 0x000A465E, 0x0008425F,
        0x000F414D, 0x00056B8E, 0x002DACE9, 0x00055280, 0x000A465E, 0x00085B63, 0x0042897F, 0x0037393A, 0x00000100, 0x000A0E08, 0x001D2116, 0x00212519, 0x002F3125, 0x002F3026, 0x00202118, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFEFF, 0xFFFFFDFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00191C1A, 0x00181C16, 0x00030701, 0x000B0C08, 0x00171814, 0x000F1510, 0x00202B28, 0x00455652, 0x0040544F, 0x00356E70, 0x00437476, 0x003B6161, 0x00436564, 0x002A4D49,
        0x00042C2B, 0x00002426, 0x0000292E, 0x00072334, 0x00041F34, 0x00142B41, 0x000A202C, 0x00465F5B, 0x008BADA2, 0x009AC4BD, 0x0085B5B7, 0x008AAAA9, 0x0078938F, 0x0044675D, 0x00123E31, 0x00082319, 0x004F4E44, 0x00887F71, 0x00565943, 0x0028302F,
        0x00253C44, 0x00062A3C, 0x00001C2E, 0x0006232A, 0x00142423, 0x00171F1E, 0x00151A1D, 0x00092117, 0x00132417, 0x0014180C, 0x00201E16, 0x00131718, 0x00031123, 0x00001B3A, 0x000F3761, 0x0000496A, 0x00003E64, 0x00003E66, 0x00208CAE, 0x0063CDE5,
        0x0079BCCB, 0x00607F82, 0x00889995, 0x00728C8C, 0x00759398, 0x006D8186, 0x005B5B61, 0x0072AAB5, 0x00167686, 0x0057828B, 0x00A0B3A2, 0x006B9F88, 0x002D4B50, 0x00005277, 0x0033C7FD, 0x00086E99, 0x00193748, 0x0019363B, 0x00053946, 0x000B4A48,
        0x001D5A56, 0x0030635F, 0x004B6E6A, 0x005E7472, 0x00526769, 0x004E6E73, 0x00356266, 0x00426E7B, 0x001A5B69, 0x0000424E, 0x000C4057, 0x001D5D8D, 0x002A9ED9, 0x0031A5CE, 0x00356B7C, 0x00669C9C, 0x0043868F, 0x0046858D, 0x005F8480, 0x0083918D,
        0x009EA7AA, 0x00262F2C, 0x00363C29, 0x00373E31, 0x00394033, 0x003C4336, 0x00404536, 0x00404536, 0x00424535, 0x00424535, 0x00424535, 0x00414435, 0x00464B3C, 0x00434839, 0x00434839, 0x0044493A, 0x00434839, 0x00414637, 0x00424738, 0x00464B3C,
        0x00444738, 0x00454839, 0x00515243, 0x00525546, 0x004E5142, 0x00515445, 0x00505344, 0x00494C3F, 0x00454738, 0x004E4F3F, 0x00535444, 0x00505244, 0x00535444, 0x00535444, 0x00505242, 0x004A4C3D, 0x00494A3B, 0x004B4C3E, 0x004E5040, 0x004F5040,
        0x00515141, 0x00505142, 0x004F5243, 0x004E5042, 0x00515343, 0x004D4F40, 0x004B4E41, 0x004D4F3F, 0x004F5040, 0x00535444, 0x004E5042, 0x00505142, 0x004F5141, 0x00505242, 0x00525545, 0x00545647, 0x00555646, 0x00525343, 0x00515242, 0x00535444,
        0x00505141, 0x004F5040, 0x00515344, 0x004A4C3D, 0x004B4D3E, 0x00494E3E, 0x004B5041, 0x004D5142, 0x004B4E3F, 0x00474A3B, 0x00454939, 0x00464939, 0x00444737, 0x00424535, 0x00414434, 0x003E3F36, 0x002A2D24, 0x00798377, 0x00849689, 0x005C7A6F,
        0x00668E89, 0x006F9C9F, 0x00508288, 0x00065975, 0x002483AA, 0x002D9DD1, 0x001695D2, 0x000287C5, 0x001D9AD4, 0x002A99C7, 0x00157AA1, 0x00003744, 0x0020322B, 0x00483F31, 0x003C332F, 0x00262B2A, 0x00283025, 0x002E3423, 0x00353D32, 0x00313726,
        0x00343A29, 0x00353B2A, 0x003A402F, 0x00383E2D, 0x003B4130, 0x003A402F, 0x003C4231, 0x00414539, 0x00404438, 0x003F4337, 0x003D4135, 0x003C4034, 0x003B3F33, 0x003B3F33, 0x003B3F33, 0x003A3C30, 0x00393B2F, 0x003A3C30, 0x003E4034, 0x00404236,
        0x003F4135, 0x003E4034, 0x00404236, 0x003D4135, 0x003D4135, 0x003D4135, 0x003D4135, 0x003D4135, 0x003D4135, 0x003D4135, 0x003C4034, 0x003B4233, 0x003C4132, 0x003A3F30, 0x00383D2E, 0x00393C2D, 0x00393C2D, 0x003B3B2D, 0x003C3C2E, 0x00393C2C,
        0x00383C31, 0x00393933, 0x003B372C, 0x00403B2C, 0x002A3227, 0x000C292D, 0x00103D4B, 0x00044456, 0x00074759, 0x0009495B, 0x0007465A, 0x0007465A, 0x0009485D, 0x0009485D, 0x0008475C, 0x00034859, 0x000A4A5C, 0x000E4C5E, 0x00074C5B, 0x0000414F,
        0x00549CA8, 0x00326978, 0x00355D6F, 0x001C5965, 0x0068A5B1, 0x0090D0DB, 0x00276772, 0x0010505B, 0x002A6A75, 0x007CB9C5, 0x005D9AA6, 0x00194A60, 0x0030596F, 0x003D7181, 0x004B95A1, 0x0000414D, 0x000C475A, 0x0010445B, 0x00023E56, 0x0004405D,
        0x000C3E4A, 0x0002688B, 0x002BAAE7, 0x00055280, 0x000A4860, 0x000C5F67, 0x00478E84, 0x00393B3C, 0x00000100, 0x000C100A, 0x001D2116, 0x00202418, 0x002B2D21, 0x002E2F25, 0x0022231A, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFEFF, 0xFFFFFDFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x001B1E1C, 0x001C231C, 0x00030701, 0x00030400, 0x000D0E0A, 0x0010140F, 0x00515A57, 0x00CFDDD9, 0x00EFFFFC, 0x00ECFFF9, 0x00F8FFFB, 0x00FBFFF6, 0x00DDE7DB, 0x00698278,
        0x00123733, 0x00073235, 0x00123B44, 0x000F3539, 0x00103740, 0x000F2E3D, 0x00162A35, 0x00959A9B, 0x00FFFFFC, 0x00FFFEFF, 0x00FBF7FF, 0x00F0FFF9, 0x00ECFAEE, 0x00AFCAB6, 0x0037604B, 0x00163427, 0x0081837D, 0x00BBB1A7, 0x00878371, 0x003C5551,
        0x005C8287, 0x00164A5A, 0x00003443, 0x0006343C, 0x00001317, 0x0003151C, 0x00000B19, 0x00000A11, 0x00070E11, 0x000D0A06, 0x00160F0C, 0x0001080B, 0x00001F2F, 0x000E4969, 0x001F6E97, 0x001D8FBE, 0x0036A5D5, 0x0040BFEC, 0x003ECAF1, 0x00239BB9,
        0x00377B92, 0x003C5765, 0x00425056, 0x003A404D, 0x00124D5D, 0x00135567, 0x003A5968, 0x002A515F, 0x00003044, 0x003D616B, 0x006C9989, 0x006E877D, 0x00001B2E, 0x00035A8C, 0x0046C4FE, 0x00166D99, 0x00002F41, 0x00063A40, 0x000B454B, 0x000E414B,
        0x0000393F, 0x000D4B51, 0x0001323A, 0x00001A29, 0x00000619, 0x0000273D, 0x0024687F, 0x003E91AD, 0x00003752, 0x000A4753, 0x000B5059, 0x0000385B, 0x002680B7, 0x0034A5D0, 0x001C6F84, 0x00548276, 0x00225E5E, 0x002C6567, 0x00577972, 0x0084928C,
        0x009FA8AB, 0x00242C2B, 0x00363C29, 0x00394033, 0x003A4134, 0x003C4336, 0x00404536, 0x00404536, 0x00424535, 0x00424535, 0x00424535, 0x00424536, 0x0044493A, 0x00434839, 0x00424738, 0x00434839, 0x00414637, 0x003F4435, 0x00414637, 0x00454A3B,
        0x00434637, 0x00414435, 0x00505242, 0x004D5041, 0x00494C3D, 0x004E5142, 0x004E5041, 0x00494C3E, 0x0046493A, 0x004C4F40, 0x00515243, 0x004F5142, 0x00525343, 0x00505243, 0x00494C3D, 0x004D5041, 0x004D5040, 0x004F5040, 0x00535444, 0x00515243,
        0x00515141, 0x004F5040, 0x004E5041, 0x004E4F41, 0x00535444, 0x00525445, 0x00494C3F, 0x00454738, 0x004E4F3F, 0x00535444, 0x00505244, 0x00535444, 0x00535444, 0x00545545, 0x00545545, 0x00545545, 0x00545545, 0x00545545, 0x00505141, 0x004F5040,
        0x004D4D3D, 0x004E4F3F, 0x004E4F3F, 0x00454839, 0x00424536, 0x00444838, 0x00474A3B, 0x00484B3C, 0x00444738, 0x00424536, 0x00444738, 0x00454839, 0x00424536, 0x00424536, 0x00454839, 0x0048453D, 0x002A2D24, 0x00748277, 0x00859B8F, 0x00627E71,
        0x00668479, 0x00728F86, 0x0068837A, 0x00598D99, 0x003C8195, 0x002889AB, 0x00259CCD, 0x001295CE, 0x000E90CB, 0x001E95CD, 0x001F8DC1, 0x0011495C, 0x00132825, 0x003D3627, 0x002C261F, 0x0009100D, 0x00151E11, 0x00313726, 0x0030382E, 0x00353B2A,
        0x00373D2C, 0x00393F2E, 0x003B4130, 0x00383E2D, 0x00393F2E, 0x00393F2E, 0x003B4130, 0x003D4338, 0x003D4338, 0x003D4338, 0x003D4338, 0x003D4338, 0x003E4439, 0x003F453A, 0x003F453A, 0x003B3F34, 0x00393D32, 0x003A3E33, 0x003E4237, 0x0041453A,
        0x00404439, 0x003F4338, 0x003F4338, 0x003A4035, 0x003A4035, 0x003B4136, 0x003C4237, 0x003E4439, 0x003F453A, 0x0040463B, 0x0040463B, 0x0041483B, 0x0040473A, 0x003F4337, 0x003D4135, 0x003A3E32, 0x003A3C30, 0x00393B2F, 0x00383A2E, 0x00373729,
        0x003A3B31, 0x003A3732, 0x003C352C, 0x00453D30, 0x002D3229, 0x000C272B, 0x00103C4D, 0x00044456, 0x00074759, 0x0008485A, 0x0007465A, 0x0007465A, 0x0009485D, 0x0009485D, 0x0007465B, 0x00004556, 0x0009495B, 0x00044254, 0x00004251, 0x00004553,
        0x00579FAB, 0x00447B8A, 0x0061899B, 0x00588F9C, 0x000C4652, 0x004F8C98, 0x0090D0DB, 0x005C9CA7, 0x0077B4C0, 0x00447E8A, 0x000E4552, 0x00527E95, 0x00587F95, 0x003F7282, 0x004F97A3, 0x00004955, 0x00023D50, 0x000C4057, 0x0005435B, 0x00033F5C,
        0x00093D49, 0x0000678A, 0x002CABE8, 0x00075482, 0x000C4A62, 0x000B6068, 0x00458E84, 0x003A3C3D, 0x00010402, 0x000D110B, 0x001D2116, 0x001F2317, 0x0026281C, 0x002A2B21, 0x001F2017, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x001E211F, 0x00171F18, 0x00040B04, 0x000F100C, 0x00191A16, 0x000E120D, 0x00484F4C, 0x00D1DCD9, 0x00EBF9F5, 0x00FFFAF1, 0x00FFFFF8, 0x00FDEEE5, 0x00B6BAB4, 0x00456766,
        0x0004404C, 0x00003853, 0x00003F64, 0x0000405A, 0x00003F5F, 0x00003E61, 0x00103D58, 0x00818F9B, 0x00E9DEE0, 0x00FFF0F2, 0x00FFFAFF, 0x00F1F2E9, 0x00D3D3C3, 0x009DAD96, 0x00254D3B, 0x00082D29, 0x005C666D, 0x006E6869, 0x00504C41, 0x00314B4B,
        0x00547D86, 0x00306B7B, 0x005DA1AE, 0x0047878C, 0x00003234, 0x00164953, 0x0000283A, 0x0007263B, 0x00091E2D, 0x00161C21, 0x00242222, 0x00191E1F, 0x0019323C, 0x000A3C50, 0x00064964, 0x00266188, 0x00156185, 0x000E7897, 0x002A9EB5, 0x002D8095,
        0x00406371, 0x00283B40, 0x00112F2A, 0x00001B34, 0x00005F81, 0x001B7CA2, 0x002C6481, 0x000A354A, 0x000B2B42, 0x00517281, 0x006B948F, 0x007B8487, 0x00002948, 0x000C6CA1, 0x00267CB0, 0x002C5576, 0x00154049, 0x00225450, 0x003D4E4B, 0x003E555D,
        0x002F555A, 0x00235456, 0x00093338, 0x004C6A75, 0x00527285, 0x00457A8F, 0x0079C4DA, 0x003EAFC9, 0x0019587A, 0x0012495E, 0x0004454E, 0x00014A60, 0x001C8CB6, 0x0022A0C9, 0x00156786, 0x003C6F68, 0x0007464A, 0x00205B5D, 0x0060817A, 0x00929D95,
        0x00A0A7AA, 0x001F2726, 0x003C4433, 0x003B4235, 0x003B4235, 0x003C4336, 0x003E4334, 0x003F4435, 0x00424535, 0x00434636, 0x00434636, 0x0046483C, 0x00474B3F, 0x0045493D, 0x0043473B, 0x0042463A, 0x00414539, 0x00404438, 0x003E4236, 0x003C4034,
        0x00434637, 0x00414435, 0x00454738, 0x0047493A, 0x00474B3C, 0x00494D3E, 0x00484D3E, 0x00484C3D, 0x00484B3C, 0x004B4F41, 0x004D5041, 0x004D4F41, 0x004D4F40, 0x004E5141, 0x004C4F40, 0x004B4F41, 0x004D4F3F, 0x004F5040, 0x00535444, 0x004E5042,
        0x00505142, 0x00505141, 0x004B4E3E, 0x004C4E3F, 0x004C4F40, 0x00525445, 0x0046493C, 0x00454839, 0x004C4F40, 0x00515243, 0x00505142, 0x00535444, 0x00545546, 0x00525343, 0x00505242, 0x00505242, 0x00525344, 0x00565747, 0x00535444, 0x00515242,
        0x004F5040, 0x00525242, 0x00474737, 0x00454839, 0x00424536, 0x00414435, 0x00414435, 0x003E4132, 0x003D4031, 0x00414435, 0x0046493A, 0x0046493A, 0x00424536, 0x00434637, 0x00474A3B, 0x0049463E, 0x00292C23, 0x007A887D, 0x00889E92, 0x006A8679,
        0x006B897E, 0x00617E75, 0x00637E75, 0x0080A19A, 0x00306163, 0x00025061, 0x001A83A4, 0x00239CC8, 0x00108ABE, 0x00168CC0, 0x001E8EC3, 0x0018546C, 0x00132B2B, 0x003C392B, 0x00302E26, 0x00171E19, 0x0020291C, 0x00393F2E, 0x00333731, 0x00373D2C,
        0x00393F2E, 0x003B4130, 0x003A402F, 0x003A402F, 0x00383E2D, 0x003A402F, 0x003B4130, 0x003C4237, 0x003C4237, 0x003C4237, 0x003C4237, 0x003D4338, 0x003D4338, 0x003E4439, 0x003F453A, 0x003D4136, 0x003A3E33, 0x003A3E33, 0x003E4237, 0x00404439,
        0x003E4237, 0x003D4136, 0x003E4237, 0x00393F34, 0x00393F34, 0x003A4035, 0x003B4136, 0x003C4237, 0x003E4439, 0x003F453A, 0x003F453A, 0x0040463B, 0x003F453A, 0x003E4439, 0x003F4338, 0x003C4035, 0x003A3E33, 0x003A3B31, 0x0038392F, 0x00353829,
        0x00393A31, 0x00383832, 0x003D362D, 0x00453D30, 0x002D3229, 0x000B252B, 0x000D394A, 0x00054557, 0x00074759, 0x0008485A, 0x0007465A, 0x0007465A, 0x000A495E, 0x000A495E, 0x0007465B, 0x0004495A, 0x000D4D5F, 0x000B495B, 0x00024756, 0x00004553,
        0x005098A4, 0x0039707F, 0x00487082, 0x0083CDD9, 0x0073B2C0, 0x00194A5A, 0x003F6779, 0x0085ADBF, 0x002E5F6F, 0x000F4E5C, 0x005AA4B0, 0x0084AEC5, 0x0044697F, 0x003C6D7D, 0x004F97A3, 0x0000434F, 0x000F4A5D, 0x00093F56, 0x0007475F, 0x00064561,
        0x000D414D, 0x00036B8E, 0x002CAEEA, 0x00075583, 0x00084860, 0x00065B63, 0x003D867C, 0x002D2F30, 0x00000100, 0x000B0F09, 0x00202419, 0x0025291D, 0x00292B1F, 0x002B2C22, 0x001E1F16, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFDFF, 0xFFFFFEFF, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00202321, 0x001C241D, 0x00040B04, 0x000E120D, 0x001A1B17, 0x000F100C, 0x00424745, 0x00CAD1CE, 0x00D4DFDC, 0x00E3E9E8, 0x00EEEAE9, 0x00BDBBBB, 0x007A9193, 0x0056939F,
        0x0053AFCC, 0x003EA4D5, 0x003C9DDC, 0x003EA4E5, 0x0034A2E4, 0x0042AFED, 0x004499C6, 0x006695AA, 0x009DADAC, 0x00C7CAC1, 0x00F3F4EA, 0x00D1CCC3, 0x00D3CEBF, 0x00A9B9A7, 0x001E514A, 0x00003443, 0x0045647D, 0x00394956, 0x00202F2B, 0x0045545D,
        0x00234152, 0x00083B4F, 0x005899A8, 0x00428B8F, 0x002C797B, 0x007BCFD5, 0x00348F9E, 0x00002D3D, 0x00002934, 0x000C272B, 0x00242F2C, 0x002A2B27, 0x00292E2D, 0x00172128, 0x0012222E, 0x00331724, 0x00443E49, 0x0069898E, 0x0084B6B6, 0x008CA8A8,
        0x00D0D4CF, 0x00BACBBE, 0x006A9B85, 0x00004862, 0x002FAFDA, 0x00429CD7, 0x00003D66, 0x00003B4D, 0x00023341, 0x00648794, 0x00A9B3BA, 0x00718487, 0x002D7391, 0x002F96C3, 0x000C4263, 0x00322F3E, 0x00233332, 0x00243C34, 0x004E2E28, 0x003B3D37,
        0x003D463C, 0x00546459, 0x00738479, 0x00C9DBD4, 0x00C4DAD8, 0x00B8DBDE, 0x00BCEBEF, 0x00B3EDFF, 0x006DCBE8, 0x002793B2, 0x00074E62, 0x000C4358, 0x002087A7, 0x0030B1D8, 0x001D7FA9, 0x001B5F6C, 0x00045063, 0x002C6C77, 0x005B7D76, 0x008B9589,
        0x00A8AEAD, 0x00242C2B, 0x00364030, 0x003D4437, 0x003C4336, 0x003B4235, 0x003E4334, 0x003F4435, 0x00424535, 0x00434636, 0x00434636, 0x00484A3E, 0x00464A3E, 0x0044483C, 0x0042463A, 0x00414539, 0x00414539, 0x00414539, 0x00404438, 0x003F4337,
        0x0046493A, 0x00474A3B, 0x00474A3A, 0x00444737, 0x00464B3C, 0x00494D3E, 0x00494D3E, 0x00484B3B, 0x004A4B3B, 0x004A4C3F, 0x004D4F40, 0x004E4F41, 0x00525344, 0x00535444, 0x00515344, 0x00494C3F, 0x00454738, 0x004E4F3F, 0x00535444, 0x00515244,
        0x00525343, 0x004C4E3E, 0x00484A3B, 0x00484A3B, 0x004A4C3E, 0x004F5242, 0x004B4F41, 0x00484A3B, 0x00494C42, 0x004E5143, 0x00505142, 0x004F5040, 0x00525445, 0x00505243, 0x004F5243, 0x00525445, 0x00515343, 0x00555646, 0x00545444, 0x00515242,
        0x00505141, 0x00505040, 0x0048493B, 0x0046483C, 0x00424438, 0x0036382C, 0x002E3024, 0x00222418, 0x0027291D, 0x00303226, 0x003A3C30, 0x00414337, 0x00434539, 0x0044463A, 0x0045473B, 0x003F4037, 0x0025281F, 0x007D877B, 0x007B8D80, 0x005A786D,
        0x0058807B, 0x00336063, 0x0022545A, 0x006A8B7C, 0x00295751, 0x0000424B, 0x0017738C, 0x002F9AC0, 0x001B8BB9, 0x001D8EC0, 0x002492C6, 0x000E4C6A, 0x00153034, 0x00403F31, 0x003B3C32, 0x0037423A, 0x00353F2F, 0x00383D2E, 0x00323630, 0x00363A2E,
        0x0035392D, 0x00393D31, 0x00363A2E, 0x00393D31, 0x00373B2F, 0x003A3E32, 0x003A3E32, 0x00384035, 0x00373F34, 0x00363E33, 0x00353D32, 0x00353D32, 0x00353D32, 0x00353D32, 0x00353D32, 0x00383E33, 0x00353B30, 0x00343A2F, 0x00373D32, 0x00383E33,
        0x00363C31, 0x00363C31, 0x00383E33, 0x00343C31, 0x00343C31, 0x00343C31, 0x00343C31, 0x00343C31, 0x00343C31, 0x00343C31, 0x00343C31, 0x00333B31, 0x00343C32, 0x00373C33, 0x00383D34, 0x003A3D34, 0x00393C33, 0x00383B32, 0x00393A31, 0x0035392D,
        0x00343930, 0x00353632, 0x0038352D, 0x003F3B30, 0x00293228, 0x0009272C, 0x0008384A, 0x00054557, 0x00074759, 0x00074759, 0x00064559, 0x0008475B, 0x000A495E, 0x000A495E, 0x0006455A, 0x00014657, 0x00074759, 0x00104E60, 0x00094E5D, 0x00004452,
        0x00549CA8, 0x003C7382, 0x00234B5D, 0x001D5060, 0x0074A8B8, 0x009AD1E0, 0x003C7584, 0x000A4352, 0x00265D6C, 0x0089BDCD, 0x005C8F9F, 0x00294F67, 0x002C4C63, 0x003D6B7C, 0x005197A4, 0x00004450, 0x000F4A5D, 0x000D435A, 0x00014159, 0x00054460,
        0x000B414C, 0x00026A8D, 0x002CAEEA, 0x00085684, 0x000A4A62, 0x00055D64, 0x003B877C, 0x002B2D2E, 0x00000100, 0x00070B05, 0x001D2116, 0x0024281C, 0x00282A1E, 0x002D2E24, 0x00202118, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFDFF, 0xFFFFFEFF, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00222523, 0x001B261E, 0x00000600, 0x000B0F0A, 0x00191814, 0x00151410, 0x004C4F4D, 0x00CDD2D0, 0x00D2DBD8, 0x00B4C9C6, 0x00BCC3BE, 0x0091958F, 0x006D8781, 0x00438286,
        0x00237E93, 0x001975A0, 0x001F71AB, 0x002274A4, 0x000E6EA3, 0x000B74A7, 0x00136B90, 0x004C8392, 0x008CA4A2, 0x009CADA0, 0x00AEC0B3, 0x00BEC1B8, 0x00C9CDC1, 0x00A9C7BC, 0x003F848D, 0x000C6083, 0x000C4D79, 0x00002E45, 0x00144646, 0x00234454,
        0x0010394F, 0x0001344E, 0x000C4457, 0x00043B42, 0x00559296, 0x00B0F8FF, 0x0060AEBF, 0x001B4E51, 0x00154140, 0x00001813, 0x000C1D14, 0x001A1F16, 0x001C1911, 0x001B1510, 0x00211815, 0x000F1105, 0x005A594F, 0x00D9E2D8, 0x00E5F7F0, 0x00939D97,
        0x00C7C0BD, 0x00C6CCC7, 0x00719589, 0x0000495E, 0x0031BBE9, 0x00368DCF, 0x00002E57, 0x00014951, 0x000A3D3F, 0x0032595B, 0x00515354, 0x003C5148, 0x00306B7F, 0x00186E8C, 0x00001F28, 0x00281811, 0x001F2219, 0x0011231C, 0x00341D15, 0x00141B0E,
        0x00141408, 0x00575445, 0x00C8C9B9, 0x00DDE8D8, 0x00839588, 0x00B5C4BC, 0x00B2BDBA, 0x00D8CDCF, 0x0052B7D0, 0x0034C8F2, 0x002781A4, 0x00113D54, 0x002C6683, 0x003D9FC9, 0x001E9ECF, 0x00257DA5, 0x00207BA2, 0x00418AA0, 0x005A7E78, 0x008B9285,
        0x00B5B9B4, 0x002B3431, 0x00303A2D, 0x003D4437, 0x003C4336, 0x003C4336, 0x003F4435, 0x00414637, 0x00434636, 0x00424535, 0x00414434, 0x0044463A, 0x0044483C, 0x0043473B, 0x00404438, 0x003F4337, 0x00404438, 0x00414539, 0x00414539, 0x00414539,
        0x00484B3C, 0x004B4E3F, 0x00484B3B, 0x00474939, 0x00494D3F, 0x004C5142, 0x004C5041, 0x004B4D3E, 0x00505141, 0x00515345, 0x004D5141, 0x004F5243, 0x004D5041, 0x00515344, 0x004F5143, 0x0046493B, 0x00474A3B, 0x004C4F40, 0x004F5142, 0x004F5142,
        0x004D4F40, 0x00494C3D, 0x004F5243, 0x004B4E3F, 0x004D4E3F, 0x00525343, 0x004D4F41, 0x00505242, 0x004D4F43, 0x004D4F3F, 0x004D4D3D, 0x004E4F3F, 0x004E4E3F, 0x004F5242, 0x004F5243, 0x00515445, 0x004D4F40, 0x00525343, 0x00555646, 0x00545545,
        0x00505141, 0x0047483A, 0x00424337, 0x00424438, 0x00383A2E, 0x0024261A, 0x001A1C10, 0x00131509, 0x0015170B, 0x001A1C10, 0x0027291D, 0x00383A2E, 0x0044463A, 0x0045473B, 0x00414337, 0x0041453F, 0x00262A1F, 0x007E8578, 0x00818F83, 0x0063827B,
        0x0062949A, 0x00287082, 0x00004B65, 0x003B6C64, 0x00175051, 0x00003D4B, 0x00106782, 0x00389AC2, 0x002591C1, 0x00208EC2, 0x001E8EC3, 0x000C4B6D, 0x000F2C31, 0x00353529, 0x002B2F24, 0x002E3C31, 0x002B3725, 0x00313627, 0x0030342F, 0x0034372E,
        0x0031342B, 0x0034372E, 0x0030332A, 0x0035382F, 0x0031342B, 0x0035382F, 0x0033362D, 0x0031392F, 0x0030382E, 0x002F372D, 0x002E362C, 0x002D352B, 0x002D352B, 0x002D352B, 0x002D352B, 0x0031362D, 0x002F342B, 0x002E332A, 0x002F342B, 0x002F342B,
        0x002E332A, 0x002F342B, 0x0033382F, 0x002C342A, 0x002C342A, 0x002C342A, 0x002B3329, 0x002B3329, 0x002B3329, 0x002A3228, 0x002A3228, 0x00293029, 0x002A312A, 0x002B322B, 0x002F332D, 0x0030342E, 0x0033352F, 0x00343630, 0x00343630, 0x00313A2D,
        0x002B332C, 0x002C322D, 0x0033342B, 0x0037372B, 0x0026332B, 0x000C2F33, 0x000B3F50, 0x00054557, 0x00074759, 0x00074759, 0x00064559, 0x0008475B, 0x000B4A5F, 0x000A495E, 0x0006455A, 0x00084D5E, 0x00074759, 0x000C4A5C, 0x00004554, 0x00003E4C,
        0x00549CA8, 0x00467D8C, 0x002A5264, 0x004A586E, 0x00294D5F, 0x00337784, 0x0081DAE4, 0x002E8791, 0x0083C7D4, 0x004A6E80, 0x0037455B, 0x00284C64, 0x00436279, 0x003C6879, 0x00549AA7, 0x00034D59, 0x00003B4E, 0x00063F55, 0x0001445B, 0x0003425E,
        0x00093F4A, 0x0000688A, 0x0029ADE9, 0x00065784, 0x000A4D64, 0x00096168, 0x00408C81, 0x00313334, 0x00000301, 0x00050903, 0x001A1E13, 0x0022261A, 0x0026281C, 0x002D2E24, 0x0022231A, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFDFF, 0xFFFFFEFF, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00232624, 0x001B261E, 0x00000600, 0x000F130E, 0x001C1B17, 0x00191814, 0x004F504E, 0x00C7CCCA, 0x00CBD2CF, 0x00A8BEAC, 0x009DA18E, 0x00928A73, 0x00A4AC95, 0x005D8474,
        0x0004403F, 0x0000354A, 0x000C3359, 0x00123838, 0x000A444A, 0x00003846, 0x00003745, 0x006C8C91, 0x00C8CDCB, 0x00B4B3AF, 0x00A4A9A8, 0x00A5B4AC, 0x00BACABF, 0x009CC8C2, 0x0063BACE, 0x0056C0EF, 0x003A96CB, 0x00004D6A, 0x00004443, 0x00003F51,
        0x0000435A, 0x000E4B65, 0x0004364A, 0x001E414B, 0x008AA6AD, 0x00D7F6FF, 0x00CCF0FF, 0x00DDF0E7, 0x009DB0A7, 0x00223328, 0x000B1C0F, 0x001A2719, 0x00192013, 0x001E2014, 0x001A190F, 0x000D2618, 0x001A1C16, 0x0072706F, 0x008B9D9E, 0x0054797D,
        0x008CBAC1, 0x008FCDD3, 0x004CA0A5, 0x00004255, 0x0031BDE6, 0x002689C7, 0x00004064, 0x00074545, 0x0065847D, 0x0089B1A6, 0x007F9087, 0x009BA08B, 0x006C8893, 0x00104A5D, 0x00002319, 0x00272007, 0x0022291A, 0x0004261F, 0x000F2219, 0x00011A16,
        0x00101A14, 0x00302C27, 0x00A0A198, 0x00B1C1B6, 0x00576A61, 0x00A9B0AD, 0x0084797C, 0x00A99A8A, 0x00095670, 0x0040B4EF, 0x003896C4, 0x00003F51, 0x00114056, 0x001B5987, 0x001E9DD4, 0x002A91CA, 0x001278AD, 0x002A7A97, 0x00517672, 0x008E9384,
        0x00B1B3AD, 0x00232C29, 0x00364236, 0x003C4336, 0x003C4336, 0x003C4336, 0x00404536, 0x00424738, 0x00444737, 0x00424535, 0x003F4232, 0x00414238, 0x0046483C, 0x0043473B, 0x00404438, 0x003E4236, 0x003F4337, 0x00404438, 0x00414539, 0x00414539,
        0x00484B3C, 0x004B4E3F, 0x00434636, 0x00454736, 0x00484C3E, 0x004B5041, 0x004A4F40, 0x00494C3D, 0x00525344, 0x00525546, 0x004E5142, 0x00515445, 0x004E5142, 0x004E5142, 0x00505344, 0x00484B3C, 0x0045483A, 0x00494C3F, 0x004D4E40, 0x004D4E3E,
        0x004F5142, 0x004E5041, 0x004E5243, 0x004F5243, 0x004D4F3F, 0x00525344, 0x00525345, 0x004B4E3E, 0x004D4F41, 0x00515242, 0x004F5040, 0x00525242, 0x00484838, 0x004D4F3F, 0x004E5142, 0x00505344, 0x004C4E3F, 0x004D4F40, 0x00515242, 0x00515242,
        0x004E5040, 0x0047483B, 0x00404236, 0x003E4034, 0x002F3125, 0x001B1D11, 0x0014160A, 0x001E2014, 0x00191B0F, 0x0015170B, 0x001D1F13, 0x00323428, 0x0045473B, 0x0046483C, 0x003E4034, 0x003A423B, 0x00272B20, 0x00858879, 0x00889285, 0x00567671,
        0x00538F9B, 0x00358FAD, 0x000E7AA3, 0x00155559, 0x00084D56, 0x00004157, 0x0011678B, 0x003999C7, 0x001D87BC, 0x001788C0, 0x002093CC, 0x00145477, 0x000B282F, 0x0035372B, 0x002E3226, 0x00263428, 0x0025311F, 0x0034392A, 0x002B2F2A, 0x00343630,
        0x0030322C, 0x0032342E, 0x002B2D27, 0x0031332D, 0x002B2D27, 0x002E302A, 0x002A2C26, 0x00293127, 0x00293127, 0x00283026, 0x00283026, 0x00283026, 0x00283026, 0x00293127, 0x00293127, 0x002B3027, 0x00292E25, 0x00292E25, 0x002A2F26, 0x00292E25,
        0x00282D24, 0x002B3027, 0x0030352C, 0x00242C22, 0x00242C22, 0x00242C22, 0x00252D23, 0x00252D23, 0x00252D23, 0x00262E24, 0x00262E24, 0x00252C25, 0x00252C25, 0x00252C25, 0x00272B25, 0x00282C26, 0x002A2E28, 0x002E302A, 0x002F312B, 0x002B382A,
        0x00212E26, 0x00242E28, 0x002B3027, 0x00303428, 0x0026352D, 0x0011373C, 0x00114758, 0x00064658, 0x00074759, 0x00074759, 0x00064559, 0x0008475B, 0x000B4A5F, 0x000A495E, 0x0006455A, 0x00004556, 0x0008485A, 0x000A485A, 0x00034857, 0x00004957,
        0x005199A5, 0x003D7483, 0x00335B6D, 0x003A556A, 0x002D5568, 0x00185363, 0x00468F9D, 0x0071BAC8, 0x004E8999, 0x00224A5D, 0x00425D72, 0x00355971, 0x00315067, 0x00467182, 0x004D919E, 0x00003A46, 0x00124D60, 0x000F485E, 0x0000435A, 0x00054662,
        0x000B414C, 0x0000698B, 0x0028ACE8, 0x00055683, 0x00084B62, 0x00086067, 0x003F8B80, 0x002D2F30, 0x00000200, 0x00060A04, 0x001E2217, 0x00282C20, 0x002A2C20, 0x002E2F25, 0x00202118, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFDFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00222725, 0x00152623, 0x00000805, 0x000F0F09, 0x001E1813, 0x001D1A15, 0x00505A54, 0x0065807C, 0x00587F7D, 0x0068837F, 0x00547070, 0x004D6C6F, 0x005D8189, 0x004B7281,
        0x00194459, 0x000B3853, 0x00154460, 0x00013C56, 0x00074059, 0x0004394E, 0x00174A5A, 0x00487681, 0x005D878C, 0x00598082, 0x00608484, 0x005F8383, 0x00688B87, 0x005C8483, 0x00265F6E, 0x00045479, 0x0049ABE1, 0x003AA1D8, 0x00004074, 0x00064252,
        0x0011405C, 0x000B3A5A, 0x00003951, 0x00083D47, 0x008EA8A8, 0x00D5DADD, 0x00A7ADB2, 0x00DBE5D9, 0x00B7C1B5, 0x00273026, 0x00121B11, 0x00232B24, 0x001D251E, 0x001E2520, 0x001E2520, 0x00282019, 0x000B1614, 0x00002025, 0x00498994, 0x0051A0AB,
        0x005FB0B8, 0x0090DBDD, 0x004F9491, 0x00004A63, 0x0043B4EC, 0x001B95C9, 0x00003B5C, 0x00283E57, 0x00CCDACF, 0x00ECFBE0, 0x00F3EEEF, 0x00CACFD0, 0x00E1E8E5, 0x00979F98, 0x002A3428, 0x00182216, 0x00212A20, 0x001B231C, 0x00181F1A, 0x00132819,
        0x0016231B, 0x00111716, 0x0017252B, 0x000C2E34, 0x00124248, 0x0036686E, 0x001C4C52, 0x00073945, 0x0000496A, 0x0052B8EC, 0x002A8FBC, 0x0000455B, 0x00125252, 0x0007544D, 0x00016260, 0x0020708D, 0x002B869B, 0x001A6A75, 0x004E767B, 0x00889494,
        0x00B4BFB7, 0x00232D21, 0x00383C30, 0x003C4035, 0x003F4338, 0x003E4237, 0x00414337, 0x0045473B, 0x00464638, 0x00434335, 0x00474739, 0x00414435, 0x00444739, 0x0043473B, 0x003F4337, 0x003D4135, 0x003D4135, 0x003E4236, 0x003F4337, 0x003E4236,
        0x00444738, 0x00454839, 0x00434636, 0x00474838, 0x0045473A, 0x004A4F40, 0x00484E3F, 0x0046493A, 0x00555646, 0x004D5041, 0x00494C3D, 0x004E5142, 0x004C4F40, 0x004E5142, 0x00515445, 0x004B4E3F, 0x00494C3E, 0x004C4E3E, 0x004D4D3D, 0x004E4F3F,
        0x004E4E3F, 0x004F5242, 0x004F5243, 0x004E5243, 0x004C4E3F, 0x00525344, 0x004E5040, 0x00474A3B, 0x004D4F41, 0x00515242, 0x00505141, 0x00525242, 0x00515141, 0x004D4E3E, 0x004F5141, 0x00515445, 0x004E5142, 0x004D5041, 0x00505243, 0x00515242,
        0x004E5040, 0x0048493D, 0x00424339, 0x003D3E34, 0x0028291F, 0x001A1B11, 0x001D1E14, 0x00161413, 0x001B1918, 0x001B1B15, 0x0015160D, 0x002A2C20, 0x00444738, 0x00434636, 0x00424633, 0x00444335, 0x001D2B1F, 0x008C867F, 0x00849286, 0x005C7A6F,
        0x00669097, 0x001C809C, 0x002190C2, 0x002880A4, 0x00004F6B, 0x00003B50, 0x000E6881, 0x00389FC6, 0x00178BBA, 0x001A90BF, 0x001A90BA, 0x00036F98, 0x00004F64, 0x00557B87, 0x003A424F, 0x006E7376, 0x00344639, 0x00617B6E, 0x00233E42, 0x0060776F,
        0x0023453B, 0x00567D75, 0x00264B43, 0x00506C66, 0x00344B47, 0x004A6A65, 0x00254F48, 0x00426464, 0x00355652, 0x003E5955, 0x004F675F, 0x003B524A, 0x004A5F5C, 0x00374F4D, 0x00536A6C, 0x00224443, 0x0057766D, 0x00234136, 0x00547A74, 0x00215153,
        0x00477A7D, 0x001D4C49, 0x0050786C, 0x0028504E, 0x00557574, 0x00275955, 0x00536F6F, 0x00265955, 0x004F6E6D, 0x00305D5A, 0x00395E5C, 0x003C6361, 0x00335A58, 0x00436A68, 0x002B5250, 0x00456C6A, 0x002A514F, 0x004D7472, 0x002B5250, 0x004C7179,
        0x001F4948, 0x005D7B70, 0x002A382D, 0x00587070, 0x001F5F71, 0x00439EC5, 0x0004659D, 0x00004556, 0x00004455, 0x00044658, 0x00044357, 0x0007465A, 0x000D495F, 0x00094359, 0x000B455B, 0x00004155, 0x000A465C, 0x000B4459, 0x00064456, 0x00004354,
        0x005299A7, 0x00316C7B, 0x00386677, 0x00246F77, 0x004B7D89, 0x002E5968, 0x004F93A0, 0x005BAFBB, 0x004C8EA0, 0x0031566C, 0x003F5670, 0x003B5873, 0x0038536D, 0x00457083, 0x004D97A3, 0x00004853, 0x00044554, 0x000D465B, 0x0005465B, 0x000A405E,
        0x00084650, 0x00046A8D, 0x0032ABE9, 0x00005985, 0x00094D64, 0x000E5D66, 0x002B7F73, 0x001E2321, 0x00000100, 0x000A0E09, 0x001D1F19, 0x0023261D, 0x0028291F, 0x002E2E22, 0x001D1D11, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFDFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00202523, 0x00172523, 0x00030A07, 0x0010100A, 0x001E1A15, 0x00191B15, 0x00384945, 0x002D504C, 0x000D3C39, 0x00163F42, 0x00113B40, 0x0009373E, 0x0010404C, 0x000D4050,
        0x0002374C, 0x00073D54, 0x000B435C, 0x00063F58, 0x000F485E, 0x000A4156, 0x00083C4D, 0x000F404E, 0x000C3A45, 0x0009343D, 0x00113D44, 0x000F3940, 0x0010363A, 0x00143F42, 0x00033C4B, 0x00003759, 0x000F6795, 0x0051AEDB, 0x0009638C, 0x00003A4A,
        0x000F3E5A, 0x00134262, 0x0009455D, 0x000B404A, 0x007B9595, 0x00A3A8AB, 0x00666C71, 0x00D1DBCF, 0x00ACB6AA, 0x001F281E, 0x0010190F, 0x00222A23, 0x001C241D, 0x00202722, 0x00222924, 0x00131E16, 0x00132825, 0x00001E1D, 0x00124D4F, 0x00165D61,
        0x000B5756, 0x0017615D, 0x000D534C, 0x00004B63, 0x003CB2E5, 0x001597C6, 0x00003D5B, 0x00204259, 0x00CBE3D9, 0x00DDF4D8, 0x00BFC7C6, 0x00737879, 0x00CDD4D1, 0x00B8C0B9, 0x00353F33, 0x00111B0F, 0x001A2319, 0x00222A23, 0x00262D28, 0x00162724,
        0x0003181A, 0x0004252E, 0x00033D49, 0x00146978, 0x000A6B79, 0x00015D6E, 0x00005365, 0x00104D4F, 0x00005066, 0x0056BFE8, 0x0058B5DC, 0x004B869A, 0x006B8E92, 0x0065888B, 0x0069979E, 0x000C546C, 0x001E7383, 0x002C757D, 0x005F8587, 0x008B9694,
        0x009FAAA2, 0x00313C32, 0x002F352A, 0x003C4035, 0x0042463B, 0x0041453A, 0x00404236, 0x00414337, 0x00434335, 0x00424234, 0x00464638, 0x00434637, 0x00434638, 0x00424639, 0x003E4236, 0x003C4034, 0x003C4034, 0x003D4135, 0x003D4135, 0x003C4034,
        0x003F4233, 0x00414435, 0x00424435, 0x00484938, 0x0047493C, 0x00464A3C, 0x00484E3F, 0x00414334, 0x00474939, 0x0046493A, 0x0045493A, 0x00484C3D, 0x00484D3E, 0x00494E3F, 0x004C5042, 0x00494C3D, 0x004C4E40, 0x00515242, 0x004F5040, 0x00525242,
        0x00484838, 0x004D4F3F, 0x004E5142, 0x004F5243, 0x00494C3D, 0x004E5142, 0x004B4D3E, 0x0046493A, 0x004D5042, 0x00545545, 0x00505141, 0x004C4C3C, 0x00505040, 0x00515141, 0x004E5040, 0x00515445, 0x004E5142, 0x004E5142, 0x00505344, 0x004F5042,
        0x004E5142, 0x0047493C, 0x00414238, 0x003E3F35, 0x002C2D23, 0x00191A10, 0x0013140A, 0x001B1918, 0x00171612, 0x00161610, 0x001A1B12, 0x00313327, 0x00454839, 0x00414434, 0x00414532, 0x00414032, 0x001D2B1F, 0x0086837B, 0x0089998E, 0x0067847B,
        0x0068949B, 0x001C809C, 0x001180B2, 0x003291B8, 0x001B7594, 0x00025870, 0x000B6784, 0x003099C2, 0x001386B8, 0x00168BBE, 0x002093C0, 0x001879A5, 0x001D6D86, 0x00528899, 0x002B5366, 0x0049777F, 0x002A665B, 0x004E8E82, 0x00175254, 0x004D6C6B,
        0x00315957, 0x003E706C, 0x00376362, 0x00688C8C, 0x00335555, 0x003B6264, 0x00386A6A, 0x002C6567, 0x0053898A, 0x00386967, 0x00396663, 0x002B5855, 0x004A7B79, 0x00265C5D, 0x004E8789, 0x0029575E, 0x0040696B, 0x002A5050, 0x004B777E, 0x00497E92,
        0x00578FAA, 0x00467B90, 0x006998A6, 0x00418598, 0x005C97AB, 0x00398395, 0x005A91A6, 0x003B8799, 0x00588FA4, 0x003E8698, 0x0048879B, 0x004D8FA2, 0x004C8EA1, 0x005395A8, 0x004C8EA1, 0x004F91A4, 0x00428497, 0x005193A6, 0x003C7E91, 0x004D8BA9,
        0x003E8295, 0x00528B94, 0x002D5053, 0x00597F81, 0x000B4953, 0x00216D84, 0x005AA2C4, 0x000C4C5E, 0x00044456, 0x00064658, 0x00044357, 0x00044357, 0x0008475C, 0x00054459, 0x0007465B, 0x00054A5E, 0x000C485E, 0x00084156, 0x00044254, 0x00004152,
        0x00539AA8, 0x00417C8B, 0x00578596, 0x006BB6BE, 0x0086B8C4, 0x003F6A79, 0x00488C99, 0x005FB3BF, 0x00488A9C, 0x0022475D, 0x00445B75, 0x003A5772, 0x0038536D, 0x00446F82, 0x004C96A2, 0x00004853, 0x00044554, 0x000D465B, 0x0005465B, 0x00083E5C,
        0x0007454F, 0x0002688B, 0x0032ABE9, 0x00005985, 0x000A4E65, 0x000F5E67, 0x002D8175, 0x00232826, 0x00000100, 0x000A0E09, 0x001C1E18, 0x0022251C, 0x0028291F, 0x002F2F23, 0x00202014, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFEFDFF, 0xFFFFFEFF, 0xFFFDFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x001C211F, 0x001B2623, 0x00060C07, 0x000D0A05, 0x0017140F, 0x00141B16, 0x00334E4A, 0x00204F4C, 0x0003403C, 0x0009434F, 0x000B4655, 0x00074251, 0x00054050, 0x00054053,
        0x00084357, 0x0009455B, 0x00044056, 0x00073D54, 0x000D435A, 0x000C4358, 0x000C4156, 0x000D4256, 0x000D4054, 0x000D4152, 0x00134758, 0x00174759, 0x0013434F, 0x00144450, 0x000A4253, 0x0000415A, 0x00075272, 0x0078C4E1, 0x001B6680, 0x00003D4D,
        0x000D3D59, 0x000D3E5E, 0x00024058, 0x00073E47, 0x00799393, 0x00989FA2, 0x0061676C, 0x00D2DCD0, 0x00AAB4A8, 0x0020291F, 0x00131C12, 0x00242C25, 0x001A221B, 0x001E2520, 0x00232A25, 0x000E1D19, 0x001A2E29, 0x002C4541, 0x00557672, 0x0082ABA6,
        0x0092C2BC, 0x00699C94, 0x004F847B, 0x002A8C9E, 0x0046BCEB, 0x0028A9D0, 0x001D7D95, 0x004C7B90, 0x00D0EFE6, 0x00CAE9CE, 0x00A8BEB9, 0x00606566, 0x00C9D0CD, 0x00BCC4BD, 0x00273125, 0x00121C10, 0x0020291F, 0x001F2720, 0x00151C17, 0x002A2526,
        0x00181D20, 0x00324C53, 0x005B929B, 0x009AE9F4, 0x0098E7F4, 0x00A0E1F0, 0x00AAD8EA, 0x0085AFA8, 0x001F646E, 0x002A839E, 0x00287895, 0x002C5D6D, 0x00455B61, 0x0045555C, 0x00576A77, 0x006EACBC, 0x002E7C83, 0x00529596, 0x006A8A89, 0x00929996,
        0x00A6AEA7, 0x0027342C, 0x00363D36, 0x003C4035, 0x0041453A, 0x003F4338, 0x003F4135, 0x0045473B, 0x004A4A3C, 0x00464638, 0x00434335, 0x00444738, 0x00434637, 0x00414437, 0x003C4034, 0x003C4034, 0x003C4034, 0x003D4135, 0x003C4034, 0x003C4034,
        0x00404334, 0x00424536, 0x00404334, 0x00444434, 0x00434535, 0x00434638, 0x00434638, 0x00434637, 0x00434637, 0x00414435, 0x003E4132, 0x00434536, 0x00484B3D, 0x00484C3E, 0x00484B3C, 0x0046493A, 0x004D4F41, 0x00515242, 0x00505141, 0x00525242,
        0x00515141, 0x004D4E3E, 0x004F5141, 0x00515445, 0x00494C3D, 0x004C4F40, 0x004A4D3E, 0x00454839, 0x0046483B, 0x00515242, 0x004A4C3C, 0x004D4E3F, 0x00515243, 0x00515141, 0x004D4D3E, 0x00505243, 0x004E5041, 0x00505243, 0x00545545, 0x004B4B3B,
        0x004C4E3F, 0x0044463A, 0x003F4035, 0x00414238, 0x0036372D, 0x00212218, 0x0014150B, 0x0015150F, 0x0010100A, 0x0016170E, 0x0025261C, 0x00393B2F, 0x00424536, 0x003F4232, 0x00444737, 0x004B4A3C, 0x00203124, 0x007E7B73, 0x00809085, 0x005E7B72,
        0x00618D94, 0x001E84A1, 0x001283B5, 0x001D88B4, 0x002A8EB1, 0x00187693, 0x000D6E90, 0x00309BC7, 0x00188ABF, 0x00198BC0, 0x002693C6, 0x002983B2, 0x00126886, 0x002F7B92, 0x000C5571, 0x00003F52, 0x00095D59, 0x00468E88, 0x0011484F, 0x000E5152,
        0x00004446, 0x00004E4F, 0x00257778, 0x0030797D, 0x0002464B, 0x00055157, 0x00004347, 0x0000404A, 0x003B7C84, 0x00286268, 0x001F5457, 0x000C4547, 0x00044449, 0x00003B41, 0x0031828A, 0x00276271, 0x00144F58, 0x000E4C54, 0x00004658, 0x001F799B,
        0x001179A4, 0x00117DA7, 0x00127BA2, 0x00157BA6, 0x001E79A6, 0x000D79A3, 0x002076A4, 0x000D7BA5, 0x0019719F, 0x000D76A1, 0x001C7AA7, 0x001275A1, 0x001477A3, 0x001376A2, 0x001D80AC, 0x000E719D, 0x001679A5, 0x001578A4, 0x001174A0, 0x001875AD,
        0x001277A4, 0x0015708F, 0x00034558, 0x00144D56, 0x00003C40, 0x001C565B, 0x007AA5AE, 0x001A5467, 0x00084356, 0x00094457, 0x00074458, 0x00004255, 0x00014459, 0x00014459, 0x0001465A, 0x00004458, 0x00074359, 0x00094257, 0x00094759, 0x00004152,
        0x00478E9C, 0x002F6A79, 0x00487687, 0x004B969E, 0x0051838F, 0x00295463, 0x005094A1, 0x005EB2BE, 0x005193A5, 0x0032576D, 0x0039506A, 0x003A5772, 0x0037526C, 0x00436E81, 0x004B95A1, 0x00004752, 0x00044554, 0x000C455A, 0x0004455A, 0x00073D5B,
        0x0005434D, 0x0001678A, 0x0032ABE9, 0x00015A86, 0x000A4E65, 0x00105F68, 0x002E8276, 0x00282D2B, 0x00000301, 0x000A0E09, 0x001B1D17, 0x0021241B, 0x0027281E, 0x002F2F23, 0x00212115, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFEFDFF, 0xFFFFFEFF, 0xFFFDFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00181D1B, 0x00131A17, 0x00090A06, 0x00110E09, 0x00171711, 0x00101E18, 0x002F524E, 0x0017524E, 0x00014C4A, 0x00003E56, 0x00003E56, 0x00003E56, 0x00064258, 0x000A445A,
        0x000A4359, 0x00084157, 0x00063F55, 0x000E4358, 0x00083F54, 0x00073E53, 0x00063F55, 0x00074059, 0x0008405B, 0x00043F59, 0x00013C56, 0x00073F58, 0x000B4158, 0x000B4257, 0x00094356, 0x00104B5F, 0x001E5C6E, 0x0078B6C6, 0x0023606E, 0x00003E4E,
        0x000B3B57, 0x000A3B5B, 0x00013F57, 0x000A414A, 0x007D9999, 0x00969DA0, 0x00646D71, 0x00D4DED2, 0x00A9B3A7, 0x0020291F, 0x00161F15, 0x00232B24, 0x00171F18, 0x001C231E, 0x00202722, 0x00171C1B, 0x00585B59, 0x00D7D8D4, 0x00E9EBE5, 0x00BDC4BD,
        0x00DCE9E1, 0x00DDF2EA, 0x00DBF5EF, 0x0078D5E4, 0x0069D2FB, 0x0060D1F2, 0x007FDBEE, 0x0099C8DD, 0x00E2FDF9, 0x00BFD9C1, 0x00A1B7B2, 0x006D7273, 0x00C8CFCC, 0x00B6BEB7, 0x001E281C, 0x00182216, 0x0020291F, 0x00212922, 0x00202722, 0x0022261A,
        0x00202419, 0x004D554E, 0x00A4BAB5, 0x00CBEAE3, 0x0098B0A8, 0x00DCE0DA, 0x00EDDDD7, 0x00DFE4DB, 0x003D6064, 0x00003F51, 0x00003F51, 0x00073E4B, 0x00123A3F, 0x000D343C, 0x001B4855, 0x00558B96, 0x0003484B, 0x003B7776, 0x005D7874, 0x00909691,
        0x00B3BBB4, 0x0018251D, 0x00373F38, 0x003F4338, 0x003A3E33, 0x00292D22, 0x0024261A, 0x00323428, 0x00454537, 0x00474739, 0x00434335, 0x00444738, 0x00424536, 0x00414436, 0x003D4134, 0x003B3F33, 0x003C4034, 0x003D4135, 0x003D4135, 0x003C4034,
        0x003E4132, 0x00434637, 0x00424536, 0x00474737, 0x00454636, 0x00464839, 0x00424536, 0x003D412F, 0x00474939, 0x003E4030, 0x00464838, 0x004A4C3C, 0x004C4E3F, 0x004F5041, 0x004C4E3F, 0x0046493A, 0x004D5042, 0x00545545, 0x00515242, 0x004D4D3D,
        0x004F5040, 0x004F5040, 0x004E5040, 0x00515445, 0x004A4D3E, 0x004D4F41, 0x00515343, 0x004D4F40, 0x004B4E41, 0x00494B3C, 0x00434435, 0x0047493A, 0x004D4F41, 0x00505142, 0x004F5141, 0x00505242, 0x00515444, 0x004F5243, 0x00505142, 0x00515141,
        0x004C4D3D, 0x00434538, 0x003F4135, 0x0044463A, 0x00424438, 0x0035372B, 0x0027291D, 0x001A1B12, 0x001D1E15, 0x00292A20, 0x00383A2E, 0x00414337, 0x00404334, 0x00404334, 0x00474A3A, 0x003E3E32, 0x001A2A1F, 0x0087837E, 0x008B9B90, 0x00628178,
        0x00638E97, 0x001A809D, 0x000D7DB1, 0x000578AA, 0x00238FB8, 0x001F83A5, 0x0010759B, 0x002C9ACA, 0x001B8CC5, 0x001D8BC5, 0x002993C8, 0x00116E9B, 0x00197493, 0x0026819C, 0x001E769A, 0x00186C88, 0x003A828A, 0x00658F94, 0x00637384, 0x006797A3,
        0x0046818B, 0x00377881, 0x00609DA9, 0x00568B98, 0x00528393, 0x006099A8, 0x00347885, 0x00387988, 0x00548F9E, 0x00669AA6, 0x0061929C, 0x006C9FA9, 0x003B7983, 0x002D7985, 0x003D919D, 0x008296A8, 0x006D808D, 0x0065818C, 0x001C4E64, 0x0024739A,
        0x000D72A6, 0x001788C0, 0x000D82B5, 0x00168BC2, 0x001784BC, 0x001591C7, 0x001B82BB, 0x000F8DC3, 0x00147DB6, 0x00118BC1, 0x002091C9, 0x001488BF, 0x000F83BA, 0x000A7EB5, 0x001387BE, 0x00087CB3, 0x00188CC3, 0x001589C0, 0x001A8EC5, 0x001882C1,
        0x001489C0, 0x001C8CB6, 0x00176F8D, 0x00004153, 0x00074B50, 0x00124646, 0x00496867, 0x0021566A, 0x000A4255, 0x000A4457, 0x000A475B, 0x00004154, 0x00004357, 0x00004559, 0x00004559, 0x00004559, 0x00074359, 0x00084156, 0x00074557, 0x00004051,
        0x0049909E, 0x00326D7C, 0x004B798A, 0x0057A2AA, 0x00689AA6, 0x002D5867, 0x00428693, 0x005CB0BC, 0x004E90A2, 0x00294E64, 0x00455C76, 0x003A5772, 0x0036516B, 0x00426D80, 0x004A94A0, 0x00004752, 0x00044554, 0x000B4459, 0x00024358, 0x00083E5C,
        0x0005434D, 0x0001678A, 0x0032ABE9, 0x00015A86, 0x00084C63, 0x000E5D66, 0x002E8276, 0x002A2F2D, 0x00000402, 0x000A0E09, 0x001B1D17, 0x0021241B, 0x0025261C, 0x002D2D21, 0x00202014, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFEFDFF, 0xFFFFFEFF, 0xFFFDFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00161B19, 0x00111510, 0x000C0B07, 0x0016130E, 0x00191B15, 0x000C1D19, 0x002A5250, 0x000A4A4A, 0x00004849, 0x000D4562, 0x00063E5B, 0x00063C5A, 0x000A3F5A, 0x000D405A,
        0x000E3F59, 0x000F3F57, 0x0015435B, 0x000E4357, 0x000C4358, 0x000D465C, 0x000C455E, 0x0006415B, 0x00033F5C, 0x00044260, 0x00044260, 0x00043E5B, 0x00013D5A, 0x00043E5B, 0x000A445A, 0x00083E4F, 0x00083E49, 0x00235763, 0x00083E49, 0x00034151,
        0x000D3D59, 0x000C3F5F, 0x0003435B, 0x000B444D, 0x007F9B9B, 0x008A9396, 0x00616A6E, 0x00D3DDD1, 0x00A6B0A4, 0x001E271D, 0x00151E14, 0x00222A23, 0x00171F18, 0x001D241F, 0x00202722, 0x000B100F, 0x004F504E, 0x00DEDDD9, 0x00D8D8D2, 0x00797D77,
        0x008B9791, 0x009FB2AF, 0x00AEC4C2, 0x0065B4C1, 0x0059A9CE, 0x0058B1CC, 0x006FBCCC, 0x007EA7BD, 0x00E1EEF0, 0x00CCD8C4, 0x00A4B2AC, 0x006E7374, 0x00C3CAC7, 0x00ACB4AD, 0x001E281C, 0x001A2418, 0x00172016, 0x00171F18, 0x001C231E, 0x000F2C1C,
        0x000B1D10, 0x0040483D, 0x00B5BDB2, 0x00C7D6C8, 0x00677765, 0x00A8B099, 0x00B5B198, 0x00BABEB8, 0x003A595A, 0x00013F49, 0x00004753, 0x000C515B, 0x000E4952, 0x0005434D, 0x00044A57, 0x00083A46, 0x00003D41, 0x00255E5D, 0x005B7470, 0x008B8F8A,
        0x00B1B9B2, 0x00222F27, 0x003A423B, 0x003D4136, 0x00393D32, 0x002A2E23, 0x0026281C, 0x0035372B, 0x00464638, 0x00474739, 0x00424234, 0x00434637, 0x00424536, 0x00414435, 0x00404436, 0x003F4435, 0x003D4233, 0x00404333, 0x00434636, 0x00454838,
        0x00454838, 0x00434636, 0x00454838, 0x00474936, 0x00454734, 0x00494B39, 0x00424636, 0x00474B3B, 0x00484B3B, 0x00474B3B, 0x00494B3C, 0x004F5142, 0x00525345, 0x00515343, 0x004E5142, 0x0046493A, 0x0046483B, 0x00515242, 0x00505141, 0x00525343,
        0x004B4D3E, 0x00474939, 0x0048493A, 0x004F5142, 0x004A4C3D, 0x004D4E40, 0x00535444, 0x00515344, 0x0046493C, 0x00414435, 0x003F4233, 0x00434637, 0x004A4C3E, 0x00535444, 0x00535444, 0x00535444, 0x00505242, 0x004E5040, 0x004D4D3D, 0x004F4F40,
        0x004A4B3D, 0x00424438, 0x003F4135, 0x00414337, 0x0046483C, 0x00434539, 0x003B3D31, 0x0037392D, 0x003A3C30, 0x00404236, 0x0045473B, 0x0044463A, 0x00414435, 0x00434637, 0x00434637, 0x00414135, 0x0018291E, 0x008C8984, 0x008D9E95, 0x0063827B,
        0x0068969E, 0x001F85A2, 0x001487BA, 0x000D83B7, 0x00208DB9, 0x001E86A9, 0x000E759C, 0x002390C3, 0x001386BF, 0x001C8AC4, 0x002892C7, 0x00126892, 0x00015A75, 0x0019738C, 0x001A7395, 0x0009607A, 0x000A545A, 0x00335D62, 0x00424E60, 0x0024555F,
        0x001C555E, 0x000C4D56, 0x0016545E, 0x002F6370, 0x00326371, 0x00296271, 0x000F505E, 0x001A5765, 0x001E5562, 0x002D626C, 0x00174B52, 0x00285E65, 0x001D5C64, 0x001D6871, 0x000A5A65, 0x003C6169, 0x00345858, 0x002C5351, 0x0010464D, 0x00135E78,
        0x00207FA7, 0x001B83B2, 0x00117CA8, 0x001382B0, 0x001C80B0, 0x001388B5, 0x001978A9, 0x000D84B1, 0x001A7CAC, 0x001083B0, 0x001B83B2, 0x00238FBE, 0x001581B0, 0x00137FAE, 0x000E7AA9, 0x00137FAE, 0x001581B0, 0x001985B4, 0x001682B1, 0x001C7EAE,
        0x001181AC, 0x001886AA, 0x001C7695, 0x0000475E, 0x00004452, 0x00043F49, 0x0051757F, 0x001D5266, 0x00073F52, 0x000A4457, 0x000B485C, 0x00014356, 0x00004458, 0x00004559, 0x00004559, 0x0001465A, 0x0009455B, 0x00074055, 0x00034153, 0x00004051,
        0x005097A5, 0x00397483, 0x004D7B8C, 0x00529DA5, 0x0070A2AE, 0x00406B7A, 0x004E929F, 0x0060B4C0, 0x005092A4, 0x00274C62, 0x00415872, 0x003A5772, 0x0036516B, 0x00416C7F, 0x0049939F, 0x00004752, 0x00044554, 0x000B4459, 0x00024358, 0x000A405E,
        0x0006444E, 0x0001678A, 0x0033ACEA, 0x00015A86, 0x00074B62, 0x000C5B64, 0x002D8175, 0x002A2F2D, 0x00000200, 0x00080C07, 0x001B1D17, 0x0021241B, 0x0024251B, 0x002B2B1F, 0x001D1D11, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFEFDFF, 0xFFFFFEFF, 0xFFFDFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00161B19, 0x00171B16, 0x000C0C06, 0x00120E09, 0x00141511, 0x000C1A18, 0x00335959, 0x00115152, 0x00004E51, 0x000D3F5D, 0x000A3C58, 0x000C3E5A, 0x000A3A56, 0x000D3C58,
        0x0015425D, 0x0014415C, 0x0016435E, 0x00094055, 0x000A4156, 0x000A4359, 0x000A425B, 0x00063E59, 0x00043F59, 0x0005415E, 0x0006425F, 0x00073F5A, 0x00023E5C, 0x0000405F, 0x000C4761, 0x000C4253, 0x00154753, 0x00043747, 0x000E4659, 0x00054655,
        0x000D3F5B, 0x000C3F5F, 0x00004058, 0x00063F48, 0x007A9998, 0x00828B8E, 0x00626D71, 0x00DBE5D9, 0x00ADB7AB, 0x00242D23, 0x00192218, 0x00252D26, 0x001C241D, 0x00222924, 0x00202722, 0x001A271F, 0x000E1E17, 0x00273E3A, 0x00203F3C, 0x00082E2E,
        0x00214A4C, 0x00194748, 0x001B4B4D, 0x00044953, 0x00053F62, 0x0005485F, 0x00064B55, 0x00264B61, 0x00CCCFD7, 0x00E3E5D2, 0x00B6C1B9, 0x006C7172, 0x00C5CCC9, 0x00A5ADA6, 0x00232D21, 0x001E281C, 0x0020291F, 0x001F2720, 0x001A211C, 0x001C2725,
        0x00141315, 0x00282128, 0x0054565E, 0x005D7176, 0x00173C3A, 0x00265049, 0x0029524A, 0x003B6361, 0x000D4648, 0x00004B53, 0x00004B56, 0x00024756, 0x00064151, 0x000D4858, 0x00074759, 0x000E4052, 0x000A4B54, 0x00286163, 0x00607878, 0x00919492,
        0x00B5BCB5, 0x001A271F, 0x00333B34, 0x00373B30, 0x003F4338, 0x0041453A, 0x00434539, 0x004A4C40, 0x004D4D3F, 0x00464638, 0x00414133, 0x00434637, 0x00434637, 0x00434637, 0x00434637, 0x00424637, 0x00404435, 0x00414434, 0x00424535, 0x00434636,
        0x00414434, 0x00444737, 0x00464939, 0x00494B38, 0x004A4C39, 0x004A4D3A, 0x00454838, 0x00484B3D, 0x004A4E3F, 0x004B4E3F, 0x004B4D3E, 0x00525344, 0x00545648, 0x004F5243, 0x00505243, 0x004A4D3E, 0x00484B3D, 0x00494B3C, 0x00494B3B, 0x00494B3C,
        0x00444738, 0x00414435, 0x00434637, 0x0046493A, 0x00474A3A, 0x00494B3C, 0x00494C3D, 0x00494C3D, 0x00434637, 0x00414434, 0x003F4233, 0x00414435, 0x00434637, 0x004A4C3C, 0x004F5041, 0x004C4D3F, 0x004F5141, 0x00505141, 0x00515242, 0x00494B3C,
        0x00434636, 0x00424536, 0x003F4233, 0x003D4031, 0x00424536, 0x00454839, 0x00424536, 0x0046493A, 0x00454839, 0x00404334, 0x00404334, 0x003E4132, 0x00404334, 0x0045473B, 0x003F4135, 0x00424137, 0x0016271E, 0x00827F7B, 0x0084958C, 0x00597A73,
        0x0063909B, 0x002188A8, 0x001688BD, 0x001A8EC5, 0x00208BB7, 0x002085AB, 0x001279A0, 0x00228FC2, 0x001185BC, 0x00198BC0, 0x002492C2, 0x00287197, 0x00003549, 0x00377F90, 0x003B879D, 0x00207382, 0x00025753, 0x00448782, 0x002D5E66, 0x00216362,
        0x000F5A58, 0x00277A78, 0x00136362, 0x00478C8F, 0x00307376, 0x00277274, 0x00116466, 0x0028646A, 0x00337074, 0x00437F7F, 0x00326E6D, 0x001E5D5B, 0x002C6E6D, 0x001C6164, 0x00246D71, 0x00298983, 0x002C8375, 0x000B5843, 0x00287468, 0x000F6166,
        0x00459CB0, 0x00338AA5, 0x004397B3, 0x00348BA6, 0x004997B4, 0x002B88A2, 0x004189A7, 0x002A89A3, 0x004992B0, 0x002B86A1, 0x003588A4, 0x004498B4, 0x003B8FAB, 0x003D91AD, 0x003286A2, 0x004094B0, 0x00368AA6, 0x003D91AD, 0x003185A1, 0x004996B0,
        0x002C869E, 0x004099AE, 0x00438BA3, 0x002A6D84, 0x00004961, 0x00034961, 0x00386D88, 0x00114B5E, 0x00043F52, 0x000A4558, 0x000B485C, 0x00024457, 0x0002455A, 0x00014459, 0x00004559, 0x00004155, 0x00074359, 0x00094257, 0x00064456, 0x00004152,
        0x004C93A1, 0x002E6978, 0x003B697A, 0x00156068, 0x00336571, 0x00285362, 0x004C909D, 0x0055A9B5, 0x005193A5, 0x0030556B, 0x003A516B, 0x003A5772, 0x0036516B, 0x00406B7E, 0x0049939F, 0x00004752, 0x00054655, 0x000B4459, 0x00014257, 0x000B415F,
        0x0005434D, 0x00006689, 0x0033ACEA, 0x00015A86, 0x00064A61, 0x000B5A63, 0x002C8074, 0x002A2F2D, 0x00000100, 0x00070B06, 0x001C1E18, 0x0022251C, 0x0024251B, 0x0029291D, 0x001B1B0F, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFEFDFF, 0xFFFFFEFF, 0xFFFDFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00171C1A, 0x00161A14, 0x00080802, 0x00100C07, 0x00181713, 0x000D1A18, 0x003A5B5E, 0x00134D52, 0x0000444B, 0x000C4259, 0x000A4057, 0x0010465D, 0x000C425B, 0x000B415A,
        0x000D425D, 0x00083D58, 0x000A3E5C, 0x00094258, 0x00084157, 0x00063F55, 0x00063F55, 0x000A4359, 0x000A4359, 0x00074056, 0x00074056, 0x000C4156, 0x0007415E, 0x00004062, 0x0002405E, 0x000C4156, 0x001B4D5F, 0x000A4057, 0x00054361, 0x00014251,
        0x000B3D59, 0x000D4060, 0x00003F57, 0x00013C45, 0x00779695, 0x00788486, 0x00636E72, 0x00DEE8DC, 0x00AFB9AD, 0x00252E24, 0x00172016, 0x00242C25, 0x00202821, 0x00262D28, 0x001F2621, 0x00151E11, 0x000E2118, 0x00002323, 0x00033940, 0x00003D48,
        0x0000404A, 0x00003C45, 0x0008464E, 0x00044952, 0x000B3F5D, 0x000A4656, 0x0000434A, 0x001A4359, 0x00CDD2DB, 0x00E2E3D3, 0x009FB0A5, 0x006C7172, 0x00D3DAD7, 0x00AFB7B0, 0x00313B2F, 0x00182216, 0x001A2319, 0x00222A23, 0x00202722, 0x00291D1B,
        0x00251A1D, 0x00181721, 0x00001626, 0x0004354B, 0x00003B52, 0x00003F57, 0x00003F5B, 0x0005424C, 0x0000434D, 0x00004E59, 0x0001495A, 0x00064258, 0x00063953, 0x000F455C, 0x00033F55, 0x00104560, 0x0000384B, 0x00205D67, 0x00577276, 0x00939897,
        0x00AEB5AE, 0x00222D23, 0x003A4035, 0x00393D32, 0x00404439, 0x0042463B, 0x00434539, 0x0045473B, 0x00464638, 0x00444436, 0x00474739, 0x00454839, 0x0046493A, 0x0046493A, 0x00454839, 0x00444738, 0x00414536, 0x00424535, 0x00424535, 0x00424535,
        0x00414435, 0x00464939, 0x00444737, 0x00454637, 0x00444634, 0x00404331, 0x00414334, 0x0047493B, 0x00494C3D, 0x00464A3B, 0x00484A3B, 0x004D4D3F, 0x004D4F40, 0x0047483A, 0x004A4B3C, 0x00434637, 0x00424536, 0x00424536, 0x00444738, 0x00444738,
        0x00434637, 0x00424536, 0x00424536, 0x00444738, 0x00454839, 0x00464839, 0x0046493A, 0x0046493A, 0x00444738, 0x00424536, 0x00424536, 0x00404334, 0x00414435, 0x00444637, 0x0046493A, 0x00474A3C, 0x00484A3B, 0x00484A3A, 0x00454839, 0x00424536,
        0x003F4233, 0x00424536, 0x00424536, 0x003E4132, 0x00404334, 0x00434637, 0x00404334, 0x00414434, 0x003F4232, 0x003A3D2D, 0x003E4132, 0x003D4031, 0x003D3F33, 0x0045473B, 0x00404236, 0x00414238, 0x0022332A, 0x0081807C, 0x008C9E97, 0x005F7F7A,
        0x005D8B96, 0x002F96B6, 0x001A8EC3, 0x00208CC2, 0x002287B4, 0x002585A9, 0x00197CA2, 0x002796C4, 0x001488BD, 0x00168BBE, 0x002595C3, 0x00236B89, 0x00074450, 0x0074A7AA, 0x0065939B, 0x0088BEBF, 0x003F7D6F, 0x0066A297, 0x003C6C70, 0x008FABA5,
        0x00466C66, 0x0079A8A0, 0x00467069, 0x007E9F9B, 0x00567572, 0x007EA3A1, 0x00558481, 0x00689390, 0x0053817B, 0x005E9288, 0x00558D80, 0x004C8477, 0x0064988E, 0x004E7C76, 0x007FA7A5, 0x00357579, 0x006DA19A, 0x00527969, 0x0097B8A9, 0x004A6F6D,
        0x0084ACB8, 0x00648A9C, 0x008BAFBF, 0x005A97A3, 0x0085BAC7, 0x004E959F, 0x007DAEBC, 0x004F97A1, 0x007DB1BE, 0x005698A3, 0x006EA8B4, 0x0064A0AC, 0x006AA6B2, 0x006AA6B2, 0x0066A2AE, 0x006EAAB6, 0x0065A1AD, 0x006CA8B4, 0x005F9BA7, 0x0082BBC4,
        0x00569AA1, 0x0079B8C0, 0x006C9BA9, 0x007BADC1, 0x00468BA6, 0x00509ABC, 0x004688B1, 0x00064658, 0x00024254, 0x0008485A, 0x0007465A, 0x00044357, 0x0006455A, 0x00034257, 0x0006455A, 0x0001465A, 0x0008445A, 0x00084156, 0x00064456, 0x00004051,
        0x004A919F, 0x00336E7D, 0x004B798A, 0x0061ACB4, 0x007AACB8, 0x003F6A79, 0x00428693, 0x0059ADB9, 0x004D8FA1, 0x0023485E, 0x004E657F, 0x003B5873, 0x0036516B, 0x00406B7E, 0x0049939F, 0x00004853, 0x00054655, 0x000C455A, 0x00014257, 0x000A405E,
        0x0004424C, 0x00006588, 0x0033ACEA, 0x00015A86, 0x00064A61, 0x000B5A63, 0x002E8276, 0x002C312F, 0x00000100, 0x00070B06, 0x001C1E18, 0x0023261D, 0x0025261C, 0x002A2A1E, 0x001D1D11, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFEFDFF, 0xFFFFFEFF, 0xFFFDFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00181D1B, 0x00171E17, 0x00090903, 0x00130F0A, 0x001C1915, 0x000D1816, 0x003F5E61, 0x001C5259, 0x00074A53, 0x000B4757, 0x00033E51, 0x00064357, 0x00074359, 0x0004425A,
        0x00003F58, 0x00003A56, 0x00044462, 0x00074059, 0x000C455E, 0x000B445A, 0x000B4158, 0x000D4459, 0x000D4256, 0x000D4054, 0x00124657, 0x00104353, 0x00063E59, 0x00003F62, 0x00044161, 0x00093F56, 0x00083D52, 0x000D4665, 0x00004067, 0x00054655,
        0x000E405C, 0x000D4362, 0x00014159, 0x0006414A, 0x0084A3A2, 0x008C989A, 0x00828D91, 0x00D1DBCF, 0x00A3ADA1, 0x00192218, 0x000D160C, 0x001D251E, 0x001E261F, 0x00262D28, 0x001D241F, 0x00271E10, 0x00202720, 0x000B2B30, 0x001B5463, 0x000E5569,
        0x00084F63, 0x0018586A, 0x00124D5C, 0x00004A50, 0x000C415C, 0x000C4756, 0x00004044, 0x00114055, 0x00C4CED8, 0x00C7CFBE, 0x0070887C, 0x00505556, 0x00B8BFBC, 0x00919992, 0x00252F23, 0x000D170B, 0x00141D13, 0x001F2720, 0x001B221D, 0x001E2A14,
        0x00102516, 0x00042C2A, 0x00155E66, 0x0044A7BB, 0x0056BFE0, 0x004BA9D4, 0x003A87B8, 0x002B6074, 0x00134E61, 0x00004255, 0x00044358, 0x000F4661, 0x00063C5A, 0x000D4A64, 0x0000445A, 0x00074060, 0x00004058, 0x00084553, 0x00223E45, 0x004C5051,
        0x00585F58, 0x00273125, 0x002F3629, 0x003B3F34, 0x003E4237, 0x003E4237, 0x00424438, 0x0047493D, 0x0048483A, 0x00474739, 0x004B4B3D, 0x00474A3B, 0x00494C3D, 0x00494C3D, 0x00474A3B, 0x00434637, 0x00404334, 0x00404334, 0x00414434, 0x00444737,
        0x00444738, 0x00454839, 0x00454839, 0x0047493A, 0x00464939, 0x0046493A, 0x00474A3B, 0x00464638, 0x00494A3C, 0x0048493B, 0x004D4D3F, 0x00464638, 0x0049493B, 0x00464638, 0x0049493B, 0x00474A3B, 0x00474A3B, 0x00474A3B, 0x00474A3B, 0x0046493A,
        0x00454839, 0x00434637, 0x00424536, 0x00454839, 0x0046493A, 0x00474A3B, 0x00474A3B, 0x00474A3B, 0x0046493A, 0x00454839, 0x00444738, 0x00404334, 0x00414435, 0x00424536, 0x00434637, 0x00434637, 0x00434637, 0x00424536, 0x00414435, 0x00414435,
        0x003E4132, 0x00434637, 0x00474A3B, 0x00434637, 0x00434637, 0x00444738, 0x003F4233, 0x003E422F, 0x003F4330, 0x00414434, 0x004A4D3D, 0x00434637, 0x003B3D31, 0x0045473B, 0x00434539, 0x003C3D33, 0x00182B22, 0x0053524E, 0x0053655E, 0x001E3E39,
        0x0022505B, 0x00238AAA, 0x001F93C8, 0x00238AC1, 0x002889B5, 0x002884A7, 0x0017789C, 0x002996C2, 0x001388BB, 0x001389B8, 0x002599C2, 0x0025758C, 0x00003E42, 0x0084A5A1, 0x00606E6D, 0x009EACA8, 0x00586E5C, 0x0099ADA1, 0x00556068, 0x009AAEA2,
        0x00466255, 0x008CB0A2, 0x0047695E, 0x0096AEA4, 0x00576C63, 0x0089A69D, 0x004C7167, 0x0093A59E, 0x0061796D, 0x007B9C8D, 0x00648B76, 0x006E937F, 0x007A9486, 0x0067776C, 0x00949B96, 0x00516D7E, 0x0093A6AB, 0x00606B61, 0x00A3B1A5, 0x00465F5B,
        0x008FB5BA, 0x00659198, 0x008AB6BD, 0x0057878D, 0x0094BBC3, 0x00548C91, 0x0094B8C0, 0x00538B90, 0x0089ADB5, 0x005D9197, 0x0088B4BB, 0x0069979E, 0x007BA9B0, 0x0073A1A8, 0x0077A5AC, 0x00719FA6, 0x006F9DA4, 0x0076A4AB, 0x006C9AA1, 0x007FAFB1,
        0x00629898, 0x0084B4B5, 0x0066838A, 0x009BBDCD, 0x00407D97, 0x0028769B, 0x00004372, 0x00004455, 0x00004556, 0x0007495B, 0x00054458, 0x00044357, 0x0008445A, 0x00053F55, 0x000A445A, 0x0004495D, 0x00074359, 0x00084156, 0x00094759, 0x00003F50,
        0x00468D9B, 0x00346F7E, 0x00568495, 0x005FAAB2, 0x0061939F, 0x00345F6E, 0x00478B98, 0x0055A9B5, 0x004C8EA0, 0x00274C62, 0x00405771, 0x003C5974, 0x0036516B, 0x00406B7E, 0x0049939F, 0x00004853, 0x00064756, 0x000C455A, 0x00014257, 0x00093F5D,
        0x0002404A, 0x00006487, 0x0033ACEA, 0x00025B87, 0x00064A61, 0x000C5B64, 0x002F8377, 0x002E3331, 0x00000200, 0x00070B06, 0x001C1E18, 0x0024271E, 0x0026271D, 0x002C2C20, 0x001F1F13, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFDFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00171C1A, 0x00161A15, 0x00100B08, 0x00091009, 0x000E140F, 0x001A1C1C, 0x002F5E5C, 0x00055C59, 0x00054C50, 0x00084853, 0x0000424D, 0x00054956, 0x0004495A, 0x00125467,
        0x00034257, 0x00073F5A, 0x000E435E, 0x0000445C, 0x0005465B, 0x00074154, 0x000D4050, 0x00134656, 0x000E4357, 0x00033F55, 0x0002425B, 0x0008405B, 0x0008405B, 0x0008405B, 0x0008405B, 0x0009415C, 0x0009415C, 0x0009415C, 0x0009415C, 0x00004159,
        0x00004059, 0x000E445D, 0x00124157, 0x00143F54, 0x006D97AA, 0x00C2F0FF, 0x009ACBDB, 0x00607F82, 0x00485C57, 0x001A2217, 0x00171E17, 0x000B1417, 0x000C171B, 0x00131914, 0x00221F10, 0x000E2422, 0x002B423A, 0x007D9184, 0x00BBCEBF, 0x00A0B3AA,
        0x00B5CCCE, 0x00B9D4E2, 0x009FBBD3, 0x002796D4, 0x002A9BDD, 0x00299DDC, 0x00107DB1, 0x00157599, 0x003B8EAD, 0x003587AA, 0x001F749C, 0x000E6B9C, 0x00086E91, 0x00135C70, 0x00121D25, 0x00281615, 0x001C2014, 0x00001A07, 0x00052010, 0x00171919,
        0x000C1217, 0x004C5862, 0x008495A2, 0x00E8FCFF, 0x00CDE1E2, 0x00E2F6EA, 0x00E6F9E6, 0x00D2EADE, 0x003B655E, 0x00044248, 0x00044659, 0x00104B65, 0x00033A55, 0x00054157, 0x0003495A, 0x00094E58, 0x00064553, 0x00043A4B, 0x00002C41, 0x00001E2E,
        0x00001821, 0x00031F20, 0x00112A26, 0x0031322E, 0x00333430, 0x00363733, 0x003A3A34, 0x003A3A34, 0x003A3B32, 0x003C3A32, 0x003C3A32, 0x00353C35, 0x003E3E38, 0x00413B34, 0x00413730, 0x0040372E, 0x00403B32, 0x003B3C32, 0x00323B2E, 0x003B3A2E,
        0x003D3B30, 0x003F3D32, 0x003D3C32, 0x003D3C32, 0x003B3C32, 0x003E3F36, 0x00404138, 0x00373933, 0x003B3C38, 0x00343533, 0x003A3838, 0x00383636, 0x00333432, 0x003C3D39, 0x00343630, 0x003B392E, 0x003A382E, 0x0037352D, 0x00413E3A, 0x00373430,
        0x003F3835, 0x003C312D, 0x004A3E38, 0x003F3629, 0x00494032, 0x00463F30, 0x00393523, 0x00464634, 0x00393B27, 0x00383E27, 0x00343C25, 0x003C352C, 0x003C372E, 0x003E3B33, 0x003C3934, 0x003C3A32, 0x003E3C31, 0x00413B2E, 0x00463F30, 0x003A3C30,
        0x003C3C30, 0x003E3D2F, 0x003B382A, 0x00433C2D, 0x00443C2B, 0x00463C2B, 0x00453B2A, 0x003F382F, 0x00423B32, 0x00423B32, 0x003D382F, 0x003C372E, 0x003C3A30, 0x003C3A30, 0x0037352B, 0x00262423, 0x000E201F, 0x0000191A, 0x00002E37, 0x000B4E63,
        0x00004869, 0x00248AB5, 0x001A91C2, 0x001E8DBD, 0x002389B9, 0x002380AD, 0x001978A3, 0x002B94BF, 0x001584B2, 0x001D88BB, 0x002F93CA, 0x00126487, 0x002B3743, 0x005B574C, 0x00495948, 0x0054584C, 0x005D5947, 0x00565C4B, 0x004B4C48, 0x0069675C,
        0x00525045, 0x00616155, 0x0056564A, 0x0057594D, 0x00525448, 0x005A5C50, 0x00515549, 0x0066655B, 0x005A594F, 0x005B5A50, 0x005A594F, 0x0059584E, 0x0058574D, 0x0055544A, 0x00616056, 0x00565A4F, 0x005A5E53, 0x0052564B, 0x00585C51, 0x004C5045,
        0x005E6257, 0x0052564B, 0x0063675C, 0x00535248, 0x00626157, 0x0056554B, 0x0065665C, 0x00525349, 0x00606459, 0x0052564B, 0x005F6358, 0x004C5045, 0x005B5F54, 0x005A5E53, 0x005B5F54, 0x005A5E53, 0x005A5E53, 0x0061655A, 0x00575B50, 0x00616859,
        0x005C5951, 0x0066625D, 0x0053594E, 0x00636958, 0x0046463A, 0x0027393A, 0x00103D4A, 0x000A485A, 0x000A485A, 0x0009465A, 0x00064559, 0x00064559, 0x0004455A, 0x0005465B, 0x0005465B, 0x00044358, 0x000B455B, 0x000F485D, 0x00004153, 0x00004253,
        0x00488F9D, 0x002F6675, 0x003D6577, 0x004A949A, 0x0039858B, 0x001F535F, 0x00508491, 0x0052A7B1, 0x0045909E, 0x002C4F63, 0x003B576F, 0x003D5571, 0x003B526C, 0x003F697C, 0x004A909D, 0x00004A55, 0x00074857, 0x000A4358, 0x00014257, 0x0004435F,
        0x0005404A, 0x000B5E84, 0x0030AFEC, 0x00035A86, 0x000A4860, 0x00006267, 0x0039786F, 0x00202A2A, 0x00000300, 0x000C0E08, 0x00212016, 0x0028261B, 0x0026261A, 0x002A2B21, 0x001B1E15, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFDFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00171C1A, 0x00141813, 0x000D0805, 0x00091009, 0x00121813, 0x001D1F1F, 0x00346361, 0x000D6461, 0x000B5256, 0x00224248, 0x00173B43, 0x0016404C, 0x00114250, 0x000E4657,
        0x00094257, 0x000A435C, 0x00083F5A, 0x00054459, 0x000F4556, 0x00143C48, 0x00113137, 0x00143138, 0x00153B47, 0x000E4052, 0x00094258, 0x0008405B, 0x0008405B, 0x0008405B, 0x0008405B, 0x0009415C, 0x0009415C, 0x0009415C, 0x0009415C, 0x000D4961,
        0x000D465F, 0x00073F58, 0x00074056, 0x0000354A, 0x0030788A, 0x0082D2E3, 0x0058B0BE, 0x0004383E, 0x00072C28, 0x00061A0D, 0x00131F13, 0x00151F19, 0x00171E1B, 0x001B1E15, 0x00221F10, 0x00101611, 0x00656A61, 0x00F6FEED, 0x00EFFAE6, 0x0097A795,
        0x00BAD2C8, 0x00B4D3D2, 0x00A2C4CA, 0x0040ABD1, 0x0037B0E1, 0x0016A2DD, 0x0024B7F5, 0x002FC1FB, 0x0023B2EB, 0x002CBAFB, 0x0022B2FA, 0x0028B8FF, 0x0025B5F6, 0x00238BBA, 0x00082C4A, 0x00191423, 0x00211F1F, 0x00141C15, 0x001B1E15, 0x00161F0A,
        0x00131D0D, 0x00465149, 0x00B3BCB9, 0x00DBE2DF, 0x0093978C, 0x00D6D5C1, 0x00CECAB1, 0x00BEDCD1, 0x003B6865, 0x0009474D, 0x00003D50, 0x0003405A, 0x0009415C, 0x000D495F, 0x00004556, 0x0000424F, 0x00003D4D, 0x0001394C, 0x00053449, 0x00082E40,
        0x00062633, 0x00052227, 0x00052121, 0x000C1C15, 0x000B1B14, 0x000B1913, 0x000B1A12, 0x000D1A12, 0x000D1B10, 0x000C1A0F, 0x000D180E, 0x000A140E, 0x000D140F, 0x00121912, 0x00141812, 0x0011160D, 0x000F170D, 0x00111A10, 0x00101C10, 0x00162014,
        0x00111D11, 0x000D190D, 0x000E1A0E, 0x000F1D12, 0x00101E13, 0x000B1A12, 0x0007160E, 0x00181A14, 0x00171B15, 0x00121611, 0x00161917, 0x00151816, 0x00121611, 0x00191D17, 0x00141610, 0x000E180B, 0x00111B0F, 0x000D180E, 0x00141F17, 0x000D1810,
        0x000F1A12, 0x00121A13, 0x000E150E, 0x00041C12, 0x00021911, 0x000A1C15, 0x0003130C, 0x000C1714, 0x000D1613, 0x000B1110, 0x000C1110, 0x00121A0F, 0x0010190F, 0x000F1A10, 0x000B160C, 0x000A150B, 0x000A160A, 0x000D170A, 0x00111B0B, 0x000B1915,
        0x000A1814, 0x000C1A16, 0x000A1814, 0x00081612, 0x000C1714, 0x0006110E, 0x0006110E, 0x000D160C, 0x0010190F, 0x00111A10, 0x00111A10, 0x00121D13, 0x00121D13, 0x000D1B10, 0x000B190E, 0x00111919, 0x00001614, 0x00002928, 0x00336D72, 0x003A7F90,
        0x000E607F, 0x002991BC, 0x00158EC0, 0x001E8FBA, 0x00258EBA, 0x001E7DAE, 0x00036999, 0x002190C0, 0x001C92C3, 0x001C8CC1, 0x00238DC3, 0x00085A7D, 0x00192531, 0x00403C31, 0x002E3E2D, 0x00383C30, 0x003E3A28, 0x003A402F, 0x00353632, 0x003D3D31,
        0x002F2F23, 0x003D3D31, 0x0035372B, 0x003B3D31, 0x002F3327, 0x0035392D, 0x002D3125, 0x003A3B31, 0x00313228, 0x0034352B, 0x0033342A, 0x0033342A, 0x0033342A, 0x00303127, 0x0037382E, 0x0032362B, 0x0035392E, 0x00303429, 0x0033372C, 0x002B2F24,
        0x0033372C, 0x00262A1F, 0x00303429, 0x002D2C22, 0x0037362C, 0x002D2C22, 0x0038392F, 0x002D2E24, 0x00363A2F, 0x00292D22, 0x0031352A, 0x002C3025, 0x0032362B, 0x002D3126, 0x002E3227, 0x002D3126, 0x002A2E23, 0x0031352A, 0x002D3126, 0x002B3223,
        0x0028251D, 0x002D2924, 0x0022281D, 0x00343A29, 0x002B2B1F, 0x00182A2B, 0x000D3A47, 0x00084658, 0x00084658, 0x00094759, 0x0007465A, 0x0007465A, 0x0005465B, 0x0004455A, 0x00034459, 0x00024156, 0x000A445A, 0x000E475C, 0x00003F51, 0x00003C4D,
        0x00458C9A, 0x003D7483, 0x00598193, 0x007AC2C9, 0x005FABB1, 0x00386A76, 0x00588C99, 0x0052A7B1, 0x00458E9C, 0x002A4D61, 0x003C566E, 0x003D5571, 0x003A516B, 0x003E687B, 0x00498F9C, 0x00004954, 0x00064756, 0x000A4358, 0x00024358, 0x0004435F,
        0x0005404A, 0x000B5E84, 0x0030AFEC, 0x00045B87, 0x000A4860, 0x00006267, 0x003A7970, 0x00212B2B, 0x00000200, 0x000A0C06, 0x001E1D13, 0x0027251A, 0x0029291D, 0x002E2F25, 0x001D2017, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFDFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00171C1A, 0x00171B16, 0x000B0603, 0x00091009, 0x00131914, 0x001D1F1F, 0x00396866, 0x0019706D, 0x00165D61, 0x00080808, 0x00000404, 0x00081B20, 0x001E3F48, 0x0015404F,
        0x00124559, 0x000C455B, 0x00023D57, 0x000B4558, 0x00194552, 0x00182F31, 0x00000A04, 0x00000400, 0x0013282A, 0x001B4250, 0x000D4256, 0x0008405B, 0x0008405B, 0x0008405B, 0x0008405B, 0x0009415C, 0x0009415C, 0x0009415C, 0x0009415C, 0x000C425B,
        0x000E465F, 0x00043C55, 0x000D4961, 0x00004057, 0x0018647B, 0x0059AEC4, 0x003A93A8, 0x00003745, 0x00012E31, 0x000E261C, 0x00141D10, 0x00191C13, 0x00161715, 0x001A1C1D, 0x00181719, 0x0020161C, 0x003C3434, 0x00939189, 0x007D8475, 0x00465847,
        0x00728C7F, 0x0053756E, 0x0039605E, 0x000C4B59, 0x00004062, 0x00017AB2, 0x0024B4FB, 0x001CB3FE, 0x001CB0FE, 0x0027B9FF, 0x0027B7FF, 0x0018B2FF, 0x0021B3FF, 0x001985BF, 0x0000254E, 0x00080F23, 0x001E1F23, 0x0023241B, 0x00241E13, 0x00171D06,
        0x001F2814, 0x00353E34, 0x00A2B0AC, 0x00A8B6B4, 0x0066766F, 0x009FB0A3, 0x007B8B7A, 0x00759A96, 0x001F4F50, 0x000F4C56, 0x0007495C, 0x0004425A, 0x0009455D, 0x0009485D, 0x00014355, 0x00024456, 0x00044155, 0x00023B51, 0x0004354B, 0x00083147,
        0x000B2F3F, 0x000B2B36, 0x0008282E, 0x004F605C, 0x004B5C58, 0x00485851, 0x0045554E, 0x0045534D, 0x0045544C, 0x0045544C, 0x0046534B, 0x00525756, 0x004A4F4D, 0x0049524F, 0x0046514E, 0x00434F49, 0x00434D47, 0x004B524B, 0x004A514A, 0x00445247,
        0x00445247, 0x0045524A, 0x0043524A, 0x0044524C, 0x0043534C, 0x0043534C, 0x0043524E, 0x00454C45, 0x00485049, 0x004A554D, 0x0047524A, 0x00424D45, 0x003C473F, 0x00454D46, 0x00464D46, 0x00444F45, 0x00455046, 0x003D483E, 0x003C4941, 0x003D4C44,
        0x0034423C, 0x003F4F48, 0x003D4D46, 0x00364A45, 0x0031423E, 0x00394A47, 0x003C4848, 0x003B4447, 0x00444B4E, 0x003F4348, 0x003F4348, 0x003F4C44, 0x003E4B43, 0x003F4C44, 0x003C4A3F, 0x003C4A3F, 0x0038483D, 0x003C4C41, 0x003B4B40, 0x003F4643,
        0x003C4443, 0x003D4846, 0x003B4846, 0x00354342, 0x003B4B4A, 0x00314344, 0x00344647, 0x003A4941, 0x003B4A42, 0x0035443C, 0x0033443B, 0x00394A41, 0x00394A41, 0x00384B42, 0x003F5249, 0x00081C21, 0x00001E1F, 0x00366563, 0x009EDADA, 0x0077BDCA,
        0x001F7691, 0x002591BB, 0x000D8ABD, 0x002394BC, 0x001B84B0, 0x00248ABB, 0x00107EB2, 0x001892C8, 0x000E8DC4, 0x00118AC2, 0x001D8CC4, 0x0015678A, 0x00212D39, 0x00413D32, 0x00314130, 0x003A3E32, 0x003F3B29, 0x00393F2E, 0x003A3B37, 0x003E3E32,
        0x003B3B2F, 0x003E4034, 0x003B3D31, 0x0042463A, 0x0035392D, 0x00394033, 0x00333A2D, 0x003A3E33, 0x00363A2F, 0x00373B30, 0x00363A2F, 0x00373B30, 0x00393D32, 0x0034382D, 0x0034382D, 0x00363A2F, 0x00363A2F, 0x0035392E, 0x0034382D, 0x00363A2F,
        0x00393D32, 0x0032362B, 0x00373B30, 0x0035342A, 0x0039382E, 0x00333228, 0x0036372D, 0x0036372D, 0x00383C31, 0x00303429, 0x0034382D, 0x00373B30, 0x0034382D, 0x002F3328, 0x0032362B, 0x0032362B, 0x002F3328, 0x00303429, 0x00303429, 0x00313829,
        0x00343129, 0x00332F2A, 0x002D3328, 0x00343A29, 0x00313125, 0x00182A2B, 0x00103D4A, 0x00064454, 0x00074557, 0x00094759, 0x0008485A, 0x0008475B, 0x0005475A, 0x00034459, 0x00024358, 0x00034257, 0x00084258, 0x000E475C, 0x0006485A, 0x00004556,
        0x00458C9A, 0x00346B7A, 0x00466E80, 0x00499198, 0x003C868C, 0x00225460, 0x0050818F, 0x0051A6B0, 0x0047909E, 0x002B4E62, 0x003B556D, 0x003D5571, 0x003A516B, 0x003D677A, 0x00478D9A, 0x00004752, 0x00054655, 0x00094257, 0x00024358, 0x0003425E,
        0x0005404A, 0x000B5E84, 0x002FAEEB, 0x00045B87, 0x000A4860, 0x00006166, 0x003B7A71, 0x00242E2E, 0x00000200, 0x000A0C06, 0x001D1C12, 0x00262419, 0x002B2B1F, 0x002E2F25, 0x001C1F16, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFCFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00181D1B, 0x001D211C, 0x000D0805, 0x00080F08, 0x00101611, 0x00181A1A, 0x003A6967, 0x00217875, 0x0020676B, 0x00100E06, 0x00000200, 0x00000F0E, 0x0027454A, 0x00123F4A,
        0x000F4354, 0x000D465C, 0x000C4761, 0x00044252, 0x001B4950, 0x001C322D, 0x00000500, 0x00020500, 0x00132722, 0x001F4950, 0x00084051, 0x0008405B, 0x0008405B, 0x0008405B, 0x0008405B, 0x0009415C, 0x0009415C, 0x0009415C, 0x0009415C, 0x00044056,
        0x000C455E, 0x00063E57, 0x00124762, 0x00063B56, 0x00023654, 0x00184B6B, 0x00013454, 0x0000354A, 0x00042A36, 0x00041917, 0x00060D08, 0x00101615, 0x00010F1B, 0x0009203A, 0x00000E31, 0x00091B3A, 0x00000E29, 0x00001125, 0x00012330, 0x00012C35,
        0x0012434B, 0x00033944, 0x00003844, 0x0000444F, 0x00107895, 0x002AB1E7, 0x001CB8F9, 0x0021BCFB, 0x0024B1EA, 0x000988BF, 0x001087BF, 0x00258DC8, 0x002C8BBD, 0x001E6489, 0x00002038, 0x0003141D, 0x000D1A18, 0x000D1D12, 0x00081709, 0x00141414,
        0x0011171C, 0x00000D19, 0x002C4958, 0x00325D70, 0x00256070, 0x00367A87, 0x00246F78, 0x0070A0A2, 0x001F5359, 0x0004404C, 0x00024155, 0x00004156, 0x0006445C, 0x00044358, 0x00044357, 0x00014257, 0x00044358, 0x00053F55, 0x0000354A, 0x00002E43,
        0x00032D40, 0x00062D3C, 0x00042937, 0x003B4545, 0x00373F3F, 0x002F3736, 0x002A3231, 0x002C3330, 0x002C3330, 0x002D3230, 0x002C322D, 0x00313034, 0x00272A2E, 0x00273131, 0x00243231, 0x00293735, 0x00293432, 0x002F3433, 0x002A2B29, 0x002A302B,
        0x002C312F, 0x002D3230, 0x002B322F, 0x00292F2E, 0x00262E2D, 0x00262E2E, 0x00272F2F, 0x0025332F, 0x0024342D, 0x00263930, 0x001F3327, 0x00263A2E, 0x0024372E, 0x0025352E, 0x0024322E, 0x00323735, 0x002F3530, 0x00313530, 0x00293029, 0x00383F3A,
        0x002B3633, 0x002A3836, 0x00213130, 0x00383031, 0x00373231, 0x00363231, 0x00383733, 0x0031332D, 0x00313831, 0x00273026, 0x00273026, 0x002C3231, 0x002C3330, 0x00313732, 0x00303631, 0x00303631, 0x00262F2C, 0x002A3735, 0x00233130, 0x0037342C,
        0x0034322A, 0x0033342B, 0x0030342E, 0x00272E27, 0x00303B33, 0x0029352F, 0x00283630, 0x00293130, 0x002E3635, 0x002C3735, 0x002F3A38, 0x0035403E, 0x00303D3B, 0x00313E3C, 0x003D4A48, 0x0005272D, 0x0000272A, 0x00386A6A, 0x0088C5C7, 0x004A96A2,
        0x0016758F, 0x002292BD, 0x001490C6, 0x001581A3, 0x00076E95, 0x003197C7, 0x002393C8, 0x000D8CC3, 0x00098EC7, 0x001997D1, 0x001188C0, 0x000D5F82, 0x001E2A36, 0x003D392E, 0x002F3F2E, 0x00393D31, 0x00413D2B, 0x00373D2C, 0x00363733, 0x003E3F35,
        0x00424339, 0x003A3E33, 0x00373B30, 0x0040463B, 0x00353B30, 0x003E4439, 0x003A4237, 0x003D4136, 0x003D4136, 0x003C4035, 0x00393D32, 0x003B3F34, 0x003E4237, 0x00393D32, 0x0034382D, 0x003F4337, 0x003C4034, 0x00373B2F, 0x002F3327, 0x00363A2E,
        0x0034382C, 0x0032362A, 0x0034382C, 0x0038372D, 0x0038372D, 0x0037362C, 0x0033342A, 0x00393A30, 0x0034382D, 0x0035392E, 0x003B3F34, 0x00373D32, 0x00343A2F, 0x00343A2F, 0x00343A2F, 0x00363C31, 0x00373D32, 0x0031372C, 0x002E3429, 0x002D3425,
        0x0037342C, 0x0034302B, 0x00353B30, 0x00313726, 0x00323226, 0x00102223, 0x00093643, 0x00064454, 0x00074555, 0x00084658, 0x0008485A, 0x0008485A, 0x0005475A, 0x00044659, 0x00034558, 0x0006455A, 0x00064056, 0x00074055, 0x00024456, 0x00004455,
        0x00448B99, 0x00366D7C, 0x00487082, 0x0064ACB3, 0x0058A2A8, 0x00346672, 0x00528391, 0x004C9EA9, 0x003F8896, 0x00294A5E, 0x003D576F, 0x003D5571, 0x003A516B, 0x003C6679, 0x00468C99, 0x00004651, 0x00044554, 0x00094257, 0x00024358, 0x0003425E,
        0x0006414B, 0x000A5D83, 0x002FAEEB, 0x00055C88, 0x0009475F, 0x00006065, 0x003E7D74, 0x00242E2E, 0x00000200, 0x000E100A, 0x001F1E14, 0x00242217, 0x0029291D, 0x002A2B21, 0x00181B12, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFCFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00181D1B, 0x001F231E, 0x000E0906, 0x00091009, 0x00111712, 0x00181A1A, 0x00396866, 0x001F7673, 0x001D6468, 0x00152D21, 0x0000170E, 0x00022723, 0x00255557, 0x00104450,
        0x00094154, 0x00043C55, 0x00013954, 0x00004654, 0x0010474E, 0x001B3D36, 0x000F2213, 0x00051809, 0x0011322B, 0x0014484F, 0x00024554, 0x0008405B, 0x0008405B, 0x0008405B, 0x0008405B, 0x0009415C, 0x0009415C, 0x0009415C, 0x0009415C, 0x0009415A,
        0x000B435C, 0x0009415A, 0x000B425D, 0x00124762, 0x0011435F, 0x000E3D59, 0x000D3C58, 0x0007394F, 0x000C3746, 0x0005272D, 0x00042125, 0x00082C34, 0x0000314A, 0x00186494, 0x000B65A5, 0x000F69A4, 0x001B78AF, 0x000F70A2, 0x00187EA9, 0x00137CA5,
        0x000C759C, 0x00137AA1, 0x001B82A9, 0x001588B5, 0x002DB0E9, 0x0026B6FD, 0x002DBCFF, 0x00259FD3, 0x00005B7C, 0x00004258, 0x00064155, 0x00003D50, 0x00023849, 0x00012C3B, 0x0000262F, 0x000F3137, 0x0007252A, 0x00022025, 0x00001D21, 0x00001122,
        0x00031B2F, 0x0004233C, 0x001B4A66, 0x00266482, 0x00226F8F, 0x00106A89, 0x00187A98, 0x0056919B, 0x00235D69, 0x00084353, 0x000D4A5E, 0x0007485D, 0x0004475C, 0x00044659, 0x000C495D, 0x00003F57, 0x0006455A, 0x0009465A, 0x00074154, 0x00063B4F,
        0x00053749, 0x00013143, 0x00002A3C, 0x00273B40, 0x00203439, 0x001A2D32, 0x0016292C, 0x0018292C, 0x00192B2C, 0x00192B2C, 0x001B2A2C, 0x00182C31, 0x00132C30, 0x00102F32, 0x00002424, 0x00042828, 0x00062625, 0x00142E2E, 0x00182D2E, 0x00172928,
        0x00162827, 0x00152726, 0x00142829, 0x0015292A, 0x00152A2C, 0x0014292B, 0x0013282A, 0x00112F30, 0x000F2C29, 0x00132D27, 0x00051E14, 0x00162F25, 0x00142E28, 0x000F2C29, 0x001A3839, 0x001B3136, 0x000C2122, 0x00233633, 0x001D2E2A, 0x00132623,
        0x000B2021, 0x00132E32, 0x00153239, 0x000F2433, 0x001C323E, 0x0010262C, 0x000F2628, 0x00152C28, 0x00142C22, 0x00182F21, 0x001A3220, 0x0014272E, 0x0014272A, 0x001B2B2A, 0x00182926, 0x00172928, 0x000B2224, 0x00153138, 0x000C2A35, 0x00102C2C,
        0x00112D2D, 0x00143030, 0x0013302D, 0x000D2C29, 0x0013322F, 0x0012322D, 0x00072722, 0x0014292A, 0x00162B2C, 0x0014292A, 0x00132B2B, 0x00162E2E, 0x00163030, 0x001E3838, 0x002F4949, 0x0006343C, 0x0006353D, 0x000B4247, 0x00135861, 0x00005565,
        0x00167E9B, 0x001E91BC, 0x001991C5, 0x001D819D, 0x00004667, 0x000E6B92, 0x00258EBA, 0x00219ACB, 0x00098DC2, 0x001091C8, 0x00138EC8, 0x000A5C7F, 0x00232F3B, 0x00413D32, 0x0030402F, 0x003A3E32, 0x00484432, 0x003A402F, 0x00373834, 0x0041453A,
        0x00484C41, 0x003F453A, 0x003D4338, 0x00464E43, 0x0040483D, 0x00495146, 0x00495347, 0x0043493E, 0x00454B40, 0x0042483D, 0x0040463B, 0x0042483D, 0x00464C41, 0x00464C41, 0x003F453A, 0x00414539, 0x003D4135, 0x0035392D, 0x002F3327, 0x00363A2E,
        0x0033372B, 0x0035392D, 0x0035392D, 0x0039382E, 0x003A392F, 0x003B3A30, 0x0034352B, 0x00393A30, 0x0032362B, 0x003B3F34, 0x00464A3F, 0x003F453A, 0x003C4237, 0x003F453A, 0x00383E33, 0x003B4136, 0x0043493E, 0x00373D32, 0x0030362B, 0x002C3324,
        0x0037342C, 0x00312D28, 0x0032382D, 0x002D3322, 0x00353529, 0x0017292A, 0x0013404D, 0x00074555, 0x00074555, 0x00084656, 0x00074759, 0x00074759, 0x00054759, 0x0005475A, 0x00044659, 0x0007465B, 0x000A445A, 0x000C455A, 0x00054759, 0x00003F50,
        0x003F8694, 0x003D7483, 0x00537B8D, 0x004C9299, 0x004C949B, 0x0032626E, 0x0050818F, 0x004B9DA8, 0x00408795, 0x00294A5E, 0x00415971, 0x003D5571, 0x0039506A, 0x003C6679, 0x00468C99, 0x00004651, 0x00044554, 0x00094257, 0x00014257, 0x0002415D,
        0x0006414B, 0x00095C82, 0x002EADEA, 0x00055C88, 0x0008465E, 0x00005F64, 0x00407F76, 0x00242E2E, 0x00000200, 0x000F110B, 0x00222117, 0x00242217, 0x0027271B, 0x0028291F, 0x00181B12, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFBFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00191E1C, 0x001A1E19, 0x000E0906, 0x000B120B, 0x00131914, 0x001B1D1D, 0x00366563, 0x00156C69, 0x0011585C, 0x00376965, 0x001E5350, 0x00114A4B, 0x00104B54, 0x00003C4A,
        0x00054054, 0x000D445F, 0x000C405E, 0x00004256, 0x00084551, 0x00225454, 0x00365F58, 0x00325B54, 0x001D4D4E, 0x000B4551, 0x00004257, 0x0008405B, 0x0008405B, 0x0008405B, 0x0008405B, 0x0009415C, 0x0009415C, 0x0009415C, 0x0009415C, 0x00103E5D,
        0x000D3F5B, 0x0009425B, 0x00003D52, 0x0002475A, 0x00044C5D, 0x00003E4F, 0x00004654, 0x00003D4D, 0x00074251, 0x000B434E, 0x00073E45, 0x0000353F, 0x0000465F, 0x001E8DBF, 0x0033B6F9, 0x001EB4FB, 0x001EB7FC, 0x0020BCFE, 0x0022BEFF, 0x001EBBFA,
        0x0027C0FD, 0x0028BCF8, 0x0025B7F1, 0x002FB6FF, 0x0021AAFF, 0x002DB1FF, 0x0033A2E8, 0x000E5F8C, 0x0002344B, 0x001E3D4C, 0x002C4352, 0x00004C4F, 0x00053E47, 0x000D3D49, 0x001B5665, 0x00296779, 0x00113F57, 0x000C334F, 0x0006324F, 0x00053B46,
        0x00083C49, 0x00043849, 0x00093E53, 0x00003851, 0x0000324E, 0x00004261, 0x00004260, 0x00094E5F, 0x00125062, 0x00033D50, 0x00094759, 0x00004356, 0x00004255, 0x00024457, 0x000D485C, 0x00084860, 0x00044659, 0x00014251, 0x0001404E, 0x0004414F,
        0x00074252, 0x00053D50, 0x0002374C, 0x0012434D, 0x00103F47, 0x000C3B43, 0x000A3941, 0x000B3940, 0x000C3A41, 0x000E3B3F, 0x000D3A3E, 0x00083B3E, 0x00205558, 0x00377072, 0x002C6566, 0x00265F60, 0x00074140, 0x00063C3C, 0x000E4242, 0x000D3E3C,
        0x000F403E, 0x00104041, 0x000D3F3F, 0x000A3B3D, 0x00073A3C, 0x00093C3E, 0x000C3F42, 0x0005373D, 0x00275354, 0x00517470, 0x0047635D, 0x0044605A, 0x001C3F3B, 0x00123E3F, 0x003F7177, 0x004F8D97, 0x000A4449, 0x00083C3C, 0x00194845, 0x000D3C3A,
        0x000D3D41, 0x00356A74, 0x00578E9D, 0x0010667C, 0x001A6D82, 0x000B5769, 0x00003A47, 0x00003B44, 0x00003336, 0x000C3839, 0x00123A39, 0x00093B47, 0x00083941, 0x000F3C3F, 0x000E3A3B, 0x000E3E40, 0x00053A44, 0x001E5A6A, 0x0017586D, 0x000C5F75,
        0x0014647B, 0x001B687B, 0x00165E6F, 0x00195F6C, 0x0015565F, 0x001B595F, 0x0000373D, 0x000A3C3C, 0x00093B3B, 0x000A3C3C, 0x00083C3C, 0x00073B3B, 0x00063C3C, 0x000B4141, 0x00104646, 0x00093D49, 0x000F4350, 0x00003848, 0x00004359, 0x000B6C88,
        0x002796BC, 0x001C8EBD, 0x002696CA, 0x002E88A0, 0x00004861, 0x00004A63, 0x00166E8C, 0x0035A1C3, 0x001D96C0, 0x00108CC2, 0x001690CC, 0x00095B7E, 0x0025313D, 0x003F3B30, 0x002C3C2B, 0x0034382C, 0x0045412F, 0x00373D2C, 0x00353632, 0x00383E33,
        0x0041473C, 0x003F473C, 0x003F473C, 0x00474F44, 0x00444E42, 0x00475145, 0x00485246, 0x003C4439, 0x003F473C, 0x003B4338, 0x003C4439, 0x0040483D, 0x00434B40, 0x00474F44, 0x0041493E, 0x00383D2E, 0x003A3F30, 0x002F3425, 0x00303526, 0x0034392A,
        0x0034392A, 0x00333829, 0x0034392A, 0x0036352B, 0x0038372D, 0x0038372D, 0x0034352B, 0x0035362C, 0x00303429, 0x003A3E33, 0x004A4E43, 0x00454D42, 0x003E463B, 0x00424A3F, 0x00343C31, 0x00353D32, 0x00424A3F, 0x00323A2F, 0x002D352A, 0x00313829,
        0x003A372F, 0x0034302B, 0x002F352A, 0x002C3221, 0x00313125, 0x00152728, 0x000E3B48, 0x00074654, 0x00074654, 0x00084656, 0x00074857, 0x0008485A, 0x0006485A, 0x0006485A, 0x0006485B, 0x0008475C, 0x000D475D, 0x000E475C, 0x000A4C5E, 0x00004253,
        0x003E8593, 0x00336A79, 0x003C6476, 0x001A6067, 0x00287077, 0x001E4E5A, 0x004B7A88, 0x0050A0AB, 0x00478E9C, 0x002D4C61, 0x00415971, 0x003D5571, 0x0039506A, 0x003D677A, 0x00468C99, 0x00004651, 0x00044554, 0x00094257, 0x00014257, 0x0002415D,
        0x0006414B, 0x00095C82, 0x002EADEA, 0x00065D89, 0x0007455D, 0x00005E63, 0x00438279, 0x002B3535, 0x00000200, 0x000C0E08, 0x00222117, 0x00242217, 0x0028281C, 0x0028291F, 0x001B1E15, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFEFF, 0xFFFDFCFE, 0xFFFBFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00191E1C, 0x00151914, 0x000E0906, 0x000A110A, 0x00111712, 0x001C1E1E, 0x0032615F, 0x000A615E, 0x00074E52, 0x00165056, 0x000F4A53, 0x000B4854, 0x00004150, 0x00014054,
        0x00044058, 0x000D4361, 0x00083B5B, 0x0006435D, 0x00043F53, 0x00043E4A, 0x000E454C, 0x0012484F, 0x000A3F4C, 0x00063D52, 0x000E4560, 0x0008405B, 0x0008405B, 0x0008405B, 0x0008405B, 0x0009415C, 0x0009415C, 0x0009415C, 0x0009415C, 0x00113E5F,
        0x00114361, 0x00124B64, 0x00064559, 0x00014453, 0x000A4D56, 0x000D4D52, 0x000B484C, 0x000F4C56, 0x0000333F, 0x0008424E, 0x001A5156, 0x001E5455, 0x00236872, 0x000E6988, 0x000E7BAE, 0x002EBAFD, 0x0026B5F9, 0x0026BBFE, 0x001EB7FA, 0x001BB7F9,
        0x0023BDFE, 0x0022B7F7, 0x0028BBF9, 0x0018B3F8, 0x002EC3FF, 0x002BADE9, 0x00005883, 0x00003A51, 0x000A4C57, 0x00003F4D, 0x00004559, 0x00004A5B, 0x0000394E, 0x00053950, 0x00125E74, 0x001A6D83, 0x00024058, 0x00093A54, 0x00093F56, 0x00003E49,
        0x00013E4A, 0x00063F4E, 0x0009404F, 0x000D4256, 0x00114C60, 0x004E8EA6, 0x002E718A, 0x00327E94, 0x0044879E, 0x0010495E, 0x00074255, 0x00004455, 0x00004656, 0x00004457, 0x00043D52, 0x0006485B, 0x00024456, 0x0000444E, 0x0003474E, 0x00064A51,
        0x00074752, 0x00034153, 0x00013E52, 0x00024050, 0x00033F4F, 0x0003404E, 0x0003404E, 0x0004404C, 0x0004404C, 0x00053F4B, 0x0005404A, 0x000B454B, 0x003A7178, 0x00689EA5, 0x00679BA1, 0x00598D93, 0x00164D50, 0x0000383A, 0x000A4547, 0x000B4B4B,
        0x00064646, 0x00004140, 0x00003F40, 0x00004243, 0x00004346, 0x00004144, 0x00003E41, 0x00003C46, 0x001D575D, 0x00588183, 0x0064817E, 0x006C8986, 0x00295254, 0x000D474D, 0x004C939D, 0x005FB7C7, 0x00287A85, 0x00003C40, 0x00074747, 0x000E494B,
        0x0006414A, 0x001D5B6D, 0x00387890, 0x003C8D9C, 0x00368494, 0x00347F8D, 0x00004553, 0x00014251, 0x00003C4C, 0x00053E4D, 0x0007404F, 0x00004154, 0x00003E4E, 0x0008434C, 0x00064046, 0x0009474F, 0x00024758, 0x0024718B, 0x00217392, 0x000A7198,
        0x001C7DA1, 0x002883A2, 0x00247590, 0x003F869A, 0x00387785, 0x00558C95, 0x00255960, 0x000B484A, 0x00003E3F, 0x00003B3C, 0x00003C3D, 0x00003E3F, 0x00064748, 0x00094C4D, 0x00024546, 0x000B414C, 0x00083E4F, 0x00054460, 0x001C6E91, 0x002791BA,
        0x002297C4, 0x001F90C2, 0x00248ABE, 0x00004D5E, 0x001D6271, 0x00276470, 0x00024855, 0x00177386, 0x002594B4, 0x00259CCD, 0x000F87C3, 0x00095B7E, 0x0025313D, 0x003F3B30, 0x0030402F, 0x00363A2E, 0x0045412F, 0x00353B2A, 0x003A3B37, 0x00353D33,
        0x003B4339, 0x0041493F, 0x003E473D, 0x0040493F, 0x003F4A40, 0x003B463C, 0x003C473D, 0x00384236, 0x003C463A, 0x00384236, 0x003B4539, 0x003E483C, 0x003D473B, 0x00434D41, 0x003F493D, 0x00424738, 0x00464B3C, 0x00313627, 0x00373C2D, 0x002F3425,
        0x00333829, 0x002E3324, 0x00313627, 0x0038372D, 0x003A392F, 0x0035342A, 0x0038392F, 0x0035362C, 0x0035392E, 0x00383C31, 0x00494D42, 0x00464E43, 0x003B4338, 0x00444C41, 0x00363E33, 0x00373F34, 0x00424A3F, 0x002E362B, 0x002E362B, 0x002E3526,
        0x0037342C, 0x0037332E, 0x002E3429, 0x00323827, 0x00323226, 0x00182A2B, 0x000C3946, 0x00064553, 0x00074654, 0x00094856, 0x00094A59, 0x000A4B5A, 0x0007495B, 0x0006485A, 0x00054759, 0x0009485D, 0x00094359, 0x00043D52, 0x00004254, 0x00003F50,
        0x00408795, 0x00356C7B, 0x00335B6D, 0x006BAFB6, 0x0064ACB3, 0x003E6B78, 0x00507F8D, 0x004B9BA6, 0x00438897, 0x002B4A5F, 0x00415770, 0x003C5470, 0x0039506A, 0x003D677A, 0x00488E9B, 0x00004853, 0x00054655, 0x00094257, 0x00004156, 0x0001405C,
        0x0006414B, 0x00085B81, 0x002DACE9, 0x00075E8A, 0x0007455D, 0x00005D62, 0x0044837A, 0x00404A4A, 0x00000200, 0x00080A04, 0x001E1D13, 0x00242217, 0x002A2A1E, 0x0028291F, 0x001D2017, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFEFF, 0xFFFDFCFE, 0xFFFBFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00191E1C, 0x00141813, 0x000F0A07, 0x00070E07, 0x000D130E, 0x00191B1B, 0x002E5D5B, 0x00045B58, 0x00044B4F, 0x000D4152, 0x00093E52, 0x000B4459, 0x00023E54, 0x000C4963,
        0x00023C59, 0x00063D5C, 0x00053B5A, 0x000B3A5A, 0x000C415C, 0x00063F55, 0x00023D50, 0x00094457, 0x000E445B, 0x000E3E5A, 0x00123D5E, 0x0008405B, 0x0008405B, 0x0008405B, 0x0008405B, 0x0009415C, 0x0009415C, 0x0009415C, 0x0009415C, 0x00083E5F,
        0x00083F5E, 0x00074059, 0x00073F52, 0x0012414F, 0x00466A72, 0x0081999F, 0x008B9C9F, 0x007EAFB9, 0x002B5A68, 0x00315B68, 0x00628085, 0x0094ABA7, 0x00A8C4C4, 0x00376374, 0x00003959, 0x000868A4, 0x002A8FCD, 0x002997D7, 0x002096D7, 0x001E9ADA,
        0x001591D1, 0x001994D2, 0x0028A2DE, 0x0037ADD6, 0x002C97BD, 0x00085E7C, 0x00044252, 0x00154547, 0x00134649, 0x0003495A, 0x00003E5E, 0x0000405D, 0x00163C5E, 0x00234C6C, 0x00307C92, 0x002D8B98, 0x000A555E, 0x0009484C, 0x00004544, 0x000A4359,
        0x0002384F, 0x000D4459, 0x00063F54, 0x00054458, 0x00003E54, 0x0035889E, 0x000D6780, 0x0014667F, 0x003B7E97, 0x00053E54, 0x00054053, 0x0003495A, 0x00004757, 0x00034859, 0x000C455A, 0x00004053, 0x00094D5A, 0x001A5F68, 0x00286F73, 0x00256C70,
        0x00145962, 0x00044756, 0x00003F52, 0x00023B50, 0x00033C51, 0x00073E53, 0x00084053, 0x00084053, 0x00093F50, 0x00083E4F, 0x00073D4E, 0x0013404B, 0x002C5460, 0x0040626F, 0x00395560, 0x003B5762, 0x0012363E, 0x00275158, 0x005C8A91, 0x00357274,
        0x001E5B5D, 0x000D4A4C, 0x0019585C, 0x0039787C, 0x0049898E, 0x003D7D82, 0x0029696E, 0x00146776, 0x00004049, 0x00063336, 0x00203C3C, 0x005E7A7A, 0x00356265, 0x00165962, 0x0058ABBA, 0x00076277, 0x0058AABB, 0x00357D85, 0x002A676B, 0x00235960,
        0x00093D4D, 0x00073D56, 0x00144B6A, 0x007C9290, 0x00637D7D, 0x00708F92, 0x001E454D, 0x0012404B, 0x000B4251, 0x00023D50, 0x00003E52, 0x00003F58, 0x00033E52, 0x000C4352, 0x000A3E4A, 0x00094251, 0x00004055, 0x00236C8C, 0x001D6C93, 0x00197098,
        0x002B7CA1, 0x00337A9B, 0x002B647D, 0x004D798A, 0x0042636C, 0x006B8284, 0x00324443, 0x00084045, 0x0010484D, 0x0031696E, 0x004E888D, 0x00579196, 0x00518E92, 0x00367377, 0x000D4A4E, 0x00114752, 0x00063D52, 0x0019597B, 0x00388FBB, 0x002291C3,
        0x00118ABC, 0x002190C2, 0x00005486, 0x002B7686, 0x0072AFB9, 0x008EC3C6, 0x004C8888, 0x0022737B, 0x000F768F, 0x002093C0, 0x00188DCA, 0x00005275, 0x001B2733, 0x00373328, 0x0030402F, 0x00363A2E, 0x00403C2A, 0x002E3423, 0x00373834, 0x003D453B,
        0x003D453B, 0x00454E44, 0x003D463C, 0x00374238, 0x003B463C, 0x00333E34, 0x00324035, 0x003D473B, 0x00414B3F, 0x003C463A, 0x00414B3F, 0x00404A3E, 0x003B4539, 0x00414B3F, 0x003D473B, 0x00454A3B, 0x004B5041, 0x002F3425, 0x00383D2E, 0x002B3021,
        0x00363B2C, 0x00333829, 0x003A3F30, 0x003A392F, 0x003B3A30, 0x00323127, 0x003B3C32, 0x0037382E, 0x00393D32, 0x00363A2F, 0x0045493E, 0x0040483D, 0x00333B30, 0x0041493E, 0x003B4338, 0x003D453A, 0x00424A3F, 0x002B3328, 0x002F372C, 0x002F3627,
        0x00343129, 0x0035312C, 0x00282E23, 0x00313726, 0x00303024, 0x001A2C2D, 0x000D3A47, 0x00054452, 0x00074654, 0x000B4A58, 0x000B4C5B, 0x000C4D5C, 0x00094C5B, 0x0006485A, 0x00044658, 0x0006455A, 0x000D475D, 0x000C455A, 0x00054759, 0x00003E4F,
        0x003E8593, 0x00376E7D, 0x00375F71, 0x0065A9B0, 0x005BA3AA, 0x00315E6B, 0x00437280, 0x004696A1, 0x00448998, 0x002B4A5F, 0x0040566F, 0x003C5470, 0x0039506A, 0x003E687B, 0x00498F9C, 0x00004954, 0x00054655, 0x00094257, 0x00004156, 0x0001405C,
        0x0006414B, 0x00085B81, 0x002DACE9, 0x00075E8A, 0x0006445C, 0x00005D62, 0x0045847B, 0x00535D5D, 0x00000502, 0x00050701, 0x001B1A10, 0x00232116, 0x002A2A1E, 0x0026271D, 0x001B1E15, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFDFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00181D1B, 0x00101611, 0x00010D07, 0x00080C06, 0x001F1613, 0x000F1413, 0x002D5554, 0x00125256, 0x00084C53, 0x000D4556, 0x00094356, 0x00034054, 0x00003F54, 0x0003435B,
        0x00014257, 0x00003F52, 0x00064658, 0x00073F5A, 0x000B4660, 0x0009445E, 0x0008445C, 0x00074359, 0x00003F54, 0x00014054, 0x0009485C, 0x00044358, 0x0008445A, 0x00053E57, 0x00084059, 0x000D4560, 0x0008435D, 0x00033F5C, 0x0002415D, 0x000C4156,
        0x000B425D, 0x000B4162, 0x00063A5E, 0x00133D5A, 0x00355562, 0x0096A9A6, 0x00A8B3A3, 0x008DA599, 0x0055838E, 0x00487C8D, 0x0077908C, 0x009C9D89, 0x008E968B, 0x002A5055, 0x00003B47, 0x0004414D, 0x00004155, 0x000F6180, 0x00116686, 0x00003853,
        0x000C3E4A, 0x0089A29E, 0x00DEE8DB, 0x00D6E4D9, 0x00CBE0CA, 0x002E7075, 0x00004F6C, 0x001C7883, 0x00055052, 0x00054759, 0x000F475A, 0x0000395C, 0x00174452, 0x00B0C7C9, 0x00D7EAED, 0x00D6E8E9, 0x00CBE0DD, 0x00325A5F, 0x00003D55, 0x0000414B,
        0x000B4959, 0x00094257, 0x00073E59, 0x00074060, 0x00003B5E, 0x00257398, 0x00004E72, 0x00155574, 0x00236A7E, 0x00004956, 0x00004757, 0x0000465F, 0x00044B66, 0x00034250, 0x001C5556, 0x00105A66, 0x0021555B, 0x00BFD4D2, 0x00E8E8E2, 0x00EBEAE6,
        0x00B1C7CC, 0x000A4150, 0x0000475E, 0x00054054, 0x00054054, 0x00064155, 0x00064155, 0x00054054, 0x00054054, 0x00043F53, 0x00043F53, 0x0006444A, 0x000B444D, 0x0000343F, 0x0000313B, 0x00003E43, 0x00074244, 0x002C5453, 0x009BB1AF, 0x0096958B,
        0x006F918B, 0x00518B86, 0x006E998C, 0x00909E8C, 0x009DB4B0, 0x007BCEEA, 0x0027B2EA, 0x0045B6D7, 0x002A7EA1, 0x00003251, 0x000C4155, 0x0032737B, 0x00115953, 0x001D554A, 0x0075998D, 0x003C5557, 0x0091ACB0, 0x0067888B, 0x00678D91, 0x00235256,
        0x000F4349, 0x00074147, 0x0008434C, 0x000E394A, 0x000F3A4B, 0x000D3B4C, 0x000C3D4D, 0x000B3F4F, 0x000A4150, 0x00094251, 0x00084352, 0x00084352, 0x00034054, 0x00064258, 0x00084053, 0x000D424F, 0x00024050, 0x00237090, 0x000F6D98, 0x001A6F9D,
        0x001F77A0, 0x002D84A4, 0x00045067, 0x00003141, 0x00083F46, 0x00478787, 0x000B554F, 0x0005424C, 0x00004041, 0x007F9593, 0x00FFFDF9, 0x00FFFFF9, 0x00FFFFFB, 0x00A5B1B5, 0x00073E41, 0x00093B47, 0x00003E51, 0x000A5F7F, 0x003095BC, 0x002C93BA,
        0x00308DAC, 0x000E5E6F, 0x0000454E, 0x00C6D7C9, 0x00FAFFF0, 0x00F6F3E4, 0x00F8FFF8, 0x0074A09F, 0x00003C4B, 0x000A7596, 0x001B90BD, 0x00196795, 0x00103444, 0x003A3830, 0x00443B31, 0x003A3A2E, 0x00383925, 0x003B3C2C, 0x00343A35, 0x0038392F,
        0x0036372D, 0x003A3B31, 0x00393A30, 0x0036372D, 0x0037382E, 0x0037382E, 0x00393A30, 0x00363A2F, 0x00383C31, 0x0035362C, 0x0037382E, 0x0037382E, 0x0036352B, 0x003A392F, 0x0037362C, 0x0035362C, 0x00313228, 0x0034352B, 0x0035362C, 0x0033342A,
        0x0036372D, 0x003A3B31, 0x0035362C, 0x002F3328, 0x0034382D, 0x0034382D, 0x00353B30, 0x002F352A, 0x002C3429, 0x002E362B, 0x00373F34, 0x00333B30, 0x0030382D, 0x0030382D, 0x00343A2F, 0x00343A2F, 0x00363A2F, 0x00363A2F, 0x0035392E, 0x00373A2A,
        0x0032362B, 0x0030332A, 0x00323025, 0x00353525, 0x00243024, 0x000A2C2C, 0x000B3F4C, 0x00104952, 0x0000414A, 0x00054F5B, 0x00004C5C, 0x00004A5A, 0x00094F60, 0x00074255, 0x000E4455, 0x00194C60, 0x00084053, 0x0006485A, 0x00004554, 0x0000404E,
        0x003B8696, 0x003C697E, 0x0041556E, 0x003E5771, 0x002D5169, 0x0013485D, 0x003E7D91, 0x005C9BAF, 0x004F8499, 0x00294D65, 0x003B546E, 0x003D5474, 0x0035526D, 0x00376076, 0x00538B9C, 0x00004652, 0x00004B58, 0x00003F51, 0x00004559, 0x00114250,
        0x0000395B, 0x000065A0, 0x0035ACEA, 0x00055A8C, 0x000E3D58, 0x001C5C5D, 0x001E8979, 0x004A4E4F, 0x00010604, 0x00080C06, 0x001B1F14, 0x001D2115, 0x0024261A, 0x002D2C22, 0x00201E16, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFEFDFF, 0xFFFEFDFF, 0xFFFDFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00181D1B, 0x0010110D, 0x00000802, 0x00090D07, 0x00211A17, 0x00212726, 0x003F6968, 0x000F5253, 0x0000464A, 0x000F3E53, 0x000F4056, 0x000C4057, 0x00084059, 0x000B435E,
        0x0006415B, 0x00003D55, 0x00034159, 0x00043D56, 0x00043D56, 0x0000364F, 0x00033B54, 0x000D435C, 0x000E445D, 0x000E415B, 0x00073A54, 0x000F3F5B, 0x0011415D, 0x000C3C58, 0x000B3D59, 0x000D425D, 0x0009405B, 0x0009445E, 0x0006435D, 0x000D4158,
        0x000A415C, 0x00053E5E, 0x00073C5D, 0x00123E56, 0x001D3842, 0x0066706A, 0x007D7D6D, 0x00354F42, 0x000F3D48, 0x00093748, 0x003D514C, 0x00857F6C, 0x00565C51, 0x00183E42, 0x0003404A, 0x00033F4F, 0x00003E53, 0x001B627D, 0x0029728E, 0x00003F54,
        0x000E434D, 0x00719896, 0x00B7D3C6, 0x00B2D1D4, 0x00B2D1C8, 0x007DBFD2, 0x0067C5F0, 0x0065B5CC, 0x00276674, 0x0001415A, 0x00033B54, 0x0000475E, 0x001A4D50, 0x0095ABA6, 0x00BBC9C5, 0x00C4D0CA, 0x00B4CABE, 0x00285A56, 0x0000414F, 0x001B475F,
        0x00093B52, 0x00054054, 0x00074759, 0x00033F4B, 0x0014484F, 0x0082A8AC, 0x005E7D80, 0x004D798A, 0x0082B9C2, 0x0005474C, 0x00004755, 0x00003D58, 0x0000425F, 0x00033F55, 0x004A8692, 0x0071B1B6, 0x00598B8B, 0x00A8C8BD, 0x00B6C9B8, 0x00BFD2C3,
        0x008DAFA9, 0x00134950, 0x00004251, 0x00054054, 0x00054054, 0x00064155, 0x00064155, 0x00064155, 0x00054054, 0x00043F53, 0x00043F53, 0x00013C4F, 0x00073C51, 0x000A3F54, 0x00053E53, 0x00003D4D, 0x000A454F, 0x00285259, 0x0071898F, 0x00838D8D,
        0x0089A9AE, 0x00619094, 0x0086A9A5, 0x00849489, 0x00698585, 0x007FC8E6, 0x0034A9E0, 0x004BB3D6, 0x003B89AD, 0x000C3F5F, 0x000A3B51, 0x000A454F, 0x00003D3D, 0x002E5C56, 0x004F6B65, 0x002F4A46, 0x00789592, 0x00274B4B, 0x00204A4F, 0x000D3E46,
        0x000D4451, 0x00033F4F, 0x00004052, 0x000D3B4C, 0x000D3B4C, 0x000C3D4D, 0x000A3E4E, 0x0009404F, 0x00064150, 0x00064351, 0x00074452, 0x00074251, 0x00023F53, 0x00054157, 0x00084053, 0x000D424F, 0x00034151, 0x00227291, 0x0012709B, 0x00126D9A,
        0x001C79A0, 0x00328BA6, 0x00004759, 0x0009414C, 0x0043777D, 0x00629FA1, 0x00054D4D, 0x00094555, 0x0000363F, 0x00909CA2, 0x00E9D9DA, 0x00B7B7B1, 0x00AFB4B2, 0x00889194, 0x00396062, 0x00505D6B, 0x0041596D, 0x003D6480, 0x004B80A1, 0x00457B9C,
        0x0051829C, 0x00456B7D, 0x0048646F, 0x0091A6A4, 0x00C0C7C4, 0x00B9B3AE, 0x00C2BFBA, 0x00708583, 0x00073540, 0x000C4A62, 0x00286D8E, 0x001C6388, 0x0015363F, 0x003B392E, 0x003E382D, 0x0038392F, 0x00393B28, 0x003A3C29, 0x00323630, 0x00363A2F,
        0x00393D32, 0x00373B30, 0x00383C31, 0x00393D32, 0x00383C31, 0x00393D32, 0x003A3E33, 0x003A4035, 0x003C4237, 0x00373D32, 0x00393D32, 0x00383C31, 0x0036372D, 0x003A3B31, 0x0038392F, 0x003B3F34, 0x0035392E, 0x0035392E, 0x00373B30, 0x0034382D,
        0x00363A2F, 0x00373B30, 0x0034382D, 0x00373B30, 0x0031352A, 0x0032362B, 0x0032382D, 0x00363C31, 0x00323A2F, 0x00343C31, 0x00333B30, 0x00323A2F, 0x00333B30, 0x0031392E, 0x0031372C, 0x0033392E, 0x0034382D, 0x0031352A, 0x00303429, 0x00373A2A,
        0x0032362B, 0x0030332A, 0x00333126, 0x00363626, 0x00243024, 0x000B2D2D, 0x000C404D, 0x00094652, 0x00114E5C, 0x00054353, 0x00054557, 0x00115064, 0x0006485B, 0x00014355, 0x000B5061, 0x00003C4F, 0x0019566A, 0x00074256, 0x00044456, 0x00054A5B,
        0x00397A89, 0x003C6C7E, 0x002B4A5F, 0x00385068, 0x0034546B, 0x00224F64, 0x0044778B, 0x0056899D, 0x004E7B90, 0x00305067, 0x003C546C, 0x003C4B6C, 0x00385671, 0x002D5F71, 0x00488893, 0x0000444E, 0x00044252, 0x000A4359, 0x000E435E, 0x00003E54,
        0x00016588, 0x002AA0D3, 0x002B95CA, 0x00004A71, 0x000A4E61, 0x000C5857, 0x00358E85, 0x00383C3D, 0x00000100, 0x00050903, 0x001B1F14, 0x00202418, 0x0026281C, 0x002B2A20, 0x001E1C14, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFDFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00181D1B, 0x00161211, 0x00020904, 0x000C100B, 0x0015100D, 0x00182320, 0x003C6B68, 0x0008514F, 0x00044E50, 0x00144058, 0x0014415C, 0x000E3D58, 0x000B3B57, 0x000C3E5C,
        0x00083E5C, 0x00073E5D, 0x00083F5E, 0x00094258, 0x000F4760, 0x000D435C, 0x000E415B, 0x000A3C58, 0x000B3B57, 0x00154362, 0x00134160, 0x00103D5E, 0x00113F5E, 0x000E3D5C, 0x000F415F, 0x000D425D, 0x00063B56, 0x0009405B, 0x00043C55, 0x000C3D57,
        0x00093F5D, 0x00033F5D, 0x0009415E, 0x00174257, 0x00172D33, 0x0054524A, 0x007A6A59, 0x000E2C21, 0x0007353D, 0x00002A37, 0x002B3731, 0x00867C6A, 0x00353A31, 0x0013393D, 0x00034149, 0x0009425B, 0x00074056, 0x002C6378, 0x0042798E, 0x00003A4A,
        0x00033E47, 0x00599291, 0x009CD1C8, 0x0086C4C4, 0x006A9C92, 0x0034798C, 0x00186E98, 0x002B6F82, 0x00215B61, 0x00003D4C, 0x00044554, 0x00004053, 0x00194A48, 0x0072998A, 0x00A1C9BD, 0x00A3CCBD, 0x007EA694, 0x001A4F46, 0x00004350, 0x000E3B5C,
        0x000D4060, 0x0004405D, 0x00004259, 0x00024050, 0x000E4249, 0x0099BFBF, 0x0099B7B2, 0x00A0C0BF, 0x009BC6C3, 0x000B4443, 0x0003414B, 0x00104E66, 0x00064260, 0x00023E5B, 0x00145368, 0x00255D62, 0x001E544F, 0x0072A694, 0x009BCEB3, 0x00A5D7BF,
        0x005D9284, 0x00124849, 0x00083E49, 0x00064155, 0x00064155, 0x00064155, 0x00064155, 0x00064155, 0x00054054, 0x00054054, 0x00043F53, 0x00043D5C, 0x00073A5A, 0x000E3F5F, 0x0008405D, 0x00003C54, 0x00043F52, 0x001B4855, 0x004F6F7A, 0x006B888F,
        0x00507180, 0x00446574, 0x00556F75, 0x00485F5B, 0x003B6163, 0x004789A2, 0x002E86B5, 0x0041A2C4, 0x00095677, 0x00033958, 0x00114159, 0x000B4251, 0x00094047, 0x00264C50, 0x00586F71, 0x00476E66, 0x00618984, 0x001E4A4B, 0x0034646A, 0x001E5360,
        0x00074255, 0x00003D55, 0x00003C58, 0x000B3F4F, 0x000B3F4F, 0x0009404F, 0x00084150, 0x00074251, 0x00064351, 0x00054452, 0x00034452, 0x000A4554, 0x00054256, 0x00074359, 0x00094154, 0x000B424F, 0x00013F4F, 0x00217190, 0x0012709B, 0x001576A2,
        0x001B7C9E, 0x002C8397, 0x002F747E, 0x0007393F, 0x0058878B, 0x003D777D, 0x00003E46, 0x0000455A, 0x000F5D6D, 0x007E9CA7, 0x00889397, 0x0088B1AA, 0x00B8E7DE, 0x00B6DAD4, 0x00A8DBD4, 0x00ACD5D8, 0x00A5D3DA, 0x009AD1DA, 0x009CDAE4, 0x0093D4DD,
        0x00A3E1E9, 0x00A1D9DE, 0x00A8DEDF, 0x00A6DDE2, 0x00D9FEFF, 0x00BFD3D4, 0x008B9B9A, 0x00486562, 0x001A4548, 0x000C3F49, 0x00104451, 0x000C4B60, 0x0018302E, 0x00403B2C, 0x003B362D, 0x00333731, 0x00353B2A, 0x00383A27, 0x0035362C, 0x003A4237,
        0x00434B40, 0x00394136, 0x003B4338, 0x0041493E, 0x003B4338, 0x003D453A, 0x003D453A, 0x003C463A, 0x00414B3F, 0x0040483D, 0x00424A3F, 0x0040483D, 0x003C4237, 0x003F453A, 0x003D4338, 0x00434B40, 0x003B4338, 0x003A4237, 0x003F473C, 0x0041493E,
        0x0040483D, 0x0041493E, 0x0040483D, 0x00464A3F, 0x0034382D, 0x00383C31, 0x0032382D, 0x003D4338, 0x00384035, 0x00434B40, 0x003B4338, 0x00384035, 0x0040483D, 0x003C4439, 0x00393F34, 0x003E4439, 0x00404439, 0x00383C31, 0x00363A2F, 0x00373A2A,
        0x0032362B, 0x0031342B, 0x00343227, 0x00373727, 0x00253125, 0x000B2D2D, 0x000C404D, 0x00003E52, 0x00144F63, 0x00063E51, 0x00154D60, 0x00144E61, 0x00003E50, 0x00085363, 0x00004C5C, 0x00004F5F, 0x00004456, 0x00144B60, 0x0015485C, 0x00023A4B,
        0x00377282, 0x00396D7D, 0x002A5667, 0x002C4C5F, 0x00315265, 0x00224A5C, 0x002D5869, 0x002F5A6B, 0x00345C6E, 0x002A4B5E, 0x00305063, 0x00374667, 0x00244A62, 0x00266671, 0x00428B8F, 0x0009474F, 0x00124353, 0x000D3C58, 0x00073A5B, 0x0000597F,
        0x0032ACD4, 0x002098C2, 0x00004D75, 0x00003D58, 0x0002575F, 0x00055D5D, 0x002F7777, 0x002D3132, 0x00000100, 0x00050903, 0x001A1E13, 0x0022261A, 0x0027291D, 0x002A291F, 0x00201E16, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFDFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00171C1A, 0x00170F0F, 0x00010604, 0x000E120D, 0x00100D09, 0x001A2522, 0x003D6D67, 0x00084D4A, 0x00064C4B, 0x00033C55, 0x00084059, 0x00073D54, 0x000B3E58, 0x000E405C,
        0x000D3E5E, 0x000B3D61, 0x0004385D, 0x000A4057, 0x000A4057, 0x00073D54, 0x00084059, 0x00073F58, 0x00053D58, 0x000B435E, 0x00063E59, 0x00114966, 0x0008425F, 0x00053F5C, 0x0007425C, 0x000B4660, 0x00063E57, 0x00134660, 0x0012435D, 0x000D3D59,
        0x000A425F, 0x0006425F, 0x00033F57, 0x000E3C4D, 0x00192F34, 0x0057544C, 0x00857061, 0x0003251E, 0x00103F47, 0x000B313D, 0x002B322D, 0x007E7567, 0x003B423D, 0x001D454A, 0x0007454B, 0x00003455, 0x000E3E56, 0x00487180, 0x0069939F, 0x00114551,
        0x00003842, 0x003A8282, 0x007DC6BE, 0x006AC3B3, 0x0042896F, 0x00003A3D, 0x00003854, 0x0037767A, 0x0050887D, 0x00054F4B, 0x0004524B, 0x00184059, 0x000F3C3F, 0x00448274, 0x0076CEBE, 0x006BC4B4, 0x00367C6B, 0x000A4040, 0x00114359, 0x00094650,
        0x00114A59, 0x000B4054, 0x000C4156, 0x0013485C, 0x000E4A56, 0x008FD2D5, 0x0097DDDC, 0x00B6DDD5, 0x007CAFA8, 0x00135250, 0x0007464E, 0x00094454, 0x00023B50, 0x00074458, 0x00004254, 0x00063E49, 0x00003737, 0x00489385, 0x0079CCB3, 0x007ECFB6,
        0x002A7265, 0x00003A3C, 0x000C404D, 0x00044155, 0x00044155, 0x00054256, 0x00054256, 0x00044155, 0x00044155, 0x00034054, 0x00034054, 0x0004405D, 0x00073D5C, 0x00083959, 0x00043C59, 0x0001445B, 0x00003D4C, 0x000A424D, 0x00457079, 0x003B6F76,
        0x00001725, 0x00001B2A, 0x00001C23, 0x0000211D, 0x000A3C3A, 0x00003341, 0x00064665, 0x003293B4, 0x00035475, 0x00003A59, 0x00003B55, 0x00064559, 0x00054250, 0x001F4F5B, 0x007395A2, 0x00195456, 0x00124C51, 0x001B545D, 0x004B8591, 0x00124D5D,
        0x00003549, 0x0008445A, 0x00054159, 0x00074252, 0x00074252, 0x00064252, 0x00044252, 0x00054353, 0x00034453, 0x00014453, 0x00014453, 0x00094654, 0x00014054, 0x00044358, 0x00084255, 0x000C4350, 0x00004150, 0x00247493, 0x001675A0, 0x000B7096,
        0x00147793, 0x00308692, 0x005E9E9F, 0x000F3B3C, 0x003D676C, 0x00164D5A, 0x00004556, 0x00278EA9, 0x00368BA1, 0x00628396, 0x0070848F, 0x009BD7D1, 0x009EE0D4, 0x0090B9B1, 0x00A3CDC2, 0x00B3CDCD, 0x00B8D3D0, 0x00B1CFCA, 0x00B2D0CB, 0x00ABCBC6,
        0x00B3D5CF, 0x00ACCDC9, 0x00ADCDCC, 0x0088C0C1, 0x00A3CCCE, 0x009BB6BA, 0x00738E92, 0x002B5457, 0x00094043, 0x00054147, 0x00074049, 0x00002D3A, 0x0012271E, 0x00443E2B, 0x003B392F, 0x00303732, 0x00313829, 0x00373926, 0x003A3A2E, 0x003A4438,
        0x00475145, 0x00353F33, 0x00394337, 0x00424C40, 0x00374135, 0x003A4438, 0x00394337, 0x002F3B2F, 0x00384438, 0x003B473B, 0x00434D41, 0x00414B3F, 0x003B4338, 0x003C4439, 0x00394136, 0x003A4438, 0x00303A2E, 0x002F392D, 0x00374135, 0x003B4539,
        0x00374135, 0x00353F33, 0x00364034, 0x0043473C, 0x00303429, 0x003C4035, 0x0032382D, 0x003D4338, 0x00333B30, 0x00454D42, 0x003B4338, 0x00323A2F, 0x0040483D, 0x003D453A, 0x00393F34, 0x0041473C, 0x0042463B, 0x00363A2F, 0x0033372C, 0x00363929,
        0x0032362B, 0x0031342B, 0x00343227, 0x00383828, 0x00263226, 0x000C2E2E, 0x000D414E, 0x000B475F, 0x00024156, 0x00115365, 0x00084E5B, 0x00044C56, 0x0009545D, 0x00004A56, 0x000B5763, 0x00015763, 0x00034C5A, 0x00033F4F, 0x00124F5D, 0x0000424F,
        0x00307683, 0x006CA9B7, 0x00548797, 0x005C8D9B, 0x00608F9D, 0x00558492, 0x0054818F, 0x004A7785, 0x00548391, 0x00558492, 0x00598A98, 0x005F7D9A, 0x0053869A, 0x00489098, 0x0034797C, 0x00083F48, 0x0015485C, 0x0000405D, 0x00085E82, 0x0035A2D5,
        0x002B96C2, 0x00005176, 0x00003752, 0x000D505F, 0x00004D4F, 0x00055B5B, 0x00368082, 0x00313536, 0x00000200, 0x00070B05, 0x00171B10, 0x00202418, 0x0026281C, 0x002A291F, 0x0024221A, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFDFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00171C1A, 0x0023181A, 0x00060907, 0x000D110C, 0x00120F0A, 0x00202A24, 0x00436D66, 0x0013514B, 0x000A4443, 0x00004759, 0x00044A5B, 0x00044252, 0x000B4453, 0x000D4054,
        0x00093C56, 0x000E4162, 0x00093D62, 0x00083E55, 0x000A4057, 0x000A4359, 0x0009465A, 0x00064559, 0x00034557, 0x00024758, 0x00004657, 0x0002475A, 0x00004153, 0x00004658, 0x00004357, 0x00084B60, 0x0006425A, 0x000F425C, 0x00113E59, 0x000D3F5B,
        0x000A425D, 0x00094660, 0x00023E54, 0x000C3D4D, 0x0027434A, 0x005D6362, 0x007E766F, 0x00426A68, 0x0040727E, 0x00325C68, 0x004A5A53, 0x0074756B, 0x004C5E5F, 0x001A4850, 0x00024046, 0x00073F62, 0x00123E55, 0x003C6068, 0x0053797E, 0x00053945,
        0x00003741, 0x00469094, 0x009BE8E1, 0x0083DFCE, 0x00539A80, 0x00004548, 0x0011617E, 0x004A878B, 0x00437B70, 0x0000423E, 0x00004A43, 0x00124062, 0x00073945, 0x004A928C, 0x0091F1EA, 0x007DE1DB, 0x00388B83, 0x00074954, 0x00003557, 0x00004347,
        0x00003E46, 0x00004554, 0x00094B5E, 0x00003C4B, 0x0000444B, 0x0083CDC9, 0x0090DCD0, 0x008DC7C6, 0x005CA2A2, 0x00003E44, 0x00054E56, 0x000C4751, 0x00134852, 0x00023C42, 0x00003F44, 0x00003E56, 0x00004652, 0x0059AEAA, 0x0083E0D1, 0x007FDBCA,
        0x002D7F7A, 0x00003B46, 0x000D435A, 0x00054256, 0x00054256, 0x00054256, 0x00054256, 0x00054256, 0x00044155, 0x00044155, 0x00034054, 0x00004051, 0x00043F53, 0x00073E53, 0x00034054, 0x00024859, 0x00003F48, 0x00004247, 0x002A6267, 0x002A7174,
        0x00013640, 0x00082E3A, 0x00163C41, 0x000A3F3C, 0x00044641, 0x0006444A, 0x000E4455, 0x00056785, 0x00328CAA, 0x000F5F7C, 0x00004C67, 0x00004D64, 0x0000485B, 0x00307285, 0x00548C9F, 0x00005166, 0x00065268, 0x002D798C, 0x003D8295, 0x00034355,
        0x00033F4F, 0x000E4756, 0x00013847, 0x00054353, 0x00054353, 0x00034453, 0x00034453, 0x00034453, 0x00034453, 0x00014453, 0x00014453, 0x00054250, 0x00003D51, 0x00024156, 0x00084255, 0x000B4551, 0x00034453, 0x00287A99, 0x001F7EA9, 0x0010708E,
        0x001F7D90, 0x002D7E85, 0x00266563, 0x00194342, 0x00315B60, 0x004A8190, 0x004C93A7, 0x00276E8F, 0x000A425F, 0x001A2540, 0x00585A6C, 0x00779EA0, 0x00658B85, 0x008A918A, 0x0093948B, 0x00868A85, 0x008B8B85, 0x00848278, 0x00898378, 0x00868075,
        0x00858379, 0x007A7C76, 0x00737974, 0x00758076, 0x00828681, 0x007B7C80, 0x00636F7B, 0x00204454, 0x00033B4E, 0x0005465B, 0x00003F54, 0x0000313E, 0x00152A21, 0x0044402D, 0x003C3A30, 0x002F3933, 0x00303A2A, 0x00373926, 0x0037392D, 0x003A4438,
        0x00475145, 0x00364034, 0x003A4438, 0x00434D41, 0x003A4438, 0x003D473B, 0x003C463A, 0x00303C30, 0x00384438, 0x003A463A, 0x00404A3E, 0x003E483C, 0x00394136, 0x003C4439, 0x00394136, 0x00434D41, 0x003C463A, 0x00394337, 0x00404A3E, 0x00434D41,
        0x003B4539, 0x00343E32, 0x00343E32, 0x0041453A, 0x00303429, 0x003F4338, 0x00383E33, 0x0043493E, 0x00373F34, 0x00454D42, 0x00373F34, 0x0030382D, 0x003F473C, 0x003D453A, 0x003A4035, 0x0040463B, 0x003F4338, 0x0031352A, 0x002C3025, 0x00353828,
        0x0031352A, 0x0031342B, 0x00353328, 0x00383828, 0x00263226, 0x000C2E2E, 0x000D414E, 0x000C455E, 0x00084C5F, 0x0000464E, 0x00005353, 0x002D8683, 0x0067B6B3, 0x008ACACB, 0x0097CED3, 0x0085C5C6, 0x006FACB0, 0x00327277, 0x00105A60, 0x00004147,
        0x00004850, 0x00327683, 0x00508494, 0x00468B95, 0x00498994, 0x00498692, 0x004C8692, 0x00427C88, 0x0045828E, 0x0044848F, 0x0040858F, 0x00498297, 0x00488998, 0x002C717B, 0x001A5862, 0x00054050, 0x00004159, 0x00005F7F, 0x002CADCE, 0x003797CC,
        0x0000406F, 0x00073A5B, 0x000A4559, 0x00054A54, 0x00074B52, 0x00105A5E, 0x002F8787, 0x00363A3B, 0x00000402, 0x00070B05, 0x00161A0F, 0x001F2317, 0x0024261A, 0x0029281E, 0x0024221A, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFDFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00161B19, 0x00160B0E, 0x00020404, 0x000F130E, 0x001E1A15, 0x001C231C, 0x00385A53, 0x002D5D57, 0x00285350, 0x001B5C65, 0x0026616A, 0x00285F64, 0x002C5F62, 0x001B4C54,
        0x00083A4C, 0x000C435E, 0x00094262, 0x0009415C, 0x000A435C, 0x000D465B, 0x00003B4B, 0x000C4652, 0x00245D66, 0x00266066, 0x00316B70, 0x00286268, 0x00205E64, 0x001E616A, 0x0000424F, 0x00014657, 0x0008445A, 0x000D3F5B, 0x0011405C, 0x000C425B,
        0x000A415C, 0x000C4860, 0x00064258, 0x000F4458, 0x0027515E, 0x00456168, 0x00576A6F, 0x003F6B72, 0x00225B6A, 0x00215762, 0x00496964, 0x005B6F6A, 0x004C6D76, 0x00154959, 0x0008474F, 0x00073F62, 0x000B394B, 0x0021464A, 0x002D5659, 0x0008424E,
        0x00024758, 0x0052969B, 0x00A3E2D9, 0x0093D9D8, 0x00689D93, 0x00195B6E, 0x002A78A3, 0x00165165, 0x000E444B, 0x00004352, 0x00034C5A, 0x00004062, 0x0007434F, 0x006DA3A4, 0x00AAE4E9, 0x0098D8DD, 0x006DB0B3, 0x003B8E9D, 0x00167C9F, 0x00197AAC,
        0x00107BAE, 0x000379AD, 0x000079AA, 0x00007098, 0x0012718B, 0x0074BECA, 0x009CD7D9, 0x009AE1E5, 0x0063B4BC, 0x00005564, 0x0017606E, 0x003E747B, 0x00366263, 0x004C7E7C, 0x00316F6F, 0x00014463, 0x00135A6E, 0x0070BABE, 0x008AD7D0, 0x0088D3CB,
        0x00559B9B, 0x00084656, 0x0008405B, 0x00034256, 0x00034256, 0x00044357, 0x00044357, 0x00044357, 0x00034256, 0x00024155, 0x00024155, 0x0000474D, 0x0002424D, 0x000A4352, 0x00003E50, 0x00004151, 0x00003F4C, 0x0000444D, 0x0001444D, 0x00035459,
        0x00044651, 0x000B3F4F, 0x000E4552, 0x00004049, 0x00004047, 0x00044952, 0x00033E4D, 0x00003755, 0x00207694, 0x002E84A2, 0x00338CA7, 0x00318CA7, 0x00268099, 0x003586A1, 0x002E7894, 0x002882A4, 0x002781A0, 0x00257995, 0x0004516B, 0x00003B4F,
        0x00074857, 0x00084450, 0x000B4650, 0x00034355, 0x00034355, 0x00034355, 0x00034355, 0x00034355, 0x00054355, 0x00054355, 0x00054355, 0x00084755, 0x00004154, 0x00024358, 0x00084356, 0x000B4551, 0x00004251, 0x00267897, 0x001F7EA9, 0x002B8193,
        0x003E929E, 0x001A676A, 0x00003E3C, 0x00113F40, 0x0019444D, 0x00164E5F, 0x00135A6E, 0x0004405D, 0x00003B53, 0x000E293E, 0x00566575, 0x006A9395, 0x00678580, 0x009A9792, 0x00827D74, 0x00657E70, 0x00617568, 0x005D6D5C, 0x006A7565, 0x006C7666,
        0x00677464, 0x00607265, 0x00586F61, 0x0086866E, 0x00908F81, 0x006D7275, 0x00496576, 0x001F5C76, 0x00156C8C, 0x0016789A, 0x00086C8E, 0x00125368, 0x001A3734, 0x003E3E2E, 0x003A382E, 0x00323A33, 0x00353D2C, 0x00373B28, 0x0031372C, 0x003A4237,
        0x00434B40, 0x003A4237, 0x003E463B, 0x00454D42, 0x003F473C, 0x00424A3F, 0x00424A3F, 0x003C463A, 0x00404A3E, 0x003D453A, 0x003E463B, 0x003B4338, 0x00393F34, 0x003E4439, 0x003D4338, 0x0040483D, 0x003D453A, 0x003B4338, 0x003F473C, 0x00434B40,
        0x003C4439, 0x00353D32, 0x00363E33, 0x004A4E43, 0x00373B30, 0x003B3F34, 0x00363C31, 0x0042483D, 0x003D453A, 0x00464E43, 0x003D453A, 0x00394136, 0x00434B40, 0x00424A3F, 0x0040463B, 0x0043493E, 0x00404439, 0x0034382D, 0x002F3328, 0x00343727,
        0x0031352A, 0x0031342B, 0x00353328, 0x00383828, 0x00263226, 0x000C2E2E, 0x000D414E, 0x00044658, 0x0000434D, 0x00247370, 0x0074C6B9, 0x0085CEBE, 0x0072A89B, 0x008EB0A9, 0x00ACC2C0, 0x00B9D4CA, 0x00C0DFD8, 0x00BAE3DE, 0x0062A19F, 0x00136566,
        0x0003575D, 0x00004554, 0x000B4356, 0x00004652, 0x0000434F, 0x00004451, 0x00054B58, 0x00004653, 0x00014754, 0x00004753, 0x00004551, 0x00004654, 0x00034655, 0x00003446, 0x00003F54, 0x0000425C, 0x00026482, 0x002EA4C7, 0x001A9FC4, 0x00004874,
        0x0009365C, 0x00183E5C, 0x00064357, 0x00004253, 0x000E4657, 0x00195D62, 0x001D8078, 0x00393D3E, 0x00000100, 0x00030701, 0x00181C11, 0x00202418, 0x0024261A, 0x0028271D, 0x00211F17, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFDFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00161B19, 0x001C1316, 0x00090B0B, 0x000C100B, 0x001D1712, 0x00171711, 0x00526961, 0x00A2C2BD, 0x00C6DEDC, 0x00CDE7ED, 0x00D6EFF1, 0x00CEE6E4, 0x00B3CECA, 0x006B908E,
        0x00215058, 0x00084356, 0x00003C55, 0x0001425E, 0x00003D57, 0x000A4156, 0x00154452, 0x006C9199, 0x00CAE8E9, 0x00D9F0EC, 0x00E2F6F1, 0x00E2F5F2, 0x00CEEBE8, 0x00A2CBCD, 0x002D636A, 0x00094453, 0x00094359, 0x00043954, 0x000D3E5E, 0x000D435A,
        0x000B445A, 0x000C455E, 0x00054159, 0x00094359, 0x000A4255, 0x000F4354, 0x00275A6A, 0x002D5C6A, 0x00003A4E, 0x00034452, 0x00285957, 0x002F5756, 0x00275868, 0x00043F53, 0x00023F4B, 0x00013A59, 0x00184957, 0x00386261, 0x0044777A, 0x004B8B9D,
        0x00377C90, 0x00578E95, 0x0078A297, 0x00608C8D, 0x006B8E84, 0x00316C80, 0x002F80AD, 0x0000415A, 0x000C4756, 0x00074D65, 0x00004057, 0x00004A64, 0x0013474E, 0x00708F8E, 0x00779296, 0x0066868B, 0x006D9D9F, 0x0056A6B1, 0x0042B0CE, 0x0039A4DE,
        0x003DAEEC, 0x0029A4E6, 0x002CACED, 0x0045BBF6, 0x0046A6D4, 0x004089A7, 0x00568FA4, 0x0062A1A5, 0x003D8793, 0x002F7B91, 0x00317084, 0x00537C85, 0x00244346, 0x0060898B, 0x00447C81, 0x003C7F9A, 0x003D788B, 0x00619195, 0x00628B84, 0x006E958D,
        0x00689291, 0x00144652, 0x00053D50, 0x00034256, 0x00044357, 0x00044357, 0x00044357, 0x00044357, 0x00034256, 0x00034256, 0x00024155, 0x0000494F, 0x00034550, 0x00084255, 0x00054159, 0x000B556F, 0x00095873, 0x000A5772, 0x00094E69, 0x000B5A6D,
        0x0009546A, 0x000F5671, 0x00094F6D, 0x00074E6F, 0x000E5674, 0x000C526F, 0x00105570, 0x00155877, 0x00034C6C, 0x000B5B7A, 0x00075F7D, 0x00005A79, 0x00015B7A, 0x00015578, 0x000D5F82, 0x00025B7D, 0x00085F7F, 0x00045A78, 0x00004E68, 0x000D5B72,
        0x000F5A70, 0x00085264, 0x00064E60, 0x00014153, 0x00014153, 0x00044254, 0x00044254, 0x00064154, 0x00074255, 0x00074255, 0x00084255, 0x000B4A58, 0x00024457, 0x0004455A, 0x00094457, 0x000B4551, 0x00004150, 0x00247796, 0x001D7FA9, 0x00489097,
        0x003A8488, 0x0000484A, 0x00044445, 0x000F4147, 0x001A4B55, 0x00003A48, 0x00004656, 0x00004052, 0x00004451, 0x00002B37, 0x003B666F, 0x00659B9B, 0x006E8E89, 0x00898B85, 0x008E988C, 0x00748577, 0x00697668, 0x00697265, 0x007F8378, 0x007E8277,
        0x0072796C, 0x00727B6E, 0x006B786A, 0x00778867, 0x0070806E, 0x004F6A6E, 0x003B7085, 0x0022799B, 0x001486AE, 0x000E8AB2, 0x001995BD, 0x001E6A8E, 0x00153A42, 0x0036382C, 0x0039372C, 0x00353B30, 0x00373D2A, 0x00383E2B, 0x00303831, 0x00373B30,
        0x003A3E33, 0x00383C31, 0x00393D32, 0x003B3F34, 0x003A3E33, 0x003B3F34, 0x003C4035, 0x003A4035, 0x003C4237, 0x00363C31, 0x00393D32, 0x00373B30, 0x0035362C, 0x003A3B31, 0x0038392F, 0x003A3E33, 0x003C4035, 0x00393D32, 0x003B3F34, 0x00404439,
        0x003E4237, 0x003A3E33, 0x003B3F34, 0x0041453A, 0x0035392E, 0x00303429, 0x002E3429, 0x00343A2F, 0x00353D32, 0x00394136, 0x00394136, 0x00363E33, 0x00384035, 0x00384035, 0x00393F34, 0x00393F34, 0x00383C31, 0x0032362B, 0x002F3328, 0x00333626,
        0x00303429, 0x0030332A, 0x00343227, 0x00383828, 0x00263226, 0x000C2E2E, 0x000C404D, 0x0000444C, 0x002D7575, 0x0094CDC4, 0x0093BBA9, 0x0097AF97, 0x00CCD8C2, 0x00DDDECE, 0x00FFFFF7, 0x00F6F4DC, 0x00DED8C5, 0x00DCDCD0, 0x00D0E4DF, 0x0082B0B1,
        0x00195860, 0x00004251, 0x000A495D, 0x00034557, 0x00004354, 0x00004354, 0x00014657, 0x00004556, 0x00014657, 0x00024758, 0x00034557, 0x00003E47, 0x000C4757, 0x00073F5A, 0x00003C5E, 0x00005F85, 0x002A9CC4, 0x003EA6D1, 0x00004A78, 0x00013756,
        0x00154E67, 0x00003C4F, 0x0002485F, 0x000E4E6C, 0x00013F57, 0x000B555B, 0x002E8A7D, 0x00434748, 0x00000100, 0x00020600, 0x001C2015, 0x0022261A, 0x0025271B, 0x0029281E, 0x00201E16, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFDFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00161B19, 0x001B1215, 0x00060B0A, 0x00090D08, 0x00241B17, 0x0016120D, 0x0053635C, 0x00C1D8D3, 0x00E7F4F2, 0x00FFFBFF, 0x00FFFEFF, 0x00F6F3EE, 0x00C8D1C7, 0x0069847B,
        0x00124041, 0x0001414C, 0x0000495B, 0x00004562, 0x0004445D, 0x00114458, 0x00173A48, 0x007C8F94, 0x00EEF0F0, 0x00F4EAE3, 0x00F5E4DB, 0x00FFF4ED, 0x00FCF8F3, 0x00CCDCDB, 0x00365B5F, 0x00083A46, 0x000F465B, 0x00073D5B, 0x00114667, 0x00094257,
        0x000B445A, 0x000D455E, 0x000A435C, 0x0008455F, 0x00003A53, 0x00003C53, 0x00286E85, 0x00336579, 0x00003C53, 0x00004351, 0x000A4645, 0x000C4243, 0x00094257, 0x00004058, 0x00054452, 0x00003A54, 0x0010454F, 0x00174846, 0x000E484D, 0x0032798D,
        0x0033768F, 0x0056858D, 0x00718B7E, 0x0069877A, 0x008EAA93, 0x003A767C, 0x00156F8E, 0x00003D4A, 0x000A4F52, 0x00004657, 0x00004657, 0x00063D52, 0x0024474A, 0x00899C93, 0x00768B88, 0x005C7976, 0x00577F7A, 0x0014555D, 0x0000445F, 0x00004A4F,
        0x00004757, 0x00004461, 0x0000476F, 0x00064B73, 0x00216082, 0x00286278, 0x004D8793, 0x00356567, 0x000D4955, 0x0003465D, 0x000A3C52, 0x002C4755, 0x0013262D, 0x001A3B44, 0x000E3F4D, 0x0000364B, 0x00174955, 0x004E6A6A, 0x006A786D, 0x007E887C,
        0x007A908B, 0x0022484C, 0x000F414D, 0x00044357, 0x00044357, 0x00044357, 0x00044357, 0x00044357, 0x00044357, 0x00034256, 0x00024155, 0x0000414A, 0x00034453, 0x00063E57, 0x00144E71, 0x003D82A9, 0x003581AB, 0x0029759F, 0x003479A4, 0x00337E9E,
        0x002D7B9F, 0x00227198, 0x002A77A5, 0x00317AAC, 0x002B72A4, 0x002C72A1, 0x002C779E, 0x0046799A, 0x003A7595, 0x002D7495, 0x002A7B9C, 0x0023779A, 0x0022769A, 0x002A7DA3, 0x00207399, 0x00247793, 0x00237692, 0x00277A96, 0x002A7E98, 0x00297D97,
        0x00247993, 0x00358AA4, 0x001B708A, 0x00024052, 0x00024052, 0x00034153, 0x00054053, 0x00074154, 0x00074154, 0x000A4255, 0x000A4255, 0x00054452, 0x00003E51, 0x00004156, 0x00084356, 0x000B4753, 0x00024554, 0x002A7D9C, 0x002587B1, 0x00488686,
        0x00145758, 0x00004545, 0x0006464A, 0x00114650, 0x00104451, 0x00084755, 0x0000404E, 0x00123F4D, 0x00003E47, 0x00002F38, 0x00385F67, 0x00658B8D, 0x00798383, 0x00726360, 0x007B7A70, 0x00829281, 0x006F7C6E, 0x006E766C, 0x00838781, 0x007E807A,
        0x006B7067, 0x0070776A, 0x006C7666, 0x006E7658, 0x00727B6E, 0x0064767F, 0x00396584, 0x0018648E, 0x002489B6, 0x00228DB9, 0x00238CB8, 0x00156A97, 0x00083342, 0x002E332A, 0x0039372C, 0x00363A2E, 0x00363D28, 0x003B4130, 0x00333D37, 0x003A3B31,
        0x0038392F, 0x003B3C32, 0x00393A30, 0x0035362C, 0x0035362C, 0x0035362C, 0x0036372D, 0x0035392E, 0x00383C31, 0x0038392F, 0x003B3C32, 0x003B3C32, 0x0039382E, 0x003B3A30, 0x0036352B, 0x0037382E, 0x003A3B31, 0x0036372D, 0x0033342A, 0x0038392F,
        0x0038392F, 0x0034352B, 0x0036372D, 0x00303429, 0x0033372C, 0x0033372C, 0x00373D32, 0x00353B30, 0x0031392E, 0x002E362B, 0x00333B30, 0x002F372C, 0x002C3429, 0x002C3429, 0x0031372C, 0x0030362B, 0x0032362B, 0x0033372C, 0x0031352A, 0x00323525,
        0x002F3328, 0x0030332A, 0x00343227, 0x00383828, 0x00263226, 0x000B2D2D, 0x000C404D, 0x00005455, 0x0075BDB7, 0x00799D8F, 0x0091937D, 0x00ECD9BE, 0x00FFEED4, 0x00FFF1DB, 0x00FFF5E2, 0x00FFFFE2, 0x00FADBC2, 0x00E7C4B6, 0x00B49E99, 0x00A4ADB1,
        0x0066909C, 0x00084658, 0x00004256, 0x000E455A, 0x000B465A, 0x0009465A, 0x00044659, 0x00034558, 0x00074458, 0x00094458, 0x000B4257, 0x00134A53, 0x000D3D4F, 0x00063C5D, 0x0000567E, 0x0035AEDA, 0x00229AC8, 0x00003B6C, 0x000B3167, 0x00174255,
        0x00004752, 0x00004C58, 0x0000435E, 0x0000375E, 0x00054E6A, 0x0001555A, 0x00318475, 0x00515556, 0x00000402, 0x00030701, 0x001E2217, 0x0023271B, 0x0025271B, 0x002C2B21, 0x00222018, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFEFF, 0xFFFDFCFE, 0xFFFCFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00191E1C, 0x0007150A, 0x00000802, 0x00111615, 0x000D0C10, 0x001A1C1D, 0x00656C67, 0x00B6C4B8, 0x00B5C8B7, 0x00DAEDDA, 0x00DFDCCE, 0x00D0C1BE, 0x008C9194, 0x0064959F,
        0x0049A0B4, 0x004CAFCF, 0x003C9CC4, 0x0050ADC4, 0x0034A4B6, 0x004DC7D3, 0x0043A5AF, 0x006FA3A9, 0x00B3BDBD, 0x00B3ADA6, 0x00AFAC9E, 0x00D6DACE, 0x00C4D7C4, 0x00A0C7B2, 0x00275D56, 0x00023F4D, 0x0004435F, 0x00003B5A, 0x0003425E, 0x00084357,
        0x00124369, 0x00083C64, 0x0003475A, 0x00034452, 0x000D3A4F, 0x001C4050, 0x002C5857, 0x0049544A, 0x002E4334, 0x0088AC9C, 0x00639994, 0x00064A51, 0x00084C59, 0x0048868C, 0x00538787, 0x00508484, 0x00397075, 0x00003A43, 0x001E5963, 0x00689FA6,
        0x0054898C, 0x002F6264, 0x00194C4E, 0x00104646, 0x00296A7F, 0x002176A4, 0x000C78B2, 0x00007EB5, 0x000C8AC0, 0x00087CB7, 0x001179BE, 0x00207BAE, 0x002180B1, 0x00268BB8, 0x001985AF, 0x000E7EA9, 0x001484B2, 0x001786B8, 0x001581B7, 0x000086B1,
        0x00006086, 0x00003A5A, 0x0018455A, 0x00144848, 0x00004440, 0x001482A0, 0x0028B4FF, 0x00005D80, 0x0000485D, 0x0009474D, 0x00184D50, 0x000A414E, 0x00003E53, 0x00014159, 0x00003D50, 0x00024254, 0x00024254, 0x00014153, 0x00014153, 0x00014153,
        0x00014153, 0x00024254, 0x00024254, 0x00024457, 0x00024457, 0x00014356, 0x00014356, 0x00014356, 0x00014356, 0x00004255, 0x00004255, 0x00004753, 0x00074055, 0x0006415B, 0x000C5270, 0x003C7999, 0x00254D6A, 0x002F4D66, 0x002B5163, 0x003F4D6A,
        0x0040526F, 0x00374E68, 0x00334E68, 0x002B475F, 0x0036526A, 0x00365068, 0x0031495F, 0x002C4D5D, 0x00334D5E, 0x002F5161, 0x00295465, 0x002A4A5D, 0x0045526A, 0x00384D63, 0x00224D60, 0x00254E57, 0x00284659, 0x00203E57, 0x0022475D, 0x00305161,
        0x00344C60, 0x00325576, 0x003D78A0, 0x00034355, 0x00034355, 0x00034355, 0x00034355, 0x00034355, 0x00034355, 0x00034355, 0x00034355, 0x00104256, 0x000F4256, 0x00084051, 0x00024050, 0x00014453, 0x0000414D, 0x0034838E, 0x0043939E, 0x001E646B,
        0x00054B52, 0x0000444D, 0x00074856, 0x00014153, 0x00044155, 0x00074359, 0x00013D55, 0x00084664, 0x00003A42, 0x00093332, 0x00325962, 0x005C919B, 0x006B827D, 0x00544C3B, 0x00626653, 0x00859486, 0x00738274, 0x006B7A6C, 0x00818E80, 0x007B887A,
        0x00778174, 0x00717B6E, 0x00727C6F, 0x008D7B74, 0x006B7471, 0x004F6F75, 0x00406B7E, 0x000D5069, 0x0011728C, 0x00127B96, 0x000F6E88, 0x001A555F, 0x001D3939, 0x0030392C, 0x0034402E, 0x00323A2F, 0x003B3732, 0x003B352E, 0x00353A2B, 0x00393D32,
        0x00393D32, 0x00383C31, 0x00373B30, 0x0035392E, 0x0035392E, 0x00373B30, 0x00393D32, 0x00383C30, 0x00373B2F, 0x00363A2E, 0x0035392D, 0x0035392D, 0x0035392D, 0x0035392D, 0x00363A2E, 0x00393B2F, 0x0037392D, 0x0036382C, 0x0036382C, 0x00383A2E,
        0x00383A2E, 0x0036382C, 0x0034362A, 0x003A3A2E, 0x0039392D, 0x0039392D, 0x0038382C, 0x0038382C, 0x0038382C, 0x0038382C, 0x0039392D, 0x0030362B, 0x0032382D, 0x0032382D, 0x0031352A, 0x0031352A, 0x0035362C, 0x0035362C, 0x0033342A, 0x00313229,
        0x003C352C, 0x00353328, 0x002E362B, 0x002B3329, 0x002C2F2D, 0x000E2926, 0x0005403C, 0x002F8B7E, 0x007BA79A, 0x00696D62, 0x00CCC9C4, 0x00FBFCFA, 0x00FBF3EC, 0x009F917A, 0x00A19670, 0x00ECE7D2, 0x00FEFEE6, 0x00E4DAC2, 0x00B09783, 0x00867E71,
        0x0083A5A4, 0x0022656E, 0x00004457, 0x0000405B, 0x0004445D, 0x00094055, 0x00104657, 0x000A4554, 0x000A4656, 0x00114C5F, 0x00033C51, 0x00004260, 0x00043A5B, 0x000E5C81, 0x002CA9D6, 0x001B95CB, 0x00004276, 0x00033B56, 0x00004E4C, 0x0001445B,
        0x00014356, 0x00044554, 0x00044358, 0x00054460, 0x0003485C, 0x00095A5D, 0x002C8476, 0x00444E4E, 0x00000401, 0x00020600, 0x001E1F15, 0x0028281C, 0x00282A1E, 0x002C3025, 0x001D2219, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFCFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00191E1C, 0x00101B11, 0x00050B06, 0x00111111, 0x00141113, 0x001C1B1D, 0x00646B68, 0x00BACABF, 0x00AAC1B2, 0x00D0DCC8, 0x00BCB7A8, 0x00B09F96, 0x008B8A86, 0x006F9698,
        0x00448F98, 0x00388EA2, 0x00277B95, 0x006191AD, 0x00397D94, 0x003D8C9F, 0x00367A87, 0x00698994, 0x009FA4A7, 0x009D9D97, 0x009FA89B, 0x00BFBDB5, 0x00B1BEB0, 0x0095B4A5, 0x002D5A57, 0x000C4050, 0x000A405F, 0x00033A59, 0x000C435E, 0x00004A5C,
        0x00114165, 0x001F4067, 0x000E4052, 0x00013F49, 0x00083C4C, 0x0014343F, 0x00213530, 0x00263432, 0x005A5C5C, 0x00C3C6CA, 0x008DADB8, 0x0033788B, 0x00468FA3, 0x0084ABB9, 0x0093959D, 0x008FAEAB, 0x00487279, 0x00124353, 0x004B7B87, 0x0097C0C2,
        0x0090B8B3, 0x00487578, 0x00063C47, 0x0018677A, 0x00137496, 0x00188BBD, 0x0037B1E7, 0x0035A8DA, 0x002FA0C8, 0x0031A6CD, 0x0035B1D9, 0x0028A7EB, 0x0029A9EA, 0x001D9FDB, 0x0027AAE3, 0x002FB0E9, 0x00219FD9, 0x00269FDD, 0x0032A8E9, 0x0044B7E4,
        0x0046B0D5, 0x00056283, 0x00002E4A, 0x00174B57, 0x00114145, 0x00004766, 0x0029ABEE, 0x00117AAB, 0x00086285, 0x00004759, 0x00003A48, 0x00003C4E, 0x0002425A, 0x0004455A, 0x00034355, 0x00034355, 0x00024254, 0x00024254, 0x00014153, 0x00014153,
        0x00024254, 0x00024254, 0x00034355, 0x00014356, 0x00014356, 0x00014356, 0x00014356, 0x00014356, 0x00004255, 0x00004255, 0x00004255, 0x0000424F, 0x00074055, 0x00003953, 0x000C5270, 0x004283A2, 0x00285471, 0x004E7088, 0x00729DAE, 0x00375B6D,
        0x00285160, 0x0054818F, 0x0070A4B1, 0x0068A3AD, 0x005E9CA6, 0x00397D84, 0x0050949B, 0x00357782, 0x00629EAA, 0x005A97A3, 0x0065A6B4, 0x00558898, 0x00344F64, 0x003F5C71, 0x005C8EA0, 0x005EA1A4, 0x005C96A2, 0x005D95A8, 0x005391A1, 0x006197A2,
        0x00385F6E, 0x002F5B78, 0x0037789E, 0x00034355, 0x00034355, 0x00034355, 0x00034355, 0x00034355, 0x00034355, 0x00034355, 0x00034355, 0x000A4255, 0x00084255, 0x000D485B, 0x00074555, 0x00004352, 0x00084E5B, 0x00408894, 0x002F7985, 0x000A5057,
        0x0000444D, 0x0000454F, 0x00094A58, 0x00054557, 0x00064357, 0x0008445A, 0x00044058, 0x0001405C, 0x00034347, 0x002A5552, 0x004D767F, 0x005E97A0, 0x006E8E89, 0x0046463A, 0x0059685A, 0x0083877B, 0x00696D61, 0x0064665A, 0x00838579, 0x00898B7F,
        0x007F7F73, 0x00707064, 0x00737367, 0x007E705D, 0x007C8374, 0x00637772, 0x00576D73, 0x002F5462, 0x000E4F5E, 0x00003B4C, 0x00054355, 0x0000333F, 0x00112627, 0x00303428, 0x0038402F, 0x00343C31, 0x003E3A35, 0x003E3831, 0x00363B2C, 0x00383C31,
        0x00393D32, 0x00383C31, 0x00373B30, 0x0035392E, 0x0034382D, 0x0035392E, 0x00363A2F, 0x00363A2E, 0x00363A2E, 0x0035392D, 0x0035392D, 0x0034382C, 0x0034382C, 0x0034382C, 0x0034382C, 0x00383A2E, 0x0036382C, 0x0035372B, 0x0035372B, 0x0036382C,
        0x0037392D, 0x0036382C, 0x0035372B, 0x00393B2F, 0x0037392D, 0x0036382C, 0x0034362A, 0x0034362A, 0x0034362A, 0x0036382C, 0x0036382C, 0x002F352A, 0x0031372C, 0x0032382D, 0x0031352A, 0x0031352A, 0x0035362C, 0x0035362C, 0x00323329, 0x002F3229,
        0x003B342B, 0x00333126, 0x002C3429, 0x002B3027, 0x002D302E, 0x00122A28, 0x0008433F, 0x0047998D, 0x0044685C, 0x00908E83, 0x00FFFBF2, 0x00FFFFFB, 0x00E3D9CF, 0x008B7C62, 0x008F855D, 0x00948F76, 0x00CAC9AD, 0x00C3B89D, 0x009E8571, 0x00736A5D,
        0x006E8F8B, 0x00488991, 0x00004152, 0x00084A5C, 0x00004356, 0x0000445B, 0x00054760, 0x0006415B, 0x0002384F, 0x00073D4E, 0x00174E5B, 0x00053E57, 0x00005F82, 0x002DA9D9, 0x003497C9, 0x00014A70, 0x00003D55, 0x0001465A, 0x00073D56, 0x0001445B,
        0x00024457, 0x00044554, 0x00044358, 0x00054460, 0x0003485C, 0x00095A5D, 0x002C8476, 0x00465050, 0x00000200, 0x00000400, 0x00212218, 0x002C2C20, 0x00292B1F, 0x00292D22, 0x001B2017, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFCFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00171C1A, 0x000C130C, 0x00090A06, 0x00140F10, 0x001C1518, 0x001A1818, 0x005E6562, 0x00B5C8BF, 0x00A5C1B4, 0x00899686, 0x007B786A, 0x00988980, 0x00909188, 0x0053726F,
        0x00043F41, 0x00004049, 0x00014251, 0x0003344E, 0x00074359, 0x0000394D, 0x000D394A, 0x007C8593, 0x0087767F, 0x00503C3B, 0x0063564E, 0x008F8F8F, 0x00A2AEA8, 0x009DB8AF, 0x00396062, 0x000F3C51, 0x00114060, 0x000F3E5E, 0x000F405A, 0x00003A4E,
        0x000B4261, 0x00153F5C, 0x00133D4A, 0x004C7780, 0x00608391, 0x00354B51, 0x00374436, 0x00242E35, 0x003D4048, 0x00535E6C, 0x001F4960, 0x00004866, 0x00074C67, 0x00314858, 0x00977F85, 0x00636B64, 0x002B4551, 0x000F3851, 0x00234A59, 0x0028423C,
        0x002E4739, 0x00153F44, 0x0011506C, 0x00206D9E, 0x003C97CE, 0x0041A5DF, 0x001870A6, 0x00003E69, 0x000B4764, 0x00004657, 0x0000525E, 0x00004D62, 0x00025164, 0x00004D5A, 0x00004652, 0x00044B55, 0x000F5360, 0x00104E5E, 0x00003E50, 0x00065986,
        0x003AA5CA, 0x0032B2D5, 0x00006084, 0x00003953, 0x00234251, 0x00154F6C, 0x002F99CE, 0x0052C0FA, 0x004AA8D5, 0x0025718E, 0x0003465D, 0x0000425B, 0x00034661, 0x00014257, 0x00054353, 0x00044456, 0x00034355, 0x00034355, 0x00024254, 0x00024254,
        0x00034355, 0x00034355, 0x00044456, 0x00014356, 0x00014356, 0x00014356, 0x00004255, 0x00004255, 0x00004255, 0x00004255, 0x00004255, 0x00034754, 0x000C455A, 0x00023D57, 0x000F5775, 0x00377D9B, 0x00174763, 0x00436D84, 0x006699A9, 0x00538A93,
        0x004E888E, 0x004D8B91, 0x005CA0A5, 0x005AA7A9, 0x0069C1C1, 0x0079DDD8, 0x0089F0EB, 0x0086E4EA, 0x00469BA3, 0x0052A7B1, 0x0067BCC6, 0x002B6979, 0x0022475B, 0x004B6E82, 0x00679CB0, 0x00368D8A, 0x007FCDD4, 0x007DCBD8, 0x00469BA5, 0x0072BCC2,
        0x00437783, 0x002B617A, 0x0030789A, 0x00024254, 0x00024254, 0x00024254, 0x00024254, 0x00024254, 0x00024254, 0x00024254, 0x00024254, 0x00034256, 0x00044456, 0x0008485A, 0x00034355, 0x00024352, 0x00094A59, 0x002B6C7A, 0x000E4F5D, 0x00004049,
        0x0000434D, 0x00024653, 0x00064756, 0x00054557, 0x00074458, 0x00074359, 0x0008445A, 0x000C3954, 0x00124244, 0x007F9A96, 0x009EB9C3, 0x0063919C, 0x0071888A, 0x00615C59, 0x006B7674, 0x00828E82, 0x00707C70, 0x006A766A, 0x00838D81, 0x008B9589,
        0x007F877C, 0x006F776C, 0x00757D72, 0x0074806A, 0x00677F6D, 0x00516C63, 0x00708184, 0x0079929C, 0x0052828E, 0x00124C58, 0x00093C4C, 0x00002835, 0x001A2729, 0x003D3B30, 0x003C3F2F, 0x0032362B, 0x003A3631, 0x003B3830, 0x00303A2A, 0x00373B30,
        0x00383C31, 0x00383C31, 0x00373B30, 0x0035392E, 0x0034382D, 0x0035392E, 0x00363A2F, 0x00363A2E, 0x00363A2E, 0x00363A2E, 0x00363A2E, 0x00363A2E, 0x0035392D, 0x0035392D, 0x0034382C, 0x0036382C, 0x0035372B, 0x0035372B, 0x0035372B, 0x0037392D,
        0x00383A2E, 0x00383A2E, 0x0037392D, 0x00363D30, 0x00353C2F, 0x0032392C, 0x0030372A, 0x0030372A, 0x0031382B, 0x00333A2D, 0x00343B2E, 0x0030362B, 0x0033392E, 0x0032382D, 0x0032362B, 0x0031352A, 0x0035362C, 0x0034352B, 0x00313228, 0x0030332A,
        0x0039342B, 0x00323025, 0x002C3227, 0x002B3027, 0x002F302E, 0x00152B29, 0x000D4441, 0x0046877E, 0x004F675D, 0x00988F82, 0x00DCD0C4, 0x00F5ECE2, 0x00CDBDB0, 0x00AD9C81, 0x00C4BD92, 0x00AEA387, 0x009C9778, 0x009F9175, 0x00977C67, 0x00665A4E,
        0x004E6E69, 0x005A999D, 0x00044855, 0x00134E58, 0x00004152, 0x00004B62, 0x00004363, 0x00033B5E, 0x00134563, 0x00074154, 0x0000414B, 0x000F5D82, 0x002CABD1, 0x001295BD, 0x00014F74, 0x00103F5A, 0x0000424F, 0x00003E53, 0x00193D61, 0x0001445B,
        0x00024457, 0x00054655, 0x00044358, 0x00054460, 0x0003485C, 0x00095A5D, 0x002C8476, 0x00515B5B, 0x00000502, 0x00010500, 0x00202117, 0x002B2B1F, 0x00292B1F, 0x002A2E23, 0x0021261D, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFCFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00151A18, 0x000A0E09, 0x000A0905, 0x00181010, 0x001F1717, 0x001C1A1A, 0x00525D5B, 0x00809A94, 0x006C9189, 0x00405955, 0x00495452, 0x00838585, 0x008C9696, 0x004B6D6D,
        0x000C4046, 0x000E4953, 0x00104756, 0x0006455A, 0x0004495D, 0x00024457, 0x00184356, 0x005C6A7C, 0x00655E6B, 0x0050464C, 0x00585453, 0x00424E58, 0x00607779, 0x006C8E8D, 0x0029555C, 0x000B3C52, 0x000F4060, 0x000D4060, 0x000D435C, 0x0016485F,
        0x00044561, 0x00004053, 0x001B4A52, 0x009DB0BD, 0x00C4CDE1, 0x00546268, 0x00263D27, 0x0044494C, 0x000E2729, 0x002B6269, 0x00338295, 0x0030809D, 0x003A738C, 0x00243A40, 0x00514C43, 0x00343728, 0x00344E5A, 0x00487796, 0x00568194, 0x00415C52,
        0x00476350, 0x0021575E, 0x002D7EA4, 0x001187C2, 0x003AA8E2, 0x001173A9, 0x00003F6C, 0x00003F5C, 0x00054D59, 0x0007595A, 0x002D8A83, 0x006FB9B5, 0x006EB6B0, 0x0083CDC7, 0x0065AFA9, 0x002A7773, 0x000E6061, 0x00005157, 0x00004F59, 0x00003860,
        0x00005C7F, 0x0028A9D0, 0x002FAFDF, 0x000A5F87, 0x000A364D, 0x0014465C, 0x0008597E, 0x00005F8D, 0x000E6286, 0x00084E65, 0x00003B4F, 0x0001415A, 0x00034661, 0x00014459, 0x00094757, 0x00024457, 0x00024457, 0x00014356, 0x00014356, 0x00014356,
        0x00014356, 0x00024457, 0x00024457, 0x00014356, 0x00014356, 0x00014356, 0x00004255, 0x00004255, 0x00004255, 0x00004255, 0x00004255, 0x0000414E, 0x00053C51, 0x00003953, 0x000F5876, 0x00357D9B, 0x00285D78, 0x00618DA4, 0x006198A7, 0x002F5E6C,
        0x0041707E, 0x00326470, 0x00457B86, 0x005C9AA2, 0x007CC4CB, 0x0076C7CC, 0x00388F91, 0x0084D4DF, 0x00529CA8, 0x0068B2BE, 0x006FBAC8, 0x003B7686, 0x0033536A, 0x0044647B, 0x0070A3B7, 0x005FA5A5, 0x004D8B95, 0x00498C9B, 0x0059A8B3, 0x0071B5BC,
        0x002F616D, 0x00265A71, 0x0035799C, 0x00024254, 0x00024254, 0x00024254, 0x00024254, 0x00024254, 0x00024254, 0x00024254, 0x00024254, 0x00004558, 0x00014659, 0x00004354, 0x00003F51, 0x000B495B, 0x00033F4F, 0x000A4555, 0x00003B4B, 0x0000414E,
        0x00054956, 0x00034655, 0x00004150, 0x00034355, 0x00064357, 0x00054256, 0x0008445A, 0x0012425A, 0x00093B3B, 0x008BAAA3, 0x009CBCC1, 0x004A818A, 0x0046696D, 0x00546062, 0x004B686D, 0x00646B66, 0x00656C67, 0x00646B66, 0x00646A65, 0x00656B66,
        0x00636762, 0x005B5F5A, 0x00656964, 0x00486C66, 0x00305E58, 0x00355C5E, 0x005A7480, 0x00446273, 0x00195164, 0x00004357, 0x00003F54, 0x00052635, 0x00232A2D, 0x00443B31, 0x00373727, 0x0025291E, 0x00332F2A, 0x003D3A32, 0x00354030, 0x00373B30,
        0x00373B30, 0x00373B30, 0x0035392E, 0x0034382D, 0x0035392E, 0x00373B30, 0x00393D32, 0x00363C31, 0x00373D32, 0x00373D32, 0x00383E33, 0x00383E33, 0x00373D32, 0x00363C31, 0x00353B30, 0x0033372C, 0x0034382D, 0x00363A2F, 0x00373B30, 0x00393D32,
        0x00393D32, 0x00383C31, 0x00373B30, 0x00343E32, 0x00343E32, 0x00323C30, 0x00323C30, 0x00323C30, 0x00333D31, 0x00353F33, 0x00364034, 0x00363C31, 0x00373D32, 0x00343A2F, 0x0032362B, 0x00303429, 0x0034352B, 0x0034352B, 0x00323329, 0x002F342B,
        0x0039342B, 0x00323025, 0x002D3328, 0x002D3027, 0x00312F2E, 0x00152A28, 0x000D423F, 0x00366866, 0x0047564E, 0x00998C7E, 0x00A39484, 0x00AA9D8F, 0x00836F5E, 0x00AA9879, 0x00DFDAAD, 0x00B9AA8A, 0x006A6342, 0x00A39579, 0x00B19682, 0x0074685C,
        0x0046645F, 0x004B8688, 0x0005444C, 0x000E4358, 0x00004457, 0x0000495C, 0x0000435C, 0x000C415C, 0x000C405E, 0x00004762, 0x00005F77, 0x002AA2DD, 0x002F96BD, 0x00005267, 0x00003C48, 0x00044659, 0x0005405A, 0x000E415B, 0x00093B4F, 0x0002455C,
        0x00024457, 0x00054655, 0x00044358, 0x00054460, 0x0002475B, 0x00095A5D, 0x002B8375, 0x004D5757, 0x00000401, 0x00040802, 0x001E1F15, 0x0026261A, 0x0027291D, 0x00282C21, 0x0022271E, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFCFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00131816, 0x0010140F, 0x000A0703, 0x00130C09, 0x00160F0C, 0x001A1B19, 0x00415451, 0x00294E4A, 0x000A3936, 0x00184150, 0x001B3C4B, 0x00294351, 0x00224150, 0x00164150,
        0x00094154, 0x000C465C, 0x00033B56, 0x000D4158, 0x00003C54, 0x00003E56, 0x00003A50, 0x00114355, 0x00164350, 0x00194C4F, 0x000E4847, 0x00193B4B, 0x00163F48, 0x001C4F52, 0x000F4752, 0x000C455E, 0x00013C5C, 0x00003C58, 0x00084A5D, 0x00154660,
        0x00003C55, 0x00084D5E, 0x00123D46, 0x00405A6B, 0x00708BA6, 0x0037515D, 0x00334332, 0x0039413A, 0x000A2620, 0x00296261, 0x000F6068, 0x00004B5D, 0x000A4755, 0x000C2521, 0x006D6C58, 0x0037432F, 0x00194049, 0x000D4A6A, 0x00114D63, 0x001F4D47,
        0x00568477, 0x002F7582, 0x00187AA4, 0x001FAAE3, 0x00228ABF, 0x00003865, 0x00054060, 0x00004355, 0x001E7075, 0x0097DEDB, 0x00C2FBF3, 0x00E4F4ED, 0x00ECFFF9, 0x00E0F9F5, 0x00D4F6F5, 0x00C7F7FD, 0x008CCBD9, 0x00307C92, 0x0000445E, 0x00164C6A,
        0x00003E5B, 0x0000537D, 0x00269FD7, 0x00309ECE, 0x00004962, 0x00054151, 0x00023F59, 0x0000374F, 0x00003F4E, 0x000D444D, 0x000E444F, 0x00064357, 0x00004059, 0x00004055, 0x00014251, 0x00024457, 0x00024457, 0x00024457, 0x00014356, 0x00014356,
        0x00024457, 0x00024457, 0x00024457, 0x00014356, 0x00014356, 0x00014356, 0x00014356, 0x00004255, 0x00004255, 0x00004255, 0x00004255, 0x00014754, 0x000A4358, 0x00003A54, 0x00095270, 0x002F7593, 0x0020506C, 0x00406A81, 0x00295C6C, 0x002F4561,
        0x00384E6A, 0x00455B77, 0x003D5670, 0x002E4963, 0x0043637A, 0x003A5C73, 0x00284D63, 0x002C5768, 0x004B7183, 0x00396376, 0x003F7183, 0x00436A80, 0x003A4E67, 0x00364E66, 0x0038677D, 0x0042666E, 0x00395566, 0x002B4D64, 0x00356577, 0x00366370,
        0x00365767, 0x00375F7B, 0x002F6E94, 0x00024254, 0x00024254, 0x00024254, 0x00024254, 0x00024254, 0x00024254, 0x00024254, 0x00024254, 0x00004658, 0x00004557, 0x00004255, 0x00014355, 0x000F4D5F, 0x00054053, 0x00084051, 0x000A4253, 0x00034557,
        0x000A4C5E, 0x00034557, 0x00003E50, 0x00034355, 0x00084559, 0x00044155, 0x00054256, 0x00003D54, 0x00064B48, 0x0078AA9E, 0x0077AAAC, 0x004C969C, 0x001F585A, 0x00365B5F, 0x002E656E, 0x002C5B58, 0x002F5E5B, 0x0034615E, 0x002A5754, 0x002F5A57,
        0x00325D5A, 0x002D5855, 0x00375F5D, 0x003E5459, 0x0026474A, 0x00405D62, 0x006C7A86, 0x00395060, 0x00043747, 0x00003F52, 0x0000394E, 0x00052635, 0x0022292C, 0x0040372D, 0x00313121, 0x001E2217, 0x002D2924, 0x0038352D, 0x00313C2C, 0x00363A2F,
        0x00363A2F, 0x0035392E, 0x0033372C, 0x0033372C, 0x0035392E, 0x00393D32, 0x003D4136, 0x00393F34, 0x00393F34, 0x003A4035, 0x003B4136, 0x003B4136, 0x003B4136, 0x003A4035, 0x00393F34, 0x0032362B, 0x0035392E, 0x00393D32, 0x003C4035, 0x003C4035,
        0x003B3F34, 0x003A3E33, 0x00383C31, 0x00343E32, 0x00353F33, 0x00364034, 0x00374135, 0x00384236, 0x00394337, 0x003A4438, 0x003A4438, 0x003B4136, 0x003A4035, 0x00363C31, 0x0031352A, 0x002F3328, 0x0033342A, 0x0034352B, 0x0033342A, 0x002F342B,
        0x0038362C, 0x00343227, 0x0030362B, 0x0032332A, 0x0034302F, 0x00152726, 0x000B3C3A, 0x00346367, 0x002B3A36, 0x00857C6E, 0x00837765, 0x00A89989, 0x00846C5A, 0x00846F53, 0x00CDCA9E, 0x009C8B6A, 0x007C7352, 0x00C0B197, 0x00A18878, 0x0060574E,
        0x00415E5B, 0x003C7577, 0x00034147, 0x00073B5F, 0x000A455F, 0x00034151, 0x000E4854, 0x000C4352, 0x0000344F, 0x00006184, 0x0028A6CF, 0x001891C9, 0x0000446C, 0x000F4153, 0x00064C53, 0x0000414D, 0x000D435C, 0x000F425C, 0x0000495B, 0x0002455C,
        0x00034558, 0x00054655, 0x00044358, 0x00054460, 0x0002475B, 0x0008595C, 0x002B8375, 0x003C4646, 0x00000200, 0x00050903, 0x00202117, 0x0027271B, 0x00282A1E, 0x0025291E, 0x001E231A, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFCFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00121715, 0x000D1210, 0x000A0905, 0x0017110C, 0x001A1611, 0x00222823, 0x004B6663, 0x001B4C4A, 0x00054343, 0x00093F58, 0x000F4158, 0x000C3A52, 0x000C3C54, 0x00134B64,
        0x00003C5A, 0x0000385B, 0x000E4D73, 0x0020637C, 0x001F6681, 0x00125F7A, 0x00004B65, 0x00004860, 0x00003D50, 0x00004350, 0x00054A53, 0x0014455F, 0x00083E4F, 0x0006414B, 0x00064252, 0x0005415E, 0x00003958, 0x00003C57, 0x00024A5C, 0x0001445D,
        0x00003C56, 0x001B4558, 0x001B3C4B, 0x0015536B, 0x00439ABC, 0x001A4F64, 0x003A3233, 0x002A382C, 0x00363E34, 0x00AFBCBA, 0x007EACB3, 0x0002505D, 0x0000434D, 0x00253D3B, 0x0069554A, 0x00334F3C, 0x000D3F45, 0x0000415F, 0x00003E5A, 0x0002444F,
        0x004A8A8F, 0x003D8EA3, 0x00187AA2, 0x0028A9E2, 0x001C70A0, 0x00042C4F, 0x00183D51, 0x00417F89, 0x008DD4D7, 0x00BAE2E1, 0x00A2A7A6, 0x00D4D0AD, 0x00E6E4C2, 0x00E4E9CA, 0x00ECFBE0, 0x00C2E3CE, 0x00A8DED1, 0x00A0EAE4, 0x00419593, 0x00044553,
        0x00134E5E, 0x00003A5F, 0x000B74AD, 0x0034AEE2, 0x0000546F, 0x00004957, 0x000B4054, 0x000B4854, 0x000C4348, 0x00164648, 0x00154852, 0x00064155, 0x00004059, 0x0002475B, 0x00074857, 0x00004358, 0x00004358, 0x00004257, 0x00004257, 0x00004257,
        0x00004257, 0x00004358, 0x00004358, 0x00024457, 0x00024457, 0x00024457, 0x00014356, 0x00014356, 0x00014356, 0x00014356, 0x00004255, 0x0000424E, 0x000D485C, 0x00023D57, 0x000C5472, 0x004283A2, 0x0026506D, 0x0034536C, 0x002A5264, 0x00505679,
        0x00434C6E, 0x00354465, 0x00435776, 0x00384C6B, 0x003C4E6B, 0x004D5B78, 0x004A5573, 0x003E4E65, 0x0049556D, 0x0030475D, 0x002B4D64, 0x00314D65, 0x00475670, 0x003F5670, 0x00194A60, 0x00374C5B, 0x004E5870, 0x003E4967, 0x0037506A, 0x00344D61,
        0x00405269, 0x00315476, 0x00407EA7, 0x00034355, 0x00034355, 0x00034355, 0x00034355, 0x00034355, 0x00034355, 0x00034355, 0x00034355, 0x0001465A, 0x00004256, 0x0005495C, 0x00034558, 0x00054355, 0x000A4558, 0x000F495C, 0x000A4555, 0x00034558,
        0x0007495C, 0x00034558, 0x00014054, 0x0007465A, 0x000B495B, 0x00054355, 0x00034153, 0x000A3B5B, 0x0014464C, 0x006C8B84, 0x00628085, 0x0040757F, 0x0012383D, 0x003E5158, 0x002A515F, 0x00403E4A, 0x00373541, 0x003D3B47, 0x00393541, 0x003F3B47,
        0x00403946, 0x0038313E, 0x003C3542, 0x004E4D51, 0x0030393C, 0x00333B3B, 0x005B575C, 0x00485155, 0x0021454B, 0x00154A54, 0x000E3E4A, 0x00032D3A, 0x001D2A2C, 0x003A382D, 0x00363929, 0x002A2E23, 0x00332F2A, 0x0036332B, 0x002D3727, 0x0035392E,
        0x0034382D, 0x0033372C, 0x0032362B, 0x0032362B, 0x0034382D, 0x00383C31, 0x003C4035, 0x00363E33, 0x00363E33, 0x00373F34, 0x00373F34, 0x00373F34, 0x00373F34, 0x00373F34, 0x00373F34, 0x002F352A, 0x0032382D, 0x00373D32, 0x00393F34, 0x003A4035,
        0x00383E33, 0x00363C31, 0x00353B30, 0x00333B30, 0x00343C31, 0x00363E33, 0x00384035, 0x003A4237, 0x003A4237, 0x003A4237, 0x003A4237, 0x003B4136, 0x003A4035, 0x00353B30, 0x0031352A, 0x002E3227, 0x0033342A, 0x0034352B, 0x0033342A, 0x002C342A,
        0x0038362C, 0x00353328, 0x0032382D, 0x0034352C, 0x0035302F, 0x00172524, 0x00093836, 0x00275965, 0x002F4445, 0x004B4D41, 0x00534F3D, 0x00ADA090, 0x00C0A696, 0x00AE9B80, 0x00BFBF97, 0x00928160, 0x009B9375, 0x00978A74, 0x00654F44, 0x0049423F,
        0x00405F60, 0x00336D72, 0x0005434B, 0x000A4063, 0x00093E59, 0x000C4253, 0x000A4450, 0x00003C4A, 0x000E6782, 0x0034A0CA, 0x001A90C4, 0x00004B68, 0x0000375A, 0x00003D5F, 0x00074458, 0x000A464C, 0x000D474C, 0x00004457, 0x00004A6A, 0x0003465D,
        0x00034558, 0x00054655, 0x00044358, 0x00054460, 0x0002475B, 0x0008595C, 0x002A8274, 0x00434D4D, 0x00000200, 0x00060A04, 0x00212218, 0x002A2A1E, 0x002E3024, 0x002C3025, 0x00292E25, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFCFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00101513, 0x00070F0E, 0x00090D08, 0x0014110C, 0x0017150D, 0x000C1812, 0x00325551, 0x000E4748, 0x0000484A, 0x00064056, 0x00033D53, 0x00033D53, 0x00053F55, 0x00013E58,
        0x0000405F, 0x00185980, 0x003879A5, 0x00317592, 0x0029718F, 0x003885A5, 0x002E7FA0, 0x00186383, 0x0000425F, 0x000B415A, 0x00103E56, 0x00093C5D, 0x000D435C, 0x000E4455, 0x00063D52, 0x00023857, 0x0003395C, 0x0006435D, 0x0006485A, 0x00003D58,
        0x00114964, 0x001F4158, 0x00183B4F, 0x00005372, 0x0029ABD6, 0x00004B6F, 0x00382C3E, 0x00202B28, 0x005D5C58, 0x00B4B4B4, 0x0077949D, 0x00357789, 0x003A8091, 0x004F737D, 0x00605F63, 0x00476B5B, 0x003C7076, 0x00377E99, 0x002C7DA0, 0x00287897,
        0x003E8BA5, 0x0030809D, 0x000E6285, 0x000C9AD7, 0x001E89B5, 0x0000455B, 0x00135C60, 0x0074C8C4, 0x0082CECA, 0x00648882, 0x00A8A69E, 0x00D8C8BB, 0x00FFFFF0, 0x00F5E6D6, 0x00F4EBDD, 0x00FEFFF4, 0x00C3D5CE, 0x00A9CCC8, 0x00AFDEDC, 0x00237471,
        0x0006464A, 0x00003E5A, 0x001674A9, 0x003EB2E7, 0x00004C68, 0x00004454, 0x00084051, 0x00004156, 0x00033E4E, 0x000D434E, 0x000D4556, 0x0001415A, 0x00003F5C, 0x00004357, 0x0002444F, 0x00004358, 0x00004358, 0x00004257, 0x00004257, 0x00004257,
        0x00004257, 0x00004358, 0x00004358, 0x00034558, 0x00024457, 0x00024457, 0x00024457, 0x00024457, 0x00014356, 0x00014356, 0x00014356, 0x00004450, 0x000A475B, 0x00003B55, 0x00084B6A, 0x00427D9D, 0x002C4E6C, 0x003B506B, 0x00435E72, 0x003E4965,
        0x00455A75, 0x00355971, 0x005C8EA2, 0x0043788C, 0x001F5163, 0x00375F72, 0x0027485C, 0x00344C62, 0x003A4F65, 0x003C5B70, 0x00457085, 0x003B6278, 0x00354C66, 0x0032546C, 0x004E899D, 0x00558091, 0x00334E68, 0x003B4E6F, 0x00415977, 0x00354B64,
        0x00455774, 0x003E658B, 0x00266D99, 0x00044456, 0x00044456, 0x00044456, 0x00044456, 0x00044456, 0x00044456, 0x00044456, 0x00044456, 0x0004455A, 0x00034459, 0x000A4B60, 0x00014054, 0x00003D51, 0x00094759, 0x00074557, 0x00044254, 0x00014257,
        0x0004455A, 0x00034459, 0x00044357, 0x00064559, 0x00084658, 0x00054355, 0x00044254, 0x00143C66, 0x00123947, 0x00526463, 0x00586A71, 0x00376069, 0x00273F45, 0x00373E47, 0x00001B29, 0x0007182B, 0x00041528, 0x00152639, 0x0009182B, 0x00051427,
        0x00051326, 0x00031124, 0x0009172A, 0x00233540, 0x00234349, 0x00264548, 0x003F5456, 0x00335054, 0x00083C42, 0x00003E48, 0x00083F4E, 0x00043844, 0x00152A2B, 0x00313529, 0x00363E2D, 0x0031392E, 0x003C3833, 0x003D3730, 0x00363B2C, 0x0032362B,
        0x0032362B, 0x0032362B, 0x0032362B, 0x0031352A, 0x0031352A, 0x0033372C, 0x0035392E, 0x0030382E, 0x0030382E, 0x0030382E, 0x0030382E, 0x0031392F, 0x0031392F, 0x00323A30, 0x00323A30, 0x002D3229, 0x002F342B, 0x0033382F, 0x00343930, 0x00343930,
        0x0032372E, 0x0032372E, 0x0033382F, 0x0032372E, 0x0033382F, 0x0033382F, 0x00343930, 0x00353A31, 0x00353A31, 0x00353A31, 0x00353A31, 0x00353B30, 0x00353B30, 0x0032382D, 0x00303429, 0x002F3328, 0x0033342A, 0x0034352B, 0x00323329, 0x002A3329,
        0x0036352B, 0x00343227, 0x0032382D, 0x0037352D, 0x00383030, 0x00182424, 0x000B3736, 0x00064053, 0x0025474D, 0x0025352A, 0x00313726, 0x00584F41, 0x009E8375, 0x00BFAA94, 0x0090926E, 0x008A7859, 0x007A7358, 0x00504634, 0x0057443F, 0x005A5759,
        0x0046696D, 0x001C585E, 0x00003E48, 0x00094555, 0x000B4054, 0x000C445D, 0x00004762, 0x0000617E, 0x00309EC0, 0x003B9AC5, 0x00004776, 0x0007454F, 0x0001465A, 0x00003E5C, 0x000F415D, 0x00073E4D, 0x0000444C, 0x00025060, 0x00003653, 0x0003465D,
        0x00034558, 0x00064756, 0x00044358, 0x00054460, 0x0002475B, 0x0008595C, 0x002A8274, 0x005E6868, 0x00000300, 0x00030701, 0x001F2016, 0x002C2C20, 0x002E3024, 0x002B2F24, 0x0030352C, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFCFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00101513, 0x0006110F, 0x000A100B, 0x0011110B, 0x001D1E15, 0x000A1A13, 0x002B534E, 0x000D4F4E, 0x00004548, 0x00104859, 0x00043F4F, 0x000B4757, 0x00024052, 0x00003A52,
        0x002A6886, 0x003D7CA2, 0x000E5079, 0x00344A73, 0x00294972, 0x0013446C, 0x0016577E, 0x003C88AC, 0x001B6385, 0x00003653, 0x000C4461, 0x00103D63, 0x000E3D5C, 0x000C3D53, 0x0014425A, 0x00143F60, 0x000E3B60, 0x0011435F, 0x000E4657, 0x000E3F5F,
        0x0008425F, 0x000A3D51, 0x000C4156, 0x0000466C, 0x002BB1E7, 0x0000507E, 0x000D142D, 0x001D2025, 0x00151E21, 0x002C4547, 0x0015424D, 0x0010495F, 0x0008425F, 0x00205269, 0x00204B5A, 0x002C5147, 0x002E5E62, 0x00155770, 0x00004C75, 0x00005380,
        0x00004F78, 0x00014B6F, 0x00004664, 0x0033A5EC, 0x001375A5, 0x00003C4E, 0x005DA5A5, 0x0083C3BD, 0x00527A75, 0x0093968D, 0x00E3C7BC, 0x00DCE4E4, 0x00F4F7F5, 0x00FBF8F3, 0x00F5F0E7, 0x00FFFFF8, 0x00E8F1E7, 0x00AABFB6, 0x009AB9B0, 0x005CBAAF,
        0x00004A43, 0x0000485A, 0x001571A2, 0x0043ABE0, 0x0000496A, 0x00004455, 0x00074353, 0x00003E63, 0x00004361, 0x0005455E, 0x0003425E, 0x00003F60, 0x00003D5E, 0x00004357, 0x00074851, 0x00004358, 0x00004257, 0x00004257, 0x00004156, 0x00004156,
        0x00004257, 0x00004257, 0x00004358, 0x00034558, 0x00034558, 0x00034558, 0x00024457, 0x00024457, 0x00024457, 0x00024457, 0x00024457, 0x0000434E, 0x00014054, 0x0007425C, 0x000F506F, 0x00427899, 0x00355170, 0x0046526E, 0x00405368, 0x003B5365,
        0x002C5362, 0x00387581, 0x006CBDC4, 0x0067C2C7, 0x0057AEB2, 0x0056A4AA, 0x00549AA1, 0x005C879A, 0x00365E71, 0x0019485D, 0x005F9AAD, 0x0057899F, 0x001E425A, 0x003E6A81, 0x0066A9BE, 0x0067B0BE, 0x00245771, 0x002B5072, 0x002E4F70, 0x0038536E,
        0x00324A68, 0x002E5C85, 0x002575A4, 0x00044456, 0x00044456, 0x00044456, 0x00044456, 0x00044456, 0x00044456, 0x00044456, 0x00044456, 0x00074359, 0x000D495F, 0x0009485D, 0x00003D51, 0x0008475B, 0x000B4A5E, 0x00003C4E, 0x0006485A, 0x0003435B,
        0x0003435B, 0x00034459, 0x00044358, 0x00014054, 0x00034153, 0x00054355, 0x00064456, 0x00003B65, 0x00004652, 0x00134642, 0x000E3F41, 0x00003E41, 0x000E4746, 0x00183E40, 0x00023E44, 0x00003849, 0x0003495A, 0x0024697A, 0x00064B5C, 0x00003748,
        0x00003D4F, 0x000A4C5E, 0x00155769, 0x0017556D, 0x00135F71, 0x0005545F, 0x001A5C67, 0x00206771, 0x00065F6D, 0x00056376, 0x000C607A, 0x00144F59, 0x00163232, 0x00293225, 0x002E3A28, 0x002C3429, 0x0034302B, 0x00342E27, 0x002F3425, 0x002F3328,
        0x0031352A, 0x0032362B, 0x0032362B, 0x00303429, 0x002F3328, 0x002E3227, 0x002F3328, 0x002B3329, 0x002B3329, 0x002A3228, 0x002A3228, 0x002A3228, 0x002B3329, 0x002D352B, 0x002E362C, 0x002B3027, 0x002D3229, 0x002F342B, 0x002F342B, 0x002E332A,
        0x002D3229, 0x002F342B, 0x0030352C, 0x0032352C, 0x0031342B, 0x0031342B, 0x0030332A, 0x0030332A, 0x0030332A, 0x0031342B, 0x0031342B, 0x002E3429, 0x0030362B, 0x0030362B, 0x002F3328, 0x002F3328, 0x0033342A, 0x0033342A, 0x00313228, 0x002A3329,
        0x0035342A, 0x00333126, 0x0033372C, 0x0037352D, 0x003B3131, 0x001A2626, 0x000F3938, 0x0000384D, 0x00214A53, 0x00223931, 0x00293626, 0x003E3629, 0x0070564A, 0x0063503B, 0x00646747, 0x00AE9E81, 0x00706B52, 0x00484132, 0x00716260, 0x005D5D63,
        0x00365B63, 0x00003B45, 0x0006434F, 0x00034540, 0x0018505B, 0x00013E5E, 0x00005380, 0x0027A4D1, 0x001F98C2, 0x0000446A, 0x0013385E, 0x00004B56, 0x00043F48, 0x001C4954, 0x000C3E52, 0x00004061, 0x00004D6D, 0x00004256, 0x00194E58, 0x0003465D,
        0x00034558, 0x00064756, 0x00044358, 0x00054460, 0x0001465A, 0x0007585B, 0x002A8274, 0x006C7676, 0x00000300, 0x00000200, 0x001E1F15, 0x002C2C20, 0x0027291D, 0x001E2217, 0x00242920, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFCFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00131816, 0x000C0D0B, 0x00010A07, 0x000F130E, 0x001E1714, 0x00161D1A, 0x0037625F, 0x000E504F, 0x0004474A, 0x000F425C, 0x000A4057, 0x000B3A56, 0x000A355C, 0x0012537F,
        0x00247DA2, 0x00074D64, 0x003C5666, 0x005C8BA6, 0x0079B6C4, 0x0067A7AB, 0x0030616B, 0x00225068, 0x004380A2, 0x00115376, 0x00043C5F, 0x000A425D, 0x0009415C, 0x0008405B, 0x00073F5A, 0x00073F5A, 0x0009415C, 0x000B435E, 0x000D4560, 0x00114661,
        0x000D435A, 0x000E4358, 0x00053F55, 0x00004362, 0x003688B2, 0x0040A1DB, 0x00004487, 0x00003038, 0x00003941, 0x0000424A, 0x0000474F, 0x0000464E, 0x0000454D, 0x0000464E, 0x00004850, 0x0007495B, 0x00024554, 0x0000454D, 0x00004C52, 0x00004B52,
        0x00004151, 0x00075369, 0x002A7792, 0x0040BDE9, 0x000E6083, 0x00114F61, 0x007EC7CB, 0x0048797B, 0x00655E61, 0x00CFB6AC, 0x0097967C, 0x006D724B, 0x00938A69, 0x00C0A890, 0x009C8674, 0x00EDE5D4, 0x00FFFFF4, 0x00C2BCAF, 0x00928478, 0x0069A9AA,
        0x00105C62, 0x0000465D, 0x000F729E, 0x0035A2D8, 0x00004374, 0x00123F54, 0x00004B3E, 0x00044358, 0x00024156, 0x00034257, 0x00044358, 0x00034257, 0x00014055, 0x00024156, 0x00054459, 0x00063F5E, 0x00063F5E, 0x00063F5E, 0x00063F5E, 0x00063F5E,
        0x00063F5E, 0x00063F5E, 0x00063F5E, 0x0002415D, 0x0003425E, 0x0003425E, 0x0004435F, 0x0004435F, 0x0003425E, 0x0003425E, 0x0002415D, 0x00004350, 0x0000485A, 0x0000415C, 0x00084D6E, 0x00417C9C, 0x001B4961, 0x00395A6A, 0x00405963, 0x003C5363,
        0x00335664, 0x003F7580, 0x006EB8BE, 0x0076CFD3, 0x008DEAEB, 0x0075D2D3, 0x0052AEAF, 0x0074A8B5, 0x00245865, 0x001D525F, 0x00528C98, 0x005794A0, 0x004B8B96, 0x00337580, 0x0066ABB5, 0x00578E9D, 0x002F596C, 0x00364E66, 0x00414C6A, 0x003E4D6D,
        0x00325374, 0x00225978, 0x00317997, 0x00054654, 0x00044553, 0x00044553, 0x00034452, 0x00034452, 0x00034452, 0x00034452, 0x00044553, 0x00054459, 0x00054459, 0x00054459, 0x00054459, 0x00054459, 0x00054459, 0x00054459, 0x00054459, 0x0002425A,
        0x0002425A, 0x0004425A, 0x0004425A, 0x0004425A, 0x0006425A, 0x0006425A, 0x0006425A, 0x00064150, 0x00064150, 0x00064150, 0x0005404F, 0x00043F4E, 0x00033E4D, 0x00023D4C, 0x00013C4B, 0x00074458, 0x00003B4E, 0x00307889, 0x00115463, 0x00003746,
        0x00468190, 0x001D6472, 0x00045864, 0x00125D77, 0x00105B75, 0x000E5973, 0x00105B75, 0x00135E78, 0x00145F79, 0x00115C76, 0x000F5A74, 0x00173B45, 0x00001C20, 0x00273834, 0x001A2316, 0x00363929, 0x001E2014, 0x00363C37, 0x0018201F, 0x0028382D,
        0x0016231B, 0x00343B36, 0x00191E1C, 0x002C2F2D, 0x00161D16, 0x00313B2F, 0x001A2417, 0x002D352E, 0x001F241B, 0x0031352A, 0x00212E20, 0x00182C1F, 0x00172C23, 0x001D2A28, 0x00292E2F, 0x001A271F, 0x00212E26, 0x0015221A, 0x00212C24, 0x001C271F,
        0x002E362F, 0x00131B14, 0x00333B34, 0x00191C13, 0x0034372E, 0x00161910, 0x0033362D, 0x0020231A, 0x002F3229, 0x0022251C, 0x002D3027, 0x001A261A, 0x00253125, 0x001F2B1F, 0x00243024, 0x00222E22, 0x001B271B, 0x00232F23, 0x001A261A, 0x00202E2A,
        0x001B261E, 0x002A2F20, 0x00272A1A, 0x002B3225, 0x001B2925, 0x00092028, 0x001E3B4A, 0x0004393C, 0x00114244, 0x001B4143, 0x001D3737, 0x00242F2D, 0x002E2D29, 0x00332721, 0x002D1D16, 0x00281E14, 0x00311E17, 0x004B3831, 0x0060645F, 0x00375F5D,
        0x00004144, 0x0000414D, 0x00004154, 0x0010445B, 0x00004053, 0x0000587A, 0x003799D9, 0x002990CE, 0x00004F68, 0x00004349, 0x00074752, 0x00054054, 0x00044155, 0x00064357, 0x00074458, 0x00064559, 0x00064559, 0x00044659, 0x00034558, 0x00004356,
        0x00014453, 0x00054654, 0x00054458, 0x0005455E, 0x0001465A, 0x00045558, 0x00257D70, 0x004C5350, 0x00010805, 0x00000300, 0x00151913, 0x0033362D, 0x00282C21, 0x002B2D21, 0x002D2D21, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFCFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00121715, 0x00111210, 0x00030C09, 0x000C100B, 0x001D1613, 0x00181F1C, 0x003C6764, 0x00125453, 0x0005484B, 0x00083D58, 0x000F4158, 0x000F455E, 0x00003658, 0x001E628D,
        0x0027638D, 0x00144964, 0x005E8F9D, 0x009FFAFF, 0x009EFFFF, 0x009DFBF7, 0x0071B5BA, 0x00225B71, 0x002B6B8D, 0x001F6184, 0x00003558, 0x0008405B, 0x0008405B, 0x0009415C, 0x0009415C, 0x0009415C, 0x000A425D, 0x000A425D, 0x000A425D, 0x00053D5A,
        0x000B415A, 0x000A4156, 0x000E475C, 0x00003B57, 0x00004A6F, 0x003089BB, 0x004CADE5, 0x00218FCB, 0x002694D0, 0x002C9AD6, 0x002D9BD7, 0x002B99D5, 0x002997D3, 0x002A98D4, 0x002C9AD6, 0x002795D1, 0x002A99D1, 0x00289BCE, 0x00279ACD, 0x002A9ED3,
        0x002FA2DB, 0x0033A5E4, 0x0037A7ED, 0x000D6593, 0x00003958, 0x00246B79, 0x008DCACE, 0x001F4246, 0x00565B5A, 0x00C8C0B3, 0x007E7D61, 0x0085855D, 0x00B3A785, 0x00B49F83, 0x00806E57, 0x009C9582, 0x00CFCDBB, 0x00A7A091, 0x0079695D, 0x004D8082,
        0x00195B60, 0x00003A4E, 0x002380A7, 0x003DBBEB, 0x00004C79, 0x00033F5C, 0x0007464E, 0x0000415C, 0x0000415C, 0x0000405B, 0x0000435E, 0x00014661, 0x0000405B, 0x00003D58, 0x0000435E, 0x00004054, 0x00004054, 0x00004054, 0x00004054, 0x00004054,
        0x00004054, 0x00004054, 0x00004054, 0x00004153, 0x00004153, 0x00004254, 0x00004254, 0x00004254, 0x00004254, 0x00004153, 0x00004153, 0x00054452, 0x00044357, 0x00003D59, 0x00104F71, 0x004880A3, 0x00214D6C, 0x0037566F, 0x00385165, 0x00495470,
        0x003C5069, 0x0033536A, 0x00416E83, 0x0035697A, 0x00447889, 0x003B6C7C, 0x00305C6D, 0x00406279, 0x001F445A, 0x00264D63, 0x00497288, 0x00457287, 0x00437287, 0x002D5F73, 0x0044778B, 0x00396E82, 0x00265067, 0x00354D69, 0x003F4E6E, 0x00384B6E,
        0x002D5072, 0x00275D7E, 0x00367B9C, 0x00004755, 0x00004654, 0x00004654, 0x00004654, 0x00004654, 0x00004755, 0x00014856, 0x00014856, 0x00004654, 0x00004654, 0x00004654, 0x00004654, 0x00004654, 0x00004654, 0x00004654, 0x00004654, 0x00004553,
        0x00004553, 0x00004553, 0x00004553, 0x00004553, 0x00004453, 0x00004453, 0x00004453, 0x00034453, 0x00044554, 0x00034453, 0x00034453, 0x00024352, 0x00014251, 0x0000404F, 0x0000404F, 0x00003C4E, 0x00033A49, 0x004F7581, 0x006D7F8A, 0x003A4350,
        0x006A828E, 0x0019515C, 0x00055A62, 0x00074752, 0x0004444F, 0x0002424D, 0x0002424D, 0x0004444F, 0x00054550, 0x0004444F, 0x0002424D, 0x00063D4C, 0x00002D35, 0x00476F6E, 0x00315349, 0x004E6C61, 0x002B4A43, 0x00496B6A, 0x00103638, 0x004F6F64,
        0x0026453C, 0x0044645F, 0x00224241, 0x004F6F6E, 0x00244443, 0x00446660, 0x00254740, 0x004A595B, 0x003E504F, 0x00455B56, 0x003A4F47, 0x0041534C, 0x0040514D, 0x003A4C4B, 0x003F5456, 0x00354D4B, 0x0049615F, 0x00253D3B, 0x00526866, 0x001F3533,
        0x00526765, 0x00233836, 0x00516664, 0x0023413C, 0x0046645F, 0x0022403B, 0x004A6863, 0x0023413C, 0x003E5C57, 0x002A4843, 0x003F5D58, 0x00354C48, 0x003F5652, 0x00384F4B, 0x003D5450, 0x003C534F, 0x00364D49, 0x003D5450, 0x00344B47, 0x003C6060,
        0x001C3D39, 0x00415E55, 0x001C372D, 0x004E6D66, 0x000A3032, 0x000B3843, 0x00053749, 0x00043D46, 0x000A3E45, 0x000F3B42, 0x0014373B, 0x00193032, 0x001C2828, 0x001D2221, 0x001D1E1C, 0x00142020, 0x001B272B, 0x00334550, 0x002F5060, 0x000D4054,
        0x00003D4F, 0x00074353, 0x000A4253, 0x00003E56, 0x00085F7F, 0x0036A7CF, 0x002A96C0, 0x00004A74, 0x0000385C, 0x00074458, 0x0000464A, 0x00034054, 0x00044155, 0x00054256, 0x00054458, 0x00054458, 0x00034558, 0x00034558, 0x00034558, 0x00014558,
        0x00024554, 0x00074856, 0x00064559, 0x00074760, 0x0003485C, 0x0007585B, 0x00288073, 0x003F4643, 0x00000200, 0x00040A05, 0x00161A14, 0x00282B22, 0x00292D22, 0x00404236, 0x0049493D, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFCFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00121715, 0x000D0E0C, 0x00050E0B, 0x0010140F, 0x001D1613, 0x00101714, 0x00305B58, 0x000C4E4D, 0x0006494C, 0x00023D57, 0x000B3D54, 0x000A465C, 0x00003754, 0x002F749C,
        0x00315381, 0x00284E6E, 0x008ED2DF, 0x0080FDFF, 0x0071F3EC, 0x0095FFFD, 0x008DDCDF, 0x001D5B73, 0x001A5C7F, 0x00317598, 0x00054060, 0x00073F5A, 0x0008405B, 0x000A425D, 0x000B435E, 0x000B435E, 0x000A425D, 0x0009415C, 0x0008405B, 0x00084160,
        0x000A425D, 0x0001384D, 0x000D4459, 0x0009455B, 0x00003451, 0x00014F74, 0x002779A3, 0x001E82BC, 0x001F83BD, 0x002084BE, 0x001F83BD, 0x001D81BB, 0x001C80BA, 0x001D81BB, 0x001E82BC, 0x001785B5, 0x001A89B7, 0x001989B4, 0x001481AD, 0x001380AC,
        0x001A83B4, 0x00137BB0, 0x000468A2, 0x0002345E, 0x00003B53, 0x002D7A83, 0x0081B6B9, 0x0025393E, 0x005E6463, 0x00959888, 0x00848668, 0x00ABA07A, 0x00EEDEBA, 0x00D6C4A5, 0x009E9276, 0x008A866E, 0x00CFCBB8, 0x00AFA698, 0x00705E53, 0x00406164,
        0x00286569, 0x00013D4D, 0x00075475, 0x003BBBE4, 0x00199BC6, 0x00004D76, 0x00003659, 0x00034151, 0x00084656, 0x00044252, 0x00003E4E, 0x00024050, 0x00024050, 0x00024050, 0x00094757, 0x0007454F, 0x0007454F, 0x0007454F, 0x0007454F, 0x0007454F,
        0x0007454F, 0x0007454F, 0x0007454F, 0x0007464E, 0x0007464E, 0x0007464E, 0x0007464E, 0x0007464E, 0x0007464E, 0x0007464E, 0x0007464E, 0x00154950, 0x000E4350, 0x00043B50, 0x00164C6A, 0x00487B9B, 0x00265271, 0x00335670, 0x002F4E65, 0x00495273,
        0x00425171, 0x00354B67, 0x0037526D, 0x0027425C, 0x00354A65, 0x003A4761, 0x003F4863, 0x003B4C67, 0x00364964, 0x00364964, 0x00394E69, 0x0029425C, 0x00324D67, 0x002A455F, 0x002E4C65, 0x00205465, 0x00224B61, 0x002F4E65, 0x003B506B, 0x00344C6A,
        0x002A4E6C, 0x002A5F7A, 0x002F708C, 0x0004414F, 0x0004414F, 0x0004414F, 0x00054250, 0x00064351, 0x00074452, 0x00084553, 0x00094654, 0x00094850, 0x00094850, 0x00094850, 0x00094850, 0x00094850, 0x00094850, 0x00094850, 0x00094850, 0x00074A4D,
        0x00074A4D, 0x0009494D, 0x0009494D, 0x000A494D, 0x000A494D, 0x000A494D, 0x000C494D, 0x000C4352, 0x000D4453, 0x000D4453, 0x000C4352, 0x000B4251, 0x000A4150, 0x0009404F, 0x00083F4E, 0x000C404D, 0x000C4046, 0x003B6D69, 0x0033584E, 0x0016332A,
        0x00365955, 0x001D5556, 0x00438C90, 0x000B4A58, 0x00084755, 0x00044351, 0x00034250, 0x00044351, 0x00054452, 0x00054452, 0x00044351, 0x00084150, 0x00063B45, 0x0039696B, 0x00234E4B, 0x00325E57, 0x00204F4C, 0x00437678, 0x00245B60, 0x00456455,
        0x00204438, 0x00426C65, 0x002D5C59, 0x004B7D7D, 0x0019494A, 0x00376362, 0x00285251, 0x002E5B5F, 0x002C6564, 0x0033716B, 0x002A5C52, 0x003B5A51, 0x003D5751, 0x00345E57, 0x0039766C, 0x00396062, 0x003D6365, 0x002D5355, 0x003D6365, 0x0025484B,
        0x003D6063, 0x00294A4D, 0x00446568, 0x00214D4C, 0x003B6766, 0x00214D4C, 0x003D6968, 0x00214D4C, 0x00325E5D, 0x00255150, 0x00356160, 0x00335757, 0x003A5E5E, 0x00335757, 0x00365A5A, 0x00365A5A, 0x00335757, 0x00395D5D, 0x00305454, 0x003D6A6D,
        0x00275052, 0x003A625D, 0x00294F49, 0x0048706E, 0x001D4C50, 0x00104450, 0x00094152, 0x000B4249, 0x00053B42, 0x0008383E, 0x000F3A3D, 0x00123538, 0x000F2B2B, 0x000D2523, 0x00132825, 0x00162D2F, 0x000E3238, 0x000E3F4F, 0x00003249, 0x0003324E,
        0x001B445D, 0x00184354, 0x0016434E, 0x00005B75, 0x003FA4D1, 0x002490BA, 0x00005468, 0x00004457, 0x000F395E, 0x000C395A, 0x000E5154, 0x00034054, 0x00044155, 0x00034256, 0x00044357, 0x00044357, 0x00034558, 0x00024457, 0x00024457, 0x00014558,
        0x00024554, 0x00064755, 0x00064559, 0x00074760, 0x0002475B, 0x0007585B, 0x00288073, 0x00454C49, 0x00000200, 0x00000601, 0x0011150F, 0x0023261D, 0x002D3126, 0x003D3F33, 0x00323226, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFCFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00101513, 0x000A0B09, 0x00050E0B, 0x000F130E, 0x001D1613, 0x000F1613, 0x002D5855, 0x000D4F4E, 0x0006494C, 0x0000425B, 0x00023B51, 0x00044155, 0x00003E59, 0x0034759C,
        0x002E5B87, 0x001F4A6B, 0x0087BED3, 0x008EF9FC, 0x0089F8F4, 0x009AFAF4, 0x0078B9C2, 0x001B4D69, 0x001F5F82, 0x002C7093, 0x00003856, 0x00073F5A, 0x0008405B, 0x000A425D, 0x000B435E, 0x000B435E, 0x000A425D, 0x0009415C, 0x0008405B, 0x00054361,
        0x000D4862, 0x00084157, 0x000B4356, 0x000A4457, 0x00013D53, 0x00003E57, 0x00003855, 0x00003E52, 0x00003D51, 0x00003D51, 0x00003D51, 0x00003D51, 0x00003D51, 0x00003E52, 0x00003E52, 0x00003F4B, 0x00003D49, 0x0000424B, 0x0000434D, 0x0000404A,
        0x0000404E, 0x00034151, 0x00003949, 0x00164063, 0x00003347, 0x002C787E, 0x0074B1B3, 0x00183036, 0x006D686A, 0x00968F80, 0x00838869, 0x00D2BE9B, 0x00E0CDAA, 0x00C9BD9B, 0x00CAC3A2, 0x00B0AD91, 0x00AEAB96, 0x00887F71, 0x0074665A, 0x004C6365,
        0x000A4A4B, 0x0004414D, 0x00003550, 0x00006689, 0x0038B4DD, 0x002D93C4, 0x00004377, 0x00003D54, 0x0000435A, 0x00034960, 0x0002485F, 0x0000445B, 0x0000445B, 0x0000435A, 0x00003D54, 0x00003F5C, 0x00003F5C, 0x00003F5C, 0x00003F5C, 0x00003F5C,
        0x00003F5C, 0x00003F5C, 0x00003F5C, 0x0000415C, 0x0000405B, 0x00003F5A, 0x00003F5A, 0x00003F5A, 0x00003F5A, 0x0000405B, 0x0000415C, 0x00004259, 0x0000405B, 0x00003E60, 0x00065178, 0x003780AC, 0x002D719E, 0x003E7FAB, 0x003D7BA4, 0x002677A4,
        0x00287CA6, 0x002278A2, 0x00267EA7, 0x0020779F, 0x002B7BA4, 0x002B769D, 0x003278A0, 0x0031789E, 0x00347BA1, 0x002D749A, 0x002F789E, 0x00257096, 0x002C779D, 0x00267499, 0x00257398, 0x00257293, 0x002E7597, 0x00327096, 0x00397299, 0x0037729A,
        0x002F719A, 0x002B7AA1, 0x00227A9F, 0x0000405F, 0x0000405F, 0x00003F5E, 0x0000405F, 0x0000405F, 0x00014160, 0x00024261, 0x00034362, 0x0001415F, 0x0001415F, 0x0001415F, 0x0001415F, 0x0001415F, 0x0001415F, 0x0001415F, 0x0001415F, 0x0000455C,
        0x0000455C, 0x0001455C, 0x0001455C, 0x0002455C, 0x0002455C, 0x0004445C, 0x0004445C, 0x00013E5E, 0x00013E5E, 0x00013E5E, 0x00013E5E, 0x00013E5E, 0x00003D5D, 0x00003C5C, 0x00003B5B, 0x0000395C, 0x0000445C, 0x00337F8B, 0x001D6565, 0x00044143,
        0x001C5A64, 0x00196276, 0x00227994, 0x000B4856, 0x00094654, 0x00064351, 0x00054250, 0x00064351, 0x00074452, 0x00074452, 0x00064351, 0x00003C60, 0x00003D5D, 0x00003953, 0x00013B51, 0x00003A4E, 0x0005465B, 0x00165C74, 0x002F7894, 0x00496E72,
        0x00356069, 0x003E7582, 0x0037768A, 0x0022667D, 0x00003B54, 0x00003B55, 0x00053A55, 0x00003C5B, 0x0002566F, 0x00197685, 0x00236D79, 0x003D6A78, 0x00416674, 0x0030717A, 0x00248288, 0x00094C65, 0x00003851, 0x0000425B, 0x00002F48, 0x0000425B,
        0x0000364F, 0x00003D56, 0x00003B54, 0x00003850, 0x00023E56, 0x00003A52, 0x00003850, 0x00054159, 0x0000374F, 0x00013D55, 0x00003B53, 0x00003E55, 0x00004259, 0x00003B52, 0x00003D54, 0x00003F56, 0x00003E55, 0x00004259, 0x00003B52, 0x00023A55,
        0x00073F58, 0x00033950, 0x00093E53, 0x00043A51, 0x000D4764, 0x00003557, 0x00003B61, 0x00004561, 0x00003D58, 0x00003C54, 0x00004057, 0x00003F54, 0x0000384C, 0x00003649, 0x00003A4A, 0x000D423F, 0x00004542, 0x00004A48, 0x00004D50, 0x0014525C,
        0x000B4453, 0x00003D4B, 0x00055A69, 0x002AA5C9, 0x003294C2, 0x00024D73, 0x00003948, 0x00084B54, 0x00054157, 0x000B415A, 0x000E3E50, 0x00044155, 0x00024155, 0x00034256, 0x00034256, 0x00024457, 0x00024457, 0x00004457, 0x00004457, 0x00004255,
        0x00004251, 0x00034452, 0x00034256, 0x0004445D, 0x00004559, 0x00055659, 0x00277F72, 0x004F5653, 0x00000502, 0x00050B06, 0x00191D17, 0x00373A31, 0x0043473C, 0x003F4135, 0x00222216, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFEFF, 0xFFFEFDFF, 0xFFFDFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x000F1412, 0x000F100E, 0x00050E0B, 0x00080C07, 0x001D1613, 0x001A211E, 0x003A6562, 0x00165857, 0x0005484B, 0x0000445C, 0x00004255, 0x00073F52, 0x00103F5B, 0x00236187,
        0x0026739A, 0x0009486A, 0x004A6A87, 0x00A6DAEB, 0x00AEEFF8, 0x0090CBD4, 0x004A7285, 0x00294E70, 0x003B749B, 0x001F6485, 0x00003F58, 0x0009415C, 0x0009415C, 0x000A425D, 0x000A425D, 0x0009415C, 0x0009415C, 0x0009415C, 0x0009415C, 0x00003E5A,
        0x0004415B, 0x00094359, 0x000B4459, 0x000A4255, 0x00084053, 0x000D475A, 0x000A4559, 0x000E4554, 0x000D4453, 0x000D4453, 0x000D4453, 0x000E4554, 0x000F4655, 0x000F4655, 0x000E4554, 0x000A4D5C, 0x00064658, 0x000B495B, 0x000F4A5D, 0x000A4255,
        0x000B4152, 0x00124657, 0x00144757, 0x0000374F, 0x000F4353, 0x0024666B, 0x0064B1B3, 0x001D4950, 0x0044363C, 0x0071584E, 0x00717355, 0x00AA9579, 0x008D7E5E, 0x00827957, 0x0095906F, 0x00918D70, 0x00615C47, 0x003F3C2E, 0x00535048, 0x00405C5D,
        0x00004746, 0x00003C46, 0x00163F58, 0x00003150, 0x00126D94, 0x0043AADB, 0x001D97CD, 0x00135462, 0x00003F4D, 0x00003E4C, 0x00074856, 0x00034452, 0x00034452, 0x00064755, 0x00014250, 0x00064456, 0x00064456, 0x00064456, 0x00064456, 0x00064456,
        0x00064456, 0x00064456, 0x00064456, 0x00064456, 0x00054355, 0x00044254, 0x00044254, 0x00044254, 0x00044254, 0x00054355, 0x00064456, 0x00054A4D, 0x00044A51, 0x0000454F, 0x00004354, 0x00115A6E, 0x000A5369, 0x00115A70, 0x000C5269, 0x000E546C,
        0x00105870, 0x0009536B, 0x000B576D, 0x0007566B, 0x000C596C, 0x00085467, 0x000D566A, 0x00145669, 0x0015596C, 0x00105467, 0x001A5E71, 0x00195D70, 0x00195D70, 0x0014596C, 0x0013586B, 0x000C5765, 0x00155E6C, 0x000F5463, 0x00135665, 0x00135867,
        0x000E5667, 0x000C5A6A, 0x0000505F, 0x00074450, 0x00074450, 0x0006434F, 0x0006434F, 0x0006434F, 0x0006434F, 0x00074450, 0x00074450, 0x00074255, 0x00074255, 0x00074255, 0x00074255, 0x00074255, 0x00074255, 0x00074255, 0x00074255, 0x00064651,
        0x00064651, 0x00064651, 0x00084551, 0x00084551, 0x00084551, 0x00094551, 0x00094551, 0x000A4652, 0x000A4652, 0x000A4652, 0x000A4652, 0x000A4652, 0x00094551, 0x00084450, 0x0007434F, 0x00003D56, 0x00023D4D, 0x003F6C70, 0x00627D7A, 0x002F4140,
        0x005B797E, 0x0035717D, 0x00015769, 0x0000475B, 0x0000465A, 0x0000465A, 0x0000465A, 0x0000475B, 0x0000475B, 0x0000475B, 0x0000465A, 0x000F4556, 0x00124958, 0x00083D4A, 0x00164E59, 0x0007424C, 0x0004424C, 0x00003C47, 0x00145865, 0x003F6157,
        0x002C5550, 0x00285C5C, 0x00236266, 0x0015565F, 0x00084551, 0x000C4350, 0x000F434F, 0x000F3C51, 0x00074654, 0x00185F63, 0x00295C5E, 0x00455C5E, 0x004A5B5E, 0x00386261, 0x0019605D, 0x000C4F58, 0x0002454E, 0x0002434C, 0x0003444D, 0x0004454E,
        0x00094751, 0x0005434D, 0x0004424C, 0x00094650, 0x0008454F, 0x000B4852, 0x00013E48, 0x00104D57, 0x00023F49, 0x000C4953, 0x0007444E, 0x00044651, 0x00064853, 0x0002444F, 0x0002444F, 0x00044651, 0x00054752, 0x00074954, 0x0002444F, 0x000C414E,
        0x000C424D, 0x00164B55, 0x00043943, 0x00104651, 0x000B4251, 0x000E4959, 0x000D485B, 0x000A4A55, 0x00074752, 0x0004454E, 0x0007464E, 0x0008474F, 0x0008484D, 0x0007474B, 0x0008474B, 0x00184658, 0x0008434C, 0x00014243, 0x00155151, 0x0016474F,
        0x0000364D, 0x00126287, 0x0037A0CB, 0x002896C6, 0x00004E6D, 0x00054459, 0x0013455C, 0x00053F52, 0x00034A4E, 0x0000424C, 0x00063C5B, 0x00034256, 0x00034256, 0x00034256, 0x00014356, 0x00014356, 0x00004356, 0x00004457, 0x00004457, 0x00004255,
        0x00004251, 0x00034452, 0x00034256, 0x0004445D, 0x00004559, 0x0006575A, 0x00288073, 0x0039403D, 0x00000200, 0x00010702, 0x000C100A, 0x0025281F, 0x002C3025, 0x00282A1E, 0x0018180C, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFDFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x000E1311, 0x000F100E, 0x0009120F, 0x000B0F0A, 0x001F1815, 0x00161D1A, 0x00325D5A, 0x00115352, 0x00014447, 0x00003F5A, 0x00024659, 0x000C3E50, 0x00123751, 0x000A4769,
        0x002482A6, 0x00186586, 0x002E4C6F, 0x00435878, 0x00496F87, 0x00365F75, 0x00274463, 0x003E6189, 0x00356D96, 0x00004461, 0x00054458, 0x000B435E, 0x000A425D, 0x0009415C, 0x0008405B, 0x0008405B, 0x0008405B, 0x0009415C, 0x0009415C, 0x00004059,
        0x0004425A, 0x00023E56, 0x00064056, 0x000E475C, 0x000D4558, 0x00084051, 0x000D4354, 0x000B455B, 0x000A445A, 0x000A445A, 0x000A445A, 0x000A445A, 0x000A445A, 0x00094359, 0x00084258, 0x0001435C, 0x0003425E, 0x0003415F, 0x00033E5E, 0x00013D5B,
        0x0007425C, 0x0008445A, 0x00044155, 0x00004A5C, 0x00083947, 0x00083F48, 0x0062B9BD, 0x00387982, 0x0014151F, 0x00735A56, 0x00B1B096, 0x0082725B, 0x00756A4F, 0x00757051, 0x007C7758, 0x00867D62, 0x004A4332, 0x0030332A, 0x003B4945, 0x0020494B,
        0x00004548, 0x00003D4C, 0x001A435A, 0x000E3C54, 0x00013D5B, 0x000F648C, 0x0030B3DE, 0x003689A8, 0x00095C7B, 0x00004867, 0x00005170, 0x00004D6C, 0x00004766, 0x00004B6A, 0x00004F6E, 0x00004E62, 0x00004E62, 0x00004E62, 0x00004E62, 0x00004E62,
        0x00004E62, 0x00004E62, 0x00004E62, 0x00004D63, 0x00004D63, 0x00004D63, 0x00004C62, 0x00004C62, 0x00004D63, 0x00004D63, 0x00004D63, 0x00004E55, 0x0002515A, 0x0002525D, 0x00004C58, 0x00015463, 0x00005162, 0x00005565, 0x00004E60, 0x000A4B60,
        0x000D4E63, 0x000A4E61, 0x00094E61, 0x00044C5D, 0x00044F5F, 0x00014E5E, 0x00055360, 0x00024F5F, 0x00075464, 0x00014E5E, 0x00004D5D, 0x00004C5C, 0x00024D5D, 0x00024D5D, 0x00034E5E, 0x00004D59, 0x00035763, 0x0000505C, 0x0000525C, 0x0000545E,
        0x0000515B, 0x0000545E, 0x00004F59, 0x0000535B, 0x0000535B, 0x0000525A, 0x00005159, 0x00005159, 0x00005159, 0x0000525A, 0x0000525A, 0x00005264, 0x00005264, 0x00005264, 0x00005264, 0x00005264, 0x00005264, 0x00005264, 0x00005264, 0x00005362,
        0x00005362, 0x00005362, 0x00005362, 0x00005362, 0x00005362, 0x00025362, 0x00025362, 0x0002555D, 0x0003565E, 0x0003565E, 0x0003565E, 0x0003565E, 0x0002555D, 0x0001545C, 0x0001545C, 0x00084D68, 0x0000465A, 0x00044B55, 0x000D4A4E, 0x00003336,
        0x001A535C, 0x00095162, 0x00004B5F, 0x000A4E55, 0x000B4F56, 0x000B4F56, 0x000C5057, 0x000C5057, 0x000C5057, 0x000C5057, 0x000B4F56, 0x00024C58, 0x00004450, 0x0004505C, 0x0003525D, 0x00014F5C, 0x00004754, 0x00004F5B, 0x00004A56, 0x00074644,
        0x00003C3D, 0x00014B4F, 0x0000444C, 0x0000515D, 0x00004652, 0x0004535E, 0x00004955, 0x00044C5E, 0x00004652, 0x00004F54, 0x00004548, 0x00023F43, 0x00063E43, 0x00054C50, 0x0000494D, 0x00004A56, 0x00034D59, 0x00004753, 0x000A525E, 0x00004450,
        0x00074D5A, 0x00004552, 0x00044A57, 0x00004A55, 0x0000525D, 0x00004C57, 0x0001535E, 0x00004853, 0x00004D58, 0x00004B56, 0x0000525D, 0x00004957, 0x00014C5A, 0x00004A58, 0x00004957, 0x00004A58, 0x00014C5A, 0x00024D5B, 0x00004A58, 0x0004535E,
        0x00004853, 0x0005545F, 0x00004651, 0x00095865, 0x00004451, 0x00004F5C, 0x00004D5D, 0x00054C5A, 0x00064E5A, 0x00044C58, 0x00004854, 0x00004854, 0x00024A54, 0x00004B54, 0x00004851, 0x0000406D, 0x00004166, 0x0000415C, 0x0002455C, 0x0000425D,
        0x0012618A, 0x003293CB, 0x002192D4, 0x00004773, 0x00004152, 0x00004450, 0x00093F5D, 0x0012415D, 0x000E484E, 0x0000434A, 0x00004663, 0x00044357, 0x00024457, 0x00014356, 0x00014356, 0x00004356, 0x00004356, 0x00004457, 0x00004457, 0x00014558,
        0x00024554, 0x00054654, 0x00054458, 0x0006465F, 0x0003485C, 0x00095A5D, 0x002C8477, 0x00454C49, 0x00000401, 0x00070D08, 0x000A0E08, 0x00181B12, 0x001C2015, 0x00212317, 0x00252519, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFDFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x000D1210, 0x00090A08, 0x000A1310, 0x0010140F, 0x001F1815, 0x000C1310, 0x00224D4A, 0x00094B4A, 0x00024548, 0x00003C59, 0x00094055, 0x00124353, 0x0006384E, 0x00003C5E,
        0x001A658C, 0x002C7399, 0x002F698C, 0x00294C78, 0x00185073, 0x00175573, 0x00366A8F, 0x004376A1, 0x001B5981, 0x00003C58, 0x00114555, 0x000B435E, 0x000A425D, 0x000A425D, 0x0009415C, 0x0008405B, 0x0008405B, 0x0009415C, 0x0009415C, 0x00044358,
        0x000B4961, 0x0008465E, 0x00013F57, 0x0007435B, 0x000B455B, 0x000C4358, 0x0010485B, 0x000A4457, 0x000A4457, 0x000A4457, 0x00094356, 0x00094356, 0x00084255, 0x00094356, 0x000A4457, 0x00084353, 0x000D485B, 0x000C465C, 0x0006425A, 0x0008445A,
        0x00094A59, 0x00074A53, 0x0003474C, 0x00014758, 0x00174856, 0x00033541, 0x00307C88, 0x006AB8C5, 0x00214955, 0x001A1F1D, 0x007A7360, 0x00635B4A, 0x005B5641, 0x005D5A3E, 0x008B8366, 0x008F816B, 0x00383023, 0x001C2724, 0x00254344, 0x00094244,
        0x00002D37, 0x00064056, 0x000C4156, 0x00003C4B, 0x00093D4E, 0x00033B58, 0x00046787, 0x003AB2FA, 0x002EA6EE, 0x0028A0E8, 0x002EA6EE, 0x0033ABF3, 0x002FA7EF, 0x002DA5ED, 0x0031A9F1, 0x002EA7E5, 0x002EA7E5, 0x002EA7E5, 0x002EA7E5, 0x002EA7E5,
        0x002EA7E5, 0x002EA7E5, 0x002EA7E5, 0x002FA5E6, 0x002FA5E6, 0x002FA5E6, 0x0030A6E7, 0x0030A6E7, 0x002FA5E6, 0x002FA5E6, 0x002FA5E6, 0x002FA2DF, 0x002FA1DD, 0x0032A5DE, 0x0032A3DC, 0x0031A4DD, 0x002FA3DC, 0x002CA2DD, 0x002CA2DD, 0x001DA7DC,
        0x001FA6DC, 0x0021A7DD, 0x0022A9DD, 0x001DA4D8, 0x001CA3D5, 0x001BA4D5, 0x0018A3D4, 0x0014A2D7, 0x001AA8DD, 0x001AA8DD, 0x0019A5DA, 0x001BA7DC, 0x001FA9DE, 0x001AA4D9, 0x001CA6DB, 0x002B9BD7, 0x002FA1DD, 0x00289FD7, 0x0027A0D8, 0x002AA4DA,
        0x0029A0D7, 0x002DA1D6, 0x0032A4D9, 0x002AA1D8, 0x002AA1D8, 0x0029A0D7, 0x0029A0D7, 0x0029A0D7, 0x002AA1D8, 0x002AA1D8, 0x002BA2D9, 0x00289ED9, 0x00289ED9, 0x00289ED9, 0x00289ED9, 0x00289ED9, 0x00289ED9, 0x00289ED9, 0x00289ED9, 0x00249FD9,
        0x00249FD9, 0x00269ED9, 0x00269ED9, 0x00289ED9, 0x00289ED9, 0x002A9ED9, 0x002A9ED9, 0x00269DD4, 0x00279ED5, 0x00279ED5, 0x00279ED5, 0x00279ED5, 0x00279ED5, 0x00269DD4, 0x00259CD3, 0x003192D4, 0x002B9FDA, 0x001DA4D8, 0x000C98C7, 0x0026A8D7,
        0x00219ACC, 0x002297CE, 0x002AA2DD, 0x002599D8, 0x002498D7, 0x002498D7, 0x002498D7, 0x002397D6, 0x002397D6, 0x002498D7, 0x002498D7, 0x002B9FD6, 0x002296CD, 0x00279BD4, 0x002094CF, 0x001E91CE, 0x001F92CF, 0x002C9EDA, 0x002494D0, 0x002497CA,
        0x002195CA, 0x002C9FD8, 0x002598D5, 0x00269BD8, 0x002096D1, 0x00299DD6, 0x002297CE, 0x001C96D2, 0x001A97D1, 0x0021A1D6, 0x001D9CCF, 0x001E9BCE, 0x001793C9, 0x001E9BD5, 0x001E9ED9, 0x002294D0, 0x002496D2, 0x002898D4, 0x002494D0, 0x002A98D4,
        0x002492CE, 0x002994D1, 0x002994D1, 0x001B96CE, 0x00219CD4, 0x001C97CF, 0x00249FD7, 0x001691C9, 0x00209BD3, 0x001C97CF, 0x00249FD7, 0x002596D4, 0x002899D7, 0x00299AD8, 0x002798D6, 0x002697D5, 0x00299AD8, 0x00299AD8, 0x002899D7, 0x00279ED6,
        0x00229BD3, 0x001E99D3, 0x0028A2DE, 0x0026A0DC, 0x00229DD7, 0x00219AD2, 0x00269DD5, 0x00299AD8, 0x002A9BD9, 0x00299AD8, 0x002596D4, 0x002394D2, 0x002495D3, 0x002495D3, 0x002293D1, 0x001696C6, 0x00219ACB, 0x002A9ECD, 0x002098C6, 0x001A9AC5,
        0x002BAED6, 0x001B97C0, 0x0000537C, 0x00004051, 0x00044756, 0x00014054, 0x0008405B, 0x00063B56, 0x00033E52, 0x00084D5E, 0x00003B4D, 0x00034558, 0x00034558, 0x00024457, 0x00004356, 0x00004356, 0x00004356, 0x00004457, 0x00004558, 0x00024659,
        0x00034655, 0x00064755, 0x00054458, 0x00074760, 0x0004495D, 0x000A5B5E, 0x002D8578, 0x00575E5B, 0x00000200, 0x00030904, 0x000E120C, 0x001F2219, 0x00282C21, 0x00313327, 0x00333327, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFEFF, 0xFFFFFEFF, 0xFFFDFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x000D1210, 0x00060705, 0x0007100D, 0x000B0F0A, 0x001D1613, 0x000E1512, 0x00285350, 0x00125453, 0x00094C4F, 0x00093F5D, 0x000F3950, 0x00174B58, 0x00004455, 0x00003E5D,
        0x0000315D, 0x001F5D85, 0x00207B9A, 0x004385B5, 0x00267BA1, 0x001C7698, 0x0026739A, 0x00084C79, 0x0000365E, 0x00084861, 0x00103D4A, 0x000A425D, 0x000A425D, 0x000A425D, 0x000A425D, 0x0009415C, 0x0009415C, 0x0008405B, 0x0008405B, 0x0009465A,
        0x00014055, 0x0003435B, 0x0004445D, 0x00003F58, 0x0007425C, 0x000C465C, 0x000C4259, 0x0005455E, 0x0005455E, 0x0005455E, 0x0004445D, 0x0003435C, 0x0004445D, 0x00074760, 0x00094962, 0x00084853, 0x000C4D5C, 0x00094B5E, 0x0005485D, 0x00054A5D,
        0x00004955, 0x0000494C, 0x00005250, 0x000C4659, 0x000E424F, 0x00184957, 0x00002B3B, 0x0058AABB, 0x0071BFC6, 0x001F413B, 0x00221505, 0x00302D1F, 0x00393A26, 0x0036371D, 0x007B7257, 0x007E6D5A, 0x00393026, 0x00243433, 0x00193F43, 0x00003639,
        0x000B4757, 0x000D3C58, 0x00003C51, 0x00004C53, 0x0007424B, 0x001D4054, 0x0001415A, 0x0000527E, 0x0012739F, 0x001879A5, 0x000B6C98, 0x000F709C, 0x001374A0, 0x000E6F9B, 0x0010719D, 0x00116F9D, 0x00116F9D, 0x00116F9D, 0x00116F9D, 0x00116F9D,
        0x00116F9D, 0x00116F9D, 0x00116F9D, 0x00116D9E, 0x00116D9E, 0x00126E9F, 0x00136FA0, 0x00136FA0, 0x00126E9F, 0x00116D9E, 0x00116D9E, 0x001074AA, 0x00086B9F, 0x000E6D9E, 0x0013719E, 0x0011709B, 0x000E709A, 0x000B6F99, 0x000F75A0, 0x000C759C,
        0x00096E95, 0x000D6D95, 0x00136E95, 0x00146C94, 0x00187095, 0x00197196, 0x00126B90, 0x001B729E, 0x00166B98, 0x00146996, 0x00136693, 0x001A6D9A, 0x001D6E9B, 0x00176593, 0x001E6C9A, 0x00116D9C, 0x000D6D9B, 0x00056A97, 0x00036C97, 0x0009739C,
        0x00086E98, 0x000A6A92, 0x00136F98, 0x000F6A97, 0x000F6A97, 0x000F6A97, 0x000F6A97, 0x00106B98, 0x00116C99, 0x00126D9A, 0x00136E9B, 0x00106D94, 0x00106D94, 0x00106D94, 0x00106D94, 0x00106D94, 0x00106D94, 0x00106D94, 0x00106D94, 0x000E6D95,
        0x000E6D95, 0x000E6D95, 0x00106C95, 0x00106C95, 0x00126C95, 0x00126C95, 0x00126C95, 0x00146C9A, 0x00146C9A, 0x00146C9A, 0x00156D9B, 0x00156D9B, 0x00146C9A, 0x00146C9A, 0x00136B99, 0x00146D99, 0x000F6E96, 0x0005688E, 0x001F7A9F, 0x00106389,
        0x00196E94, 0x000C6D91, 0x00006E90, 0x000E7295, 0x000D7194, 0x000B6F92, 0x00096D90, 0x00086C8F, 0x00086C8F, 0x00096D90, 0x000B6F92, 0x00096890, 0x0013719C, 0x00096795, 0x001673A4, 0x000C679A, 0x001972A5, 0x000F6496, 0x00176B9B, 0x000B709D,
        0x001072A2, 0x00066295, 0x001670A6, 0x00065E94, 0x001975A6, 0x000E6C99, 0x0012719C, 0x001F6EA1, 0x00206D9E, 0x001E6A9A, 0x00176A97, 0x001976A3, 0x000D6A9B, 0x001368A0, 0x001D69A4, 0x000B73A2, 0x000F75A5, 0x00096F9F, 0x00096F9F, 0x001074A4,
        0x000F73A3, 0x000E70A0, 0x000D6F9F, 0x001476A4, 0x000D6F9D, 0x001375A3, 0x000B6D9B, 0x001476A4, 0x001072A0, 0x001577A5, 0x001274A2, 0x001077A8, 0x00137AAB, 0x00177EAF, 0x00147BAC, 0x001279AA, 0x00157CAD, 0x00157CAD, 0x00157CAD, 0x001A7DA9,
        0x001E83B0, 0x001C82B2, 0x001E84B5, 0x00197FB0, 0x001D81B1, 0x002083AF, 0x002082AC, 0x001581B1, 0x001581B1, 0x001581B1, 0x00157EAF, 0x00137CAD, 0x001379AD, 0x00147AAE, 0x00157BAF, 0x001881AA, 0x001473A5, 0x001B72B2, 0x001775B6, 0x001980B7,
        0x0017769D, 0x000C4F64, 0x00173F4B, 0x00005147, 0x00074154, 0x00204567, 0x000C3D53, 0x00004157, 0x00004566, 0x00003753, 0x001D4D53, 0x00044659, 0x00034558, 0x00024457, 0x00004356, 0x00004356, 0x00004457, 0x00004457, 0x00004558, 0x00004457,
        0x00014453, 0x00044553, 0x00034256, 0x0005455E, 0x0002475B, 0x00095A5D, 0x002C8477, 0x00626966, 0x00000200, 0x00040A05, 0x00181C16, 0x00282B22, 0x0031352A, 0x00393B2F, 0x00333327, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFCFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x000A1211, 0x0013130D, 0x0013100C, 0x0015100F, 0x00101213, 0x00061A1B, 0x00315F60, 0x0007504E, 0x00004D4A, 0x00034256, 0x00034256, 0x00034256, 0x00034256, 0x00024155,
        0x00014054, 0x00014054, 0x00003F53, 0x000E5062, 0x000C4E60, 0x00084A5C, 0x00044658, 0x00014355, 0x00004254, 0x00004254, 0x00014355, 0x000A4558, 0x00094457, 0x00084356, 0x00084356, 0x00084356, 0x00094457, 0x000A4558, 0x000B4659, 0x00084454,
        0x00094555, 0x000A4656, 0x00094555, 0x00084454, 0x00084454, 0x000A4656, 0x000C4858, 0x00004553, 0x00004A58, 0x00024D5B, 0x00014C5A, 0x00004B59, 0x00014C5A, 0x00024D5B, 0x00014C5A, 0x000C4E61, 0x000D4F62, 0x000E5063, 0x000D4F62, 0x000C4E61,
        0x000C4E61, 0x000C4E61, 0x000D4F62, 0x00035657, 0x00055052, 0x000A494D, 0x000F464B, 0x00285F64, 0x0067A6AA, 0x0069B4B6, 0x000F6263, 0x001D2B31, 0x00191F26, 0x0028232C, 0x004A414B, 0x0054515A, 0x002D3D43, 0x000B3133, 0x000D4141, 0x00053E4D,
        0x000A4352, 0x000C4554, 0x00074251, 0x00064150, 0x00074452, 0x00074452, 0x0004414F, 0x00003F47, 0x00003F47, 0x00003F47, 0x00003F47, 0x00003F47, 0x00003F47, 0x00003F47, 0x00003F47, 0x00063F48, 0x00063F48, 0x00053E47, 0x00053E47, 0x00053E47,
        0x00063F48, 0x00074049, 0x00074049, 0x00014048, 0x00014048, 0x00003F47, 0x00003E46, 0x00003D45, 0x00003F47, 0x0003424A, 0x0005444C, 0x00094349, 0x00084248, 0x00074147, 0x00084248, 0x00094349, 0x000A444A, 0x00094349, 0x00084248, 0x0002434C,
        0x0001424B, 0x0001424B, 0x0001424B, 0x0000414A, 0x00004049, 0x00004049, 0x00004049, 0x00004447, 0x00004548, 0x00004548, 0x00004548, 0x00004548, 0x00004649, 0x00004649, 0x00004649, 0x0000474A, 0x0000474A, 0x0000474A, 0x0000474A, 0x0000474A,
        0x00004649, 0x00004649, 0x00004649, 0x00004448, 0x00004448, 0x00004549, 0x00004549, 0x0000464A, 0x0000474B, 0x0000474B, 0x0000484C, 0x00054549, 0x00044448, 0x00044448, 0x00034347, 0x00044448, 0x00054549, 0x0006464A, 0x0007474B, 0x0008484D,
        0x0008484D, 0x0008484D, 0x0008484D, 0x0008484D, 0x0008484D, 0x0008484D, 0x0008484D, 0x0006464A, 0x0006464A, 0x0006464A, 0x0006464A, 0x0006464A, 0x0006464A, 0x0006464A, 0x0006464A, 0x00034348, 0x00034348, 0x00034348, 0x00044449, 0x00044449,
        0x00044449, 0x00044449, 0x0005454A, 0x00054549, 0x00044448, 0x00044448, 0x00034347, 0x00024246, 0x00014145, 0x00014145, 0x00004044, 0x00024246, 0x00024246, 0x00024246, 0x00024246, 0x00024246, 0x00024246, 0x00024246, 0x00024246, 0x00054349,
        0x0006444A, 0x0006444A, 0x0005454A, 0x0005454A, 0x0003454A, 0x0003454A, 0x00024449, 0x00054549, 0x00054549, 0x00054549, 0x00054549, 0x00054549, 0x00054549, 0x00054549, 0x00054549, 0x0006464A, 0x0006464A, 0x00054549, 0x00054549, 0x00044448,
        0x00044448, 0x00044448, 0x00044448, 0x0003444C, 0x0003444C, 0x0005464E, 0x0006474F, 0x0006474F, 0x0006474F, 0x0006474F, 0x0005464E, 0x00004A4B, 0x00004E4F, 0x00004E4F, 0x00044F51, 0x00095355, 0x00074E51, 0x00064B4E, 0x00105356, 0x000A5155,
        0x000A5155, 0x000B5256, 0x000D5458, 0x000F565A, 0x000F565A, 0x000C5357, 0x00095054, 0x000D4E56, 0x000D4E56, 0x00084C53, 0x0001474E, 0x0000474E, 0x00014B51, 0x00014B51, 0x0000474D, 0x0006444C, 0x0006444C, 0x0007454D, 0x0008464E, 0x0009474F,
        0x000A4850, 0x000B4951, 0x000C4A52, 0x000B4856, 0x000B4856, 0x000A4755, 0x00094654, 0x00094654, 0x000A4755, 0x000B4856, 0x000B4856, 0x00054353, 0x00054353, 0x00054353, 0x00054353, 0x00064454, 0x00064454, 0x00074555, 0x00084656, 0x000D4858,
        0x00074353, 0x00084656, 0x00084958, 0x00074C5B, 0x00004755, 0x0005505E, 0x002E7987, 0x00474F48, 0x00000400, 0x0010150C, 0x002E3128, 0x00313026, 0x00343228, 0x003D392E, 0x003A3429, 0x0034352B, 0xFFCCCDC4, 0xFFFFFFFC, 0xFFFDFBFA,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00091110, 0x000C0D09, 0x0012110D, 0x00100C0B, 0x000E0E0E, 0x000D1C1E, 0x003F6565, 0x00215D5C, 0x00075250, 0x00054654, 0x00044553, 0x00044553, 0x00044553, 0x00044553,
        0x00054654, 0x00064755, 0x00074856, 0x00074752, 0x00074752, 0x00064651, 0x00064651, 0x00054550, 0x00064651, 0x00064651, 0x00064651, 0x00004650, 0x00004751, 0x00004751, 0x00004751, 0x00014852, 0x00014852, 0x00014852, 0x00014852, 0x00024A52,
        0x00034B53, 0x00044C54, 0x00034B53, 0x00024A52, 0x00014951, 0x00024A52, 0x00044C54, 0x000F4D57, 0x000B4953, 0x000A4852, 0x000B4953, 0x0007454F, 0x00084650, 0x00185660, 0x002D6B75, 0x002B686C, 0x002D6A6E, 0x002E6B6F, 0x002D6A6E, 0x002B686C,
        0x0029666A, 0x00286569, 0x00286569, 0x00267370, 0x002B7472, 0x00337373, 0x003A7374, 0x00336C6D, 0x00377777, 0x004D9694, 0x00519E9B, 0x00366965, 0x0023504D, 0x00123735, 0x000B2D2C, 0x000C3331, 0x000C3F3B, 0x0001453E, 0x0000443B, 0x0000434A,
        0x0001454C, 0x0000464D, 0x0000444B, 0x0000444B, 0x0000464D, 0x0000474E, 0x0000484E, 0x00004A4C, 0x00004A4C, 0x00004A4C, 0x00004A4C, 0x00004A4C, 0x00014B4D, 0x00014B4D, 0x00014B4D, 0x00004B4B, 0x00004B4B, 0x00004C4C, 0x00004C4C, 0x00004B4B,
        0x00004A4A, 0x00004949, 0x00004949, 0x00044E50, 0x00054F51, 0x00054F51, 0x00034D4F, 0x00004A4C, 0x0000494B, 0x0000494B, 0x00004A4C, 0x00004D4A, 0x00004C49, 0x00004B48, 0x00004C49, 0x00004D4A, 0x00004E4B, 0x00004D4A, 0x00004C49, 0x00084B4E,
        0x00084B4E, 0x00074A4D, 0x00074A4D, 0x0006494C, 0x0006494C, 0x0005484B, 0x0005484B, 0x00034948, 0x00034948, 0x00034948, 0x00034948, 0x00034948, 0x00034948, 0x00034948, 0x00034948, 0x00074D4C, 0x00074D4C, 0x00074D4C, 0x00074D4C, 0x00074D4C,
        0x00064C4B, 0x00064C4B, 0x00064C4B, 0x00014B4B, 0x00014B4B, 0x00014B4B, 0x00014B4B, 0x00024C4C, 0x00024C4C, 0x00024C4C, 0x00024C4C, 0x00084A49, 0x00084A49, 0x00094B4A, 0x00094B4A, 0x000A4C4B, 0x000A4C4B, 0x000A4C4B, 0x000A4C4B, 0x00094A4B,
        0x00094A4B, 0x00094A4B, 0x00094A4B, 0x00094A4B, 0x00094A4B, 0x00094A4B, 0x00094A4B, 0x00084A49, 0x00084A49, 0x00084A49, 0x00084A49, 0x00084A49, 0x00084A49, 0x00084A49, 0x00084A49, 0x00064748, 0x00064748, 0x00064748, 0x00074849, 0x00074849,
        0x00074849, 0x00074849, 0x00074849, 0x00074948, 0x00074948, 0x00074948, 0x00064847, 0x00064847, 0x00054746, 0x00054746, 0x00044645, 0x00004B49, 0x00004B49, 0x00004B49, 0x00004B49, 0x00004B49, 0x00004B49, 0x00004B49, 0x00004B49, 0x00024A4A,
        0x00034B4B, 0x00054D4D, 0x00044E4E, 0x00044E4E, 0x00024E4D, 0x00004C4B, 0x00004B4A, 0x00094B4A, 0x00094B4A, 0x00094B4A, 0x00094B4A, 0x00094B4A, 0x00094B4A, 0x00094B4A, 0x00094B4A, 0x00084A49, 0x00084A49, 0x00084A49, 0x00074948, 0x00074948,
        0x00064847, 0x00064847, 0x00064847, 0x0006494C, 0x0006494C, 0x00074A4D, 0x00074A4D, 0x00084B4E, 0x00084B4E, 0x00084B4E, 0x00084B4E, 0x00135756, 0x00185A59, 0x00175958, 0x00185A59, 0x001C5C5C, 0x001E5C5C, 0x001D5B5B, 0x001E5C5C, 0x001C595B,
        0x001C595B, 0x001D5A5C, 0x00205D5F, 0x00236062, 0x00246163, 0x00236062, 0x00215E60, 0x001A5F62, 0x00175C5F, 0x00115659, 0x000C5154, 0x000A4F52, 0x000A4F52, 0x00084D50, 0x00054A4D, 0x00074E51, 0x00064D50, 0x00064D50, 0x00054C4F, 0x00054C4F,
        0x00044B4E, 0x00044B4E, 0x00034A4D, 0x0000484F, 0x0000484F, 0x0000474E, 0x0000474E, 0x0000474E, 0x0000474E, 0x0000484F, 0x0000484F, 0x0000474F, 0x0000474F, 0x0000474F, 0x0000474F, 0x00004850, 0x00004951, 0x00014A52, 0x00024B53, 0x00084D56,
        0x00014951, 0x00004850, 0x00004850, 0x00004F56, 0x00005158, 0x000C6066, 0x0031878D, 0x00454D46, 0x000A110A, 0x001E231A, 0x003A3D34, 0x00434238, 0x00444238, 0x004B473C, 0x00433D32, 0x003F4036, 0xFF9D9E95, 0xFFCFCECA, 0xFFFFFFFE,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x0008100F, 0x00050B06, 0x0010110D, 0x000F0B0A, 0x00141212, 0x00161E1E, 0x003D5555, 0x002B5554, 0x00154A47, 0x0018484C, 0x0017474B, 0x00144448, 0x00124246, 0x00114145,
        0x00114145, 0x00124246, 0x00134347, 0x000E4445, 0x000E4445, 0x000F4546, 0x000F4546, 0x000F4546, 0x000E4445, 0x000D4344, 0x000D4344, 0x000A4646, 0x000B4747, 0x000D4949, 0x000E4A4A, 0x000E4A4A, 0x000D4949, 0x000C4848, 0x000C4848, 0x000C4847,
        0x000D4948, 0x000D4948, 0x000D4948, 0x000C4847, 0x000B4746, 0x000C4847, 0x000D4948, 0x00204C4D, 0x001B4748, 0x001A4647, 0x001D494A, 0x001C4849, 0x001E4A4B, 0x002E5A5B, 0x00416D6E, 0x003A6C60, 0x003C6E62, 0x003F7165, 0x003F7165, 0x003E7064,
        0x003C6E62, 0x003B6D61, 0x003A6C60, 0x00537372, 0x004C6C6B, 0x00426261, 0x00466564, 0x00466564, 0x003B5B5A, 0x00345453, 0x002C4C4B, 0x001B3F39, 0x0013352F, 0x000B2B26, 0x00072520, 0x000D2D28, 0x00234943, 0x0026524B, 0x000F4038, 0x000D4643,
        0x000A4340, 0x0009423F, 0x000A4541, 0x000B4642, 0x000A4743, 0x000B4844, 0x000D4A46, 0x000B4844, 0x000B4844, 0x000C4945, 0x000C4945, 0x000C4945, 0x000D4A46, 0x000D4A46, 0x000D4A46, 0x000B4642, 0x000E4945, 0x00114C48, 0x00124D49, 0x00124D49,
        0x00114C48, 0x00124D49, 0x00144F4B, 0x000A4743, 0x000C4945, 0x000E4B47, 0x000E4B47, 0x000C4945, 0x000A4743, 0x00094642, 0x00094642, 0x000C4743, 0x000B4642, 0x000A4541, 0x000B4642, 0x000C4743, 0x000C4743, 0x000C4743, 0x000A4541, 0x000D3F3B,
        0x000D3F3B, 0x000C3E3A, 0x000C3E3A, 0x000B3D39, 0x000B3D39, 0x000A3C38, 0x000A3C38, 0x000B3E3A, 0x000B3E3A, 0x000B3E3A, 0x000B3E3A, 0x000B3E3A, 0x000B3E3A, 0x000A3D39, 0x000A3D39, 0x000F423E, 0x000F423E, 0x000F423E, 0x000E413D, 0x000E413D,
        0x000E413D, 0x000E413D, 0x000E413D, 0x00114643, 0x00114643, 0x00114643, 0x00114643, 0x00104542, 0x00104542, 0x00104542, 0x00104542, 0x00054942, 0x00064A43, 0x00074B44, 0x00084C45, 0x00094D46, 0x00084C45, 0x00074B44, 0x00064A43, 0x00064944,
        0x00064944, 0x00064944, 0x00064944, 0x00064944, 0x00064944, 0x00064944, 0x00064944, 0x00064A43, 0x00064A43, 0x00064A43, 0x00064A43, 0x00064A43, 0x00064A43, 0x00064A43, 0x00064A43, 0x00054843, 0x00054843, 0x00054843, 0x00064944, 0x00064944,
        0x00064944, 0x00064944, 0x00064944, 0x00064A43, 0x00064A43, 0x00064A43, 0x00064A43, 0x00064A43, 0x00054942, 0x00054942, 0x00054942, 0x000A4842, 0x000A4842, 0x000A4842, 0x000A4842, 0x000A4842, 0x000A4842, 0x000A4842, 0x000A4842, 0x000A4541,
        0x000B4642, 0x000D4844, 0x000D4A46, 0x000D4A46, 0x000B4844, 0x00074742, 0x00064641, 0x0000443D, 0x0000443D, 0x0000443D, 0x0000443D, 0x0000443D, 0x0000443D, 0x0000443D, 0x0000443D, 0x00034740, 0x00034740, 0x00034740, 0x00034740, 0x0002463F,
        0x0002463F, 0x0002463F, 0x0002463F, 0x00024842, 0x00024842, 0x00024842, 0x00024842, 0x00024842, 0x00034943, 0x00034943, 0x00044A44, 0x001C4946, 0x001E4B48, 0x00224F4C, 0x0022514E, 0x001E504C, 0x001F514D, 0x00215450, 0x0020534F, 0x00225351,
        0x00215250, 0x00215250, 0x00225351, 0x00235452, 0x00235452, 0x00235452, 0x00225351, 0x0011534E, 0x0011514C, 0x000F4F4A, 0x00104D49, 0x00114A47, 0x00104744, 0x00114845, 0x00164B48, 0x000D4844, 0x000D4844, 0x000D4844, 0x000D4844, 0x000D4844,
        0x000D4844, 0x000D4844, 0x000D4844, 0x000C4945, 0x000C4945, 0x000B4844, 0x000B4844, 0x000B4844, 0x000B4844, 0x000C4945, 0x000C4945, 0x000C4847, 0x000C4847, 0x000C4847, 0x000D4948, 0x000E4A49, 0x000F4B4A, 0x00104C4B, 0x00114D4C, 0x00175150,
        0x00134F4E, 0x00124E4D, 0x000E4D4B, 0x00105250, 0x00115653, 0x001A5F5C, 0x00327976, 0x00353C35, 0x00111811, 0x00171C13, 0x0023261D, 0x0025261D, 0x00242319, 0x00312F25, 0x0028231A, 0x0024251B, 0x003E3F36, 0x004E4D49, 0x00C0BEBD,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00070F0E, 0x00070E09, 0x000D110C, 0x000B0908, 0x0014100F, 0x00040606, 0x00081414, 0x00001311, 0x00000F0C, 0x0001120F, 0x0000110E, 0x00000F0C, 0x00000D0A, 0x00000C09,
        0x00000B08, 0x00000C09, 0x00000C09, 0x00001009, 0x00001009, 0x00001009, 0x00001009, 0x00000F08, 0x00000E07, 0x00000E07, 0x00000D06, 0x00000B07, 0x00000B07, 0x00000C08, 0x00000D09, 0x00000D09, 0x00000D09, 0x00000D09, 0x00000C08, 0x00000A05,
        0x00000B06, 0x00000C07, 0x00000D08, 0x00000D08, 0x00000D08, 0x00000D08, 0x00000D08, 0x00000D08, 0x00000B06, 0x00000904, 0x00000A05, 0x0000110C, 0x00011813, 0x00021914, 0x00001611, 0x00032213, 0x00052415, 0x00072617, 0x00092819, 0x00092819,
        0x00092819, 0x00092819, 0x000A291A, 0x000E1311, 0x0019221F, 0x001E2D29, 0x00152622, 0x000A1B17, 0x00101F1B, 0x00141D1A, 0x00010604, 0x00070B05, 0x00050903, 0x00050C05, 0x00040B04, 0x00010801, 0x00070B05, 0x00090B05, 0x00010300, 0x00000B03,
        0x00000700, 0x00000700, 0x00000B03, 0x00000D05, 0x00000B03, 0x00000901, 0x00000B03, 0x00000A06, 0x00000A06, 0x00000A06, 0x00000B07, 0x00000B07, 0x00000C08, 0x00000C08, 0x00000C08, 0x00000301, 0x00000604, 0x00000806, 0x00000806, 0x00000604,
        0x00000604, 0x00000806, 0x00000B09, 0x00000703, 0x00000905, 0x00000C08, 0x00000C08, 0x00000B07, 0x00000905, 0x00000804, 0x00000804, 0x00000705, 0x00000604, 0x00000503, 0x00000604, 0x00000705, 0x00000705, 0x00000604, 0x00000503, 0x00000A03,
        0x00000902, 0x00000902, 0x00000801, 0x00000801, 0x00000700, 0x00000700, 0x00000700, 0x00000804, 0x00000804, 0x00000905, 0x00000905, 0x00000905, 0x00000A06, 0x00000A06, 0x00000A06, 0x00000905, 0x00000905, 0x00000905, 0x00000905, 0x00000804,
        0x00000804, 0x00000804, 0x00000804, 0x00000805, 0x00000805, 0x00000805, 0x00000805, 0x00000805, 0x00000805, 0x00000805, 0x00000805, 0x00000805, 0x00000805, 0x00000906, 0x00000906, 0x00000906, 0x00000906, 0x00000906, 0x00000805, 0x00000807,
        0x00000807, 0x00000807, 0x00000807, 0x00000807, 0x00000807, 0x00000807, 0x00000807, 0x00000906, 0x00000906, 0x00000906, 0x00000906, 0x00000906, 0x00000906, 0x00000906, 0x00000906, 0x00010908, 0x00010908, 0x00010908, 0x00010908, 0x00010908,
        0x00020A09, 0x00020A09, 0x00020A09, 0x00010A07, 0x00010A07, 0x00010A07, 0x00020B08, 0x00020B08, 0x00020B08, 0x00030C09, 0x00030C09, 0x00000B06, 0x00000B06, 0x00000B06, 0x00000B06, 0x00000B06, 0x00000B06, 0x00000B06, 0x00000B06, 0x00000704,
        0x00000805, 0x00000906, 0x00000A07, 0x00000B07, 0x00000A06, 0x00000905, 0x00000804, 0x00000906, 0x00000906, 0x00000906, 0x00000906, 0x00000906, 0x00000906, 0x00000906, 0x00000906, 0x00000906, 0x00000906, 0x00000906, 0x00000906, 0x00000805,
        0x00000805, 0x00000805, 0x00000805, 0x00000B09, 0x00000A08, 0x00000A08, 0x00000907, 0x00000907, 0x00000A08, 0x00000B09, 0x00000B09, 0x00000F0A, 0x00000E09, 0x00011B15, 0x0007231D, 0x00001F18, 0x00001D16, 0x0000241C, 0x0001261E, 0x0003251E,
        0x0002241D, 0x0001231C, 0x0001231C, 0x0001231C, 0x0002241D, 0x0003251E, 0x0003251E, 0x0000261E, 0x0000251E, 0x0000261F, 0x0000221C, 0x00001913, 0x00000E09, 0x00000C08, 0x0000120E, 0x00000C09, 0x00000C09, 0x00000C09, 0x00000D0A, 0x00000D0A,
        0x00000D0A, 0x00000D0A, 0x00000D0A, 0x0000100B, 0x0000100B, 0x0000100B, 0x0000100B, 0x0000100B, 0x0000100B, 0x0000100B, 0x0000100B, 0x00000F0A, 0x00000F0A, 0x00000F0A, 0x0000100B, 0x0000110C, 0x0000130E, 0x0000140F, 0x00001510, 0x00021813,
        0x00061C17, 0x00061D18, 0x00031D17, 0x00041E18, 0x00001711, 0x0000130D, 0x00001C15, 0x00141812, 0x000E120C, 0x00171913, 0x001C1D14, 0x001B1C13, 0x0015130B, 0x00212016, 0x00141208, 0x000F1308, 0x0010130A, 0x00020300, 0x00838482,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00070F0E, 0x00050F09, 0x000D130E, 0x0012130F, 0x001E1A19, 0x00151312, 0x00131614, 0x00111C19, 0x000B1A16, 0x00000300, 0x00000400, 0x00000400, 0x00020600, 0x00030701,
        0x00040802, 0x00050903, 0x00050903, 0x00060B02, 0x00060B02, 0x00060B02, 0x00070C03, 0x00080D04, 0x00090E05, 0x000A0F06, 0x000A0F06, 0x00100D08, 0x000F0C07, 0x000F0C07, 0x000F0C07, 0x000F0C07, 0x00100D08, 0x00100D08, 0x00110E09, 0x00110F07,
        0x00110F07, 0x00131109, 0x0014120A, 0x0016140C, 0x0016140C, 0x0016140C, 0x0016140C, 0x000E190F, 0x000B160C, 0x000B160C, 0x00162117, 0x002A352B, 0x003A453B, 0x003B463C, 0x00354036, 0x0037453F, 0x00384640, 0x00394741, 0x00394741, 0x00394741,
        0x003B4943, 0x003D4B45, 0x00404E48, 0x00485B52, 0x00364F45, 0x002C4C41, 0x002A5044, 0x002A5044, 0x0026463B, 0x00112A20, 0x00000F06, 0x000D140D, 0x000F1710, 0x000D1810, 0x000D1A12, 0x000F1A12, 0x000C130C, 0x0012140E, 0x0023201B, 0x00231E15,
        0x00211C13, 0x00211F15, 0x0027251B, 0x0027261C, 0x00212016, 0x001D1C12, 0x001C1B11, 0x001A1713, 0x001A1713, 0x001A1713, 0x001A1713, 0x001B1814, 0x001B1814, 0x001B1814, 0x001B1814, 0x00242B26, 0x00252C27, 0x00242B26, 0x00202722, 0x001B221D,
        0x0019201B, 0x001A211C, 0x001D241F, 0x0026231F, 0x0026231F, 0x0026231F, 0x0024211D, 0x00211E1A, 0x001F1C18, 0x001E1B17, 0x001E1B17, 0x00171E19, 0x00161D18, 0x00151C17, 0x00151C17, 0x00151C17, 0x00161D18, 0x00141B16, 0x00131A15, 0x001C1F16,
        0x001C1F16, 0x001C1F16, 0x001B1E15, 0x001B1E15, 0x001A1D14, 0x001A1D14, 0x001A1D14, 0x00171913, 0x00181A14, 0x00191B15, 0x001A1C16, 0x001B1D17, 0x001C1E18, 0x001C1E18, 0x001D1F19, 0x00181A14, 0x00181A14, 0x00181A14, 0x00171913, 0x00171913,
        0x00171913, 0x00171913, 0x00171913, 0x00191A16, 0x00191A16, 0x001A1B17, 0x001A1B17, 0x001B1C18, 0x001B1C18, 0x001C1D19, 0x001C1D19, 0x00151D16, 0x00151D16, 0x00141C15, 0x00131B14, 0x00131B14, 0x00141C15, 0x00141C15, 0x00151D16, 0x00141B16,
        0x00141B16, 0x00141B16, 0x00141B16, 0x00141B16, 0x00141B16, 0x00141B16, 0x00141B16, 0x00141C15, 0x00141C15, 0x00141C15, 0x00141C15, 0x00141C15, 0x00141C15, 0x00141C15, 0x00141C15, 0x00151C17, 0x00151C17, 0x00151C17, 0x00161D18, 0x00161D18,
        0x00161D18, 0x00161D18, 0x00171E19, 0x00151D16, 0x00161E17, 0x00161E17, 0x00161E17, 0x00171F18, 0x00171F18, 0x00182019, 0x00182019, 0x00211E19, 0x00211E19, 0x00211E19, 0x00211E19, 0x00211E19, 0x00211E19, 0x00211E19, 0x00211E19, 0x00201B18,
        0x00201B18, 0x00201B18, 0x001F1C18, 0x001F1C18, 0x001D1C18, 0x001D1C18, 0x001D1C18, 0x0019211A, 0x0019211A, 0x0019211A, 0x0019211A, 0x0019211A, 0x0019211A, 0x0019211A, 0x0019211A, 0x00182019, 0x0019211A, 0x0019211A, 0x0019211A, 0x0019211A,
        0x0019211A, 0x0019211A, 0x0019211A, 0x0019231D, 0x0019231D, 0x0018221C, 0x0017211B, 0x0017211B, 0x0017211B, 0x0018221C, 0x0019231D, 0x001A211A, 0x00131B14, 0x001C271F, 0x002C3931, 0x00293A31, 0x0023362D, 0x00243930, 0x00243C32, 0x0024372E,
        0x0025382F, 0x00263930, 0x00273A31, 0x00293C33, 0x002C3F36, 0x002F4239, 0x0031443B, 0x002C4139, 0x002B3D36, 0x002C3C35, 0x002E3A34, 0x002A312C, 0x00212520, 0x001B1C18, 0x001C1B17, 0x00241F1C, 0x00241F1C, 0x00231E1B, 0x00211C19, 0x00201B18,
        0x001E1916, 0x001D1815, 0x001C1714, 0x001B1911, 0x001B1911, 0x001C1A12, 0x001C1A12, 0x001C1A12, 0x001C1A12, 0x001B1911, 0x001B1911, 0x001B1911, 0x001A1810, 0x001B1911, 0x001B1911, 0x001C1A12, 0x001D1B13, 0x001E1C14, 0x001F1D15, 0x00201E16,
        0x0026241C, 0x0027251D, 0x0028261E, 0x0024251C, 0x001C1D14, 0x0014150C, 0x0012130A, 0x0011120E, 0x00181915, 0x001D1D17, 0x001D1D17, 0x0021211B, 0x001A1B12, 0x0023241B, 0x0014120A, 0x000B0F04, 0x00181B12, 0x00060703, 0x0080817F,
  0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFCFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x0008100F, 0x00040E08, 0x000E140F, 0x00181915, 0x001A1915, 0x001D1C18, 0x00262723, 0x002D312B, 0x00222922, 0x00202B21, 0x00212C22, 0x00232E24, 0x00242F25, 0x00253026,
        0x00253026, 0x00263127, 0x00263127, 0x0039342B, 0x0039342B, 0x0038332A, 0x0038332A, 0x0038332A, 0x0039342B, 0x0039342B, 0x003A352C, 0x00373731, 0x00363630, 0x00363630, 0x0035352F, 0x0035352F, 0x00363630, 0x00383832, 0x00393933, 0x0037382F,
        0x0037382F, 0x00383930, 0x003A3B32, 0x003C3D34, 0x003D3E35, 0x003C3D34, 0x003B3C33, 0x003E4138, 0x0035382F, 0x00363930, 0x0044473E, 0x004E5148, 0x004D5047, 0x004A4D44, 0x004B4E45, 0x00444948, 0x00444948, 0x00434847, 0x00424746, 0x00414645,
        0x00424746, 0x00444948, 0x00474C4B, 0x003D463C, 0x003A483D, 0x00394D41, 0x003D574A, 0x00415B4E, 0x00293D31, 0x000B190E, 0x00111A10, 0x002A2E28, 0x00353933, 0x00353C35, 0x00353D36, 0x003D453E, 0x003D443D, 0x003F413B, 0x00494943, 0x0047453B,
        0x0047463C, 0x004A493F, 0x004E4D43, 0x004B4C42, 0x0047483E, 0x003F4338, 0x003D4136, 0x003A3A34, 0x003A3A34, 0x003A3A34, 0x003A3A34, 0x003A3A34, 0x003A3A34, 0x003A3A34, 0x003A3A34, 0x00424640, 0x0041453F, 0x003F433D, 0x003B3F39, 0x00373B35,
        0x00363A34, 0x00383C36, 0x003A3E38, 0x00383832, 0x00383832, 0x00383832, 0x00363630, 0x0034342E, 0x0033332D, 0x0034342E, 0x0035352F, 0x0031352F, 0x002F332D, 0x002E322C, 0x002E322C, 0x002F332D, 0x002F332D, 0x002E322C, 0x002C302A, 0x00262F25,
        0x00262F25, 0x00262F25, 0x00252E24, 0x00252E24, 0x00242D23, 0x00242D23, 0x00242D23, 0x00222B21, 0x00222B21, 0x00232C22, 0x00242D23, 0x00252E24, 0x00262F25, 0x00262F25, 0x00273026, 0x00232C22, 0x00232C22, 0x00232C22, 0x00232C22, 0x00222B21,
        0x00222B21, 0x00222B21, 0x00222B21, 0x001D251E, 0x001D251E, 0x001E261F, 0x001F2720, 0x00202821, 0x00202821, 0x00212922, 0x00212922, 0x00332922, 0x00322821, 0x00312720, 0x0030261F, 0x002F251E, 0x0030261F, 0x00312720, 0x00322821, 0x002F2420,
        0x002F2420, 0x002F2420, 0x002F2420, 0x002F2420, 0x002F2420, 0x002F2420, 0x002F2420, 0x002F251E, 0x002F251E, 0x002F251E, 0x002F251E, 0x002F251E, 0x002F251E, 0x002F251E, 0x002F251E, 0x002F2420, 0x002F2420, 0x002F2420, 0x002F2420, 0x00302521,
        0x00302521, 0x00302521, 0x00302521, 0x002F251E, 0x002F251E, 0x0030261F, 0x0030261F, 0x0030261F, 0x00312720, 0x00312720, 0x00312720, 0x0027281F, 0x0027281F, 0x0027281F, 0x0027281F, 0x0027281F, 0x0027281F, 0x0027281F, 0x0027281F, 0x00292621,
        0x00292621, 0x0025251F, 0x0025251F, 0x0023251F, 0x0023251F, 0x00252721, 0x00232721, 0x002E241D, 0x002E241D, 0x002E241D, 0x002E241D, 0x002E241D, 0x002E241D, 0x002E241D, 0x002E241D, 0x002F251E, 0x002F251E, 0x0030261F, 0x0030261F, 0x0030261F,
        0x0030261F, 0x00312720, 0x00312720, 0x00302723, 0x00302723, 0x002F2622, 0x002F2622, 0x002F2622, 0x002F2622, 0x002F2622, 0x002F2622, 0x0022251C, 0x00191C13, 0x001F2219, 0x0030352C, 0x00384036, 0x00353D33, 0x0030392F, 0x002E372D, 0x0031392F,
        0x00323A30, 0x00333B31, 0x00333B31, 0x00343C32, 0x00363E34, 0x00394137, 0x003B4339, 0x00484A44, 0x0042443E, 0x0041413B, 0x0047443F, 0x004C4843, 0x004A443F, 0x00413834, 0x00382F2B, 0x0031312B, 0x0031312B, 0x0030302A, 0x0030302A, 0x002F2F29,
        0x002E2E28, 0x002D2D27, 0x002D2D27, 0x002E2E28, 0x002E2E28, 0x002E2E28, 0x002F2F29, 0x002F2F29, 0x002E2E28, 0x002E2E28, 0x002E2E28, 0x002F3027, 0x002F3027, 0x002F3027, 0x002F3027, 0x002F3027, 0x00303128, 0x00313229, 0x0032332A, 0x00303128,
        0x0034352C, 0x00313229, 0x0033342B, 0x0034352C, 0x00313229, 0x0034352C, 0x0032332A, 0x0031302C, 0x0033322E, 0x002C2B27, 0x0025251F, 0x002D2D27, 0x002A2A24, 0x002E2F26, 0x00191C13, 0x00060C01, 0x00151A11, 0x00020601, 0x00717472,
  0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFCFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x000A1211, 0x000A110C, 0x000F1510, 0x001C201B, 0x00161812, 0x00181A14, 0x001F2219, 0x0023281F, 0x001B2017, 0x0018231B, 0x0018231B, 0x0017221A, 0x0017221A, 0x00162119,
        0x00162119, 0x00162119, 0x00162119, 0x00202118, 0x00212219, 0x00212219, 0x00202118, 0x00202118, 0x001F2017, 0x001D1E15, 0x001D1E15, 0x00151C17, 0x00151C17, 0x00151C17, 0x00151C17, 0x00151C17, 0x00161D18, 0x00161D18, 0x00161D18, 0x00141C15,
        0x00141C15, 0x00151D16, 0x00161E17, 0x00182019, 0x00182019, 0x00151D16, 0x00131B14, 0x00181A14, 0x00151711, 0x001A1C16, 0x00292B25, 0x0031332D, 0x002F312B, 0x002D2F29, 0x0031332D, 0x0030312D, 0x0031322E, 0x0030312D, 0x002F302C, 0x002E2F2B,
        0x002E2F2B, 0x0030312D, 0x0032332F, 0x003A2F2B, 0x003A312D, 0x0037332E, 0x0034312C, 0x00393631, 0x002D2924, 0x00170E0A, 0x001A0F0B, 0x00110C09, 0x00191411, 0x001B1613, 0x0016110E, 0x0017120F, 0x001A1713, 0x00161511, 0x000F100C, 0x0010150C,
        0x0013180F, 0x00151A11, 0x00141910, 0x0011190F, 0x0011190F, 0x000E170D, 0x000B140A, 0x000E160F, 0x000D150E, 0x000D150E, 0x000C140D, 0x000C140D, 0x000B130C, 0x000B130C, 0x000B130C, 0x00120E09, 0x00120E09, 0x00110D08, 0x00100C07, 0x000F0B06,
        0x00100C07, 0x00130F0A, 0x0014100B, 0x000A120B, 0x000A120B, 0x000B130C, 0x000B130C, 0x000A120B, 0x000B130C, 0x000D150E, 0x000E160F, 0x0016110E, 0x0015100D, 0x00130E0B, 0x00130E0B, 0x00140F0C, 0x00140F0C, 0x00120D0A, 0x00110C09, 0x0009120F,
        0x0009120F, 0x0008110E, 0x0008110E, 0x0007100D, 0x0007100D, 0x0007100D, 0x00060F0C, 0x00081009, 0x00081009, 0x00081009, 0x0009110A, 0x0009110A, 0x0009110A, 0x0009110A, 0x0009110A, 0x00081009, 0x00081009, 0x00081009, 0x00081009, 0x00070F08,
        0x00070F08, 0x00070F08, 0x00070F08, 0x00080E09, 0x00080E09, 0x00080E09, 0x00090F0A, 0x00090F0A, 0x00090F0A, 0x000A100B, 0x000A100B, 0x0009160E, 0x0008150D, 0x0008150D, 0x0007140C, 0x0007140C, 0x0007140C, 0x0007140C, 0x0007140C, 0x0005110B,
        0x0005110B, 0x0005110B, 0x0005110B, 0x0005110B, 0x0005110B, 0x0005110B, 0x0005110B, 0x0005120A, 0x0005120A, 0x0005120A, 0x0005120A, 0x0005120A, 0x0005120A, 0x0005120A, 0x0005120A, 0x0004100A, 0x0004100A, 0x0005110B, 0x0005110B, 0x0005110B,
        0x0005110B, 0x0006120C, 0x0006120C, 0x0005120A, 0x0005120A, 0x0005120A, 0x0005120A, 0x0005120A, 0x0006130B, 0x0006130B, 0x0006130B, 0x00081009, 0x00081009, 0x00081009, 0x00081009, 0x00081009, 0x00081009, 0x00081009, 0x00081009, 0x000B0F0A,
        0x00080E09, 0x00080E09, 0x00070D08, 0x00060D08, 0x00070E09, 0x00050F09, 0x0006100A, 0x0005120A, 0x0005120A, 0x0005120A, 0x0005120A, 0x0005120A, 0x0005120A, 0x0005120A, 0x0005120A, 0x00020F07, 0x00020F07, 0x00020F07, 0x00031008, 0x00031008,
        0x00041109, 0x00041109, 0x00041109, 0x00021109, 0x0003120A, 0x0003120A, 0x0003120A, 0x00021109, 0x00011008, 0x00011008, 0x00000F07, 0x000D110B, 0x000D110B, 0x0012140E, 0x001B1D17, 0x00272721, 0x00292621, 0x0023201B, 0x00211E19, 0x0025231B,
        0x0026241C, 0x0027251D, 0x0026241C, 0x0024221A, 0x0024221A, 0x0025231B, 0x0026241C, 0x0026231E, 0x0024211C, 0x00211E19, 0x0023201B, 0x0027241F, 0x0026231E, 0x001B1B15, 0x0011110B, 0x00080F08, 0x00080F08, 0x00080F08, 0x00091009, 0x00091009,
        0x00091009, 0x000A110A, 0x000A110A, 0x000B120D, 0x000C130E, 0x000C130E, 0x000D140F, 0x000D140F, 0x000C130E, 0x000C130E, 0x000B120D, 0x000D140D, 0x000D140D, 0x000C130C, 0x000C130C, 0x000C130C, 0x000C130C, 0x000D140D, 0x000D140D, 0x000A120B,
        0x000C130C, 0x00070E07, 0x000C130C, 0x000F130D, 0x000E120C, 0x00171913, 0x00171913, 0x001B1716, 0x001C1817, 0x00201D19, 0x00191814, 0x0021211B, 0x001C1E18, 0x001F211B, 0x0010130A, 0x0012180D, 0x00141910, 0x00000400, 0x00686B69,
  0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFCFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x000B1312, 0x000B120D, 0x000C120D, 0x0020241F, 0x00161A14, 0x0010150C, 0x00070C03, 0x00090F04, 0x000A1005, 0x0013120E, 0x0012110D, 0x0011100C, 0x00100F0B, 0x0011100C,
        0x0012110D, 0x0014130F, 0x00151410, 0x0008120C, 0x000A140E, 0x000D1711, 0x000F1913, 0x00111B15, 0x00111B15, 0x00101A14, 0x000F1913, 0x00141616, 0x00151717, 0x00161818, 0x00171919, 0x00181A1A, 0x00171919, 0x00161818, 0x00161818, 0x00191C1A,
        0x00181B19, 0x00181B19, 0x00191C1A, 0x001A1D1B, 0x00191C1A, 0x00161917, 0x00131614, 0x00151816, 0x00141715, 0x00131614, 0x00121513, 0x00151816, 0x00181B19, 0x00151816, 0x00111412, 0x00161910, 0x00171A11, 0x00191C13, 0x00191C13, 0x00191C13,
        0x00191C13, 0x001A1D14, 0x001C1F16, 0x001B1D17, 0x00141610, 0x0020221C, 0x001D1F19, 0x00141610, 0x00161812, 0x000F110B, 0x000B0D07, 0x00060D0A, 0x000E1311, 0x001B1E1C, 0x001D201E, 0x00171C1A, 0x00192421, 0x00182925, 0x000D211C, 0x0023221E,
        0x00272622, 0x00262723, 0x0021221E, 0x001E221D, 0x00212520, 0x00232722, 0x001F2520, 0x00242822, 0x00242822, 0x00232721, 0x00222620, 0x0021251F, 0x0020241E, 0x0020241E, 0x001F231D, 0x001C271F, 0x001B261E, 0x001A251D, 0x001A251D, 0x001B261E,
        0x001B261E, 0x001C271F, 0x001C271F, 0x0020241E, 0x0021251F, 0x0021251F, 0x0020241E, 0x001E221C, 0x001D211B, 0x001D211B, 0x001E221C, 0x0017211B, 0x0016201A, 0x00141E18, 0x00141E18, 0x00151F19, 0x00141E18, 0x00131D17, 0x00121C16, 0x001C1718,
        0x001C1718, 0x001C1718, 0x001B1617, 0x001B1617, 0x001A1516, 0x001A1516, 0x001A1516, 0x0018140F, 0x0017130E, 0x0017130E, 0x0016120D, 0x0016120D, 0x0015110C, 0x0015110C, 0x0014100B, 0x0014100B, 0x0014100B, 0x0014100B, 0x0014100B, 0x00130F0A,
        0x00130F0A, 0x00130F0A, 0x00130F0A, 0x00140D0A, 0x00140D0A, 0x00140D0A, 0x00140D0A, 0x00140D0A, 0x00140D0A, 0x00130C09, 0x00130C09, 0x000D0D07, 0x000D0D07, 0x000E0E08, 0x000E0E08, 0x000E0E08, 0x000D0D07, 0x000B0B05, 0x000A0A04, 0x000D0C08,
        0x000D0C08, 0x000D0C08, 0x000D0C08, 0x000D0C08, 0x000D0C08, 0x000D0C08, 0x000D0C08, 0x000D0D07, 0x000D0D07, 0x000D0D07, 0x000D0D07, 0x000D0D07, 0x000D0D07, 0x000D0D07, 0x000D0D07, 0x000B0A06, 0x000B0A06, 0x000C0B07, 0x000C0B07, 0x000C0B07,
        0x000C0B07, 0x000C0B07, 0x000D0C08, 0x000C0C06, 0x000C0C06, 0x000C0C06, 0x000C0C06, 0x000C0C06, 0x000C0C06, 0x000C0C06, 0x000C0C06, 0x000A0E08, 0x000A0E08, 0x000A0E08, 0x000A0E08, 0x000A0E08, 0x000A0E08, 0x000A0E08, 0x000A0E08, 0x000B0C08,
        0x000B0C08, 0x000A0E09, 0x000A0E09, 0x000A0E09, 0x00080E09, 0x00070D08, 0x00070D08, 0x000E0E08, 0x000E0E08, 0x000E0E08, 0x000E0E08, 0x000E0E08, 0x000E0E08, 0x000E0E08, 0x000E0E08, 0x000D0D07, 0x000E0E08, 0x000E0E08, 0x000E0E08, 0x000F0F09,
        0x000F0F09, 0x0010100A, 0x0010100A, 0x000E100A, 0x000E100A, 0x000F110B, 0x000F110B, 0x000E100A, 0x000D0F09, 0x000C0E08, 0x000B0D07, 0x00000600, 0x000E150E, 0x00131711, 0x0011130D, 0x00191611, 0x001B1712, 0x001B1510, 0x001F1612, 0x0018150D,
        0x0019160E, 0x001B1810, 0x001A170F, 0x0019160E, 0x0019160E, 0x001B1810, 0x001C1911, 0x00151711, 0x00191B15, 0x00191D17, 0x00141B14, 0x00121912, 0x00111912, 0x000C170F, 0x0008130B, 0x0013150F, 0x0012140E, 0x0012140E, 0x0011130D, 0x0010120C,
        0x000F110B, 0x000F110B, 0x000E100A, 0x000C0E0E, 0x000C0E0E, 0x000D0F0F, 0x000E1010, 0x000E1010, 0x000D0F0F, 0x000C0E0E, 0x000C0E0E, 0x000D0E0C, 0x000C0D0B, 0x000B0C0A, 0x000B0C0A, 0x000A0B09, 0x000A0B09, 0x000B0C0A, 0x000B0C0A, 0x00060907,
        0x00080B09, 0x00040705, 0x000D0E0C, 0x000E0C0B, 0x00070504, 0x000D0908, 0x000A0605, 0x000C0706, 0x000C0807, 0x0013100C, 0x00080703, 0x000A0A04, 0x000A0C06, 0x00151913, 0x00161B12, 0x00171D12, 0x0013180F, 0x00070B06, 0x00717472,
  0xFFFFFFFF, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFEF9FA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00000503, 0x000F1A17, 0x0016211E, 0x00202926, 0x001B2421, 0x001C2522, 0x00272E2B, 0x0029302D, 0x002F3633, 0x002E362C, 0x002E362C, 0x002F372D, 0x0030382E, 0x00323A30,
        0x00363E34, 0x00394137, 0x003B4339, 0x0044423A, 0x0044423A, 0x0044423A, 0x0043443B, 0x0045463D, 0x00484940, 0x00494C43, 0x004B4E45, 0x004C4F40, 0x004E5142, 0x004F5243, 0x004E5142, 0x004D5041, 0x004C4F40, 0x004C4F40, 0x004C4F40, 0x004B4D41,
        0x00494B3F, 0x0047493D, 0x0045473B, 0x00434539, 0x003F4135, 0x003A3C30, 0x0036382C, 0x002B322B, 0x002A312A, 0x001C231C, 0x000F160F, 0x00121912, 0x001B221B, 0x001D241D, 0x001C231C, 0x001A211A, 0x001C231C, 0x001E251E, 0x001F261F, 0x001E251E,
        0x001E251E, 0x001E251E, 0x001E251E, 0x001C201A, 0x0020241E, 0x0021251F, 0x001C231C, 0x00171E17, 0x00121912, 0x000C140D, 0x00070F08, 0x0017180F, 0x002E2F26, 0x003C3D34, 0x003E3F36, 0x00414239, 0x0043443B, 0x0042433A, 0x0043443B, 0x0044463A,
        0x00434539, 0x00424438, 0x00424438, 0x00424438, 0x00434539, 0x0044463A, 0x0044463A, 0x004B4B3F, 0x0049493D, 0x00454539, 0x00414135, 0x003F3F33, 0x003D3D31, 0x003C3C30, 0x003C3C30, 0x003F3F33, 0x003C3C30, 0x003D3D31, 0x00414135, 0x00424236,
        0x003E3E32, 0x003C3C30, 0x003D3D31, 0x003F3E34, 0x003D3C32, 0x003B3A30, 0x0039382E, 0x0039382E, 0x0037362C, 0x0035342A, 0x00333228, 0x00303022, 0x00313123, 0x00313123, 0x00313123, 0x00313123, 0x00313123, 0x00313123, 0x00313123, 0x002C2D23,
        0x002B2C22, 0x00292A20, 0x00292A20, 0x00292A20, 0x0028291F, 0x0027281E, 0x0025261C, 0x0026251B, 0x00242319, 0x00222117, 0x00212016, 0x00212016, 0x00201F15, 0x001E1D13, 0x001C1B11, 0x001A1A0C, 0x001B1B0D, 0x001D1D0F, 0x001D1D0F, 0x001C1C0E,
        0x001C1C0E, 0x001D1D0F, 0x001E1E10, 0x001C1B11, 0x001B1A10, 0x001A190F, 0x0019180E, 0x0019180E, 0x0019180E, 0x001A190F, 0x001B1A10, 0x0018190F, 0x00191A10, 0x00191A10, 0x001A1B11, 0x001B1C12, 0x001B1C12, 0x001A1B11, 0x001A1B11, 0x001A1B12,
        0x001A1B12, 0x001A1B12, 0x001A1B12, 0x00191A11, 0x00191A11, 0x00191A11, 0x00191A11, 0x00191A10, 0x00191A10, 0x00191A10, 0x00191A10, 0x0018190F, 0x0018190F, 0x0018190F, 0x0018190F, 0x00191A10, 0x00191A10, 0x00191A10, 0x00191A10, 0x0018190F,
        0x0018190F, 0x0018190F, 0x0018190F, 0x0018190F, 0x00191A10, 0x00191A10, 0x00191A10, 0x00191A10, 0x0018190F, 0x0017180E, 0x0017180E, 0x0017150D, 0x0017150D, 0x0017150D, 0x0017150D, 0x0017150D, 0x0017150D, 0x0017150D, 0x0017150D, 0x0016170D,
        0x0018190F, 0x00191A10, 0x00191A10, 0x0018190F, 0x0017180E, 0x0017180E, 0x0018190F, 0x0018190F, 0x0018190F, 0x00191A10, 0x00191A10, 0x00191A10, 0x00191A10, 0x00191A10, 0x001A1B11, 0x001C1D13, 0x001B1C12, 0x001A1B11, 0x001B1C12, 0x001D1E14,
        0x001E1F15, 0x001E1F15, 0x001C1D13, 0x001A1B11, 0x001B1C12, 0x001C1D13, 0x001D1E14, 0x001D1E14, 0x001C1D13, 0x001B1C12, 0x001A1B11, 0x0012170E, 0x00161B12, 0x001A1F16, 0x001B2017, 0x00191E15, 0x00191E15, 0x001B2017, 0x001D2219, 0x00131D17,
        0x0017211B, 0x0018221C, 0x00151F19, 0x00141E18, 0x0016201A, 0x00141E18, 0x000F1913, 0x001B1911, 0x0016140C, 0x0017150D, 0x001F1D15, 0x00201E16, 0x001C1A12, 0x001D1B13, 0x00232119, 0x00252519, 0x00252519, 0x0026261A, 0x0027271B, 0x0028281C,
        0x0028281C, 0x0028281C, 0x0028281C, 0x001D2A1C, 0x001D2A1C, 0x001E2B1D, 0x001E2B1D, 0x001E2B1D, 0x001D2A1C, 0x001C291B, 0x001B281A, 0x00232C22, 0x00252E24, 0x00252E24, 0x00232C22, 0x001F281E, 0x001C251B, 0x001D261C, 0x001F281E, 0x0023271C,
        0x0021251A, 0x001E2217, 0x001C2015, 0x001C2015, 0x001D2116, 0x001C2015, 0x001C2015, 0x001D1F19, 0x001A1C16, 0x00181A14, 0x00191B15, 0x001C1E18, 0x0020221C, 0x0023251F, 0x00242620, 0x00191F1A, 0x00161C17, 0x00060C07, 0xFFBBC1BC,
  0xFFFFFFFF, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFEFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x000B1614, 0x000F100E, 0x001B1C1A, 0x002E2C2B, 0x002B2928, 0x002B2726, 0x0034302F, 0x00363130, 0x00373231, 0x00322E29, 0x00322E29, 0x00302C27, 0x002F2B26, 0x002F2B26,
        0x002F2B26, 0x00302C27, 0x00312D28, 0x002E2E28, 0x002F2F29, 0x0030302A, 0x002F312B, 0x002E302A, 0x002B2F29, 0x002A2E28, 0x00292D27, 0x002C2F26, 0x002D3027, 0x002E3128, 0x002D3027, 0x002A2D24, 0x00282B22, 0x00282B22, 0x00282B22, 0x0022251C,
        0x0022251C, 0x0021241B, 0x0021241B, 0x0020231A, 0x001F2219, 0x001C1F16, 0x001A1D14, 0x00141A15, 0x001A201B, 0x00191F1A, 0x00171D18, 0x00202621, 0x00262C27, 0x00262C27, 0x00252B26, 0x00212722, 0x00222823, 0x00242A25, 0x00232924, 0x00222823,
        0x00202621, 0x001F2520, 0x001F2520, 0x00262A25, 0x00252924, 0x00222621, 0x001D231E, 0x001C221D, 0x001A201B, 0x00111813, 0x00080F0A, 0x000A0C06, 0x0012140E, 0x0011130D, 0x0010120C, 0x00171913, 0x001C1E18, 0x001C1E18, 0x001C1E18, 0x00191C13,
        0x00181B12, 0x00181B12, 0x00171A11, 0x00171A11, 0x00161910, 0x00161910, 0x00171A11, 0x00161910, 0x00161910, 0x0015180F, 0x0014170E, 0x0013160D, 0x0013160D, 0x0014170E, 0x0015180F, 0x00191C13, 0x00171A11, 0x00171A11, 0x00191C13, 0x001A1D14,
        0x00181B12, 0x00161910, 0x0015180F, 0x0013150F, 0x0012140E, 0x0012140E, 0x0012140E, 0x00141610, 0x00141610, 0x00141610, 0x0013150F, 0x00141910, 0x00141910, 0x00141910, 0x00151A11, 0x00161B12, 0x00161B12, 0x00171C13, 0x00171C13, 0x00141B14,
        0x00131A13, 0x00121912, 0x00121912, 0x00141B14, 0x00141B14, 0x00131A13, 0x00121912, 0x00151913, 0x00141812, 0x00131711, 0x00131711, 0x00141812, 0x00141812, 0x00131711, 0x00121610, 0x0013180F, 0x0012170E, 0x0011160D, 0x000F140B, 0x000D1209,
        0x000F140B, 0x0012170E, 0x00151A11, 0x00121610, 0x00121610, 0x0011150F, 0x0011150F, 0x0011150F, 0x0011150F, 0x0011150F, 0x0011150F, 0x00101710, 0x00111811, 0x00111811, 0x00121912, 0x00121912, 0x00121912, 0x00121912, 0x00111811, 0x00111712,
        0x00111712, 0x00111712, 0x00111712, 0x00101611, 0x00101611, 0x00101611, 0x00101611, 0x000F160F, 0x000F160F, 0x000F160F, 0x000F160F, 0x000E150E, 0x000E150E, 0x000E150E, 0x000E150E, 0x000C130C, 0x000C130C, 0x000C130C, 0x000D140D, 0x000D140D,
        0x000E150E, 0x000E150E, 0x000E150E, 0x00101710, 0x00111811, 0x00111811, 0x00111811, 0x00111811, 0x00101710, 0x00101710, 0x000F160F, 0x0010140F, 0x0010140F, 0x0010140F, 0x0010140F, 0x0010140F, 0x0010140F, 0x0010140F, 0x0010140F, 0x000C130C,
        0x000D140D, 0x000E150E, 0x000E150E, 0x000E150E, 0x000D140D, 0x000D140D, 0x000D140D, 0x00101710, 0x00101710, 0x00101710, 0x00101710, 0x00101710, 0x00111811, 0x00111811, 0x00111811, 0x00131A13, 0x00121912, 0x00121912, 0x00121912, 0x00131A13,
        0x00131A13, 0x00131A13, 0x00131A13, 0x00151C15, 0x00161D16, 0x00171E17, 0x00171E17, 0x00171E17, 0x00171E17, 0x00161D16, 0x00151C15, 0x00101611, 0x00181E19, 0x00222823, 0x00282E29, 0x002A302B, 0x00282E29, 0x00262C27, 0x00242A25, 0x002E2A29,
        0x002F2B2A, 0x00302C2B, 0x002F2B2A, 0x002E2A29, 0x002F2B2A, 0x002E2A29, 0x002B2726, 0x001D211C, 0x001E221D, 0x00242823, 0x002C302B, 0x00292D28, 0x001E221D, 0x00141813, 0x00111510, 0x00191C13, 0x00191C13, 0x001A1D14, 0x001B1E15, 0x001B1E15,
        0x001B1E15, 0x001B1E15, 0x001B1E15, 0x00211F17, 0x00211F17, 0x00222018, 0x00222018, 0x00211F17, 0x00201E16, 0x001E1C14, 0x001D1B13, 0x001E1B16, 0x00201D18, 0x00211E19, 0x00201D18, 0x001E1B16, 0x001D1A15, 0x001F1C17, 0x00201D18, 0x001C2118,
        0x001A1F16, 0x00191E15, 0x00191E15, 0x001A1F16, 0x001B2017, 0x001B2017, 0x001A1F16, 0x001B1F19, 0x001B1F19, 0x001C201A, 0x001D211B, 0x001E221C, 0x001F231D, 0x001F231D, 0x001E221C, 0x00161C17, 0x00000200, 0x00666C67, 0xFFF8FEF9,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFDFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x0086918F, 0x00181B19, 0x00060907, 0x00040705, 0x00030402, 0x00000100, 0x00040503, 0x00060403, 0x00050302, 0x00030100, 0x00030100, 0x00030100, 0x00030100, 0x00040201,
        0x00040201, 0x00050302, 0x00050302, 0x00000200, 0x00000301, 0x00020503, 0x00020705, 0x00030806, 0x00030806, 0x00010805, 0x00000704, 0x00050A08, 0x00070C0A, 0x00080D0B, 0x00090E0C, 0x00090E0C, 0x00080D0B, 0x00090E0C, 0x000A0F0D, 0x000B100F,
        0x000C1110, 0x000E1312, 0x00101514, 0x00111615, 0x00131817, 0x00141918, 0x00161B1A, 0x00151A19, 0x001B201F, 0x001D2221, 0x001F2423, 0x00262B2A, 0x00262B2A, 0x00232827, 0x00242928, 0x00262B2A, 0x00282D2C, 0x002A2F2E, 0x00292E2D, 0x00282D2C,
        0x00262B2A, 0x00252A29, 0x00252A29, 0x00262828, 0x00252727, 0x00232525, 0x00202524, 0x00232827, 0x00252A29, 0x00212726, 0x001A201F, 0x001A1F1D, 0x001C211F, 0x001A1F1D, 0x001C211F, 0x00242927, 0x00242927, 0x001D2220, 0x00191E1C, 0x001F2423,
        0x001F2423, 0x001E2322, 0x001E2322, 0x001C2120, 0x001B201F, 0x001A1F1E, 0x00191E1D, 0x00192120, 0x001A2221, 0x00192120, 0x00161E1D, 0x00121A19, 0x000F1716, 0x000F1716, 0x000F1716, 0x00111918, 0x00111918, 0x00101817, 0x000E1615, 0x000F1716,
        0x00101817, 0x000E1615, 0x000B1312, 0x000D1515, 0x000C1414, 0x000C1414, 0x000C1414, 0x000E1616, 0x000F1717, 0x000E1616, 0x000D1515, 0x000C1316, 0x000B1215, 0x000B1215, 0x000B1215, 0x000B1215, 0x000B1215, 0x000B1215, 0x000B1215, 0x00081212,
        0x00071111, 0x00061010, 0x00071111, 0x00081212, 0x00081212, 0x00081212, 0x00061010, 0x000A1212, 0x00091111, 0x00091111, 0x00091111, 0x000B1313, 0x000B1313, 0x000B1313, 0x000A1212, 0x00091013, 0x00091013, 0x00091013, 0x00091013, 0x000A1114,
        0x000D1417, 0x0012191C, 0x00161D20, 0x00081010, 0x00081010, 0x00081010, 0x00081010, 0x00081010, 0x00081010, 0x00070F0F, 0x00070F0F, 0x00061010, 0x00061010, 0x00061010, 0x00071111, 0x00061010, 0x00061010, 0x00050F0F, 0x00050F0F, 0x00040D10,
        0x00040D10, 0x00040D10, 0x00040D10, 0x00040D10, 0x00030C0F, 0x00030C0F, 0x00030C0F, 0x00061010, 0x00061010, 0x00061010, 0x00050F0F, 0x00050F0F, 0x00050F0F, 0x00050F0F, 0x00040E0E, 0x00061010, 0x00061010, 0x00061010, 0x00061010, 0x00061010,
        0x00061010, 0x00061010, 0x00061010, 0x00081212, 0x00091313, 0x00091313, 0x00091313, 0x00091313, 0x00081212, 0x00071111, 0x00071111, 0x00080F12, 0x00080F12, 0x00080F12, 0x00080F12, 0x00080F12, 0x00080F12, 0x00080F12, 0x00080F12, 0x000A1414,
        0x00091313, 0x000A1414, 0x000A1414, 0x000B1515, 0x000B1515, 0x000A1414, 0x00091313, 0x00061010, 0x00061010, 0x00071111, 0x00071111, 0x00071111, 0x00071111, 0x00081212, 0x00081212, 0x00081212, 0x00081212, 0x00091313, 0x00081212, 0x00071111,
        0x00071111, 0x00071111, 0x00081212, 0x00061010, 0x00061010, 0x00061010, 0x00071111, 0x00071111, 0x00061010, 0x00061010, 0x00061010, 0x00060D10, 0x00060D10, 0x00040B0E, 0x0002090C, 0x00000609, 0x00000407, 0x00000306, 0x00000205, 0x00020103,
        0x00010002, 0x00010002, 0x00020103, 0x00020103, 0x00010002, 0x00010002, 0x00020103, 0x00000003, 0x00000104, 0x00000407, 0x0001080B, 0x00030A0D, 0x00030A0D, 0x0002090C, 0x00030A0D, 0x00010908, 0x00020A09, 0x00020A09, 0x00030B0A, 0x00030B0A,
        0x00030B0A, 0x00020A09, 0x00020A09, 0x000B0B0B, 0x000B0B0B, 0x000B0B0B, 0x000B0B0B, 0x000A0A0A, 0x00090909, 0x00070707, 0x00060606, 0x00040201, 0x00050302, 0x00050302, 0x00050302, 0x00050302, 0x00050302, 0x00050302, 0x00060403, 0x00000500,
        0x00000400, 0x00000300, 0x00000300, 0x00000400, 0x00000500, 0x00000400, 0x00000300, 0x00000300, 0x00000300, 0x00000500, 0x00000500, 0x00000600, 0x00000600, 0x00000700, 0x00000700, 0x00181E19, 0xFF5F6560, 0xFFE5EBE6, 0xFFFBFFFC,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF
};

static GUI_CONST_STORAGE GUI_BITMAP _bmJTrace_300x164 = {
  300,                                 // XSize
  164,                                 // YSize
  1200,                                // BytesPerLine
  32,                                  // BitsPerPixel
  (unsigned char *)_acJTrace_300x164,  // Pointer to picture data
  NULL,                                // Pointer to palette
  GUI_DRAW_BMP8888
};

static GUI_CONST_STORAGE unsigned long _acSeggerLogo_300x181[] = {
  0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xAF292929, 0x60292929, 0x20292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x20292929, 0x60292929, 0xAF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
  0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xBF292929, 0x30292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x30292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
  0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x7F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x7F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
  0xFF000000, 0xFF000000, 0xFF000000, 0x60292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x60292929, 0xFF000000, 0xFF000000, 0xFF000000,
  0xFF000000, 0xFF000000, 0x8F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x8F292929, 0xFF000000, 0xFF000000,
  0xFF000000, 0xCF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xCF292929, 0xFF000000,
  0xFF000000, 0x40292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00363636, 0x00797979, 0x00A1A1A1, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA,
        0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA,
        0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA,
        0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA,
        0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA,
        0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA,
        0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA,
        0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA,
        0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA,
        0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA,
        0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA,
        0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA,
        0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA,
        0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA,
        0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00A1A1A1, 0x00797979, 0x00363636, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x40292929, 0xFF000000,
  0xCF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x005F5F5F, 0x00F2F2F2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2F2F2, 0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xCF292929,
  0x70292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x005F5F5F, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x70292929,
  0x30292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00E4E4E4, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00E4E4E4, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x30292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x006C6C6C, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x006C6C6C, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00949494, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00949494, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00BCBCBC, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00BCBCBC, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00DEC4C2, 0x00CBA19E, 0x00CBA19E,
        0x00D8B9B6, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00DEC4C2, 0x00CBA19E, 0x00CBA19E, 0x00DEC4C2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F8F3F3, 0x00B0726E, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x00AA6661, 0x00F8F3F3, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00EBDCDB, 0x00AA6661, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00B0726E, 0x00F8F3F3, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00AA6661, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x00AA6661, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00F8F3F3, 0x00A35B55, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00B77E7A, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00DEC4C2, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x00C49592, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00D1ADAA, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00D1ADAA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00DEC4C2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00B77E7A, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00EBDCDB, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x009D4F49, 0x00F2E8E7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00B77E7A, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x009D4F49, 0x00F8F3F3, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00DEC4C2, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00AA6661, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00D1ADAA, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00B0726E, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00B0726E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00C49592, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00F8F3F3, 0x00A35B55, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00CBA19E, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2E8E7, 0x009D4F49, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00DEC4C2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00EBDCDB, 0x009D4F49, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00DEC4C2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00DEC4C2, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x009D4F49, 0x00F2E8E7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00D8B9B6, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x009D4F49, 0x00F2E8E7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00C49592, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00AA6661, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00BD8A86, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00AA6661, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00AA6661, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00C49592, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F8F3F3, 0x00AA6661, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00BD8A86, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2E8E7, 0x009D4F49,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00DEC4C2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2E8E7, 0x009D4F49, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00D8B9B6, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00DEC4C2,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x009D4F49, 0x00F2E8E7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00DEC4C2, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x009D4F49, 0x00EBDCDB, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00C49592, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00AA6661, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00C49592, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00AA6661, 0x00F8F3F3,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00AA6661, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00C49592, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00B0726E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00B77E7A,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00F2E8E7, 0x009D4F49, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00DEC4C2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F8F3F3, 0x009D4F49, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x00D1ADAA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00DEC4C2, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x009D4F49, 0x00F2E8E7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00E5D0CF, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x00EBDCDB, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00C49592, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00AA6661, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00D1ADAA, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x009D4F49, 0x00F8F3F3, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00AA6661, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00C49592, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00B77E7A, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x00B0726E, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2E8E7, 0x009D4F49, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00DEC4C2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F8F3F3, 0x00A35B55, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x00CBA19E, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00DEC4C2, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x009D4F49, 0x00F2E8E7, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00EBDCDB, 0x009D4F49, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00DEC4C2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00C49592, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00AA6661, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00D8B9B6, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x009D4F49, 0x00F2E8E7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00AA6661, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00C49592, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00BD8A86, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00AA6661, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2E8E7, 0x009D4F49, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00DEC4C2,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F8F3F3, 0x00AA6661, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00BD8A86, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00DEC4C2, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x009D4F49,
        0x00F2E8E7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2E8E7, 0x009D4F49, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00D8B9B6, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00C49592, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x00AA6661, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00DEC4C2, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x009D4F49, 0x00EBDCDB, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00AA6661, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x00C49592, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00C49592, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00AA6661, 0x00F8F3F3, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2E8E7, 0x009D4F49, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x00DEC4C2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00B0726E, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00B77E7A, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F8F3F3, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00DEC4C2, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x009D4F49, 0x00F2E8E7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F8F3F3, 0x009D4F49,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00D1ADAA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x00EBDCDB, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00C49592, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x00AA6661, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00E5D0CF,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00E5D0CF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x00A35B55, 0x00F8F3F3, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00AA6661, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00C49592, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00D1ADAA, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x009D4F49, 0x00F8F3F3, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x00B77E7A, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2E8E7, 0x009D4F49, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00DEC4C2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00B77E7A, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00B0726E, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x00D1ADAA, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00DEC4C2, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x009D4F49, 0x00F2E8E7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00F8F3F3, 0x00AA6661, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00C49592, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x00EBDCDB, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00C49592, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00AA6661, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00EBDCDB, 0x009D4F49, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00DEC4C2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x00A35B55, 0x00F8F3F3,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00AA6661, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00C49592, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00D8B9B6, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x009D4F49, 0x00F2E8E7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00B77E7A,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2E8E7, 0x009D4F49, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00DEC4C2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00BD8A86, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00AA6661, 0x00F8F3F3, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x00D1ADAA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00DEC4C2, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x009D4F49, 0x00F2E8E7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00AA6661, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00BD8A86, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x00EBDCDB, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00C49592, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00AA6661, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2E8E7, 0x009D4F49, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00D8B9B6, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x00A35B55, 0x00F8F3F3, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00AA6661,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00C49592, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00DEC4C2, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x009D4F49, 0x00EBDCDB, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x00B77E7A, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2E8E7,
        0x009D4F49, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00DEC4C2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00A35B55, 0x00F8F3F3,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x00D1ADAA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00DEC4C2, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x009D4F49, 0x00F2E8E7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00B0726E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00A35B55, 0x00B0726E, 0x00DEC4C2,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00EBDCDB, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00C49592, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00AA6661, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F8F3F3, 0x009D4F49, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x00C49592, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00A35B55, 0x00F8F3F3, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00AA6661, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00C49592, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00EBDCDB, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x00EBDCDB, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00B77E7A, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00F2E8E7, 0x009D4F49, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00DEC4C2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00D1ADAA, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x00CBA19E, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00CBA19E, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00DEC4C2, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x009D4F49, 0x00F2E8E7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00B77E7A, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x00B77E7A, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00E5D0CF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00C49592, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00AA6661, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F8F3F3, 0x00AA6661, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x00CBA19E, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x009D4F49, 0x00F8F3F3, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00AA6661, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00C49592, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00EBDCDB, 0x009D4F49, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x00E5D0CF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00B0726E, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2E8E7, 0x009D4F49, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00DEC4C2, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x00B0726E, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00CBA19E, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00DEC4C2, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x009D4F49, 0x00F2E8E7, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00D1ADAA, 0x00A35B55, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x009D4F49, 0x00C49592,
        0x00F8F3F3, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00E5D0CF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00C49592, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00AA6661, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00EBDCDB, 0x00EBDCDB, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x009D4F49, 0x00F8F3F3, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00AA6661, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00C49592,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00B0726E, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2E8E7, 0x009D4F49, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x00DEC4C2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00CBA19E, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00DEC4C2, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x00A35B55, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00E5D0CF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00C49592, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00EBDCDB, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00C49592, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00D1ADAA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00DEC4C2, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x00AA6661, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00B77E7A, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2E8E7, 0x009D4F49, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x00DEC4C2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00A35B55, 0x00F8F3F3, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00AA6661, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00C49592,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00EBDCDB, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00C49592, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00AA6661, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00EBDCDB, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF,
        0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF,
        0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF,
        0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF,
        0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF,
        0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF,
        0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF,
        0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF,
        0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF,
        0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF,
        0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00E5D0CF, 0x00EBDCDB, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00D1ADAA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00DEC4C2, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x009D4F49, 0x00F2E8E7, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00D1ADAA, 0x009D4F49, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00C49592,
        0x00F8F3F3, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00B77E7A, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2E8E7, 0x009D4F49, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00DEC4C2, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x00B0726E, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00A35B55, 0x00F8F3F3, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00AA6661, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00C49592, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00EBDCDB, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x00DEC4C2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00EBDCDB, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00C49592, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00AA6661, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F8F3F3, 0x00A35B55, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x00CBA19E, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00D1ADAA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00DEC4C2, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x009D4F49, 0x00F2E8E7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00B77E7A, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x00B77E7A, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00B77E7A, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00F2E8E7, 0x009D4F49, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00DEC4C2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00D1ADAA, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x00CBA19E, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00A35B55, 0x00F8F3F3, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00AA6661, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00C49592, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00E5D0CF, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x00F2E8E7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00EBDCDB, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00C49592, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00AA6661, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F8F3F3, 0x009D4F49, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x00C49592, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x00D1ADAA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00DEC4C2, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x009D4F49, 0x00F2E8E7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00B0726E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00A35B55,
        0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E,
        0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E,
        0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E,
        0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E,
        0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E,
        0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E,
        0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E,
        0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E,
        0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E,
        0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B0726E, 0x00B77E7A, 0x00DEC4C2,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x00B77E7A, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2E8E7,
        0x009D4F49, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00DEC4C2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00C49592, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00AA6661, 0x00F8F3F3,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x00A35B55, 0x00F8F3F3, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00AA6661,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00C49592, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00DEC4C2, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x009D4F49, 0x00EBDCDB, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x00EBDCDB, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00C49592, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00AA6661, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2E8E7, 0x009D4F49, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00D8B9B6, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x00D1ADAA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00DEC4C2, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x009D4F49, 0x00F2E8E7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F8F3F3, 0x00AA6661, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00BD8A86, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00B77E7A,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2E8E7, 0x009D4F49, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00DEC4C2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00BD8A86, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00AA6661, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x00A35B55, 0x00F8F3F3,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00AA6661, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00C49592, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00D8B9B6, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x009D4F49, 0x00F2E8E7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x00EBDCDB, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00C49592, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00AA6661, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00EBDCDB, 0x009D4F49, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00DEC4C2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x00D1ADAA, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00DEC4C2, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x009D4F49, 0x00F2E8E7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00F8F3F3, 0x00A35B55, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00CBA19E, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x00B77E7A, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2E8E7, 0x009D4F49, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00DEC4C2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00B77E7A, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00B0726E, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x00A35B55, 0x00F8F3F3, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00AA6661, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00C49592, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00D1ADAA, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x009D4F49, 0x00F8F3F3, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x00EBDCDB, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00C49592, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x00AA6661, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00E5D0CF,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00EBDCDB, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2F2F2, 0x00CACACA, 0x00E4E4E4, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00D7D7D7, 0x00E4E4E4,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00E4E4E4, 0x00D7D7D7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00DEC4C2, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x009D4F49, 0x00F2E8E7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F8F3F3, 0x009D4F49,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00D1ADAA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00E4E4E4, 0x00A1A1A1, 0x006C6C6C, 0x00515151, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00444444, 0x006C6C6C, 0x00A1A1A1, 0x00E4E4E4,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2F2F2, 0x00CACACA, 0x00AFAFAF, 0x00949494, 0x00949494, 0x00949494,
        0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00AFAFAF, 0x00CACACA, 0x00F2F2F2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00BCBCBC, 0x00878787, 0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00444444, 0x006C6C6C, 0x00949494, 0x00D7D7D7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00949494, 0x005F5F5F, 0x00363636, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00363636,
        0x005F5F5F, 0x00949494, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00D7D7D7, 0x00CACACA, 0x00A1A1A1, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494,
        0x00CACACA, 0x00D7D7D7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00E4E4E4, 0x00CACACA, 0x00AFAFAF, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494,
        0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00CACACA, 0x00CACACA, 0x00D7D7D7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2E8E7, 0x009D4F49, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x00DEC4C2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00B0726E, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00B77E7A, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00D7D7D7, 0x006C6C6C, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x005F5F5F, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00949494, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00AFAFAF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2F2F2, 0x00949494, 0x00363636, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00444444, 0x00949494, 0x00F2F2F2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2F2F2, 0x00949494, 0x00444444, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00363636, 0x00878787, 0x00E4E4E4, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2F2F2, 0x00515151,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00515151, 0x00E4E4E4, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00797979, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x005F5F5F, 0x00A1A1A1, 0x00F2F2F2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00AA6661, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x00C49592, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00C49592, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00AA6661, 0x00F8F3F3, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00878787, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x006C6C6C, 0x00F2F2F2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00E4E4E4, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00A1A1A1, 0x00363636, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00363636, 0x00AFAFAF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00BCBCBC, 0x00363636, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00363636, 0x00949494, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00797979, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00797979, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00AFAFAF, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00363636, 0x00BCBCBC, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00C49592, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x00AA6661, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00DEC4C2, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x009D4F49, 0x00EBDCDB, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00797979, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00515151, 0x00F2F2F2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00A1A1A1, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2F2F2, 0x006C6C6C, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00797979, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00878787, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00515151, 0x00F2F2F2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00515151, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x005F5F5F, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00797979, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00AFAFAF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00DEC4C2, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x009D4F49,
        0x00F2E8E7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2E8E7, 0x009D4F49, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00D8B9B6, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00AFAFAF, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x006C6C6C, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00949494, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00515151, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2F2F2, 0x00515151, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00797979, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00797979, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00515151, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00A1A1A1, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00D7D7D7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2E8E7, 0x009D4F49, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00DEC4C2,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F8F3F3, 0x00AA6661, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00C49592, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00444444, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x006C6C6C, 0x00BCBCBC, 0x00F2F2F2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00D7D7D7, 0x00A1A1A1, 0x00444444, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00D7D7D7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00949494, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00515151, 0x00797979, 0x00E4E4E4, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x006C6C6C, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00444444, 0x00878787, 0x00AFAFAF, 0x00CACACA, 0x00CACACA,
        0x00AFAFAF, 0x00878787, 0x00363636, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00878787, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00444444, 0x00797979, 0x00A1A1A1, 0x00CACACA, 0x00CACACA, 0x00BCBCBC, 0x00878787, 0x00444444,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00949494, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x005F5F5F, 0x00AFAFAF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00797979, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00AA6661, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00C49592, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00BD8A86, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00AA6661, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00AFAFAF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00797979, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00AFAFAF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00949494, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x005F5F5F,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00A1A1A1, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00444444, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00F2F2F2, 0x00949494, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00797979, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00363636, 0x00AFAFAF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00A1A1A1, 0x00363636, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x005F5F5F, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00949494, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00BCBCBC, 0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00C49592, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00AA6661, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00D8B9B6, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x009D4F49, 0x00F2E8E7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00949494,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00515151, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00797979, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00949494, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x005F5F5F,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2F2F2, 0x00363636, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00515151, 0x00F2F2F2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00363636, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00878787, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00444444, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00515151, 0x00E4E4E4, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00D7D7D7, 0x00363636, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x005F5F5F, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00949494, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00D7D7D7, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00DEC4C2, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x009D4F49, 0x00F2E8E7, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00EBDCDB, 0x009D4F49, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00E5D0CF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00949494,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00878787, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00878787,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00797979, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00949494, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x005F5F5F,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00949494, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00515151, 0x00F2F2F2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00D7D7D7, 0x00363636, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00BCBCBC, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00AFAFAF, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00363636, 0x00E4E4E4, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00D7D7D7, 0x00363636, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00949494, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00949494, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00BCBCBC, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2E8E7, 0x009D4F49, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00DEC4C2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F8F3F3, 0x00A35B55, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x00CBA19E, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00949494,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00363636, 0x00D7D7D7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00E4E4E4, 0x00A1A1A1, 0x00949494, 0x00D7D7D7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00949494, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x005F5F5F,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00444444, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00D7D7D7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00D7D7D7, 0x005F5F5F, 0x00292929, 0x00292929, 0x00363636, 0x00AFAFAF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x006C6C6C, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00AFAFAF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2F2F2, 0x00797979, 0x00292929, 0x00292929, 0x00292929, 0x00878787, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00949494, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00AA6661, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00C49592, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00B77E7A, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x00B0726E, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00AFAFAF,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00363636, 0x00949494, 0x00F2F2F2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00949494, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x005F5F5F,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00D7D7D7, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x006C6C6C, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2F2F2,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00444444, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00949494, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00D7D7D7, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00D7D7D7, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00C49592, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00AA6661, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00D1ADAA, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x00A35B55, 0x00F8F3F3, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00E4E4E4,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x005F5F5F, 0x00949494, 0x00CACACA, 0x00F2F2F2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00949494, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x005F5F5F,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00A1A1A1, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00AFAFAF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00949494, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00949494, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00949494, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00363636, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00DEC4C2, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x009D4F49, 0x00F2E8E7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00E5D0CF, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x00EBDCDB, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00515151, 0x00797979, 0x00A1A1A1, 0x00D7D7D7, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00949494, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00363636, 0x00949494, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00878787, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00F2F2F2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00949494,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00515151, 0x00D7D7D7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00949494, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00949494, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00797979, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00F2E8E7, 0x009D4F49, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00DEC4C2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F8F3F3, 0x009D4F49, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x00D1ADAA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00D7D7D7, 0x00363636, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00363636, 0x006C6C6C,
        0x00A1A1A1, 0x00E4E4E4, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00949494, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00A1A1A1, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00949494,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00F2F2F2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00363636, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x005F5F5F, 0x00949494, 0x00949494, 0x00949494,
        0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x005F5F5F, 0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00363636, 0x00F2F2F2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00AA6661, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00C49592, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00B0726E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00BD8A86,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00D7D7D7, 0x00444444, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x005F5F5F, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00949494, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00949494, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x005F5F5F, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00878787, 0x00363636, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x005F5F5F, 0x00BCBCBC, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00949494,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00949494, 0x00444444, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x005F5F5F, 0x00AFAFAF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00363636, 0x00D7D7D7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00C49592, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00AA6661, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00C49592, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00AA6661, 0x00F8F3F3,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00F2F2F2, 0x00949494, 0x00363636, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00878787, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00949494, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00A1A1A1, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x005F5F5F, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00A1A1A1,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00E4E4E4, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00949494,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00AFAFAF, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00363636, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00363636, 0x00949494, 0x00F2F2F2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00DEC4C2,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x009D4F49, 0x00F2E8E7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00DEC4C2, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x009D4F49, 0x00EBDCDB, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00BCBCBC, 0x00797979, 0x00444444, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00797979, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00949494, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00363636, 0x00878787, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00444444, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x005F5F5F,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00949494,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00949494, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00949494, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00444444, 0x00BCBCBC, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00797979, 0x00F2F2F2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2E8E7, 0x009D4F49,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00DEC4C2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2E8E7, 0x009D4F49, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00D8B9B6, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00D7D7D7, 0x00AFAFAF, 0x00878787, 0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00AFAFAF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00949494, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00515151,
        0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00E4E4E4, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00878787,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00949494,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00D7D7D7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00AFAFAF, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00949494, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00A1A1A1, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00363636, 0x00E4E4E4, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00AA6661, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00C49592, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F8F3F3, 0x00AA6661, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00C49592, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00949494, 0x00515151, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00515151, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00949494, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x005F5F5F,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00949494, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00D7D7D7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2F2F2,
        0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00AFAFAF,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00AFAFAF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00797979, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00949494, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00444444, 0x005F5F5F, 0x005F5F5F, 0x005F5F5F,
        0x005F5F5F, 0x005F5F5F, 0x005F5F5F, 0x005F5F5F, 0x005F5F5F, 0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x006C6C6C, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00C49592, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00AA6661, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00BD8A86, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00AA6661, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00E4E4E4, 0x00949494, 0x00363636, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00949494, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x005F5F5F,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00AFAFAF, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00949494, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00D7D7D7, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00797979, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00D7D7D7,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x006C6C6C, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00E4E4E4, 0x00CACACA,
        0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00CACACA, 0x00949494, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00949494, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00949494, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2F2F2, 0x00A1A1A1, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00F2F2F2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00DEC4C2, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x009D4F49, 0x00F2E8E7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00D8B9B6, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x009D4F49, 0x00F2E8E7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00F2F2F2, 0x00878787, 0x005F5F5F, 0x005F5F5F, 0x00A1A1A1, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00E4E4E4, 0x00515151,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00949494, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x005F5F5F,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00E4E4E4, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00363636, 0x00F2F2F2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00515151, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00363636, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00E4E4E4, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00797979, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00949494, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00949494, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2E8E7, 0x009D4F49, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00DEC4C2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00EBDCDB, 0x009D4F49, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00E5D0CF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00515151, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00515151, 0x00F2F2F2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00E4E4E4,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00949494, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x005F5F5F,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00949494, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00797979, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x006C6C6C, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00E4E4E4, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00949494, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00949494, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00AFAFAF, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00AFAFAF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00B0726E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00C49592, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00F8F3F3, 0x00A35B55, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00CBA19E, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00BCBCBC,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00797979, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2F2F2,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00D7D7D7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00949494, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x005F5F5F,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00AFAFAF, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00AFAFAF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2F2F2, 0x00363636, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00E4E4E4, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00A1A1A1, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00F2F2F2, 0x00515151, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00949494, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00949494, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00949494, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00DEC4C2, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00AA6661, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00D1ADAA, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00B0726E, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00A1A1A1,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00797979, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00A1A1A1,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00363636, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00949494, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x005F5F5F,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00A1A1A1, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00D7D7D7, 0x00444444, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00797979, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00878787, 0x00F2F2F2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00E4E4E4, 0x00515151, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00949494, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00949494, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00949494, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x009D4F49, 0x00F2E8E7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00B77E7A, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00A35B55, 0x00F8F3F3, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00D7D7D7,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x006C6C6C, 0x00E4E4E4, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2F2F2, 0x00949494, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00797979, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00949494, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00444444,
        0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00D7D7D7, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00D7D7D7, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00515151, 0x00AFAFAF, 0x00F2F2F2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00D7D7D7, 0x00797979, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00F2F2F2, 0x00363636, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00444444, 0x00A1A1A1, 0x00E4E4E4, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00E4E4E4,
        0x00949494, 0x00363636, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00949494, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00797979, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494,
        0x00949494, 0x00949494, 0x00AFAFAF, 0x00F2F2F2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00949494, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00878787, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CBA19E, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00DEC4C2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00B77E7A, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00EBDCDB, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00515151, 0x00878787, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x005F5F5F, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00949494, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00AFAFAF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00AFAFAF, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00515151, 0x005F5F5F, 0x005F5F5F,
        0x005F5F5F, 0x00363636, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00444444, 0x005F5F5F, 0x005F5F5F, 0x005F5F5F, 0x00444444, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00949494, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00363636, 0x00E4E4E4, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00949494, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00444444, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00515151, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00DEC4C2, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x0096433D, 0x00C49592, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00D1ADAA, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00D1ADAA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00D7D7D7, 0x00363636, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00878787, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00949494, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00363636, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00AFAFAF, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00AFAFAF, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00949494, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00949494, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00949494, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00AA6661, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x0096433D, 0x00B0726E, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00F8F3F3, 0x00A35B55, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00BD8A86, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00D7D7D7, 0x00444444, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00797979, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00AFAFAF, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00AFAFAF, 0x00363636, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00515151, 0x00AFAFAF, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00D7D7D7, 0x00363636, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00515151, 0x00BCBCBC, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00949494, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x005F5F5F, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00949494, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00949494, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00949494, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F8F3F3, 0x00B0726E, 0x0096433D, 0x0096433D, 0x0096433D,
        0x0096433D, 0x00AA6661, 0x00F8F3F3, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00EBDCDB, 0x00AA6661, 0x0096433D, 0x0096433D, 0x0096433D, 0x0096433D, 0x00B0726E, 0x00F8F3F3, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00F2F2F2, 0x00878787, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00363636, 0x00AFAFAF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2F2F2, 0x00363636, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x005F5F5F, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00E4E4E4, 0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00878787, 0x00FFFFFF, 0x00F2F2F2, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2F2F2, 0x00797979, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x005F5F5F, 0x00F2F2F2, 0x00FFFFFF, 0x00363636, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00949494, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00A1A1A1, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00BCBCBC, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00878787, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00AFAFAF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00D7D7D7, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00E4E4E4, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00E5D0CF, 0x00CBA19E, 0x00CBA19E,
        0x00DEC4C2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00DEC4C2, 0x00CBA19E, 0x00CBA19E, 0x00E5D0CF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00E4E4E4, 0x00949494, 0x00444444, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00444444, 0x00949494, 0x00F2F2F2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00D7D7D7, 0x006C6C6C, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00363636, 0x00797979, 0x00F2F2F2, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00797979, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x005F5F5F, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00E4E4E4, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00E4E4E4, 0x00797979, 0x00363636, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00444444, 0x00BCBCBC, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00949494, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00949494,
        0x00444444, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00444444, 0x00A1A1A1, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2F2F2, 0x00515151, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x005F5F5F, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00878787, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00AFAFAF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00D7D7D7, 0x00A1A1A1, 0x00878787, 0x005F5F5F, 0x005F5F5F, 0x005F5F5F, 0x005F5F5F, 0x005F5F5F, 0x005F5F5F, 0x005F5F5F, 0x00878787, 0x00A1A1A1, 0x00D7D7D7,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2F2F2, 0x00BCBCBC, 0x00949494, 0x006C6C6C, 0x005F5F5F, 0x005F5F5F, 0x005F5F5F, 0x005F5F5F,
        0x005F5F5F, 0x00797979, 0x00A1A1A1, 0x00E4E4E4, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2F2F2, 0x00797979, 0x005F5F5F, 0x005F5F5F, 0x00BCBCBC, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00949494, 0x00797979, 0x005F5F5F, 0x005F5F5F, 0x005F5F5F, 0x005F5F5F, 0x005F5F5F, 0x006C6C6C, 0x00A1A1A1,
        0x00D7D7D7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00949494, 0x005F5F5F, 0x005F5F5F, 0x00AFAFAF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00A1A1A1, 0x00A1A1A1, 0x00D7D7D7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00E4E4E4, 0x00AFAFAF, 0x00949494, 0x00AFAFAF, 0x00E4E4E4, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00CACACA, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CACACA, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00BCBCBC, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00BCBCBC, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00949494, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00949494, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x006C6C6C, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x006C6C6C, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0x30292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00E4E4E4, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00E4E4E4, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x30292929,
  0x70292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00515151, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00515151, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x70292929,
  0xDF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x005F5F5F, 0x00F2F2F2, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF,
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F2F2F2, 0x005F5F5F, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xDF292929,
  0xFF000000, 0x40292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00363636, 0x00797979, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494,
        0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494,
        0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494,
        0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494,
        0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494,
        0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494,
        0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494,
        0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494,
        0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494,
        0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494,
        0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494,
        0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494,
        0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494,
        0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494,
        0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00949494, 0x00797979, 0x00363636, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x40292929, 0xFF000000,
  0xFF000000, 0xDF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xDF292929, 0xFF000000,
  0xFF000000, 0xFF000000, 0x8F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x9F292929, 0xFF000000, 0xFF000000,
  0xFF000000, 0xFF000000, 0xFF000000, 0x60292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x60292929, 0xFF000000, 0xFF000000, 0xFF000000,
  0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x7F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x7F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
  0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xBF292929, 0x40292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x40292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
  0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xBF292929, 0x60292929, 0x20292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x20292929, 0x60292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
  0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
  0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
  0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
  0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
  0xFF000000, 0xFF000000, 0xEF292929, 0xBF292929, 0xEF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xDF292929, 0xBF292929, 0xDF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xDF292929, 0xBF292929, 0xEF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xEF292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xCF292929, 0xBF292929, 0xEF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xCF292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xDF292929,
        0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xBF292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xBF292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xCF292929, 0xAF292929, 0x7F292929, 0x7F292929, 0x7F292929, 0x8F292929, 0xBF292929, 0xEF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xEF292929, 0xBF292929, 0x7F292929, 0x7F292929, 0x7F292929, 0x8F292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xDF292929, 0xAF292929, 0x7F292929, 0x7F292929, 0x7F292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xEF292929, 0xBF292929, 0xDF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xDF292929, 0x9F292929, 0x7F292929, 0x7F292929, 0x7F292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xEF292929, 0xBF292929, 0xDF292929, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xBF292929, 0x8F292929, 0x7F292929, 0x7F292929, 0x7F292929, 0xBF292929, 0xDF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xBF292929, 0xCF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xBF292929, 0xCF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xCF292929, 0x9F292929, 0x7F292929, 0x7F292929, 0x7F292929, 0xAF292929, 0xCF292929, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xDF292929, 0xAF292929, 0x7F292929, 0x7F292929, 0x7F292929, 0x7F292929, 0xBF292929,
        0xEF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xCF292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xEF292929, 0xAF292929,
        0x7F292929, 0x7F292929, 0x8F292929, 0xCF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xBF292929, 0x7F292929, 0x7F292929, 0x7F292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
  0xFF000000, 0x9F292929, 0x10292929, 0x00292929, 0x00292929, 0x9F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xDF292929, 0x20292929, 0x00292929, 0x00292929, 0x00292929, 0x30292929, 0xEF292929, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0x8F292929, 0x00292929, 0x00292929, 0x00292929, 0x9F292929, 0xFF000000, 0xFF000000, 0x70292929, 0x00292929, 0x00292929, 0x10292929, 0xAF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xAF292929,
        0x10292929, 0x00292929, 0x00292929, 0x00292929, 0x60292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x60292929, 0x00292929, 0x00292929, 0x10292929, 0xCF292929, 0xFF000000, 0xFF000000, 0x40292929, 0x00292929,
        0x00292929, 0x20292929, 0xCF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x9F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x9F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xEF292929,
        0x30292929, 0x00292929, 0x00292929, 0x30292929, 0xEF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x8F292929, 0x20292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x50292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xCF292929,
        0x50292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x60292929, 0xDF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xCF292929, 0x40292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x10292929, 0x7F292929, 0xFF000000, 0x9F292929, 0x10292929, 0x00292929, 0x00292929, 0x60292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xCF292929, 0x40292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x10292929, 0x8F292929, 0xFF000000, 0x9F292929, 0x00292929, 0x00292929, 0x00292929, 0x60292929, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xEF292929, 0x7F292929, 0x10292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x40292929, 0xAF292929, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xCF292929, 0x10292929, 0x00292929, 0x00292929, 0x30292929, 0xEF292929, 0xFF000000, 0x8F292929, 0x10292929, 0x00292929, 0x00292929, 0x20292929, 0xCF292929, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x7F292929, 0x20292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x20292929,
        0x9F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x9F292929, 0x20292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x50292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xEF292929, 0x40292929, 0x00292929, 0x00292929, 0x10292929, 0xCF292929, 0xEF292929, 0x70292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x20292929, 0xBF292929, 0xFF000000, 0xFF000000, 0x7F292929, 0x10292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x10292929, 0x7F292929, 0xFF000000, 0xFF000000,
  0xFF000000, 0x10292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xDF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x60292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x7F292929, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xDF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x20292929, 0xFF000000, 0xCF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x20292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x20292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xAF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x9F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x50292929, 0xFF000000, 0x9F292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x50292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xEF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xDF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x70292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x8F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xEF292929, 0x30292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x60292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x8F292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x9F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x9F292929,
        0x10292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x60292929, 0x10292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xCF292929, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0x9F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x60292929, 0x10292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xCF292929,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xCF292929, 0x10292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x50292929, 0xEF292929,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x50292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xAF292929, 0x70292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x50292929, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xDF292929, 0x30292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x30292929, 0xDF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xCF292929, 0x30292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x60292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x9F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x50292929, 0x30292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x9F292929, 0x60292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x60292929, 0xFF000000,
  0xFF000000, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x8F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x10292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x30292929, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0x8F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x10292929, 0xFF000000, 0xBF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xCF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xDF292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x70292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x60292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x40292929, 0xFF000000, 0x7F292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x9F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x9F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x20292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x7F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x40292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x9F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x8F292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x9F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xCF292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xBF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xCF292929, 0x10292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x30292929,
        0xEF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x40292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x40292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x40292929, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xEF292929, 0x20292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x20292929, 0xEF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xCF292929, 0x10292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x40292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x7F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x9F292929,
  0xFF000000, 0x20292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x50292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xDF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xEF292929, 0xFF000000, 0xFF000000,
        0xFF000000, 0x50292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x50292929, 0xFF000000, 0xDF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x8F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0x9F292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x30292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x20292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x7F292929, 0xFF000000, 0xAF292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0x70292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x60292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xDF292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xAF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xAF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x10292929, 0x60292929, 0x7F292929, 0x60292929, 0x20292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x7F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xCF292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x20292929, 0x20292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x20292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000,
        0xEF292929, 0x20292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x30292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x10292929, 0x30292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x70292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x40292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x60292929, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x50292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x10292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x7F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x30292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x10292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x7F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x7F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x20292929,
  0xFF000000, 0x60292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x10292929, 0xFF000000, 0xFF000000, 0xFF000000, 0x9F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929, 0xFF000000, 0xFF000000,
        0xFF000000, 0x10292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x9F292929, 0xFF000000, 0xFF000000, 0x30292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x40292929, 0xFF000000, 0xFF000000, 0xFF000000, 0x70292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xEF292929, 0xFF000000, 0xFF000000, 0xDF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xCF292929, 0xFF000000, 0xFF000000, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x7F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0x40292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x20292929, 0xFF000000, 0xFF000000, 0xFF000000, 0x9F292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x10292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x70292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x10292929, 0xEF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x8F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x9F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x50292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x50292929, 0xDF292929, 0xFF000000, 0xFF000000, 0xDF292929, 0x60292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x40292929, 0xFF000000, 0xFF000000, 0xFF000000, 0x9F292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x7F292929, 0xDF292929, 0xFF000000, 0xFF000000, 0x9F292929, 0x10292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000,
        0x9F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x7F292929, 0xEF292929, 0xFF000000, 0xEF292929, 0x9F292929, 0x10292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929,
        0xFF000000, 0xFF000000, 0xFF000000, 0x9F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x20292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0x8F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0xDF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0x40292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x30292929, 0x60292929, 0xEF292929, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xBF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x8F292929, 0xEF292929, 0xFF000000, 0xEF292929, 0x7F292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x40292929, 0xFF000000, 0xFF000000, 0xFF000000, 0x8F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x7F292929, 0xEF292929, 0xFF000000, 0xFF000000, 0xDF292929, 0x50292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xDF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0x7F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x7F292929, 0xDF292929, 0xFF000000,
        0xAF292929, 0x30292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x30292929, 0xBF292929, 0xFF000000, 0xEF292929, 0x7F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0xFF000000, 0xAF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xCF292929, 0xFF000000, 0xFF000000, 0x70292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x7F292929, 0xFF000000, 0xFF000000,
        0xCF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xEF292929, 0xFF000000, 0xFF000000, 0x7F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xFF000000, 0xFF000000, 0xFF000000, 0x30292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xAF292929, 0xFF000000, 0xFF000000, 0x9F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x20292929, 0xFF000000, 0xFF000000, 0xFF000000, 0x50292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x40292929, 0xFF000000, 0xFF000000, 0xFF000000, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xEF292929, 0xFF000000, 0xFF000000, 0x60292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x60292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x40292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x10292929, 0xEF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xDF292929, 0x70292929, 0x40292929, 0x9F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xDF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x30292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x40292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xDF292929, 0xFF000000, 0xFF000000, 0x50292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x7F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xCF292929, 0x10292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000,
        0x30292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x8F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xCF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929,
        0xFF000000, 0xFF000000, 0xFF000000, 0x40292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xCF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x8F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x8F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0x40292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x7F292929, 0xEF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x60292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x7F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x9F292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x60292929, 0xFF000000, 0xFF000000, 0xFF000000, 0x20292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x9F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0x40292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x7F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0x7F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x7F292929, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xBF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x10292929, 0xEF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x60292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0xFF000000, 0xFF000000, 0x10292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x8F292929, 0xFF000000, 0xFF000000, 0x30292929, 0x00292929, 0x00292929, 0x00292929, 0x30292929, 0x00292929, 0x00292929, 0x00292929, 0x40292929, 0xFF000000, 0xFF000000,
        0x8F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x30292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xCF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929, 0xFF000000, 0xFF000000, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x30292929, 0x00292929, 0x00292929, 0x00292929, 0x7F292929, 0xFF000000, 0xFF000000, 0x60292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x70292929, 0xFF000000, 0xFF000000, 0xFF000000, 0x9F292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xFF000000, 0xFF000000, 0xBF292929, 0x00292929, 0x00292929, 0x00292929, 0x20292929, 0x10292929, 0x00292929, 0x00292929, 0x00292929, 0xAF292929, 0xFF000000, 0xFF000000, 0x20292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x9F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x60292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x10292929, 0x60292929, 0x9F292929, 0xCF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xAF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x9F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x9F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x9F292929, 0xFF000000, 0xFF000000, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x10292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x70292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x20292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x60292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929,
        0xFF000000, 0xFF000000, 0xFF000000, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x40292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xEF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x40292929, 0xFF000000, 0xFF000000, 0xFF000000, 0x40292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x8F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x20292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xEF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xAF292929,
        0x30292929, 0x10292929, 0x60292929, 0xEF292929, 0xFF000000, 0xFF000000, 0xDF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x30292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xDF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x40292929, 0xFF000000, 0xFF000000, 0xFF000000, 0x7F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xEF292929, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x70292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x7F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0xFF000000, 0xFF000000, 0x50292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x50292929, 0xFF000000, 0xFF000000, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x9F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xFF000000, 0xFF000000,
        0x50292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x8F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x20292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x7F292929, 0xFF000000, 0xBF292929, 0x00292929, 0x00292929,
        0x00292929, 0x30292929, 0x7F292929, 0x00292929, 0x00292929, 0x00292929, 0x40292929, 0xFF000000, 0xFF000000, 0x10292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xAF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xDF292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xAF292929, 0xFF000000, 0x8F292929, 0x00292929, 0x00292929, 0x00292929, 0x60292929, 0x50292929, 0x00292929, 0x00292929, 0x00292929, 0x70292929, 0xFF000000, 0xDF292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0xEF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x9F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x40292929, 0x7F292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x7F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x30292929, 0x40292929, 0x40292929, 0x40292929, 0x40292929, 0x40292929, 0x40292929, 0x30292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x7F292929, 0xFF000000, 0xDF292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x60292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xBF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xCF292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x70292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xAF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929,
        0xFF000000, 0xFF000000, 0xCF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x20292929, 0x40292929, 0x40292929, 0x40292929, 0x40292929, 0x40292929, 0x40292929, 0x40292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x40292929, 0xFF000000, 0xFF000000, 0xFF000000, 0x40292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x30292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xBF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x7F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0x30292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xFF000000, 0xFF000000, 0xFF000000, 0x7F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x7F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x7F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0xFF000000, 0xFF000000, 0x9F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x10292929, 0xFF000000, 0xBF292929, 0x00292929, 0x00292929, 0x00292929, 0x30292929, 0xEF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xCF292929, 0xFF000000,
        0x10292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xDF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x70292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x40292929, 0xFF000000, 0x8F292929, 0x00292929, 0x00292929,
        0x00292929, 0x60292929, 0xBF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xFF000000, 0xCF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x10292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x30292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x70292929, 0xFF000000, 0x50292929, 0x00292929, 0x00292929, 0x00292929, 0x9F292929, 0x8F292929, 0x00292929, 0x00292929, 0x00292929, 0x40292929, 0xFF000000, 0x9F292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x50292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x30292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x20292929, 0x7F292929, 0xEF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0x7F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x7F292929, 0xFF000000, 0xBF292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x7F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xEF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xBF292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x7F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xBF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929,
        0xFF000000, 0xFF000000, 0xBF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x40292929, 0xFF000000, 0xFF000000, 0xFF000000, 0x40292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x40292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xDF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x40292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x7F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0x40292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xFF000000, 0xFF000000, 0xFF000000, 0x7F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x7F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x7F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0xFF000000, 0xFF000000, 0xEF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xCF292929, 0x7F292929, 0x00292929, 0x00292929, 0x00292929, 0x70292929, 0xFF000000, 0x30292929, 0x00292929, 0x00292929, 0x00292929, 0x8F292929, 0xCF292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x20292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xAF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xFF000000, 0x50292929, 0x00292929, 0x00292929,
        0x00292929, 0x9F292929, 0xFF000000, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929, 0x8F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x60292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x8F292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x30292929, 0xFF000000, 0x20292929, 0x00292929, 0x00292929, 0x00292929, 0xDF292929, 0xCF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xFF000000, 0x60292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x8F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xEF292929, 0x60292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x30292929, 0xEF292929, 0xFF000000, 0xFF000000, 0x7F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x7F292929, 0xFF000000, 0xBF292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x7F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xEF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xBF292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x7F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xBF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929,
        0xFF000000, 0xFF000000, 0xBF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x40292929, 0xFF000000, 0xFF000000, 0xFF000000, 0x40292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x40292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xBF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x40292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x7F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0x50292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xFF000000, 0xFF000000, 0xFF000000, 0x7F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x7F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x7F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0xFF000000, 0xFF000000, 0xFF000000, 0x40292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x7F292929, 0x50292929, 0x00292929, 0x00292929, 0x00292929, 0xAF292929, 0xFF000000, 0x70292929, 0x00292929, 0x00292929, 0x00292929, 0x50292929, 0x7F292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x70292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x10292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929, 0x20292929, 0x00292929, 0x00292929,
        0x00292929, 0xDF292929, 0xFF000000, 0x40292929, 0x00292929, 0x00292929, 0x00292929, 0x8F292929, 0x50292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x9F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xCF292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xDF292929, 0x00292929, 0x00292929, 0x00292929, 0x10292929, 0xFF000000, 0xFF000000, 0x10292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929, 0x20292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0xDF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xDF292929, 0x70292929,
        0x20292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x60292929, 0xFF000000, 0xFF000000, 0x7F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x30292929, 0x40292929, 0x40292929, 0x40292929, 0x40292929, 0x40292929, 0x40292929, 0x40292929, 0x40292929, 0x40292929, 0x40292929, 0x40292929, 0x60292929, 0xEF292929, 0xFF000000, 0xCF292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x70292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xBF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xBF292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x7F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xBF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929,
        0xFF000000, 0xFF000000, 0xBF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x20292929, 0x40292929, 0x40292929, 0x40292929, 0x40292929, 0x40292929, 0x40292929, 0x40292929, 0x40292929, 0x40292929, 0x40292929, 0x40292929,
        0x40292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0x40292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x40292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xEF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x40292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x8F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0x40292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xFF000000, 0xFF000000, 0xFF000000, 0x7F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x7F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x7F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0xFF000000, 0xFF000000, 0xFF000000, 0x8F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x40292929, 0x20292929, 0x00292929, 0x00292929, 0x00292929, 0xDF292929, 0xFF000000, 0xAF292929, 0x00292929, 0x00292929, 0x00292929, 0x20292929, 0x40292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xCF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x60292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x50292929, 0x00292929, 0x00292929, 0x00292929,
        0x20292929, 0xFF000000, 0xFF000000, 0x7F292929, 0x00292929, 0x00292929, 0x00292929, 0x50292929, 0x10292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xEF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0x20292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x60292929, 0x00292929, 0x00292929, 0x00292929, 0x50292929, 0xFF000000, 0xFF000000, 0x50292929, 0x00292929, 0x00292929, 0x00292929, 0x60292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x30292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xCF292929, 0x9F292929, 0x60292929, 0x30292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xEF292929, 0xFF000000, 0x7F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x30292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x8F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xEF292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x30292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x70292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929,
        0xFF000000, 0xFF000000, 0xDF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x60292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x40292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x40292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x20292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xEF292929,
        0x8F292929, 0x7F292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xBF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x7F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0x20292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x10292929, 0xFF000000, 0xFF000000, 0xFF000000, 0x7F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x7F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x7F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0xFF000000, 0xFF000000, 0xFF000000, 0xDF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x20292929, 0xFF000000, 0xFF000000, 0xFF000000, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x10292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x9F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x50292929, 0xFF000000, 0xFF000000, 0xBF292929, 0x00292929, 0x00292929, 0x00292929, 0x10292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x50292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0x70292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x8F292929, 0xFF000000, 0xFF000000, 0x8F292929, 0x00292929, 0x00292929, 0x00292929, 0x10292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x7F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x9F292929, 0x50292929, 0x70292929, 0xDF292929,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xEF292929, 0x7F292929, 0x10292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929, 0xFF000000, 0xBF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x70292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xAF292929, 0x9F292929, 0xDF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x30292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xEF292929, 0x20292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000,
        0x20292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xEF292929, 0x10292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929,
        0xFF000000, 0xFF000000, 0xFF000000, 0x10292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x20292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xCF292929, 0x7F292929, 0xCF292929,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x40292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x40292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x30292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xEF292929, 0x30292929,
        0x00292929, 0x00292929, 0x00292929, 0xAF292929, 0xFF000000, 0xFF000000, 0xEF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x20292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xBF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x40292929, 0xFF000000, 0xFF000000, 0xFF000000, 0x7F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x7F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x7F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x30292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x60292929, 0xFF000000, 0xFF000000, 0xFF000000, 0x40292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x60292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xEF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x8F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x8F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xBF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xCF292929, 0xFF000000, 0xFF000000, 0xCF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0xCF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x7F292929, 0x10292929, 0x00292929, 0x30292929, 0xAF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x8F292929, 0x00292929, 0x00292929, 0x00292929, 0x10292929,
        0x9F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x70292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xCF292929, 0xFF000000, 0xFF000000, 0x10292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x10292929, 0xCF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xCF292929, 0x30292929, 0x00292929, 0x00292929, 0x10292929, 0xDF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0x7F292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x10292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xEF292929, 0x50292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000,
        0x70292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x10292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xDF292929, 0x30292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929,
        0xFF000000, 0xFF000000, 0xFF000000, 0x60292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x8F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xEF292929, 0x60292929, 0x00292929, 0x00292929, 0x00292929,
        0x8F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x40292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x40292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x7F292929, 0x10292929, 0x00292929,
        0x30292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x70292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x30292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x30292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x40292929, 0xFF000000, 0xFF000000, 0xFF000000, 0x40292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x60292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xEF292929,
        0x30292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x8F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0x7F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x7F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x7F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x70292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x9F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0x7F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0xAF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x50292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0xCF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0x40292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xDF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0x10292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x10292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x20292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x70292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xCF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0x40292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x8F292929, 0xEF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xDF292929, 0x20292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xFF000000, 0xFF000000, 0xFF000000, 0x7F292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x10292929, 0x9F292929, 0xDF292929, 0xFF000000, 0xDF292929, 0x7F292929, 0x10292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x8F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xEF292929, 0x10292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x20292929, 0x40292929, 0x40292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000,
        0xDF292929, 0x10292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x30292929, 0x40292929, 0x40292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929,
        0xFF000000, 0xFF000000, 0xFF000000, 0xBF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x70292929, 0xCF292929, 0xFF000000, 0xEF292929, 0x9F292929, 0x30292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x40292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x40292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x40292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x70292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0xDF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xDF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x30292929, 0x9F292929, 0xBF292929, 0xAF292929, 0x30292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x50292929, 0xFF000000, 0xFF000000, 0xFF000000, 0x9F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x50292929, 0xBF292929, 0xFF000000, 0xDF292929, 0x9F292929, 0x20292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x10292929, 0xEF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0x7F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x7F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x7F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xCF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xCF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xBF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x8F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x10292929,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x7F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x30292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0x60292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x40292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x50292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x70292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x10292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x7F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0x60292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x40292929, 0x40292929, 0x20292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x60292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xEF292929, 0x10292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xCF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x9F292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0x8F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x70292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x70292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x40292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x40292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x10292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x7F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x70292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x40292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x9F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x7F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x7F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x7F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x20292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x10292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x50292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xDF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x40292929,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xBF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x8F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xAF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x7F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x8F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0xAF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x10292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x7F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xDF292929, 0x10292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x10292929, 0xDF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xCF292929, 0x10292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x60292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x7F292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x30292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0x60292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x10292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xEF292929, 0x30292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x30292929,
        0xEF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x40292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x40292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x10292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x7F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xEF292929, 0x30292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x7F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xEF292929, 0x30292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x60292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x7F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x7F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x8F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
  0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x7F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x60292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x60292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0xAF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x40292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x9F292929,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x20292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xDF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0x10292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xCF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xDF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x20292929,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x70292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xDF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xCF292929, 0x20292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x30292929, 0xCF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xCF292929, 0x20292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x10292929, 0x8F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xAF292929, 0x20292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x40292929, 0xEF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xAF292929, 0x20292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x40292929, 0xAF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xEF292929, 0x50292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x50292929, 0xEF292929,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x60292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x60292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x70292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0xDF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xEF292929, 0x50292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x10292929, 0x9F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xEF292929, 0x50292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x00292929, 0x00292929, 0x10292929, 0x9F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x9F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x30292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0x30292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xAF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xCF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x10292929,
  0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xEF292929, 0x60292929, 0x10292929, 0x00292929, 0x00292929, 0x50292929, 0xEF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xEF292929, 0x50292929, 0x00292929, 0x00292929,
        0x10292929, 0x70292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xCF292929, 0x50292929, 0x00292929, 0x00292929, 0x10292929, 0x70292929, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xCF292929, 0x30292929, 0x00292929, 0x00292929, 0x20292929, 0x9F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xBF292929, 0x30292929, 0x00292929, 0x00292929, 0x20292929, 0x8F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x9F292929, 0x20292929, 0x00292929, 0x00292929, 0x30292929, 0xCF292929,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x70292929, 0x10292929, 0x00292929, 0x30292929, 0xAF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x9F292929, 0x40292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x10292929, 0x50292929, 0x9F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xEF292929,
        0x8F292929, 0x30292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x30292929, 0x7F292929, 0xDF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xBF292929, 0x7F292929, 0x60292929, 0x40292929, 0x60292929, 0x7F292929, 0xCF292929, 0xFF000000, 0xCF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xAF292929, 0x7F292929, 0x50292929, 0x40292929, 0x60292929, 0x7F292929, 0xCF292929, 0xFF000000, 0xBF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xBF292929, 0x50292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x10292929, 0x60292929, 0xBF292929, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xEF292929, 0x50292929, 0x00292929, 0x00292929, 0x50292929, 0xEF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x7F292929, 0x10292929, 0x00292929,
        0x30292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xBF292929, 0x50292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x20292929, 0x7F292929,
        0xEF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xBF292929, 0x60292929, 0x10292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929,
        0x20292929, 0x7F292929, 0xEF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x70292929, 0x10292929, 0x00292929, 0x30292929, 0xCF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xCF292929, 0x30292929, 0x00292929, 0x10292929, 0x70292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x9F292929, 0x20292929, 0x00292929, 0x30292929, 0xBF292929,
  0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xCF292929, 0xBF292929, 0xBF292929, 0xBF292929, 0xBF292929, 0xDF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xEF292929, 0xBF292929, 0xBF292929, 0xBF292929, 0xBF292929, 0xEF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xDF292929,
        0xBF292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xAF292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xDF292929, 0xBF292929, 0xBF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x9F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xCF292929,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xCF292929, 0xBF292929, 0xBF292929, 0xBF292929, 0xDF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xBF292929, 0xBF292929, 0xBF292929, 0xBF292929, 0xDF292929, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xDF292929, 0xBF292929, 0xBF292929, 0xBF292929, 0xBF292929, 0xEF292929,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
  0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xAF292929, 0x00292929,
        0x00292929, 0x00292929, 0x30292929, 0xCF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x50292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0x9F292929, 0x00292929, 0x00292929, 0x00292929, 0x30292929, 0xCF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x40292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
  0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x40292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x70292929, 0xCF292929, 0xFF000000, 0xFF000000, 0xBF292929, 0x50292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x30292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0x40292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x10292929, 0x7F292929, 0xDF292929, 0xFF000000, 0xFF000000, 0xBF292929, 0x50292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x50292929, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
  0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x40292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x9F292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0x40292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0xBF292929, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
  0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xAF292929, 0x00292929,
        0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x60292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0x8F292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x60292929, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
  0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0x9F292929,
        0x10292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x70292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0x8F292929, 0x10292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x70292929, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
  0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xEF292929, 0x8F292929, 0x40292929, 0x10292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x10292929, 0x40292929, 0x7F292929, 0xDF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xEF292929, 0x8F292929, 0x40292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x00292929, 0x10292929, 0x40292929, 0x8F292929, 0xDF292929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000
};

static GUI_CONST_STORAGE GUI_BITMAP _bmSeggerLogo_300x181 = {
  300,                                     // XSize
  181,                                     // YSize
  1200,                                    // BytesPerLine
  32,                                      // BitsPerPixel
  (unsigned char *)_acSeggerLogo_300x181,  // Pointer to picture data
  NULL,                                    // Pointer to palette
  GUI_DRAW_BMP8888
};

/*********************************************************************
*
*       Types
*
**********************************************************************
*/
typedef struct {
  const GUI_BITMAP GUI_UNI_PTR * pBitmap;
  GUI_MEMDEV_Handle              hMem;
  int                            xSize;
  int                            ySize;
} IMAGE;

/*********************************************************************
*
*       Static data
*
**********************************************************************
*/
static IMAGE _aImage[] = {
  { &_bmSeggerLogo_300x181 },
  { &_bmJTrace_300x164     },
  { &_bmJLink_300x132      },
  { &_bmPlatine_250x200    }
};

static int _NumImages = sizeof(_aImage) / sizeof(_aImage[0]);

/*********************************************************************
*
*       Static code
*
**********************************************************************
*/
/*********************************************************************
*
*       _GetImage
*/
static int _GetImage(IMAGE * pImage) {
  pImage->xSize = pImage->pBitmap->XSize;
  pImage->ySize = pImage->pBitmap->YSize;
  pImage->hMem  = GUI_MEMDEV_CreateFixed(0, 0, pImage->xSize, pImage->ySize, GUI_MEMDEV_NOTRANS, GUI_MEMDEV_APILIST_32, GUI_COLOR_CONV_8888);
  if (pImage->hMem == 0) {
    return 1;
  }
  GUI_MEMDEV_Select(pImage->hMem);
  GUI_SetBkColor(GUI_TRANSPARENT);
  GUI_Clear();
  GUI_DrawBitmap(pImage->pBitmap, 0, 0);
  GUI_MEMDEV_Select(0);
  return 0;
}

/*********************************************************************
*
*       _RotateAndZoomImage
*/
static int _RotateAndZoomImage(void) {
  static GUI_MEMDEV_Handle    hDst = 0;
  static GUI_MEMDEV_Handle    hLCD = 0;
  static int                  Index;
  IMAGE                     * pImage;
  void                     (* pfRotate)(GUI_MEMDEV_Handle hSrc, GUI_MEMDEV_Handle hDst, int dx, int dy, int a, int Mag);
  int                         TimeContinue;
  int                         TimeNow;
  int                         xSize;
  int                         ySize;
  int                         Mag;
  int                         a;
  int                         i;

  pfRotate = GUI_MEMDEV_Rotate;
  pImage   = &_aImage[Index];
  xSize    = LCD_GetXSize();
  ySize    = LCD_GetYSize();
  //
  // Create memory devices if no exist
  //
  if (hLCD == 0) {
    hLCD = GUI_MEMDEV_CreateFixed(0, 0, xSize, ySize, GUI_MEMDEV_NOTRANS, GUI_MEMDEV_APILIST_32, GUI_COLOR_CONV_8888);
    if (hLCD == 0) {
      return 1;
    }
    GUI_MEMDEV_CopyFromLCD(hLCD);
  }
  if (hDst == 0) {
    hDst = GUI_MEMDEV_CreateFixed(0, 0, xSize, ySize, GUI_MEMDEV_NOTRANS, GUI_MEMDEV_APILIST_32, GUI_COLOR_CONV_8888);
    if (hDst == 0) {
      return 1;
    }
  }
  ySize -= TITLE_SIZE;
  //
  // Rotate and enlarge while moving in.
  //
  for (i = 2; (i <= 100); i += 2) {
    TimeContinue = GUI_GetTime() + MIN_TIME_PER_FRAME_ENLARGE;
    GUI_MEMDEV_Select(hDst);
    GUI_MEMDEV_Write(hLCD);
    pfRotate(pImage->hMem, hDst, (xSize - pImage->xSize) / 2 - (xSize * (100 - i)) / 250, TITLE_SIZE + (ySize - pImage->ySize) / 2, (i - 100) * 450, i * 10);
    GUI_MEMDEV_Select(0);
    GUI_MULTIBUF_Begin();
    GUI_MEMDEV_CopyToLCD(hDst);
    GUI_MULTIBUF_End();
    //
    // Delay
    //
    TimeNow = GUI_GetTime();
    if (TimeContinue > TimeNow) {
      GUI_Delay(TimeContinue - TimeNow);
    } else {
      GUI_Exec();
    }
  }
  //
  // Rotate, enlarge and shrink on spot.
  //
  Mag = 1000;
  for (a = 5; a <= 360; a += 5) {
    TimeContinue = GUI_GetTime() + MIN_TIME_PER_FRAME_ENLARGE;
    //
    // Calculate magnification
    //
    if (a <= 180) {
      Mag = (Mag * 1050) / 1000;
    } else {
      Mag = (Mag * 1000) / 1050;
    }
    //
    // Do animation
    //
    GUI_MEMDEV_Select(hDst);
    GUI_MEMDEV_Write(hLCD);
    pfRotate(pImage->hMem, hDst, (xSize - pImage->xSize) / 2, TITLE_SIZE + (ySize - pImage->ySize) / 2, a * 1000, Mag);
    GUI_MEMDEV_Select(0);
    GUI_MULTIBUF_Begin();
    GUI_MEMDEV_CopyToLCD(hDst);
    GUI_MULTIBUF_End();
    //
    // Delay
    //
    TimeNow = GUI_GetTime();
    if (TimeContinue > TimeNow) {
      GUI_Delay(TimeContinue - TimeNow);
    } else {
      GUI_Exec();
    }
  }
  //
  // Rotate complete screen
  //
  GUI_MEMDEV_CopyFromLCD(hLCD);
  for (a = 5; a <= 360; a += 5) {
    TimeContinue = GUI_GetTime() + 30;
    //
    // Calculate magnification
    //
    Mag = (a < 180)
        ? ((180 - a) * 800) / 180 + 200
        : ((a - 180) * 800) / 180 + 200;
    //
    // Do animation
    //
    GUI_MEMDEV_Select(hDst);
    GUI_SetBkColor(0xa56e3a);
    GUI_Clear();
    GUI_MEMDEV_Select(0);
    pfRotate(hLCD, hDst, 0, 0, a * 1000, Mag);
    GUI_MULTIBUF_Begin();
    GUI_MEMDEV_CopyToLCD(hDst);
    GUI_MULTIBUF_End();
    //
    // Delay
    //
    TimeNow = GUI_GetTime();
    if (TimeContinue > TimeNow) {
      GUI_Delay(TimeContinue - TimeNow);
    }
  }
  //
  // Clean up LCD context
  //
  GUI_MEMDEV_Select(hLCD);
  GUI_DrawGradientV(0, 40, xSize - 1, ySize + TITLE_SIZE - 1, GUI_WHITE, GUI_LIGHTBLUE);
  //
  // Rotate and enlarge while moving out.
  //
  for (i = 2; (i <= 100); i += 2) {
    TimeContinue = GUI_GetTime() + MIN_TIME_PER_FRAME_ENLARGE;
    GUI_MEMDEV_Select(hDst);
    GUI_MEMDEV_Write(hLCD);
    pfRotate(pImage->hMem, hDst, (xSize - pImage->xSize) / 2 + (xSize * i) / 250, TITLE_SIZE + (ySize - pImage->ySize) / 2, i * 450, (100 - i) * 10);
    GUI_MEMDEV_Select(0);
    GUI_MULTIBUF_Begin();
    GUI_MEMDEV_CopyToLCD(hDst);
    GUI_MULTIBUF_End();
    //
    // Delay
    //
    TimeNow = GUI_GetTime();
    if (TimeContinue > TimeNow) {
      GUI_Delay(TimeContinue - TimeNow);
    } else {
      GUI_Exec();
    }
  }
  GUI_MEMDEV_CopyToLCD(hLCD);
  Index = (Index + 1) % _NumImages;
  return 0;
}

/*********************************************************************
*
*       _ShiftImage
*/
static int _ShiftImage(void) {
  static GUI_MEMDEV_Handle    hMemHQ[GUI_COUNTOF(_aImage)];
  static GUI_MEMDEV_Handle    hDstEnlarge;
  static GUI_MEMDEV_Handle    hLCDEnlarge;
  static GUI_MEMDEV_Handle    hDstShift;
  static GUI_MEMDEV_Handle    hLCD;
  static int                  Index;
  IMAGE                     * pImage;
  void                     (* pfRotate)(GUI_MEMDEV_Handle hSrc, GUI_MEMDEV_Handle hDst, int dx, int dy, int a, int Mag);
  int                         xSizeImageMag;
  int                         ySizeImageMag;
  int                         TimeContinue;
  int                         DispSpaceX;
  int                         DispSpaceY;
  int                         TimeNow;
  int                         Index0;
  int                         Index1;
  int                         Index2;
  int                         Index3;
  int                         xSize;
  int                         ySize;
  int                         Step;
  int                         Add;
  int                         Mag;
  int                         a;
  int                         i;

  xSize      = LCD_GetXSize();
  ySize      = LCD_GetYSize() - TITLE_SIZE;
  DispSpaceX = xSize / 3;
  DispSpaceY = (ySize * 3) / 5;
  //
  // Create memory devices if not existing
  //
  if (hLCD == 0) {
    hLCD        = GUI_MEMDEV_CreateFixed(0,         TITLE_SIZE + ySize / 5, xSize,           DispSpaceY, GUI_MEMDEV_NOTRANS, GUI_MEMDEV_APILIST_32, GUI_COLOR_CONV_8888);
    if (hLCD == 0) {
      return 1;
    }
    GUI_MEMDEV_CopyFromLCD(hLCD);
  }
  if (hDstShift == 0) {
    hDstShift   = GUI_MEMDEV_CreateFixed(0,         TITLE_SIZE + ySize / 5, xSize,           DispSpaceY, GUI_MEMDEV_NOTRANS, GUI_MEMDEV_APILIST_32, GUI_COLOR_CONV_8888);
    if (hDstShift == 0) {
      return 1;
    }
  }
  if (hDstEnlarge == 0) {
    hDstEnlarge = GUI_MEMDEV_CreateFixed(xSize / 6, TITLE_SIZE,             (xSize * 2) / 3, ySize,      GUI_MEMDEV_NOTRANS, GUI_MEMDEV_APILIST_32, GUI_COLOR_CONV_8888);
    if (hDstEnlarge == 0) {
      return 1;
    }
  }
  if (hLCDEnlarge == 0) {
    hLCDEnlarge = GUI_MEMDEV_CreateFixed(xSize / 6, TITLE_SIZE,             (xSize * 2) / 3, ySize,      GUI_MEMDEV_NOTRANS, GUI_MEMDEV_APILIST_32, GUI_COLOR_CONV_8888);
    if (hLCDEnlarge == 0) {
      return 1;
    }
  }
  GUI_MEMDEV_Select(0);
  for (i = 0; i < _NumImages; i++) {
    if (hMemHQ[i] == 0) {
      pImage        = &_aImage[i];
      xSizeImageMag = pImage->xSize * MAG / 1000;
      ySizeImageMag = pImage->ySize * MAG / 1000;
      hMemHQ[i]     = GUI_MEMDEV_CreateFixed((DispSpaceX - xSizeImageMag) / 2 - BORDER_SIZE, TITLE_SIZE + ySize / 5 + (DispSpaceY - ySizeImageMag) / 2 - BORDER_SIZE, xSizeImageMag + BORDER_SIZE * 2, ySizeImageMag + BORDER_SIZE * 2, GUI_MEMDEV_NOTRANS, GUI_MEMDEV_APILIST_32, GUI_COLOR_CONV_8888);
      GUI_MEMDEV_CopyFromLCD(hMemHQ[i]);
      GUI_MEMDEV_RotateHQ(pImage->hMem, hMemHQ[i], (xSizeImageMag - pImage->xSize) / 2 + BORDER_SIZE, (ySizeImageMag - pImage->ySize) / 2 + BORDER_SIZE, 0, MAG);
    }
  }
  //
  // Get image indices
  //
  Index0 = (Index + 0) % _NumImages;
  Index1 = (Index + 1) % _NumImages;
  Index2 = (Index + 2) % _NumImages;
  Index3 = (Index + 3) % _NumImages;
  //
  // Perform shifting
  //
  pfRotate = GUI_MEMDEV_Rotate;
  for (i = 1; i <= FINAL_STEP; i++) {
    TimeContinue = GUI_GetTime() + MIN_TIME_PER_FRAME_SHIFT;
    Step         = (DispSpaceX * i) / FINAL_STEP;
    //
    // Calculate rotation
    //
    a = (-Step * 360 * 1000) / DispSpaceX;
    //
    // Do animation
    //
    GUI_MEMDEV_Select(hDstShift);
    GUI_MEMDEV_Write(hLCD);
    if (Step == DispSpaceX) {
      pImage        = &_aImage[Index0];
      ySizeImageMag = pImage->ySize * MAG / 1000;
      xSizeImageMag = pImage->xSize * MAG / 1000;
      GUI_MEMDEV_WriteAt(hMemHQ[Index0], (DispSpaceX - xSizeImageMag) / 2            - BORDER_SIZE, TITLE_SIZE + ySize / 5 + (DispSpaceY - ySizeImageMag) / 2 - BORDER_SIZE);
      pImage        = &_aImage[Index1];
      ySizeImageMag = pImage->ySize * MAG / 1000;
      xSizeImageMag = pImage->xSize * MAG / 1000;
      GUI_MEMDEV_WriteAt(hMemHQ[Index1], (DispSpaceX - xSizeImageMag) / 2 + Step     - BORDER_SIZE, TITLE_SIZE + ySize / 5 + (DispSpaceY - ySizeImageMag) / 2 - BORDER_SIZE);
      pImage        = &_aImage[Index2];
      ySizeImageMag = pImage->ySize * MAG / 1000;
      xSizeImageMag = pImage->xSize * MAG / 1000;
      GUI_MEMDEV_WriteAt(hMemHQ[Index2], (DispSpaceX - xSizeImageMag) / 2 + Step * 2 - BORDER_SIZE, TITLE_SIZE + ySize / 5 + (DispSpaceY - ySizeImageMag) / 2 - BORDER_SIZE);
    } else {
      pImage        = &_aImage[Index0];
      pfRotate(pImage->hMem, hDstShift, ((xSize - pImage->xSize) / 2) - (DispSpaceX * 2) + Step, (DispSpaceY - pImage->ySize) / 2, a, MAG);
      pImage        = &_aImage[Index1];
      pfRotate(pImage->hMem, hDstShift, ((xSize - pImage->xSize) / 2) -  DispSpaceX      + Step, (DispSpaceY - pImage->ySize) / 2, a, MAG);
      pImage        = &_aImage[Index2];
      pfRotate(pImage->hMem, hDstShift, ((xSize - pImage->xSize) / 2)                    + Step, (DispSpaceY - pImage->ySize) / 2, a, MAG);
      pImage        = &_aImage[Index3];
      pfRotate(pImage->hMem, hDstShift, ((xSize - pImage->xSize) / 2) +  DispSpaceX      + Step, (DispSpaceY - pImage->ySize) / 2, a, MAG);
    }
    GUI_MEMDEV_CopyToLCD(hDstShift);
    //
    // Delay
    //
    TimeNow = GUI_GetTime();
    if (TimeContinue > TimeNow) {
      GUI_Delay(TimeContinue - TimeNow);
    } else {
      GUI_Exec();
    }
  }
  //
  // Enlarge & shrink
  //
  pImage = &_aImage[Index1];
  GUI_MEMDEV_CopyFromLCD(hLCDEnlarge);
  GUI_MEMDEV_Select(hLCDEnlarge);
  GUI_DrawGradientV(DispSpaceX, TITLE_SIZE, DispSpaceX * 2 - 1, ySize + TITLE_SIZE - 1, GUI_WHITE, GUI_LIGHTBLUE);
  GUI_MEMDEV_Select(hDstEnlarge);
  Add = 1;
  Mag = MAG;
  i   = 1;
  do {
    TimeContinue = GUI_GetTime() + MIN_TIME_PER_FRAME_ENLARGE;
    //
    // Use HQ version only for last step
    //
    if (i == 0) {
      pfRotate = GUI_MEMDEV_RotateHQ;
    } else {
      pfRotate = GUI_MEMDEV_Rotate;
    }
    //
    // Calculate magnification
    //
    if (Add > 0) {
      Mag = (Mag * 1050) / 1000;
    } else {
      Mag = (Mag * 1000) / 1050;
    }
    if (Mag < MAG) {
      Mag = MAG;
    }
    //
    // Do animation
    //
    GUI_MEMDEV_Write(hLCDEnlarge);
    pfRotate(pImage->hMem, hDstEnlarge, (((xSize * 2) / 3) - pImage->xSize) / 2, (ySize - pImage->ySize) / 2, 0, Mag);
    GUI_MEMDEV_CopyToLCD(hDstEnlarge);
    i += Add;
    if (i == 20) {
      Add = -Add;
    }
    //
    // Delay
    //
    TimeNow = GUI_GetTime();
    if (TimeContinue > TimeNow) {
      GUI_Delay(TimeContinue - TimeNow);
    }
  } while (i > 0);
  if (Index == 0) {
    Index = _NumImages - 1;
  } else {
    Index--;
  }
  return 0;
}

/*********************************************************************
*
*       Public code
*
**********************************************************************
*/
void MainTask(void) {
  int FontDistY;
  int xSize;
  int ySize;
  int i;

  GUI_Init();
  //
  // Check if recommended memory for the sample is available
  //
  if (GUI_ALLOC_GetNumFreeBytes() < RECOMMENDED_MEMORY) {
    GUI_ErrorOut("Not enough memory available."); 
    return;
  }
  xSize = LCD_GetXSize();
  ySize = LCD_GetYSize();
  //
  // Get images
  //
  for (i = 0; i < _NumImages; i++) {
    if (_GetImage(&_aImage[i])) {
      return;
    }
  }
  //
  // Set background and headline
  //
  GUI_DrawGradientV(0, 0,          xSize - 1, TITLE_SIZE - 1, GUI_LIGHTBLUE, GUI_WHITE);
  GUI_DrawGradientV(0, TITLE_SIZE, xSize - 1, ySize      - 1, GUI_WHITE,     GUI_LIGHTBLUE);
  GUI_DrawBitmap(&_bmSeggerLogo50, 6, (TITLE_SIZE - _bmSeggerLogo50.YSize) / 2);
  GUI_SetTextMode(GUI_TM_TRANS);
  GUI_SetFont(&GUI_FontRounded22);
  FontDistY = GUI_GetFontDistY();
  GUI_SetColor(GUI_BLACK);
  GUI_DispStringHCenterAt("Zoom and rotate", 62 + (xSize - 62) / 2,  (TITLE_SIZE - FontDistY) / 2);
  while (1) {
    if (_RotateAndZoomImage()) {
      break;
    }
    if (_ShiftImage()) {
      break;
    }
    if (_ShiftImage()) {
      break;
    }
    if (_ShiftImage()) {
      break;
    }
  }
  GUI_SetBkColor(GUI_BLACK);
  GUI_SetColor(GUI_WHITE);
  GUI_Clear();
  GUI_SetFont(&GUI_FontRounded22);
  GUI_DispStringHCenterAt("Error. Application stopped.", xSize / 2, ySize / 2);
  while (1) {
    GUI_Delay(100);
  }
}

/*************************** End of file ****************************/
